
#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 1928
 * transforms:
 *    ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul', 'a@8', 128) => ('ishl', 'a', 7)
 *    ('imul', 'a@16', 32768) => ('ishl', 'a', 15)
 *    ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31)
 *    ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63)
 *    ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b'))
 *    ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b')))
 *    ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b'))
 *    ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b'))
 *    ('udiv', 'a', 1) => a
 *    ('idiv', 'a', 1) => a
 *    ('umod', 'a', 1) => 0
 *    ('imod', 'a', 1) => 0
 *    ('imod', 'a', -1) => 0
 *    ('irem', 'a', 1) => 0
 *    ('irem', 'a', -1) => 0
 *    ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b'))
 *    ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b')))
 *    ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b')))))
 *    ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b'))
 *    ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b')))
 *    ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b'))
 *    ('~fneg', ('fneg', 'a')) => a
 *    ('ineg', ('ineg', 'a')) => a
 *    ('fabs', ('fneg', 'a')) => ('fabs', 'a')
 *    ('fabs', ('u2f', 'a')) => ('u2f', 'a')
 *    ('iabs', ('iabs', 'a')) => ('iabs', 'a')
 *    ('iabs', ('ineg', 'a')) => ('iabs', 'a')
 *    ('f2b', ('fneg', 'a')) => ('f2b', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('~fadd', 'a', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a
 *    ('iadd', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', -1) => -1
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd'))
 *    ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c'))
 *    ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a'))
 *    ('~fmul', 'a', 0.0) => 0.0
 *    ('fmul', 'a@16', 0.0) => 0.0
 *    ('fmul', 'a@32', 0.0) => 0.0
 *    ('fmulz', 'a', 0.0) => 0.0
 *    ('fmulz', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a', 'a') => ('fmul', 'a', 'a')
 *    ('ffmaz', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b')
 *    ('imul', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', -1) => a
 *    ('~fmul', 'a', 1.0) => a
 *    ('~fmulz', 'a', 1.0) => a
 *    ('fmul(is_only_used_as_float)', 'a', 1.0) => a
 *    ('imul', 'a', 1) => a
 *    ('fmul', 'a', -1.0) => ('fneg', 'a')
 *    ('imul', 'a', -1) => ('ineg', 'a')
 *    ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a')
 *    ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a')
 *    ('~ffma', 0.0, 'a', 'b') => b
 *    ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b')
 *    ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffmaz', 'a', 'b', 0.0) => ('fmulz', 'a', 'b')
 *    ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffmaz', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('ffmaz', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~flrp', 'a', 'b', 0.0) => a
 *    ('~flrp', 'a', 'b', 1.0) => b
 *    ('~flrp', 'a', 'a', 'b') => a
 *    ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b')
 *    ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('sdot_4x8_iadd', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd', 'a', 0, 'b') => b
 *    ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd_sat', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 0, 'a', 'b') => b
 *    ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b
 *    ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c')
 *    ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('fmul@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b')
 *    ('fmul@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b')
 *    ('ffma@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('ffma@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a')
 *    ('ftrunc', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('fround_even', 'a') => ('bcsel', ('feq', ('ffract', 'a'), 0.5), ('fadd', ('ffloor', ('fadd', 'a', 0.5)), 1.0), ('ffloor', ('fadd', 'a', 0.5)))
 *    ('ffloor', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('fadd', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('ffract', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a')))
 *    ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e'))
 *    ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y')
 *    ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b'))
 *    ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b'))
 *    ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b'))
 *    ('fsum2', 'a') => ('fadd', 'a.x', 'a.y')
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd'))
 *    ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c'))
 *    ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 7))
 *    ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 15))
 *    ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 31))
 *    ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 63))
 *    ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b'))
 *    ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b'))
 *    ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b'))
 *    ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b'))
 *    ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b')
 *    ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b')
 *    ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1)
 *    ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1)
 *    ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2)
 *    ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2)
 *    ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16)
 *    ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16)
 *    ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16)
 *    ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24)
 *    ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24)
 *    ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd'))
 *    ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd'))
 *    ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b')
 *    ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b')
 *    ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b')
 *    ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b')
 *    ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b')
 *    ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b')
 *    ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b')
 *    ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b')
 *    ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b')
 *    ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False
 *    ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False
 *    ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False
 *    ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False
 *    ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a')
 *    ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a')
 *    ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b')
 *    ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b')
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b')
 *    ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b')
 *    ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b')
 *    ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b')
 *    ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0)
 *    ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0)
 *    ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b'))
 *    ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0)
 *    ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0)
 *    ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0)
 *    ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0)
 *    ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0)
 *    ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0)
 *    ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a')
 *    ('fneu', ('b2f', 'a@1'), 0.0) => a
 *    ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a')
 *    ('ine', ('b2i', 'a@1'), 0) => a
 *    ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('u2f', 'a'), 0.0) => True
 *    ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a')
 *    ('flt', ('u2f', 'a'), 0.0) => False
 *    ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a')
 *    ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0)
 *    ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a')
 *    ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0)
 *    ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a')
 *    ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0)
 *    ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0)
 *    ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0)
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a'))
 *    ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b'))
 *    ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b')))
 *    ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b')))
 *    ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0))
 *    ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b')
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c')
 *    ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b')
 *    ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b')
 *    ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b')
 *    ('~fmin', 'a', 'a') => a
 *    ('~fmax', 'a', 'a') => a
 *    ('imin', 'a', 'a') => a
 *    ('imax', 'a', 'a') => a
 *    ('umin', 'a', 'a') => a
 *    ('umin', 'a', 0) => 0
 *    ('umin', 'a', -1) => a
 *    ('umax', 'a', 'a') => a
 *    ('umax', 'a', 0) => a
 *    ('umax', 'a', -1) => -1
 *    ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b')
 *    ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b')
 *    ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b')
 *    ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b')
 *    ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b')
 *    ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b')
 *    ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c')
 *    ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c')
 *    ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c')
 *    ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c')
 *    ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c')
 *    ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c')
 *    ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b')
 *    ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0)
 *    ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0)
 *    ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0)
 *    ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0)
 *    ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a'))
 *    ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a'))
 *    ('~fmin', 'a', ('fabs', 'a')) => a
 *    ('imin', 'a', ('iabs', 'a')) => a
 *    ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a
 *    ('imax', 'a', ('ineg', ('iabs', 'a'))) => a
 *    ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a')
 *    ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a')
 *    ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a')
 *    ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a')
 *    ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a')
 *    ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a'))
 *    ('fsat', ('b2f', 'a')) => ('b2f', 'a')
 *    ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0)
 *    ('fsat', ('fsat', 'a')) => ('fsat', 'a')
 *    ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b')))
 *    ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b')))
 *    ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c')
 *    ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c')
 *    ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c')
 *    ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b'))
 *    ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b'))
 *    ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a'))
 *    ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a'))
 *    ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b'))
 *    ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255)
 *    ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c'))
 *    ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c')
 *    ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c'))
 *    ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c')
 *    ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c'))
 *    ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c'))
 *    ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c'))
 *    ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c')
 *    ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c'))
 *    ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c')
 *    ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c'))
 *    ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c'))
 *    ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a')
 *    ('~f2i16', ('i2f', 'a@16')) => a
 *    ('~f2i16', ('u2f', 'a@16')) => a
 *    ('~f2u16', ('i2f', 'a@16')) => a
 *    ('~f2u16', ('u2f', 'a@16')) => a
 *    ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a'))
 *    ('f2f16', ('f2f32', 'a@16')) => a
 *    ('i2i16', ('i2i32', 'a@16')) => a
 *    ('u2u16', ('u2u32', 'a@16')) => a
 *    ('f2f16', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2i16', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('u2u16', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a')
 *    ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a')
 *    ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a')
 *    ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a')
 *    ('f2f16', ('f2f64', 'a@16')) => a
 *    ('i2i16', ('i2i64', 'a@16')) => a
 *    ('u2u16', ('u2u64', 'a@16')) => a
 *    ('f2f16', ('b2f64', 'a@1')) => ('b2f16', 'a')
 *    ('i2i16', ('b2i64', 'a@1')) => ('b2i16', 'a')
 *    ('u2u16', ('b2i64', 'a@1')) => ('b2i16', 'a')
 *    ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a')
 *    ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a')
 *    ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a')
 *    ('~f2i32', ('i2f', 'a@32')) => a
 *    ('~f2i32', ('u2f', 'a@32')) => a
 *    ('~f2u32', ('i2f', 'a@32')) => a
 *    ('~f2u32', ('u2f', 'a@32')) => a
 *    ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a'))
 *    ('f2f32', ('f2f64', 'a@32')) => a
 *    ('i2i32', ('i2i64', 'a@32')) => a
 *    ('u2u32', ('u2u64', 'a@32')) => a
 *    ('f2f32', ('b2f64', 'a@1')) => ('b2f32', 'a')
 *    ('i2i32', ('b2i64', 'a@1')) => ('b2i32', 'a')
 *    ('u2u32', ('b2i64', 'a@1')) => ('b2i32', 'a')
 *    ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a')
 *    ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a')
 *    ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a')
 *    ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a')
 *    ('~f2i64', ('i2f', 'a@64')) => a
 *    ('~f2i64', ('u2f', 'a@64')) => a
 *    ('~f2u64', ('i2f', 'a@64')) => a
 *    ('~f2u64', ('u2f', 'a@64')) => a
 *    ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a'))
 *    ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a')
 *    ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a')
 *    ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a')
 *    ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a')
 *    ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a')
 *    ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a')
 *    ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a')
 *    ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a')
 *    ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b')
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b')
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b')
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i8', 'a@8')) => a
 *    ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b')
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i16', 'a@16')) => a
 *    ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b')
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i32', 'a@32')) => a
 *    ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b')
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i64', 'a@64')) => a
 *    ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b')
 *    ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a')
 *    ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a')
 *    ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a')
 *    ('ior', 'a', ('ieq', 'a', False)) => True
 *    ('ior', 'a', ('inot', 'a')) => -1
 *    ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b')
 *    ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b'))
 *    ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0))
 *    ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0))
 *    ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b')
 *    ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a')
 *    ('~fge', 'a', ('fmin', 'b', 'a')) => True
 *    ('~fge', ('fmax', 'a', 'b'), 'a') => True
 *    ('flt', 'a', ('fmin', 'b', 'a')) => False
 *    ('flt', ('fmax', 'a', 'b'), 'a') => False
 *    ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b')
 *    ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a')
 *    ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b')
 *    ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a')
 *    ('ige', 'a', ('imin', 'b', 'a')) => True
 *    ('ige', ('imax', 'a', 'b'), 'a') => True
 *    ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b')
 *    ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a')
 *    ('uge', 'a', ('umin', 'b', 'a')) => True
 *    ('uge', ('umax', 'a', 'b'), 'a') => True
 *    ('ilt', 'a', ('imin', 'b', 'a')) => False
 *    ('ilt', ('imax', 'a', 'b'), 'a') => False
 *    ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b')
 *    ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a')
 *    ('ult', 'a', ('umin', 'b', 'a')) => False
 *    ('ult', ('umax', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b')
 *    ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a')
 *    ('ult', 'a', ('iand', 'b', 'a')) => False
 *    ('ult', ('ior', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('iand', 'b', 'a')) => True
 *    ('uge', ('ior', 'a', 'b'), 'a') => True
 *    ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b'))
 *    ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b')
 *    ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b')
 *    ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b')
 *    ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b')
 *    ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b')
 *    ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b'))
 *    ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b'))
 *    ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b'))
 *    ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b'))
 *    ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y'))
 *    ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0)
 *    ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0)
 *    ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y'))
 *    ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y'))
 *    ('ball_iequal3', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('ieq', 'a.z', 'b.z'))
 *    ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w')))
 *    ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y'))
 *    ('bany_inequal3', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ine', 'a.z', 'b.z'))
 *    ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w')))
 *    ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y'))
 *    ('ball_fequal3', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('feq', 'a.z', 'b.z'))
 *    ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w')))
 *    ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y'))
 *    ('bany_fnequal3', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('fneu', 'a.z', 'b.z'))
 *    ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w')))
 *    ('feq', ('seq', 'a', 'b'), 1.0) => ('feq', 'a', 'b')
 *    ('feq', ('sne', 'a', 'b'), 1.0) => ('fneu', 'a', 'b')
 *    ('feq', ('slt', 'a', 'b'), 1.0) => ('flt', 'a', 'b')
 *    ('feq', ('sge', 'a', 'b'), 1.0) => ('fge', 'a', 'b')
 *    ('fneu', ('seq', 'a', 'b'), 0.0) => ('feq', 'a', 'b')
 *    ('fneu', ('sne', 'a', 'b'), 0.0) => ('fneu', 'a', 'b')
 *    ('fneu', ('slt', 'a', 'b'), 0.0) => ('flt', 'a', 'b')
 *    ('fneu', ('sge', 'a', 'b'), 0.0) => ('fge', 'a', 'b')
 *    ('feq', ('seq', 'a', 'b'), 0.0) => ('fneu', 'a', 'b')
 *    ('feq', ('sne', 'a', 'b'), 0.0) => ('feq', 'a', 'b')
 *    ('feq', ('slt', 'a', 'b'), 0.0) => ('fge', 'a', 'b')
 *    ('feq', ('sge', 'a', 'b'), 0.0) => ('flt', 'a', 'b')
 *    ('fneu', ('seq', 'a', 'b'), 1.0) => ('fneu', 'a', 'b')
 *    ('fneu', ('sne', 'a', 'b'), 1.0) => ('feq', 'a', 'b')
 *    ('fneu', ('slt', 'a', 'b'), 1.0) => ('fge', 'a', 'b')
 *    ('fneu', ('sge', 'a', 'b'), 1.0) => ('flt', 'a', 'b')
 *    ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0)
 *    ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0)
 *    ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b'))
 *    ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b'))
 *    ('iand', 'a@bool16', 1.0) => ('b2f', 'a')
 *    ('iand', 'a@bool32', 1.0) => ('b2f', 'a')
 *    ('flt', ('fneg', ('b2f', 'a@1')), 0) => a
 *    ('ilt', 'a', 'a') => False
 *    ('ige', 'a', 'a') => True
 *    ('ieq', 'a', 'a') => True
 *    ('ine', 'a', 'a') => False
 *    ('ult', 'a', 'a') => False
 *    ('uge', 'a', 'a') => True
 *    ('flt', 'a', 'a') => False
 *    ('fge', 'a(is_a_number)', 'a') => True
 *    ('feq', 'a(is_a_number)', 'a') => True
 *    ('fneu', 'a(is_a_number)', 'a') => False
 *    ('iand', 'a', 'a') => a
 *    ('iand', 'a', -1) => a
 *    ('iand', 'a', 0) => 0
 *    ('ior', 'a', 'a') => a
 *    ('ior', 'a', 0) => a
 *    ('ior', 'a', True) => True
 *    ('ixor', 'a', 'a') => 0
 *    ('ixor', 'a', 0) => a
 *    ('inot', ('inot', 'a')) => a
 *    ('ior', ('iand', 'a', 'b'), 'b') => b
 *    ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b')
 *    ('iand', ('ior', 'a', 'b'), 'b') => b
 *    ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b')
 *    ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b'))
 *    ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b'))
 *    ('ishl', 0, 'a') => 0
 *    ('ishl', 'a', 0) => a
 *    ('ishr', 0, 'a') => 0
 *    ('ishr', 'a', 0) => a
 *    ('ushr', 0, 'a') => 0
 *    ('ushr', 'a', 0) => a
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b')
 *    ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b')))
 *    ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b')))
 *    ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b')))
 *    ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b')))
 *    ('~fexp2', ('flog2', 'a')) => a
 *    ('~flog2', ('fexp2', 'a')) => a
 *    ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b')
 *    ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 'a', 1.0) => a
 *    ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a')
 *    ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 2.0, 'a') => ('fexp2', 'a')
 *    ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a
 *    ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a')
 *    ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a'))
 *    ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a'))
 *    ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a'))
 *    ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a'))
 *    ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a'))
 *    ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a'))
 *    ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a'))
 *    ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b'))
 *    ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0))
 *    ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fdiv', 1.0, 'a') => ('frcp', 'a')
 *    ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b'))
 *    ('~frcp', ('frcp', 'a')) => a
 *    ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a')
 *    ('fsqrt', 'a') => ('frcp', ('frsq', 'a'))
 *    ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a')
 *    ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))
 *    ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))
 *    ('i2b16(is_used_by_if)', 'a') => ('ine16', 'a', 0)
 *    ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0)
 *    ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0)
 *    ('ieq', 'a', True) => a
 *    ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a')
 *    ('ine', 'a', False) => a
 *    ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a')
 *    ('bcsel', 'a', True, False) => a
 *    ('bcsel', 'a', False, True) => ('inot', 'a')
 *    ('bcsel', True, 'b', 'c') => b
 *    ('bcsel', False, 'b', 'c') => c
 *    ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel', 'a', 'b', 'b') => b
 *    ('~fcsel', 'a', 'b', 'b') => b
 *    ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1'))
 *    ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a')))
 *    ('bcsel', 'a', 1, 0) => ('b2i', 'a@1')
 *    ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a'))
 *    ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a')
 *    ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a
 *    ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a')
 *    ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a')
 *    ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('i2b16', ('b2i', 'a@16')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2i', ('ftrunc', 'a')) => ('f2i', 'a')
 *    ('f2u', ('ftrunc', 'a')) => ('f2u', 'a')
 *    ('i2b', ('ineg', 'a')) => ('i2b', 'a')
 *    ('i2b', ('iabs', 'a')) => ('i2b', 'a')
 *    ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0)
 *    ('f2fmp', ('f2f32', 'a@16')) => a
 *    ('i2imp', ('i2i32', 'a@16')) => a
 *    ('i2imp', ('u2u32', 'a@16')) => a
 *    ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a')
 *    ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a')
 *    ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a')
 *    ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a')
 *    ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('f2f32', ('f2fmp', 'a@32')) => a
 *    ('i2i32', ('i2imp', 'a@32')) => a
 *    ('u2u32', ('i2imp', 'a@32')) => a
 *    ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a')
 *    ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a')
 *    ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a')
 *    ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a')
 *    ('~f2f32', ('f2f64', 'a@32')) => a
 *    ('ffloor', 'a(is_integral)') => a
 *    ('fceil', 'a(is_integral)') => a
 *    ('ftrunc', 'a(is_integral)') => a
 *    ('~ffract', 'a(is_integral)') => 0.0
 *    ('fabs', 'a(is_not_negative)') => a
 *    ('iabs', 'a(is_not_negative)') => a
 *    ('fsat', 'a(is_not_positive)') => 0.0
 *    ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a')
 *    ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0)
 *    ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0)
 *    ('fneu', 'a(is_not_zero)', 0.0) => True
 *    ('feq', 'a(is_not_zero)', 0.0) => False
 *    ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True
 *    ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True
 *    ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True
 *    ('ine', 'a(is_not_zero)', 0) => True
 *    ('ieq', 'a(is_not_zero)', 0) => False
 *    ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True
 *    ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True
 *    ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True
 *    ('ult', 0, 'a(is_gt_zero)') => True
 *    ('ult', 'a', 0) => False
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b
 *    ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b')
 *    ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a
 *    ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a
 *    ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a
 *    ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a
 *    ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a
 *    ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a
 *    ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c'))
 *    ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1)
 *    ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3)
 *    ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7)
 *    ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1)
 *    ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3)
 *    ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7)
 *    ('iand', 255, 'a') => ('extract_u8', 'a', 0)
 *    ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2))
 *    ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1))
 *    ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b'))
 *    ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b'))
 *    ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0)
 *    ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1)
 *    ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2)
 *    ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3)
 *    ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0)
 *    ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1)
 *    ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2)
 *    ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3)
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0)
 *    ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1)
 *    ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0)
 *    ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1)
 *    ('iand', 65535, 'a') => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1)
 *    ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0)
 *    ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1)
 *    ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a'))
 *    ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32))
 *    ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16))
 *    ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a')
 *    ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32))
 *    ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16))
 *    ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a')
 *    ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a')
 *    ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a')
 *    ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a'))
 *    ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0))
 *    ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a')
 *    ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0)
 *    ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0)
 *    ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd')
 *    ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6)
 *    ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5)
 *    ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4)
 *    ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3)
 *    ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0)
 *    ('ussub_4x8_vc4', 'a', 0) => a
 *    ('ussub_4x8_vc4', 'a', -1) => 0
 *    ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b'))
 *    ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b'))
 *    ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b'))
 *    ('fmulz(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b'))
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b'))
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c')
 *    ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b'))
 *    ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b')
 *    ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b')
 *    ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b')
 *    ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a
 *    ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd')
 *    ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b'))))
 *    ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b'))))
 *    ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a'))
 *    ('usub_borrow', 'a', 'b') => ('b2i', ('ult', 'a', 'b'))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base'))
 *    ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807))
 *    ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base'))
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits'))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits'))
 *    ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b')
 *    ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c')
 *    ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits')
 *    ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits')
 *    ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset')
 *    ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset')
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b')))
 *    ('b2i32', ('i2b', ('ubfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1)
 *    ('b2i32', ('i2b', ('ibfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1)
 *    ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits')))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1)))
 *    ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value'))
 *    ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value'))
 *    ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value'))
 *    ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value')))
 *    ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24)
 *    ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255)
 *    ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16)
 *    ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535)
 *    ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0))))
 *    ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0))))
 *    ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0))))
 *    ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0))))
 *    ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0)
 *    ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0)
 *    ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0)))
 *    ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0)))
 *    ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a')))
 *    ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a'))
 *    ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16)))
 *    ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a'))
 *    ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16))
 *    ('isign', 'a') => ('imin', ('imax', 'a', -1), 1)
 *    ('imin', ('imax', 'a', -1), 1) => ('isign', 'a')
 *    ('imax', ('imin', 'a', 1), -1) => ('isign', 'a')
 *    ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0)))
 *    ('amul', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215))
 *    ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c')
 *    ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b')
 *    ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c')
 *    ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b')
 *    ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b')
 *    ('imad24_ir3', 'a', 0, 'c') => c
 *    ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c')
 *    ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c')
 *    ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('imul24', 'a', 0) => 0
 *    ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c')
 *    ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c')
 *    ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b')
 *    ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b')
 *    ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c')
 *    ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c')
 *    ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b')))
 *    ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b')))
 *    ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b')))
 *    ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b')))
 *    ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b')))
 *    ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b')))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b')))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b')))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('f2b1', ('b2f', 'a@1')) => a
 *    ('i2b1', ('b2i', 'a@1')) => a
 *    ('f2b8', ('b2f', 'a@8')) => a
 *    ('i2b8', ('b2i', 'a@8')) => a
 *    ('f2b16', ('b2f', 'a@16')) => a
 *    ('i2b16', ('b2i', 'a@16')) => a
 *    ('f2b32', ('b2f', 'a@32')) => a
 *    ('i2b32', ('b2i', 'a@32')) => a
 *    ('f2f', ('b2f', 'a')) => ('b2f', 'a')
 *    ('f2u', ('b2f', 'a')) => ('b2i', 'a')
 *    ('f2i', ('b2f', 'a')) => ('b2i', 'a')
 *    ('u2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('u2u', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('i2i', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2i1', 'a@1') => a
 *    ('i2i8', 'a@8') => a
 *    ('i2i16', 'a@16') => a
 *    ('i2i32', 'a@32') => a
 *    ('i2i64', 'a@64') => a
 *    ('u2u1', 'a@1') => a
 *    ('u2u8', 'a@8') => a
 *    ('u2u16', 'a@16') => a
 *    ('u2u32', 'a@32') => a
 *    ('u2u64', 'a@64') => a
 *    ('f2f16', 'a@16') => a
 *    ('f2f32', 'a@32') => a
 *    ('f2f64', 'a@64') => a
 *    ('b2b1', 'a@1') => a
 *    ('b2b8', 'a@8') => a
 *    ('b2b16', 'a@16') => a
 *    ('b2b32', 'a@32') => a
 *    ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b')))
 *    ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b')))
 *    ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a')
 *    ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a')
 *    ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a')
 *    ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a')
 *    ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10)))
 *    ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23))
 *    ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20)))
 *    ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x')
 *    ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x')
 *    ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b')
 *    ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b')
 *    ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b')
 *    ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b')
 *    ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b')
 *    ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b')
 *    ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b')
 *    ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b')
 *    ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b')
 *    ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b')
 *    ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b')
 *    ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b')
 *    ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b')
 *    ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b')
 *    ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b')
 *    ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b')
 *    ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b')
 *    ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b')
 *    ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b')
 *    ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a')
 *    ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd'))
 *    ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd'))
 *    ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd'))
 *    ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd'))
 *    ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd'))
 *    ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c'))
 *    ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd'))
 *    ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c'))
 *    ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd'))
 *    ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c'))
 *    ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd'))
 *    ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c'))
 *    ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd'))
 *    ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c'))
 *    ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd'))
 *    ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c'))
 *    ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd'))
 *    ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd'))
 *    ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd'))
 *    ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd'))
 *    ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd'))
 *    ('fddx', 'a') => 0.0
 *    ('fddx_fine', 'a') => 0.0
 *    ('fddx_coarse', 'a') => 0.0
 *    ('fddy', 'a') => 0.0
 *    ('fddy_fine', 'a') => 0.0
 *    ('fddy_coarse', 'a') => 0.0
 *    ('umul_low', '#a(is_lower_half_zero)', 'b') => 0
 *    ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c
 *    ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b'))
 *    ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b'))
 *    ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b'))
 *    ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b'))
 *    ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216))
 *    ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b'))
 *    ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b'))
 *    ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b'))
 *    ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b'))
 *    ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b'))
 *    ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'))
 *    ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))
 *    ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'))
 *    ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'))
 *    ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'))
 *    ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd'))
 *    ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd'))
 *    ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd'))
 *    ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd'))
 *    ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd'))
 */


static const nir_search_value_union nir_opt_algebraic_values[] = {
   /* ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('imul', 'a@8', 128) => ('ishl', 'a', 7) */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x80 /* 128 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 6, 7 },
      -1,
   } },

   /* replace1_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 9 },
      -1,
   } },

   /* ('imul', 'a@16', 32768) => ('ishl', 'a', 15) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x8000 /* 32768 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 11, 12 },
      -1,
   } },

   /* replace2_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf /* 15 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 14 },
      -1,
   } },

   /* ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x80000000 /* 2147483648 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 17 },
      -1,
   } },

   /* replace3_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1f /* 31 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 19 },
      -1,
   } },

   /* ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x8000000000000000 /* 9223372036854775808 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 21, 22 },
      -1,
   } },

   /* replace4_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3f /* 63 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 24 },
      -1,
   } },

   /* ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search5_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 26 },
      -1,
   } },

   /* replace5_0_0 -> 0 in the cache */
   /* replace5_0_1_0_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 28 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 30 },
      -1,
   } },

   /* ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 32, 33 },
      -1,
   } },

   /* replace6_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 37 },
      -1,
   } },

   /* ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b'))) */
   /* search7_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 21, 39 },
      -1,
   } },

   /* replace7_0_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 42 },
      -1,
   } },
   /* replace7_1_0 -> 21 in the cache */
   /* replace7_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 44 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 43, 45 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search8_0_0 -> 16 in the cache */
   /* search8_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 47 },
      -1,
   } },

   /* replace8_0 -> 16 in the cache */
   /* replace8_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search9_0_0 -> 16 in the cache */
   /* search9_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 50 },
      -1,
   } },

   /* replace9_0 -> 16 in the cache */
   /* replace9_1 -> 36 in the cache */
   /* replace9 -> 49 in the cache */

   /* ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b')) */
   /* search10_0 -> 16 in the cache */
   /* search10_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace10_0_0 -> 16 in the cache */
   /* replace10_0_1 -> 36 in the cache */
   /* replace10_0 -> 49 in the cache */
   /* replace10_1_0 -> 16 in the cache */
   /* replace10_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 53 },
      -1,
   } },

   /* ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b')) */
   /* search11_0 -> 16 in the cache */
   /* search11_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace11_0_0 -> 16 in the cache */
   /* replace11_0_1 -> 36 in the cache */
   /* replace11_0 -> 49 in the cache */
   /* replace11_1_0 -> 16 in the cache */
   /* replace11_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 56 },
      -1,
   } },

   /* ('udiv', 'a', 1) => a */
   /* search12_0 -> 32 in the cache */
   /* search12_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace12 -> 32 in the cache */

   /* ('idiv', 'a', 1) => a */
   /* search13_0 -> 32 in the cache */
   /* search13_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace13 -> 32 in the cache */

   /* ('umod', 'a', 1) => 0 */
   /* search14_0 -> 32 in the cache */
   /* search14_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('imod', 'a', 1) => 0 */
   /* search15_0 -> 32 in the cache */
   /* search15_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace15 -> 61 in the cache */

   /* ('imod', 'a', -1) => 0 */
   /* search16_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace16 -> 61 in the cache */

   /* ('irem', 'a', 1) => 0 */
   /* search17_0 -> 32 in the cache */
   /* search17_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace17 -> 61 in the cache */

   /* ('irem', 'a', -1) => 0 */
   /* search18_0 -> 32 in the cache */
   /* search18_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace18 -> 61 in the cache */

   /* ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b')) */
   /* search19_0 -> 0 in the cache */
   /* search19_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace19_0 -> 0 in the cache */
   /* replace19_1_0 -> 3 in the cache */
   /* replace19_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b'))) */
   /* search20_0 -> 0 in the cache */
   /* search20_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace20_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_1_0 -> 3 in the cache */
   /* replace20_1_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 71, 4 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 70, 72 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b'))))) */
   /* search21_0 -> 0 in the cache */
   /* search21_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace21_0_0_0 -> 0 in the cache */
   /* replace21_0_0 -> 70 in the cache */
   /* replace21_0_1_0_0 -> 0 in the cache */
   /* replace21_0_1_0 -> 71 in the cache */
   /* replace21_0_1_1_0_0 -> 3 in the cache */
   /* replace21_0_1_1_0 -> 28 in the cache */
   /* replace21_0_1_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 71, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 70, 75 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 76 },
      -1,
   } },

   /* ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search22_0 -> 0 in the cache */
   /* search22_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace22_0 -> 0 in the cache */
   /* replace22_1_0 -> 3 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3, 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 80 },
      -1,
   } },

   /* ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search23_0 -> 0 in the cache */
   /* search23_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace23_0 -> 0 in the cache */
   /* replace23_1_0 -> 3 in the cache */
   /* replace23_1_1 -> 79 in the cache */
   /* replace23_1 -> 80 in the cache */
   /* replace23 -> 81 in the cache */

   /* ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b')) */
   /* search24_0 -> 0 in the cache */
   /* search24_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace24_0_0_0 -> 0 in the cache */
   /* replace24_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace24_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 84, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace24_2_0 -> 0 in the cache */
   /* replace24_2_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 85, 86, 87 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b'))) */
   /* search25_0 -> 0 in the cache */
   /* search25_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace25_0 -> 0 in the cache */
   /* replace25_1_0_0_0 -> 0 in the cache */
   /* replace25_1_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 86 },
      -1,
   } },
   /* replace25_1_0_1_0 -> 0 in the cache */
   /* replace25_1_0_1_1_0 -> 3 in the cache */
   /* replace25_1_0_1_1_1 -> 79 in the cache */
   /* replace25_1_0_1_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 80 },
      -1,
   } },
   /* replace25_1_0_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 90, 91, 0 },
      -1,
   } },
   /* replace25_1_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 92, 93 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 0, 94 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b')) */
   /* search26_0 -> 0 in the cache */
   /* search26_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace26_0 -> 0 in the cache */
   /* replace26_1_0 -> 3 in the cache */
   /* replace26_1 -> 28 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 28 },
      -1,
   } },

   /* ('~fneg', ('fneg', 'a')) => a */
   /* search27_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace27 -> 32 in the cache */

   /* ('ineg', ('ineg', 'a')) => a */
   /* search28_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace28 -> 32 in the cache */

   /* ('fabs', ('fneg', 'a')) => ('fabs', 'a') */
   /* search29_0_0 -> 32 in the cache */
   /* search29_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace29_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('fabs', ('u2f', 'a')) => ('u2f', 'a') */
   /* search30_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 104 },
      -1,
   } },

   /* replace30_0 -> 32 in the cache */
   /* replace30 -> 104 in the cache */

   /* ('iabs', ('iabs', 'a')) => ('iabs', 'a') */
   /* search31_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace31_0 -> 32 in the cache */
   /* replace31 -> 106 in the cache */

   /* ('iabs', ('ineg', 'a')) => ('iabs', 'a') */
   /* search32_0_0 -> 32 in the cache */
   /* search32_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace32_0 -> 32 in the cache */
   /* replace32 -> 106 in the cache */

   /* ('f2b', ('fneg', 'a')) => ('f2b', 'a') */
   /* search33_0_0 -> 32 in the cache */
   /* search33_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2b,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace33_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2b', ('ineg', 'a')) => ('i2b', 'a') */
   /* search34_0_0 -> 32 in the cache */
   /* search34_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace34_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fadd', 'a', 0.0) => a */
   /* search35_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* replace35 -> 32 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a */
   /* search36_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 115 },
      1,
   } },

   /* replace36 -> 11 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a */
   /* search37_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 117 },
      1,
   } },

   /* replace37 -> 16 in the cache */

   /* ('iadd', 'a', 0) => a */
   /* search38_0 -> 32 in the cache */
   /* search38_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace38 -> 32 in the cache */

   /* ('usadd_4x8_vc4', 'a', 0) => a */
   /* search39_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* replace39 -> 16 in the cache */

   /* ('usadd_4x8_vc4', 'a', -1) => -1 */
   /* search40_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 122 },
      -1,
   } },

   /* replace40 -> 122 in the cache */

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search41_1_0 -> 124 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 126, 128 },
      -1,
   } },

   /* replace41_0 -> 124 in the cache */
   /* replace41_1_0 -> 125 in the cache */
   /* replace41_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 124, 130 },
      -1,
   } },

   /* ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search42_0_0 -> 16 in the cache */
   /* search42_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* search42_1_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 16, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 132, 134 },
      -1,
   } },

   /* replace42_0 -> 16 in the cache */
   /* replace42_1_0 -> 36 in the cache */
   /* replace42_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 16, 136 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search43_0 -> 0 in the cache */
   /* search43_1 -> 3 in the cache */
   /* search43_2_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 0, 138, 139 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 140 },
      -1,
   } },

   /* replace43_0 -> 0 in the cache */
   /* replace43_1_0 -> 3 in the cache */
   /* replace43_1_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3, 138 },
      -1,
   } },
   /* replace43_2 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 142, 139 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search44_0 -> 0 in the cache */
   /* search44_1 -> 3 in the cache */
   /* search44_2_0 -> 0 in the cache */
   /* search44_2_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 138 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 144 },
      -1,
   } },

   /* replace44_0 -> 0 in the cache */
   /* replace44_1_0 -> 3 in the cache */
   /* replace44_1_1 -> 138 in the cache */
   /* replace44_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 0, 142 },
      -1,
   } },

   /* ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 147, 148 },
      0,
   } },
   /* search45_1_0 -> 147 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 147, 150, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 149, 152 },
      -1,
   } },

   /* replace45_0 -> 147 in the cache */
   /* replace45_1_0 -> 148 in the cache */
   /* replace45_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 148, 150 },
      -1,
   } },
   /* replace45_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 147, 154, 151 },
      -1,
   } },

   /* ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd')) */
   /* search46_0 -> 147 in the cache */
   /* search46_1_0 -> 148 in the cache */
   /* search46_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 150 },
      0,
   } },
   /* search46_2_0 -> 148 in the cache */
   /* search46_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 147, 156, 157 },
      -1,
   } },

   /* replace46_0 -> 148 in the cache */
   /* replace46_1_0 -> 147 in the cache */
   /* replace46_1_1 -> 150 in the cache */
   /* replace46_1_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 147, 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 148, 159 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search47_0 -> 16 in the cache */
   /* search47_1 -> 36 in the cache */
   /* search47_2_0 -> 16 in the cache */
   /* search47_2_1 -> 133 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 133, 161 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 36, 162 },
      -1,
   } },

   /* replace47_0 -> 16 in the cache */
   /* replace47_1_0 -> 36 in the cache */
   /* replace47_1_1 -> 133 in the cache */
   /* replace47_1 -> 136 in the cache */
   /* replace47_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 136, 161 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search48_0 -> 16 in the cache */
   /* search48_1 -> 36 in the cache */
   /* search48_2_0 -> 16 in the cache */
   /* search48_2_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 133 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 36, 165 },
      -1,
   } },

   /* replace48_0 -> 16 in the cache */
   /* replace48_1_0 -> 36 in the cache */
   /* replace48_1_1 -> 133 in the cache */
   /* replace48_1 -> 136 in the cache */
   /* replace48 -> 137 in the cache */

   /* ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search49_0_0 -> 16 in the cache */
   /* search49_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 36 },
      0,
   } },
   /* search49_1_0 -> 16 in the cache */
   /* search49_1_1 -> 133 in the cache */
   /* search49_1_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 16, 133, 161 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 167, 168 },
      -1,
   } },

   /* replace49_0 -> 16 in the cache */
   /* replace49_1_0 -> 36 in the cache */
   /* replace49_1_1 -> 133 in the cache */
   /* replace49_1 -> 136 in the cache */
   /* replace49_2 -> 161 in the cache */
   /* replace49 -> 164 in the cache */

   /* ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd')) */
   /* search50_0 -> 16 in the cache */
   /* search50_1_0 -> 36 in the cache */
   /* search50_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 133 },
      0,
   } },
   /* search50_2_0 -> 36 in the cache */
   /* search50_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 36, 161 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 16, 170, 171 },
      -1,
   } },

   /* replace50_0 -> 36 in the cache */
   /* replace50_1_0 -> 16 in the cache */
   /* replace50_1_1 -> 133 in the cache */
   /* replace50_1_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 36, 173 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search51_0_0 -> 124 in the cache */
   /* search51_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search51_1_0 -> 124 in the cache */
   /* search51_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 175, 176 },
      -1,
   } },

   /* replace51_0 -> 124 in the cache */
   /* replace51_1_0 -> 125 in the cache */
   /* replace51_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 124, 178 },
      -1,
   } },

   /* ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c')) */
   /* search52_0_0 -> 124 in the cache */
   /* search52_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search52_1_0 -> 124 in the cache */
   /* search52_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 180, 181 },
      -1,
   } },

   /* replace52_0 -> 124 in the cache */
   /* replace52_1_0 -> 125 in the cache */
   /* replace52_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 124, 183 },
      -1,
   } },

   /* ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c')) */
   /* search53_0_0 -> 124 in the cache */
   /* search53_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* search53_1_0 -> 124 in the cache */
   /* search53_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 185, 186 },
      -1,
   } },

   /* replace53_0 -> 124 in the cache */
   /* replace53_1_0 -> 125 in the cache */
   /* replace53_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 124, 188 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   /* search54_0_0 -> 32 in the cache */
   /* search54_0 -> 98 in the cache */
   /* search54_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace54 -> 113 in the cache */

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search55_0_0 -> 32 in the cache */
   /* search55_0 -> 100 in the cache */
   /* search55_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 100, 32 },
      -1,
   } },

   /* replace55 -> 61 in the cache */

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   /* search56_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search56_1_0 -> 0 in the cache */
   /* search56_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 192, 193 },
      -1,
   } },

   /* replace56 -> 3 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search57_0 -> 0 in the cache */
   /* search57_1_0_0 -> 0 in the cache */
   /* search57_1_0 -> 192 in the cache */
   /* search57_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 192, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 0, 195 },
      -1,
   } },

   /* replace57 -> 3 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search58_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search58_1_0 -> 0 in the cache */
   /* search58_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 197, 198 },
      -1,
   } },

   /* replace58 -> 3 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search59_0 -> 0 in the cache */
   /* search59_1_0_0 -> 0 in the cache */
   /* search59_1_0 -> 197 in the cache */
   /* search59_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 197, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 0, 200 },
      -1,
   } },

   /* replace59 -> 3 in the cache */

   /* ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a')) */
   /* search60_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search60_1_0_0 -> 32 in the cache */
   /* search60_1_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 202, 203 },
      -1,
   } },

   /* replace60_0_0 -> 32 in the cache */
   /* replace60_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 103 },
      -1,
   } },

   /* ('~fmul', 'a', 0.0) => 0.0 */
   /* search61_0 -> 32 in the cache */
   /* search61_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* replace61 -> 113 in the cache */

   /* ('fmul', 'a@16', 0.0) => 0.0 */
   /* search62_0 -> 11 in the cache */
   /* search62_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 115 },
      -1,
   } },

   /* replace62 -> 115 in the cache */

   /* ('fmul', 'a@32', 0.0) => 0.0 */
   /* search63_0 -> 16 in the cache */
   /* search63_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 117 },
      -1,
   } },

   /* replace63 -> 117 in the cache */

   /* ('fmulz', 'a', 0.0) => 0.0 */
   /* search64_0 -> 16 in the cache */
   /* search64_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 117 },
      -1,
   } },

   /* replace64 -> 117 in the cache */

   /* ('fmulz', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b') */
   /* search65_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 210 },
      -1,
   } },

   /* replace65_0 -> 16 in the cache */
   /* replace65_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 213, 214 },
      -1,
   } },

   /* replace66_0 -> 16 in the cache */
   /* replace66_1 -> 36 in the cache */
   /* replace66 -> 212 in the cache */

   /* ('fmulz', 'a', 'a') => ('fmul', 'a', 'a') */
   /* search67_0 -> 16 in the cache */
   /* search67_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 16, 16 },
      -1,
   } },

   /* replace67_0 -> 16 in the cache */
   /* replace67_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 16, 16 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search68_0 -> 16 in the cache */
   /* search68_1 -> 210 in the cache */
   /* search68_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 210, 133 },
      -1,
   } },

   /* replace68_0 -> 16 in the cache */
   /* replace68_1 -> 36 in the cache */
   /* replace68_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search69_0 -> 213 in the cache */
   /* search69_1 -> 214 in the cache */
   /* search69_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 213, 214, 133 },
      -1,
   } },

   /* replace69_0 -> 16 in the cache */
   /* replace69_1 -> 36 in the cache */
   /* replace69_2 -> 133 in the cache */
   /* replace69 -> 219 in the cache */

   /* ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b') */
   /* search70_0 -> 16 in the cache */
   /* search70_1 -> 16 in the cache */
   /* search70_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      -1, 0,
      { 16, 16, 36 },
      -1,
   } },

   /* replace70_0 -> 16 in the cache */
   /* replace70_1 -> 16 in the cache */
   /* replace70_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      -1, 0,
      { 16, 16, 36 },
      -1,
   } },

   /* ('imul', 'a', 0) => 0 */
   /* search71_0 -> 32 in the cache */
   /* search71_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace71 -> 61 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', 0) => 0 */
   /* search72_0 -> 16 in the cache */
   /* search72_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* replace72 -> 120 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', -1) => a */
   /* search73_0 -> 16 in the cache */
   /* search73_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 122 },
      -1,
   } },

   /* replace73 -> 16 in the cache */

   /* ('~fmul', 'a', 1.0) => a */
   /* search74_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 226 },
      -1,
   } },

   /* replace74 -> 32 in the cache */

   /* ('~fmulz', 'a', 1.0) => a */
   /* search75_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 228 },
      -1,
   } },

   /* replace75 -> 16 in the cache */

   /* ('fmul(is_only_used_as_float)', 'a', 1.0) => a */
   /* search76_0 -> 32 in the cache */
   /* search76_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 226 },
      1,
   } },

   /* replace76 -> 32 in the cache */

   /* ('imul', 'a', 1) => a */
   /* search77_0 -> 32 in the cache */
   /* search77_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 35 },
      -1,
   } },

   /* replace77 -> 32 in the cache */

   /* ('fmul', 'a', -1.0) => ('fneg', 'a') */
   /* search78_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 232 },
      -1,
   } },

   /* replace78_0 -> 32 in the cache */
   /* replace78 -> 98 in the cache */

   /* ('imul', 'a', -1) => ('ineg', 'a') */
   /* search79_0 -> 32 in the cache */
   /* search79_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace79_0 -> 32 in the cache */
   /* replace79 -> 100 in the cache */

   /* ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a') */
   /* search80_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search80_1_0 -> 32 in the cache */
   /* search80_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 235, 236 },
      -1,
   } },

   /* replace80_0_0 -> 32 in the cache */
   /* replace80_0 -> 103 in the cache */
   /* replace80_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 103, 32 },
      -1,
   } },

   /* ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a') */
   /* search81_0_0_0 -> 32 in the cache */
   /* search81_0_0 -> 235 in the cache */
   /* search81_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 235, 32 },
      -1,
   } },
   /* search81_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 239, 32 },
      -1,
   } },

   /* replace81_0_0 -> 32 in the cache */
   /* replace81_0 -> 103 in the cache */
   /* replace81_1 -> 32 in the cache */
   /* replace81 -> 238 in the cache */

   /* ('~ffma', 0.0, 'a', 'b') => b */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search82_1 -> 0 in the cache */
   /* search82_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 241, 0, 3 },
      -1,
   } },

   /* replace82 -> 3 in the cache */

   /* ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search83_0 -> 115 in the cache */
   /* search83_1 -> 11 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 115, 11, 243 },
      1,
   } },

   /* replace83 -> 243 in the cache */

   /* ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search84_0 -> 117 in the cache */
   /* search84_1 -> 16 in the cache */
   /* search84_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 117, 16, 36 },
      1,
   } },

   /* replace84 -> 36 in the cache */

   /* ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b') */
   /* search85_0 -> 117 in the cache */
   /* search85_1 -> 16 in the cache */
   /* search85_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 117, 16, 36 },
      -1,
   } },

   /* replace85_0 -> 117 in the cache */
   /* replace85_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 117, 36 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search86_0 -> 0 in the cache */
   /* search86_1 -> 3 in the cache */
   /* search86_2 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 0, 3, 241 },
      -1,
   } },

   /* replace86_0 -> 0 in the cache */
   /* replace86_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search87_0 -> 11 in the cache */
   /* search87_1 -> 243 in the cache */
   /* search87_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 243, 115 },
      -1,
   } },

   /* replace87_0 -> 11 in the cache */
   /* replace87_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 243 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search88_0 -> 16 in the cache */
   /* search88_1 -> 36 in the cache */
   /* search88_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 117 },
      -1,
   } },

   /* replace88_0 -> 16 in the cache */
   /* replace88_1 -> 36 in the cache */
   /* replace88 -> 212 in the cache */

   /* ('ffmaz', 'a', 'b', 0.0) => ('fmulz', 'a', 'b') */
   /* search89_0 -> 16 in the cache */
   /* search89_1 -> 36 in the cache */
   /* search89_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 117 },
      -1,
   } },

   /* replace89_0 -> 16 in the cache */
   /* replace89_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search90_1 -> 0 in the cache */
   /* search90_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 255, 0, 3 },
      -1,
   } },

   /* replace90_0 -> 0 in the cache */
   /* replace90_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffmaz', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   /* search91_0 -> 228 in the cache */
   /* search91_1 -> 16 in the cache */
   /* search91_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 228, 16, 36 },
      -1,
   } },

   /* replace91_0 -> 16 in the cache */
   /* replace91_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search92_1 -> 0 in the cache */
   /* search92_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 260, 0, 3 },
      -1,
   } },

   /* replace92_0_0 -> 0 in the cache */
   /* replace92_0 -> 197 in the cache */
   /* replace92_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 197, 3 },
      -1,
   } },

   /* ('ffmaz', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search93_1 -> 16 in the cache */
   /* search93_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 263, 16, 36 },
      -1,
   } },

   /* replace93_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 16 },
      -1,
   } },
   /* replace93_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 265, 36 },
      -1,
   } },

   /* ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search94_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 267, 268, 127 },
      -1,
   } },

   /* replace94_0_0 -> 124 in the cache */
   /* replace94_0_1 -> 125 in the cache */
   /* replace94_0 -> 126 in the cache */
   /* replace94_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 126, 127 },
      -1,
   } },

   /* ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search95_1 -> 33 in the cache */
   /* search95_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 271, 33, 133 },
      -1,
   } },

   /* replace95_0_0 -> 16 in the cache */
   /* replace95_0_1 -> 36 in the cache */
   /* replace95_0 -> 132 in the cache */
   /* replace95_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 132, 133 },
      -1,
   } },

   /* ('~flrp', 'a', 'b', 0.0) => a */
   /* search96_0 -> 0 in the cache */
   /* search96_1 -> 3 in the cache */
   /* search96_2 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 241 },
      -1,
   } },

   /* replace96 -> 0 in the cache */

   /* ('~flrp', 'a', 'b', 1.0) => b */
   /* search97_0 -> 0 in the cache */
   /* search97_1 -> 3 in the cache */
   /* search97_2 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 255 },
      -1,
   } },

   /* replace97 -> 3 in the cache */

   /* ('~flrp', 'a', 'a', 'b') => a */
   /* search98_0 -> 0 in the cache */
   /* search98_1 -> 0 in the cache */
   /* search98_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 0, 3 },
      -1,
   } },

   /* replace98 -> 0 in the cache */

   /* ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b') */
   /* search99_0 -> 241 in the cache */
   /* search99_1 -> 0 in the cache */
   /* search99_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 241, 0, 3 },
      -1,
   } },

   /* replace99_0 -> 0 in the cache */
   /* replace99_1 -> 3 in the cache */
   /* replace99 -> 249 in the cache */

   /* ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search100_0 -> 124 in the cache */
   /* search100_1_0 -> 124 in the cache */
   /* search100_1_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 124, 125 },
      0,
   } },
   /* search100_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 124, 278, 127 },
      -1,
   } },

   /* replace100_0_0 -> 125 in the cache */
   /* replace100_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 125, 127 },
      -1,
   } },
   /* replace100_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 280, 124 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 0, 'b') => b */
   /* search101_0 -> 16 in the cache */
   /* search101_1 -> 120 in the cache */
   /* search101_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace101 -> 36 in the cache */

   /* ('udot_4x8_uadd', 'a', 0, 'b') => b */
   /* search102_0 -> 16 in the cache */
   /* search102_1 -> 120 in the cache */
   /* search102_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace102 -> 36 in the cache */

   /* ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search103_0 -> 16 in the cache */
   /* search103_1 -> 120 in the cache */
   /* search103_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace103 -> 36 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 0, 'b') => b */
   /* search104_0 -> 16 in the cache */
   /* search104_1 -> 120 in the cache */
   /* search104_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace104 -> 36 in the cache */

   /* ('sdot_2x16_iadd', 'a', 0, 'b') => b */
   /* search105_0 -> 16 in the cache */
   /* search105_1 -> 120 in the cache */
   /* search105_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace105 -> 36 in the cache */

   /* ('udot_2x16_uadd', 'a', 0, 'b') => b */
   /* search106_0 -> 16 in the cache */
   /* search106_1 -> 120 in the cache */
   /* search106_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace106 -> 36 in the cache */

   /* ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b */
   /* search107_0 -> 16 in the cache */
   /* search107_1 -> 120 in the cache */
   /* search107_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace107 -> 36 in the cache */

   /* ('udot_2x16_uadd_sat', 'a', 0, 'b') => b */
   /* search108_0 -> 16 in the cache */
   /* search108_1 -> 120 in the cache */
   /* search108_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 120, 36 },
      -1,
   } },

   /* replace108 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 'a', 0, 'b') => b */
   /* search109_0 -> 16 in the cache */
   /* search109_1 -> 120 in the cache */
   /* search109_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 120, 36 },
      -1,
   } },

   /* replace109 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 0, 'a', 'b') => b */
   /* search110_0 -> 120 in the cache */
   /* search110_1 -> 16 in the cache */
   /* search110_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 120, 16, 36 },
      -1,
   } },

   /* replace110 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search111_0 -> 16 in the cache */
   /* search111_1 -> 120 in the cache */
   /* search111_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 120, 36 },
      -1,
   } },

   /* replace111 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b */
   /* search112_0 -> 120 in the cache */
   /* search112_1 -> 16 in the cache */
   /* search112_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 120, 16, 36 },
      -1,
   } },

   /* replace112 -> 36 in the cache */

   /* ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search113_0_0 -> 16 in the cache */
   /* search113_0_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 294 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 295, 296 },
      -1,
   } },

   /* replace113_0 -> 16 in the cache */
   /* replace113_1 -> 36 in the cache */
   /* replace113_2_0 -> 133 in the cache */
   /* replace113_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 2,
      { 16, 36, 298 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search114_0_0 -> 16 in the cache */
   /* search114_0_1 -> 36 in the cache */
   /* search114_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 294 },
      0,
   } },
   /* search114_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 300, 296 },
      -1,
   } },

   /* replace114_0 -> 16 in the cache */
   /* replace114_1 -> 36 in the cache */
   /* replace114_2_0 -> 133 in the cache */
   /* replace114_2_1 -> 161 in the cache */
   /* replace114_2 -> 298 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 2,
      { 16, 36, 298 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search115_0_0 -> 16 in the cache */
   /* search115_0_1 -> 36 in the cache */
   /* search115_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 294 },
      0,
   } },
   /* search115_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 303, 296 },
      -1,
   } },

   /* replace115_0 -> 16 in the cache */
   /* replace115_1 -> 36 in the cache */
   /* replace115_2_0 -> 133 in the cache */
   /* replace115_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 1,
      { 16, 36, 305 },
      -1,
   } },

   /* ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search116_0_0 -> 16 in the cache */
   /* search116_0_1 -> 36 in the cache */
   /* search116_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 294 },
      0,
   } },
   /* search116_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 307, 296 },
      -1,
   } },

   /* replace116_0 -> 16 in the cache */
   /* replace116_1 -> 36 in the cache */
   /* replace116_2_0 -> 133 in the cache */
   /* replace116_2_1 -> 161 in the cache */
   /* replace116_2 -> 298 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 2,
      { 16, 36, 298 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search117_0_0 -> 16 in the cache */
   /* search117_0_1 -> 36 in the cache */
   /* search117_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 294 },
      0,
   } },
   /* search117_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 310, 296 },
      -1,
   } },

   /* replace117_0 -> 16 in the cache */
   /* replace117_1 -> 36 in the cache */
   /* replace117_2_0 -> 133 in the cache */
   /* replace117_2_1 -> 161 in the cache */
   /* replace117_2 -> 298 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 2,
      { 16, 36, 298 },
      -1,
   } },

   /* ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search118_0_1 -> 36 in the cache */
   /* search118_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 313, 36, 120 },
      -1,
   } },
   /* search118_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 314, 133 },
      -1,
   } },

   /* replace118_0 -> 16 in the cache */
   /* replace118_1 -> 36 in the cache */
   /* replace118_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search119_0_0 -> 313 in the cache */
   /* search119_0_1 -> 36 in the cache */
   /* search119_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 313, 36, 120 },
      -1,
   } },
   /* search119_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 317, 133 },
      -1,
   } },

   /* replace119_0 -> 16 in the cache */
   /* replace119_1 -> 36 in the cache */
   /* replace119_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search120_0_0 -> 313 in the cache */
   /* search120_0_1 -> 36 in the cache */
   /* search120_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 313, 36, 120 },
      -1,
   } },
   /* search120_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 320, 133 },
      -1,
   } },

   /* replace120_0 -> 16 in the cache */
   /* replace120_1 -> 36 in the cache */
   /* replace120_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search121_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search121_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 323, 120 },
      -1,
   } },
   /* search121_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 324, 133 },
      -1,
   } },

   /* replace121_0 -> 16 in the cache */
   /* replace121_1 -> 36 in the cache */
   /* replace121_2 -> 133 in the cache */
   /* replace121 -> 322 in the cache */

   /* ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c') */
   /* search122_0_0 -> 313 in the cache */
   /* search122_0_1 -> 36 in the cache */
   /* search122_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 313, 36, 120 },
      -1,
   } },
   /* search122_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 326, 133 },
      -1,
   } },

   /* replace122_0 -> 16 in the cache */
   /* replace122_1 -> 36 in the cache */
   /* replace122_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c') */
   /* search123_0_0 -> 313 in the cache */
   /* search123_0_1 -> 36 in the cache */
   /* search123_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 313, 36, 120 },
      -1,
   } },
   /* search123_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 329, 133 },
      -1,
   } },

   /* replace123_0 -> 16 in the cache */
   /* replace123_1 -> 36 in the cache */
   /* replace123_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search124_0 -> 271 in the cache */
   /* search124_1 -> 33 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace124_0_0 -> 16 in the cache */
   /* replace124_0_1 -> 36 in the cache */
   /* replace124_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace124_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 334, 133 },
      -1,
   } },

   /* ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search125_0 -> 271 in the cache */
   /* search125_1 -> 33 in the cache */
   /* search125_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace125_0_0 -> 16 in the cache */
   /* replace125_0_1 -> 36 in the cache */
   /* replace125_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace125_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 337, 133 },
      -1,
   } },

   /* ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search126_0 -> 271 in the cache */
   /* search126_1 -> 33 in the cache */
   /* search126_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 271, 33, 332 },
      -1,
   } },

   /* replace126_0_0 -> 16 in the cache */
   /* replace126_0_1 -> 36 in the cache */
   /* replace126_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 120 },
      -1,
   } },
   /* replace126_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 340, 133 },
      -1,
   } },

   /* ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search127_0 -> 271 in the cache */
   /* search127_1 -> 33 in the cache */
   /* search127_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace127_0_0 -> 16 in the cache */
   /* replace127_0_1 -> 36 in the cache */
   /* replace127_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace127_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 343, 133 },
      -1,
   } },

   /* ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search128_0 -> 271 in the cache */
   /* search128_1 -> 33 in the cache */
   /* search128_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace128_0_0 -> 16 in the cache */
   /* replace128_0_1 -> 36 in the cache */
   /* replace128_0_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 120 },
      -1,
   } },
   /* replace128_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 346, 133 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search129_0 -> 271 in the cache */
   /* search129_1 -> 33 in the cache */
   /* search129_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace129_0_0 -> 16 in the cache */
   /* replace129_0_1 -> 36 in the cache */
   /* replace129_0_2 -> 120 in the cache */
   /* replace129_0 -> 334 in the cache */
   /* replace129_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 334, 133 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search130_0 -> 271 in the cache */
   /* search130_1 -> 33 in the cache */
   /* search130_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace130_0_0 -> 16 in the cache */
   /* replace130_0_1 -> 36 in the cache */
   /* replace130_0_2 -> 120 in the cache */
   /* replace130_0 -> 337 in the cache */
   /* replace130_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 337, 133 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search131_0 -> 271 in the cache */
   /* search131_1 -> 33 in the cache */
   /* search131_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 271, 33, 332 },
      -1,
   } },

   /* replace131_0_0 -> 16 in the cache */
   /* replace131_0_1 -> 36 in the cache */
   /* replace131_0_2 -> 120 in the cache */
   /* replace131_0 -> 340 in the cache */
   /* replace131_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 340, 133 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search132_0 -> 271 in the cache */
   /* search132_1 -> 33 in the cache */
   /* search132_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace132_0_0 -> 16 in the cache */
   /* replace132_0_1 -> 36 in the cache */
   /* replace132_0_2 -> 120 in the cache */
   /* replace132_0 -> 343 in the cache */
   /* replace132_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 343, 133 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search133_0 -> 271 in the cache */
   /* search133_1 -> 33 in the cache */
   /* search133_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 271, 33, 332 },
      -1,
   } },

   /* replace133_0_0 -> 16 in the cache */
   /* replace133_0_1 -> 36 in the cache */
   /* replace133_0_2 -> 120 in the cache */
   /* replace133_0 -> 346 in the cache */
   /* replace133_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 346, 133 },
      -1,
   } },

   /* ('fmul@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search134_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      1, 1,
      { 358, 117 },
      -1,
   } },
   /* search134_0_1 -> 117 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 359, 117, 360 },
      -1,
   } },
   /* search134_1_0_0 -> 360 in the cache */
   /* search134_1_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      2, 1,
      { 360, 117 },
      -1,
   } },
   /* search134_1_1 -> 117 in the cache */
   /* search134_1_2 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 362, 117, 358 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 361, 363 },
      -1,
   } },

   /* replace134_0 -> 360 in the cache */
   /* replace134_1 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 360, 358 },
      -1,
   } },

   /* ('fmul@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b') */
   /* search135_0 -> 16 in the cache */
   /* search135_1_0_0 -> 16 in the cache */
   /* search135_1_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      1, 1,
      { 16, 117 },
      -1,
   } },
   /* search135_1_1 -> 117 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      6,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 366, 117, 367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 16, 368 },
      -1,
   } },

   /* replace135_0 -> 16 in the cache */
   /* replace135_1 -> 36 in the cache */
   /* replace135 -> 254 in the cache */

   /* ('ffma@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search136_0_0_0 -> 358 in the cache */
   /* search136_0_0_1 -> 117 in the cache */
   /* search136_0_0 -> 359 in the cache */
   /* search136_0_1 -> 117 in the cache */
   /* search136_0_2 -> 360 in the cache */
   /* search136_0 -> 361 in the cache */
   /* search136_1_0_0 -> 360 in the cache */
   /* search136_1_0_1 -> 117 in the cache */
   /* search136_1_0 -> 362 in the cache */
   /* search136_1_1 -> 117 in the cache */
   /* search136_1_2 -> 358 in the cache */
   /* search136_1 -> 363 in the cache */
   /* search136_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 361, 363, 133 },
      -1,
   } },

   /* replace136_0 -> 360 in the cache */
   /* replace136_1 -> 358 in the cache */
   /* replace136_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 360, 358, 133 },
      -1,
   } },

   /* ('ffma@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search137_0 -> 16 in the cache */
   /* search137_1_0_0 -> 16 in the cache */
   /* search137_1_0_1 -> 117 in the cache */
   /* search137_1_0 -> 366 in the cache */
   /* search137_1_1 -> 117 in the cache */
   /* search137_1_2 -> 367 in the cache */
   /* search137_1 -> 368 in the cache */
   /* search137_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 16, 368, 133 },
      -1,
   } },

   /* replace137_0 -> 16 in the cache */
   /* replace137_1 -> 36 in the cache */
   /* replace137_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search138_0 -> 16 in the cache */
   /* search138_1 -> 36 in the cache */
   /* search138_2 -> 133 in the cache */
   /* search138 -> 316 in the cache */

   /* replace138_0_0_0_0_0 -> 16 in the cache */
   /* replace138_0_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace138_0_0_0_1_0 -> 36 in the cache */
   /* replace138_0_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 374, 375 },
      -1,
   } },
   /* replace138_0_0_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* replace138_0_0_1_1_0 -> 36 in the cache */
   /* replace138_0_0_1_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 378, 379 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 376, 380 },
      -1,
   } },
   /* replace138_0_1_0_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 382 },
      -1,
   } },
   /* replace138_0_1_0_1_0 -> 36 in the cache */
   /* replace138_0_1_0_1_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 383, 384 },
      -1,
   } },
   /* replace138_0_1_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 386 },
      -1,
   } },
   /* replace138_0_1_1_1_0 -> 36 in the cache */
   /* replace138_0_1_1_1_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 387, 388 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 385, 389 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 381, 390 },
      -1,
   } },
   /* replace138_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 391, 133 },
      -1,
   } },

   /* ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search139_0 -> 16 in the cache */
   /* search139_1 -> 36 in the cache */
   /* search139_2 -> 133 in the cache */
   /* search139 -> 319 in the cache */

   /* replace139_0_0_0_0_0 -> 16 in the cache */
   /* replace139_0_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace139_0_0_0_1_0 -> 36 in the cache */
   /* replace139_0_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 393, 394 },
      -1,
   } },
   /* replace139_0_0_1_0_0 -> 16 in the cache */
   /* replace139_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* replace139_0_0_1_1_0 -> 36 in the cache */
   /* replace139_0_0_1_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 396, 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 395, 398 },
      -1,
   } },
   /* replace139_0_1_0_0_0 -> 16 in the cache */
   /* replace139_0_1_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 382 },
      -1,
   } },
   /* replace139_0_1_0_1_0 -> 36 in the cache */
   /* replace139_0_1_0_1_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 400, 401 },
      -1,
   } },
   /* replace139_0_1_1_0_0 -> 16 in the cache */
   /* replace139_0_1_1_0_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 386 },
      -1,
   } },
   /* replace139_0_1_1_1_0 -> 36 in the cache */
   /* replace139_0_1_1_1_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 403, 404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 402, 405 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 399, 406 },
      -1,
   } },
   /* replace139_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 407, 133 },
      -1,
   } },

   /* ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search140_0 -> 16 in the cache */
   /* search140_1 -> 36 in the cache */
   /* search140_2 -> 133 in the cache */
   /* search140 -> 322 in the cache */

   /* replace140_0_0_0_0_0 -> 16 in the cache */
   /* replace140_0_0_0_0_1 -> 120 in the cache */
   /* replace140_0_0_0_0 -> 374 in the cache */
   /* replace140_0_0_0_1_0 -> 36 in the cache */
   /* replace140_0_0_0_1_1 -> 120 in the cache */
   /* replace140_0_0_0_1 -> 394 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 374, 394 },
      -1,
   } },
   /* replace140_0_0_1_0_0 -> 16 in the cache */
   /* replace140_0_0_1_0_1 -> 377 in the cache */
   /* replace140_0_0_1_0 -> 378 in the cache */
   /* replace140_0_0_1_1_0 -> 36 in the cache */
   /* replace140_0_0_1_1_1 -> 377 in the cache */
   /* replace140_0_0_1_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 378, 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 409, 410 },
      -1,
   } },
   /* replace140_0_1_0_0_0 -> 16 in the cache */
   /* replace140_0_1_0_0_1 -> 382 in the cache */
   /* replace140_0_1_0_0 -> 383 in the cache */
   /* replace140_0_1_0_1_0 -> 36 in the cache */
   /* replace140_0_1_0_1_1 -> 382 in the cache */
   /* replace140_0_1_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 383, 401 },
      -1,
   } },
   /* replace140_0_1_1_0_0 -> 16 in the cache */
   /* replace140_0_1_1_0_1 -> 386 in the cache */
   /* replace140_0_1_1_0 -> 387 in the cache */
   /* replace140_0_1_1_1_0 -> 36 in the cache */
   /* replace140_0_1_1_1_1 -> 386 in the cache */
   /* replace140_0_1_1_1 -> 404 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 387, 404 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 412, 413 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 411, 414 },
      -1,
   } },
   /* replace140_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 415, 133 },
      -1,
   } },

   /* ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search141_0 -> 16 in the cache */
   /* search141_1 -> 36 in the cache */
   /* search141_2 -> 133 in the cache */
   /* search141 -> 328 in the cache */

   /* replace141_0_0_0_0 -> 16 in the cache */
   /* replace141_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace141_0_0_1_0 -> 36 in the cache */
   /* replace141_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 417, 418 },
      -1,
   } },
   /* replace141_0_1_0_0 -> 16 in the cache */
   /* replace141_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* replace141_0_1_1_0 -> 36 in the cache */
   /* replace141_0_1_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 420, 421 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 419, 422 },
      -1,
   } },
   /* replace141_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 423, 133 },
      -1,
   } },

   /* ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search142_0 -> 16 in the cache */
   /* search142_1 -> 36 in the cache */
   /* search142_2 -> 133 in the cache */
   /* search142 -> 331 in the cache */

   /* replace142_0_0_0_0 -> 16 in the cache */
   /* replace142_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace142_0_0_1_0 -> 36 in the cache */
   /* replace142_0_0_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 425, 426 },
      -1,
   } },
   /* replace142_0_1_0_0 -> 16 in the cache */
   /* replace142_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* replace142_0_1_1_0 -> 36 in the cache */
   /* replace142_0_1_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 428, 429 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 427, 430 },
      -1,
   } },
   /* replace142_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 431, 133 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search143_0 -> 16 in the cache */
   /* search143_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      7,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 433 },
      -1,
   } },

   /* replace143_0 -> 16 in the cache */
   /* replace143_1 -> 36 in the cache */
   /* replace143_2 -> 133 in the cache */
   /* replace143 -> 319 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search144_0 -> 16 in the cache */
   /* search144_1 -> 36 in the cache */
   /* search144_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace144_0_0_0_0_0 -> 16 in the cache */
   /* replace144_0_0_0_0_1 -> 120 in the cache */
   /* replace144_0_0_0_0 -> 393 in the cache */
   /* replace144_0_0_0_1_0 -> 36 in the cache */
   /* replace144_0_0_0_1_1 -> 120 in the cache */
   /* replace144_0_0_0_1 -> 394 in the cache */
   /* replace144_0_0_0 -> 395 in the cache */
   /* replace144_0_0_1_0_0 -> 16 in the cache */
   /* replace144_0_0_1_0_1 -> 377 in the cache */
   /* replace144_0_0_1_0 -> 396 in the cache */
   /* replace144_0_0_1_1_0 -> 36 in the cache */
   /* replace144_0_0_1_1_1 -> 377 in the cache */
   /* replace144_0_0_1_1 -> 397 in the cache */
   /* replace144_0_0_1 -> 398 in the cache */
   /* replace144_0_0 -> 399 in the cache */
   /* replace144_0_1_0_0_0 -> 16 in the cache */
   /* replace144_0_1_0_0_1 -> 382 in the cache */
   /* replace144_0_1_0_0 -> 400 in the cache */
   /* replace144_0_1_0_1_0 -> 36 in the cache */
   /* replace144_0_1_0_1_1 -> 382 in the cache */
   /* replace144_0_1_0_1 -> 401 in the cache */
   /* replace144_0_1_0 -> 402 in the cache */
   /* replace144_0_1_1_0_0 -> 16 in the cache */
   /* replace144_0_1_1_0_1 -> 386 in the cache */
   /* replace144_0_1_1_0 -> 403 in the cache */
   /* replace144_0_1_1_1_0 -> 36 in the cache */
   /* replace144_0_1_1_1_1 -> 386 in the cache */
   /* replace144_0_1_1_1 -> 404 in the cache */
   /* replace144_0_1_1 -> 405 in the cache */
   /* replace144_0_1 -> 406 in the cache */
   /* replace144_0 -> 407 in the cache */
   /* replace144_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 8,
      { 407, 133 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search145_0 -> 16 in the cache */
   /* search145_1 -> 36 in the cache */
   /* search145_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace145_0_0_0_0_0 -> 16 in the cache */
   /* replace145_0_0_0_0_1 -> 120 in the cache */
   /* replace145_0_0_0_0 -> 374 in the cache */
   /* replace145_0_0_0_1_0 -> 36 in the cache */
   /* replace145_0_0_0_1_1 -> 120 in the cache */
   /* replace145_0_0_0_1 -> 375 in the cache */
   /* replace145_0_0_0 -> 376 in the cache */
   /* replace145_0_0_1_0_0 -> 16 in the cache */
   /* replace145_0_0_1_0_1 -> 377 in the cache */
   /* replace145_0_0_1_0 -> 378 in the cache */
   /* replace145_0_0_1_1_0 -> 36 in the cache */
   /* replace145_0_0_1_1_1 -> 377 in the cache */
   /* replace145_0_0_1_1 -> 379 in the cache */
   /* replace145_0_0_1 -> 380 in the cache */
   /* replace145_0_0 -> 381 in the cache */
   /* replace145_0_1_0_0_0 -> 16 in the cache */
   /* replace145_0_1_0_0_1 -> 382 in the cache */
   /* replace145_0_1_0_0 -> 383 in the cache */
   /* replace145_0_1_0_1_0 -> 36 in the cache */
   /* replace145_0_1_0_1_1 -> 382 in the cache */
   /* replace145_0_1_0_1 -> 384 in the cache */
   /* replace145_0_1_0 -> 385 in the cache */
   /* replace145_0_1_1_0_0 -> 16 in the cache */
   /* replace145_0_1_1_0_1 -> 386 in the cache */
   /* replace145_0_1_1_0 -> 387 in the cache */
   /* replace145_0_1_1_1_0 -> 36 in the cache */
   /* replace145_0_1_1_1_1 -> 386 in the cache */
   /* replace145_0_1_1_1 -> 388 in the cache */
   /* replace145_0_1_1 -> 389 in the cache */
   /* replace145_0_1 -> 390 in the cache */
   /* replace145_0 -> 391 in the cache */
   /* replace145_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 8,
      { 391, 133 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search146_0 -> 16 in the cache */
   /* search146_1 -> 36 in the cache */
   /* search146_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* replace146_0_0_0_0_0 -> 16 in the cache */
   /* replace146_0_0_0_0_1 -> 120 in the cache */
   /* replace146_0_0_0_0 -> 374 in the cache */
   /* replace146_0_0_0_1_0 -> 36 in the cache */
   /* replace146_0_0_0_1_1 -> 120 in the cache */
   /* replace146_0_0_0_1 -> 394 in the cache */
   /* replace146_0_0_0 -> 409 in the cache */
   /* replace146_0_0_1_0_0 -> 16 in the cache */
   /* replace146_0_0_1_0_1 -> 377 in the cache */
   /* replace146_0_0_1_0 -> 378 in the cache */
   /* replace146_0_0_1_1_0 -> 36 in the cache */
   /* replace146_0_0_1_1_1 -> 377 in the cache */
   /* replace146_0_0_1_1 -> 397 in the cache */
   /* replace146_0_0_1 -> 410 in the cache */
   /* replace146_0_0 -> 411 in the cache */
   /* replace146_0_1_0_0_0 -> 16 in the cache */
   /* replace146_0_1_0_0_1 -> 382 in the cache */
   /* replace146_0_1_0_0 -> 383 in the cache */
   /* replace146_0_1_0_1_0 -> 36 in the cache */
   /* replace146_0_1_0_1_1 -> 382 in the cache */
   /* replace146_0_1_0_1 -> 401 in the cache */
   /* replace146_0_1_0 -> 412 in the cache */
   /* replace146_0_1_1_0_0 -> 16 in the cache */
   /* replace146_0_1_1_0_1 -> 386 in the cache */
   /* replace146_0_1_1_0 -> 387 in the cache */
   /* replace146_0_1_1_1_0 -> 36 in the cache */
   /* replace146_0_1_1_1_1 -> 386 in the cache */
   /* replace146_0_1_1_1 -> 404 in the cache */
   /* replace146_0_1_1 -> 413 in the cache */
   /* replace146_0_1 -> 414 in the cache */
   /* replace146_0 -> 415 in the cache */
   /* replace146_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 8,
      { 415, 133 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search147_0 -> 16 in the cache */
   /* search147_1 -> 36 in the cache */
   /* search147_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace147_0_0_0_0 -> 16 in the cache */
   /* replace147_0_0_0_1 -> 120 in the cache */
   /* replace147_0_0_0 -> 425 in the cache */
   /* replace147_0_0_1_0 -> 36 in the cache */
   /* replace147_0_0_1_1 -> 120 in the cache */
   /* replace147_0_0_1 -> 426 in the cache */
   /* replace147_0_0 -> 427 in the cache */
   /* replace147_0_1_0_0 -> 16 in the cache */
   /* replace147_0_1_0_1 -> 377 in the cache */
   /* replace147_0_1_0 -> 428 in the cache */
   /* replace147_0_1_1_0 -> 36 in the cache */
   /* replace147_0_1_1_1 -> 377 in the cache */
   /* replace147_0_1_1 -> 429 in the cache */
   /* replace147_0_1 -> 430 in the cache */
   /* replace147_0 -> 431 in the cache */
   /* replace147_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 4,
      { 431, 133 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search148_0 -> 16 in the cache */
   /* search148_1 -> 36 in the cache */
   /* search148_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace148_0_0_0_0 -> 16 in the cache */
   /* replace148_0_0_0_1 -> 120 in the cache */
   /* replace148_0_0_0 -> 417 in the cache */
   /* replace148_0_0_1_0 -> 36 in the cache */
   /* replace148_0_0_1_1 -> 120 in the cache */
   /* replace148_0_0_1 -> 418 in the cache */
   /* replace148_0_0 -> 419 in the cache */
   /* replace148_0_1_0_0 -> 16 in the cache */
   /* replace148_0_1_0_1 -> 377 in the cache */
   /* replace148_0_1_0 -> 420 in the cache */
   /* replace148_0_1_1_0 -> 36 in the cache */
   /* replace148_0_1_1_1 -> 377 in the cache */
   /* replace148_0_1_1 -> 421 in the cache */
   /* replace148_0_1 -> 422 in the cache */
   /* replace148_0 -> 423 in the cache */
   /* replace148_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 4,
      { 423, 133 },
      -1,
   } },

   /* ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search149_0 -> 11 in the cache */
   /* search149_1 -> 243 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 243, 446 },
      -1,
   } },

   /* replace149_0 -> 445 in the cache */
   /* replace149_1 -> 243 in the cache */
   /* replace149_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 445, 243, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search150_0 -> 11 in the cache */
   /* search150_1_0 -> 11 in the cache */
   /* search150_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 243 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 11, 449, 450 },
      -1,
   } },

   /* replace150_0_0 -> 243 in the cache */
   /* replace150_0_1 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 243, 450 },
      -1,
   } },
   /* replace150_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 452, 11 },
      -1,
   } },

   /* ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search151_0_0 -> 11 in the cache */
   /* search151_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 243 },
      0,
   } },
   /* search151_1_0 -> 11 in the cache */
   /* search151_1_1 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 11, 450 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 454, 455, 456 },
      -1,
   } },

   /* replace151_0_0 -> 243 in the cache */
   /* replace151_0_1 -> 450 in the cache */
   /* replace151_0_2 -> 456 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 243, 450, 456 },
      -1,
   } },
   /* replace151_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 458, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search152_0 -> 11 in the cache */
   /* search152_1_0 -> 11 in the cache */
   /* search152_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 243 },
      0,
   } },
   /* search152_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 11, 460, 450 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace152_0_1 -> 243 in the cache */
   /* replace152_0_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 462, 243, 450 },
      -1,
   } },
   /* replace152_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 463, 11 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search153_0_0 -> 11 in the cache */
   /* search153_0_1_0 -> 462 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 462, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 467 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search153_1_1 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 469, 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 468, 470 },
      -1,
   } },

   /* replace153_0 -> 11 in the cache */
   /* replace153_1 -> 469 in the cache */
   /* replace153_2 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 469, 465 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search154_0_0 -> 11 in the cache */
   /* search154_0_1_0_0 -> 462 in the cache */
   /* search154_0_1_0_1_0 -> 465 in the cache */
   /* search154_0_1_0_1 -> 466 in the cache */
   /* search154_0_1_0 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 473 },
      -1,
   } },
   /* search154_1_0 -> 469 in the cache */
   /* search154_1_1_0 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 469, 475 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 474, 476 },
      -1,
   } },

   /* replace154_0 -> 11 in the cache */
   /* replace154_1 -> 469 in the cache */
   /* replace154_2_0 -> 465 in the cache */
   /* replace154_2 -> 475 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 469, 475 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search155_0 -> 11 in the cache */
   /* search155_1_0 -> 465 in the cache */
   /* search155_1_1_0 -> 469 in the cache */
   /* search155_1_1_1_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 469, 479 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 465, 480 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 11, 481 },
      -1,
   } },

   /* replace155_0 -> 11 in the cache */
   /* replace155_1 -> 469 in the cache */
   /* replace155_2 -> 465 in the cache */
   /* replace155 -> 472 in the cache */

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search156_0_0 -> 11 in the cache */
   /* search156_0_1_0 -> 462 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 462, 485 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 486 },
      -1,
   } },
   /* search156_1_0 -> 469 in the cache */
   /* search156_1_1_0 -> 483 in the cache */
   /* search156_1_1 -> 484 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 469, 484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 487, 488 },
      -1,
   } },

   /* replace156_0 -> 483 in the cache */
   /* replace156_1 -> 469 in the cache */
   /* replace156_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 469, 11 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search157_0 -> 11 in the cache */
   /* search157_1_0_0 -> 483 in the cache */
   /* search157_1_0 -> 484 in the cache */
   /* search157_1_1_0 -> 469 in the cache */
   /* search157_1_1_1_0 -> 11 in the cache */
   /* search157_1_1_1 -> 479 in the cache */
   /* search157_1_1 -> 480 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 484, 480 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 11, 491 },
      -1,
   } },

   /* replace157_0 -> 483 in the cache */
   /* replace157_1 -> 469 in the cache */
   /* replace157_2 -> 11 in the cache */
   /* replace157 -> 490 in the cache */

   /* ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search158_0 -> 11 in the cache */
   /* search158_1_0 -> 462 in the cache */
   /* search158_1_1_0_0 -> 483 in the cache */
   /* search158_1_1_0 -> 484 in the cache */
   /* search158_1_1 -> 485 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 462, 485 },
      -1,
   } },
   /* search158_2_0 -> 469 in the cache */
   /* search158_2_1_0 -> 483 in the cache */
   /* search158_2_1 -> 484 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 469, 484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 11, 493, 494 },
      -1,
   } },

   /* replace158_0 -> 483 in the cache */
   /* replace158_1 -> 469 in the cache */
   /* replace158_2 -> 11 in the cache */
   /* replace158 -> 490 in the cache */

   /* ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search159_1_0 -> 483 in the cache */
   /* search159_1 -> 484 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 497 },
      -1,
   } },
   /* search159_2_1_0 -> 483 in the cache */
   /* search159_2_1 -> 484 in the cache */
   /* search159_2_2 -> 497 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 498, 484, 497 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 496, 484, 499 },
      -1,
   } },

   /* replace159_0 -> 483 in the cache */
   /* replace159_1 -> 496 in the cache */
   /* replace159_2 -> 497 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 496, 497 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 502 },
      -1,
   } },
   /* search160_1_0 -> 243 in the cache */
   /* search160_1_1_0 -> 497 in the cache */
   /* search160_1_1 -> 498 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 243, 498 },
      -1,
   } },
   /* search160_2 -> 497 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 503, 504, 497 },
      -1,
   } },

   /* replace160_0 -> 502 in the cache */
   /* replace160_1 -> 243 in the cache */
   /* replace160_2 -> 497 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 243, 497 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search161_0_0 -> 502 in the cache */
   /* search161_0 -> 503 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 507 },
      -1,
   } },
   /* search161_1_1 -> 469 in the cache */
   /* search161_1_2 -> 456 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 508, 469, 456 },
      -1,
   } },
   /* search161_2_0 -> 507 in the cache */
   /* search161_2_1 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 507, 469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 503, 509, 510 },
      -1,
   } },

   /* replace161_0 -> 502 in the cache */
   /* replace161_1 -> 456 in the cache */
   /* replace161_2_0 -> 507 in the cache */
   /* replace161_2_1 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 507, 469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 502, 456, 512 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search162_0 -> 462 in the cache */
   /* search162_1_0_0_0 -> 462 in the cache */
   /* search162_1_0_0_1_0 -> 11 in the cache */
   /* search162_1_0_0_1 -> 479 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 462, 479 },
      -1,
   } },
   /* search162_1_0_1_0 -> 462 in the cache */
   /* search162_1_0_1_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 462, 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 514, 516 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 517 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 462, 518 },
      -1,
   } },

   /* replace162_0 -> 243 in the cache */
   /* replace162_1 -> 462 in the cache */
   /* replace162_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 243, 462, 11 },
      -1,
   } },

   /* ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search163_0 -> 16 in the cache */
   /* search163_1 -> 36 in the cache */
   /* search163_2_0 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 36, 521 },
      -1,
   } },

   /* replace163_0 -> 445 in the cache */
   /* replace163_1 -> 36 in the cache */
   /* replace163_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 445, 36, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search164_0 -> 16 in the cache */
   /* search164_1_0 -> 16 in the cache */
   /* search164_1_1 -> 36 in the cache */
   /* search164_1 -> 259 in the cache */
   /* search164_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 16, 259, 133 },
      -1,
   } },

   /* replace164_0_0 -> 36 in the cache */
   /* replace164_0_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 36, 133 },
      -1,
   } },
   /* replace164_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 525, 16 },
      -1,
   } },

   /* ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search165_0_0 -> 16 in the cache */
   /* search165_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search165_1_0 -> 16 in the cache */
   /* search165_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 133 },
      0,
   } },
   /* search165_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 527, 528, 161 },
      -1,
   } },

   /* replace165_0_0 -> 36 in the cache */
   /* replace165_0_1 -> 133 in the cache */
   /* replace165_0_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 36, 133, 161 },
      -1,
   } },
   /* replace165_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 530, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search166_0 -> 16 in the cache */
   /* search166_1_0 -> 16 in the cache */
   /* search166_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search166_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 16, 532, 133 },
      -1,
   } },

   /* replace166_0_0 -> 228 in the cache */
   /* replace166_0_1 -> 36 in the cache */
   /* replace166_0_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 228, 36, 133 },
      -1,
   } },
   /* replace166_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 534, 16 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search167_0_0 -> 16 in the cache */
   /* search167_0_1_0 -> 228 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 228, 537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 538 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search167_1_1 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 540, 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 539, 541 },
      -1,
   } },

   /* replace167_0 -> 16 in the cache */
   /* replace167_1 -> 540 in the cache */
   /* replace167_2 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 540, 536 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search168_0_0 -> 16 in the cache */
   /* search168_0_1_0_0 -> 228 in the cache */
   /* search168_0_1_0_1_0 -> 536 in the cache */
   /* search168_0_1_0_1 -> 537 in the cache */
   /* search168_0_1_0 -> 538 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 538 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 544 },
      -1,
   } },
   /* search168_1_0 -> 540 in the cache */
   /* search168_1_1_0 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 540, 546 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 545, 547 },
      -1,
   } },

   /* replace168_0 -> 16 in the cache */
   /* replace168_1 -> 540 in the cache */
   /* replace168_2_0 -> 536 in the cache */
   /* replace168_2 -> 546 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 540, 546 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search169_0 -> 16 in the cache */
   /* search169_1_0 -> 536 in the cache */
   /* search169_1_1_0 -> 540 in the cache */
   /* search169_1_1_1_0 -> 16 in the cache */
   /* search169_1_1_1 -> 265 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 540, 265 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 536, 550 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 16, 551 },
      -1,
   } },

   /* replace169_0 -> 16 in the cache */
   /* replace169_1 -> 540 in the cache */
   /* replace169_2 -> 536 in the cache */
   /* replace169 -> 543 in the cache */

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search170_0_0 -> 16 in the cache */
   /* search170_0_1_0 -> 228 in the cache */
   /* search170_0_1_1_0_0 -> 483 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 228, 554 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 555 },
      -1,
   } },
   /* search170_1_0 -> 540 in the cache */
   /* search170_1_1_0 -> 483 in the cache */
   /* search170_1_1 -> 553 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 540, 553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 556, 557 },
      -1,
   } },

   /* replace170_0 -> 483 in the cache */
   /* replace170_1 -> 540 in the cache */
   /* replace170_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 540, 16 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search171_0 -> 16 in the cache */
   /* search171_1_0_0 -> 483 in the cache */
   /* search171_1_0 -> 553 in the cache */
   /* search171_1_1_0 -> 540 in the cache */
   /* search171_1_1_1_0 -> 16 in the cache */
   /* search171_1_1_1 -> 265 in the cache */
   /* search171_1_1 -> 550 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 553, 550 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 16, 560 },
      -1,
   } },

   /* replace171_0 -> 483 in the cache */
   /* replace171_1 -> 540 in the cache */
   /* replace171_2 -> 16 in the cache */
   /* replace171 -> 559 in the cache */

   /* ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search172_0 -> 16 in the cache */
   /* search172_1_0 -> 228 in the cache */
   /* search172_1_1_0_0 -> 483 in the cache */
   /* search172_1_1_0 -> 553 in the cache */
   /* search172_1_1 -> 554 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 228, 554 },
      -1,
   } },
   /* search172_2_0 -> 540 in the cache */
   /* search172_2_1_0 -> 483 in the cache */
   /* search172_2_1 -> 553 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 540, 553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 16, 562, 563 },
      -1,
   } },

   /* replace172_0 -> 483 in the cache */
   /* replace172_1 -> 540 in the cache */
   /* replace172_2 -> 16 in the cache */
   /* replace172 -> 559 in the cache */

   /* ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   /* search173_0 -> 358 in the cache */
   /* search173_1_0 -> 483 in the cache */
   /* search173_1 -> 553 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 565 },
      -1,
   } },
   /* search173_2_1_0 -> 483 in the cache */
   /* search173_2_1 -> 553 in the cache */
   /* search173_2_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 566, 553, 565 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 358, 553, 567 },
      -1,
   } },

   /* replace173_0 -> 483 in the cache */
   /* replace173_1 -> 358 in the cache */
   /* replace173_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 358, 565 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search174_0_0 -> 502 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 502 },
      -1,
   } },
   /* search174_1_0 -> 36 in the cache */
   /* search174_1_1_0 -> 565 in the cache */
   /* search174_1_1 -> 566 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 566 },
      -1,
   } },
   /* search174_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 570, 571, 565 },
      -1,
   } },

   /* replace174_0 -> 502 in the cache */
   /* replace174_1 -> 36 in the cache */
   /* replace174_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 36, 565 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search175_0_0 -> 502 in the cache */
   /* search175_0 -> 570 in the cache */
   /* search175_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 360 },
      -1,
   } },
   /* search175_1_1 -> 540 in the cache */
   /* search175_1_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 574, 540, 161 },
      -1,
   } },
   /* search175_2_0 -> 360 in the cache */
   /* search175_2_1 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 360, 540 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 570, 575, 576 },
      -1,
   } },

   /* replace175_0 -> 502 in the cache */
   /* replace175_1 -> 161 in the cache */
   /* replace175_2_0 -> 360 in the cache */
   /* replace175_2_1 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 360, 540 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 502, 161, 578 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search176_0 -> 228 in the cache */
   /* search176_1_0_0_0 -> 228 in the cache */
   /* search176_1_0_0_1_0 -> 16 in the cache */
   /* search176_1_0_0_1 -> 265 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 228, 265 },
      -1,
   } },
   /* search176_1_0_1_0 -> 228 in the cache */
   /* search176_1_0_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 228, 581 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 580, 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 583 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 228, 584 },
      -1,
   } },

   /* replace176_0 -> 36 in the cache */
   /* replace176_1 -> 228 in the cache */
   /* replace176_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 36, 228, 16 },
      -1,
   } },

   /* ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search177_0 -> 21 in the cache */
   /* search177_1 -> 41 in the cache */
   /* search177_2_0 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 41, 587 },
      -1,
   } },

   /* replace177_0 -> 445 in the cache */
   /* replace177_1 -> 41 in the cache */
   /* replace177_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 445, 41, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search178_0 -> 21 in the cache */
   /* search178_1_0 -> 21 in the cache */
   /* search178_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 21, 590, 591 },
      -1,
   } },

   /* replace178_0_0 -> 41 in the cache */
   /* replace178_0_1 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 41, 591 },
      -1,
   } },
   /* replace178_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 593, 21 },
      -1,
   } },

   /* ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search179_0_0 -> 21 in the cache */
   /* search179_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search179_1_0 -> 21 in the cache */
   /* search179_1_1 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 21, 591 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 595, 596, 597 },
      -1,
   } },

   /* replace179_0_0 -> 41 in the cache */
   /* replace179_0_1 -> 591 in the cache */
   /* replace179_0_2 -> 597 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 41, 591, 597 },
      -1,
   } },
   /* replace179_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 599, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search180_0 -> 21 in the cache */
   /* search180_1_0 -> 21 in the cache */
   /* search180_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search180_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 21, 601, 591 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace180_0_1 -> 41 in the cache */
   /* replace180_0_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 603, 41, 591 },
      -1,
   } },
   /* replace180_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 604, 21 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search181_0_0 -> 21 in the cache */
   /* search181_0_1_0 -> 603 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 606 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 603, 607 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 608 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search181_1_1 -> 606 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 610, 606 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 609, 611 },
      -1,
   } },

   /* replace181_0 -> 21 in the cache */
   /* replace181_1 -> 610 in the cache */
   /* replace181_2 -> 606 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 610, 606 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search182_0_0 -> 21 in the cache */
   /* search182_0_1_0_0 -> 603 in the cache */
   /* search182_0_1_0_1_0 -> 606 in the cache */
   /* search182_0_1_0_1 -> 607 in the cache */
   /* search182_0_1_0 -> 608 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 608 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 614 },
      -1,
   } },
   /* search182_1_0 -> 610 in the cache */
   /* search182_1_1_0 -> 606 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 606 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 610, 616 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 615, 617 },
      -1,
   } },

   /* replace182_0 -> 21 in the cache */
   /* replace182_1 -> 610 in the cache */
   /* replace182_2_0 -> 606 in the cache */
   /* replace182_2 -> 616 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 610, 616 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search183_0 -> 21 in the cache */
   /* search183_1_0 -> 606 in the cache */
   /* search183_1_1_0 -> 610 in the cache */
   /* search183_1_1_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 610, 620 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 606, 621 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 21, 622 },
      -1,
   } },

   /* replace183_0 -> 21 in the cache */
   /* replace183_1 -> 610 in the cache */
   /* replace183_2 -> 606 in the cache */
   /* replace183 -> 613 in the cache */

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search184_0_0 -> 21 in the cache */
   /* search184_0_1_0 -> 603 in the cache */
   /* search184_0_1_1_0_0 -> 483 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 624 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 603, 625 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 626 },
      -1,
   } },
   /* search184_1_0 -> 610 in the cache */
   /* search184_1_1_0 -> 483 in the cache */
   /* search184_1_1 -> 624 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 610, 624 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 627, 628 },
      -1,
   } },

   /* replace184_0 -> 483 in the cache */
   /* replace184_1 -> 610 in the cache */
   /* replace184_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 610, 21 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search185_0 -> 21 in the cache */
   /* search185_1_0_0 -> 483 in the cache */
   /* search185_1_0 -> 624 in the cache */
   /* search185_1_1_0 -> 610 in the cache */
   /* search185_1_1_1_0 -> 21 in the cache */
   /* search185_1_1_1 -> 620 in the cache */
   /* search185_1_1 -> 621 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 624, 621 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 21, 631 },
      -1,
   } },

   /* replace185_0 -> 483 in the cache */
   /* replace185_1 -> 610 in the cache */
   /* replace185_2 -> 21 in the cache */
   /* replace185 -> 630 in the cache */

   /* ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search186_0 -> 21 in the cache */
   /* search186_1_0 -> 603 in the cache */
   /* search186_1_1_0_0 -> 483 in the cache */
   /* search186_1_1_0 -> 624 in the cache */
   /* search186_1_1 -> 625 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 603, 625 },
      -1,
   } },
   /* search186_2_0 -> 610 in the cache */
   /* search186_2_1_0 -> 483 in the cache */
   /* search186_2_1 -> 624 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 610, 624 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 21, 633, 634 },
      -1,
   } },

   /* replace186_0 -> 483 in the cache */
   /* replace186_1 -> 610 in the cache */
   /* replace186_2 -> 21 in the cache */
   /* replace186 -> 630 in the cache */

   /* ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search187_1_0 -> 483 in the cache */
   /* search187_1 -> 624 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 637 },
      -1,
   } },
   /* search187_2_1_0 -> 483 in the cache */
   /* search187_2_1 -> 624 in the cache */
   /* search187_2_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 638, 624, 637 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 636, 624, 639 },
      -1,
   } },

   /* replace187_0 -> 483 in the cache */
   /* replace187_1 -> 636 in the cache */
   /* replace187_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 483, 636, 637 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search188_0_0 -> 502 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 502 },
      -1,
   } },
   /* search188_1_0 -> 41 in the cache */
   /* search188_1_1_0 -> 637 in the cache */
   /* search188_1_1 -> 638 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 41, 638 },
      -1,
   } },
   /* search188_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 642, 643, 637 },
      -1,
   } },

   /* replace188_0 -> 502 in the cache */
   /* replace188_1 -> 41 in the cache */
   /* replace188_2 -> 637 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 41, 637 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search189_0_0 -> 502 in the cache */
   /* search189_0 -> 642 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 646 },
      -1,
   } },
   /* search189_1_1 -> 610 in the cache */
   /* search189_1_2 -> 597 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 647, 610, 597 },
      -1,
   } },
   /* search189_2_0 -> 646 in the cache */
   /* search189_2_1 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 646, 610 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 642, 648, 649 },
      -1,
   } },

   /* replace189_0 -> 502 in the cache */
   /* replace189_1 -> 597 in the cache */
   /* replace189_2_0 -> 646 in the cache */
   /* replace189_2_1 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 646, 610 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 502, 597, 651 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search190_0 -> 603 in the cache */
   /* search190_1_0_0_0 -> 603 in the cache */
   /* search190_1_0_0_1_0 -> 21 in the cache */
   /* search190_1_0_0_1 -> 620 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 603, 620 },
      -1,
   } },
   /* search190_1_0_1_0 -> 603 in the cache */
   /* search190_1_0_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 603, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 653, 655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 656 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 603, 657 },
      -1,
   } },

   /* replace190_0 -> 41 in the cache */
   /* replace190_1 -> 603 in the cache */
   /* replace190_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 41, 603, 21 },
      -1,
   } },

   /* ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search191_0_0 -> 147 in the cache */
   /* search191_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 147, 148 },
      0,
   } },
   /* search191_1_0 -> 147 in the cache */
   /* search191_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 147, 150 },
      0,
   } },
   /* search191_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 660, 661, 151 },
      -1,
   } },

   /* replace191_0_0 -> 148 in the cache */
   /* replace191_0_1 -> 150 in the cache */
   /* replace191_0_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 148, 150, 151 },
      -1,
   } },
   /* replace191_1 -> 147 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 663, 147 },
      -1,
   } },

   /* ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a') */
   /* search192_0 -> 0 in the cache */
   /* search192_1 -> 241 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 241, 665 },
      -1,
   } },

   /* replace192_0_0_0 -> 0 in the cache */
   /* replace192_0_0 -> 197 in the cache */
   /* replace192_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 197, 665 },
      -1,
   } },
   /* replace192_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 667, 0 },
      -1,
   } },

   /* ('ftrunc', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search193_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace193_0_0 -> 32 in the cache */
   /* replace193_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 113 },
      -1,
   } },
   /* replace193_1_0_0_0 -> 32 in the cache */
   /* replace193_1_0_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 103 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 671 },
      -1,
   } },
   /* replace193_2_0_0 -> 32 in the cache */
   /* replace193_2_0 -> 103 in the cache */
   /* replace193_2 -> 671 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 670, 672, 671 },
      -1,
   } },

   /* ('fround_even', 'a') => ('bcsel', ('feq', ('ffract', 'a'), 0.5), ('fadd', ('ffloor', ('fadd', 'a', 0.5)), 1.0), ('ffloor', ('fadd', 'a', 0.5))) */
   /* search194_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace194_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 32 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe0000000000000 /* 0.5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 675, 676 },
      -1,
   } },
   /* replace194_1_0_0_0 -> 32 in the cache */
   /* replace194_1_0_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 32, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 678 },
      -1,
   } },
   /* replace194_1_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 679, 226 },
      -1,
   } },
   /* replace194_2_0_0 -> 32 in the cache */
   /* replace194_2_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 32, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 681 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 677, 680, 682 },
      -1,
   } },

   /* ('ffloor', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search195_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace195_0 -> 32 in the cache */
   /* replace195_1_0 -> 32 in the cache */
   /* replace195_1 -> 675 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 32, 675 },
      -1,
   } },

   /* ('fadd', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search196_0 -> 32 in the cache */
   /* search196_1_0_0 -> 32 in the cache */
   /* search196_1_0 -> 675 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 32, 686 },
      -1,
   } },

   /* replace196_0 -> 32 in the cache */
   /* replace196 -> 684 in the cache */

   /* ('ffract', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search197_0 -> 32 in the cache */
   /* search197 -> 675 in the cache */

   /* replace197_0 -> 32 in the cache */
   /* replace197_1_0 -> 32 in the cache */
   /* replace197_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 32, 684 },
      -1,
   } },

   /* ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a'))) */
   /* search198_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace198_0_0_0 -> 32 in the cache */
   /* replace198_0_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 690 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search199_0 -> 11 in the cache */
   /* search199_1 -> 243 in the cache */
   /* search199_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 243, 450 },
      -1,
   } },

   /* replace199_0_0 -> 11 in the cache */
   /* replace199_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 11, 243 },
      -1,
   } },
   /* replace199_1 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 693, 450 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search200_0 -> 16 in the cache */
   /* search200_1 -> 36 in the cache */
   /* search200_2 -> 133 in the cache */
   /* search200 -> 219 in the cache */

   /* replace200_0_0 -> 16 in the cache */
   /* replace200_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace200_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 695, 133 },
      -1,
   } },

   /* ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search201_0 -> 21 in the cache */
   /* search201_1 -> 41 in the cache */
   /* search201_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 591 },
      -1,
   } },

   /* replace201_0_0 -> 21 in the cache */
   /* replace201_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace201_1 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 698, 591 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search202_0 -> 16 in the cache */
   /* search202_1 -> 36 in the cache */
   /* search202_2 -> 133 in the cache */
   /* search202 -> 373 in the cache */

   /* replace202_0_0 -> 16 in the cache */
   /* replace202_0_1 -> 36 in the cache */
   /* replace202_0 -> 132 in the cache */
   /* replace202_1 -> 133 in the cache */
   /* replace202 -> 273 in the cache */

   /* ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search203_0 -> 11 in the cache */
   /* search203_1 -> 243 in the cache */
   /* search203_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 243, 450 },
      -1,
   } },

   /* replace203_0_0 -> 11 in the cache */
   /* replace203_0_1 -> 243 in the cache */
   /* replace203_0 -> 693 in the cache */
   /* replace203_1 -> 450 in the cache */
   /* replace203 -> 694 in the cache */

   /* ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search204_0 -> 16 in the cache */
   /* search204_1 -> 36 in the cache */
   /* search204_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace204_0_0 -> 16 in the cache */
   /* replace204_0_1 -> 36 in the cache */
   /* replace204_0 -> 695 in the cache */
   /* replace204_1 -> 133 in the cache */
   /* replace204 -> 696 in the cache */

   /* ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search205_0 -> 21 in the cache */
   /* search205_1 -> 41 in the cache */
   /* search205_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 591 },
      -1,
   } },

   /* replace205_0_0 -> 21 in the cache */
   /* replace205_0_1 -> 41 in the cache */
   /* replace205_0 -> 698 in the cache */
   /* replace205_1 -> 591 in the cache */
   /* replace205 -> 699 in the cache */

   /* ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search206_0 -> 16 in the cache */
   /* search206_1 -> 36 in the cache */
   /* search206_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace206_0_0 -> 16 in the cache */
   /* replace206_0_1 -> 36 in the cache */
   /* replace206_0 -> 132 in the cache */
   /* replace206_1 -> 133 in the cache */
   /* replace206 -> 273 in the cache */

   /* ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 705 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 707, 708 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_iand,
      2, 2,
      { 706, 709 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 3,
      { 710, 711 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 4,
      { 712, 713 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace207_1_0_0_0 -> 707 in the cache */
   /* replace207_1_0_0_1 -> 708 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 707, 708 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 716, 717 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 718, 719 },
      -1,
   } },
   /* replace207_2_0 -> 717 in the cache */
   /* replace207_2_1 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 717, 719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 715, 720, 721 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b') */
   /* search208_0 -> 0 in the cache */
   /* search208_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   /* replace208_0_3 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 724, 725, 726, 255 },
      -1,
   } },
   /* replace208_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 727, 3 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search209_0_0 -> 147 in the cache */
   /* search209_0_1 -> 148 in the cache */
   /* search209_0_2 -> 150 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 147, 148, 150, 729 },
      -1,
   } },
   /* search209_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 730, 151 },
      -1,
   } },

   /* replace209_0_0 -> 147 in the cache */
   /* replace209_0_1 -> 148 in the cache */
   /* replace209_0_2 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 147, 148, 150 },
      -1,
   } },
   /* replace209_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 732, 151 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search210_0_0 -> 0 in the cache */
   /* search210_0_1 -> 241 in the cache */
   /* search210_0_2 -> 241 in the cache */
   /* search210_0_3 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 0, 241, 241, 241 },
      -1,
   } },
   /* search210_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 734, 3 },
      -1,
   } },

   /* replace210_0 -> 0 in the cache */
   /* replace210_1 -> 3 in the cache */
   /* replace210 -> 249 in the cache */

   /* ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search211_0_0 -> 124 in the cache */
   /* search211_0_1 -> 125 in the cache */
   { .constant = {
      { nir_search_value_constant, -3 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search211_0_3 -> 736 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 124, 125, 736, 736 },
      -1,
   } },
   /* search211_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 737, 127 },
      -1,
   } },

   /* replace211_0_0 -> 124 in the cache */
   /* replace211_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace211_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 739, 127 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search212_0_0 -> 147 in the cache */
   /* search212_0_1 -> 148 in the cache */
   /* search212_0_2 -> 150 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 147, 148, 150, 741 },
      -1,
   } },
   /* search212_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 742, 151 },
      -1,
   } },

   /* replace212_0_0 -> 147 in the cache */
   /* replace212_0_1 -> 148 in the cache */
   /* replace212_0_2 -> 150 in the cache */
   /* replace212_0 -> 732 in the cache */
   /* replace212_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 732, 151 },
      -1,
   } },

   /* ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search213_0_0 -> 0 in the cache */
   /* search213_0_1 -> 241 in the cache */
   /* search213_0_2 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 0, 241, 241 },
      -1,
   } },
   /* search213_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 745, 3 },
      -1,
   } },

   /* replace213_0 -> 0 in the cache */
   /* replace213_1 -> 3 in the cache */
   /* replace213 -> 249 in the cache */

   /* ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search214_0_0 -> 124 in the cache */
   /* search214_0_1 -> 125 in the cache */
   /* search214_0_2 -> 736 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 124, 125, 736 },
      -1,
   } },
   /* search214_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 747, 127 },
      -1,
   } },

   /* replace214_0_0 -> 124 in the cache */
   /* replace214_0_1 -> 125 in the cache */
   /* replace214_0 -> 739 in the cache */
   /* replace214_1 -> 127 in the cache */
   /* replace214 -> 740 in the cache */

   /* ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search215_0_0 -> 0 in the cache */
   /* search215_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 0, 241 },
      -1,
   } },
   /* search215_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 749, 3 },
      -1,
   } },

   /* replace215_0 -> 0 in the cache */
   /* replace215_1 -> 3 in the cache */
   /* replace215 -> 249 in the cache */

   /* ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y') */
   /* search216_0 -> 32 in the cache */
   /* search216_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 32, 226 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      -1, 0,
      { 752, 753 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b')) */
   /* search217_0 -> 0 in the cache */
   /* search217_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace217_0_0 -> 0 in the cache */
   /* replace217_0_1 -> 3 in the cache */
   /* replace217_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 1,
      { 249 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b')) */
   /* search218_0 -> 0 in the cache */
   /* search218_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace218_0_0 -> 0 in the cache */
   /* replace218_0_1 -> 3 in the cache */
   /* replace218_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum3,
      -1, 1,
      { 249 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b')) */
   /* search219_0 -> 0 in the cache */
   /* search219_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace219_0_0 -> 0 in the cache */
   /* replace219_0_1 -> 3 in the cache */
   /* replace219_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum4,
      -1, 1,
      { 249 },
      -1,
   } },

   /* ('fsum2', 'a') => ('fadd', 'a.x', 'a.y') */
   /* search220_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace220_0 -> 752 in the cache */
   /* replace220_1 -> 753 in the cache */
   /* replace220 -> 754 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 762 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 763 },
      0,
   } },
   /* search221_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 764, 226 },
      -1,
   } },

   /* replace221_0_0 -> 226 in the cache */
   /* replace221_0_1_0 -> 32 in the cache */
   /* replace221_0_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 226, 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 766 },
      -1,
   } },

   /* ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd')) */
   /* search222_0_0_0 -> 124 in the cache */
   /* search222_0_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 124, 268 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 768, 769 },
      -1,
   } },
   /* search222_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 770, 296 },
      -1,
   } },

   /* replace222_0_0 -> 124 in the cache */
   /* replace222_0_1_0 -> 125 in the cache */
   /* replace222_0_1_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 125, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 124, 772 },
      -1,
   } },
   /* replace222_1_0 -> 127 in the cache */
   /* replace222_1_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 127, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 773, 774 },
      -1,
   } },

   /* ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c')) */
   /* search223_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 776 },
      -1,
   } },
   /* search223_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 777, 294 },
      -1,
   } },

   /* replace223_0 -> 0 in the cache */
   /* replace223_1_0 -> 3 in the cache */
   /* replace223_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 779 },
      -1,
   } },

   /* ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search224_0_0 -> 6 in the cache */
   /* search224_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search224_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 781, 294 },
      -1,
   } },

   /* replace224_0_0_0_0 -> 36 in the cache */
   /* replace224_0_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 9 },
      -1,
   } },
   /* replace224_0_0_1_0 -> 133 in the cache */
   /* replace224_0_0_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 133, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 783, 784 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 785, 786 },
      -1,
   } },
   /* replace224_1_0 -> 6 in the cache */
   /* replace224_1_1_0 -> 36 in the cache */
   /* replace224_1_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 36, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 6, 788 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 787, 789, 790 },
      -1,
   } },

   /* ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search225_0_0 -> 6 in the cache */
   /* search225_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search225_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 792, 294 },
      -1,
   } },

   /* replace225_0_0_0_0 -> 36 in the cache */
   /* replace225_0_0_0_1 -> 9 in the cache */
   /* replace225_0_0_0 -> 783 in the cache */
   /* replace225_0_0_1_0 -> 133 in the cache */
   /* replace225_0_0_1_1 -> 9 in the cache */
   /* replace225_0_0_1 -> 784 in the cache */
   /* replace225_0_0 -> 785 in the cache */
   /* replace225_0_1 -> 786 in the cache */
   /* replace225_0 -> 787 in the cache */
   /* replace225_1_0 -> 6 in the cache */
   /* replace225_1_1_0 -> 36 in the cache */
   /* replace225_1_1_1 -> 133 in the cache */
   /* replace225_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 788 },
      -1,
   } },
   /* replace225_2 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 787, 794, 790 },
      -1,
   } },

   /* ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 7)) */
   /* search226_0_0 -> 6 in the cache */
   /* search226_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search226_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 796, 294 },
      -1,
   } },

   /* replace226_0 -> 6 in the cache */
   /* replace226_1_0_0_0 -> 36 in the cache */
   /* replace226_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 9 },
      -1,
   } },
   /* replace226_1_0_1_0 -> 133 in the cache */
   /* replace226_1_0_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 133, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 798, 799 },
      -1,
   } },
   /* replace226_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 800, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 6, 801 },
      -1,
   } },

   /* ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search227_0_0 -> 11 in the cache */
   /* search227_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search227_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 803, 294 },
      -1,
   } },

   /* replace227_0_0_0_0 -> 36 in the cache */
   /* replace227_0_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 14 },
      -1,
   } },
   /* replace227_0_0_1_0 -> 133 in the cache */
   /* replace227_0_0_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 133, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 805, 806 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 807, 808 },
      -1,
   } },
   /* replace227_1_0 -> 11 in the cache */
   /* replace227_1_1_0 -> 36 in the cache */
   /* replace227_1_1_1 -> 133 in the cache */
   /* replace227_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 788 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 809, 810, 811 },
      -1,
   } },

   /* ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search228_0_0 -> 11 in the cache */
   /* search228_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search228_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 813, 294 },
      -1,
   } },

   /* replace228_0_0_0_0 -> 36 in the cache */
   /* replace228_0_0_0_1 -> 14 in the cache */
   /* replace228_0_0_0 -> 805 in the cache */
   /* replace228_0_0_1_0 -> 133 in the cache */
   /* replace228_0_0_1_1 -> 14 in the cache */
   /* replace228_0_0_1 -> 806 in the cache */
   /* replace228_0_0 -> 807 in the cache */
   /* replace228_0_1 -> 808 in the cache */
   /* replace228_0 -> 809 in the cache */
   /* replace228_1_0 -> 11 in the cache */
   /* replace228_1_1_0 -> 36 in the cache */
   /* replace228_1_1_1 -> 133 in the cache */
   /* replace228_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 788 },
      -1,
   } },
   /* replace228_2 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 809, 815, 811 },
      -1,
   } },

   /* ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 15)) */
   /* search229_0_0 -> 11 in the cache */
   /* search229_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search229_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 817, 294 },
      -1,
   } },

   /* replace229_0 -> 11 in the cache */
   /* replace229_1_0_0_0 -> 36 in the cache */
   /* replace229_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 14 },
      -1,
   } },
   /* replace229_1_0_1_0 -> 133 in the cache */
   /* replace229_1_0_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 133, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 819, 820 },
      -1,
   } },
   /* replace229_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 821, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 11, 822 },
      -1,
   } },

   /* ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search230_0_0 -> 16 in the cache */
   /* search230_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search230_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 824, 294 },
      -1,
   } },

   /* replace230_0_0_0_0 -> 36 in the cache */
   /* replace230_0_0_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 19 },
      -1,
   } },
   /* replace230_0_0_1_0 -> 133 in the cache */
   /* replace230_0_0_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 133, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 826, 827 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x20 /* 32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 828, 829 },
      -1,
   } },
   /* replace230_1_0 -> 16 in the cache */
   /* replace230_1_1_0 -> 36 in the cache */
   /* replace230_1_1_1 -> 133 in the cache */
   /* replace230_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 788 },
      -1,
   } },
   /* replace230_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 830, 831, 120 },
      -1,
   } },

   /* ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search231_0_0 -> 16 in the cache */
   /* search231_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search231_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 833, 294 },
      -1,
   } },

   /* replace231_0_0_0_0 -> 36 in the cache */
   /* replace231_0_0_0_1 -> 19 in the cache */
   /* replace231_0_0_0 -> 826 in the cache */
   /* replace231_0_0_1_0 -> 133 in the cache */
   /* replace231_0_0_1_1 -> 19 in the cache */
   /* replace231_0_0_1 -> 827 in the cache */
   /* replace231_0_0 -> 828 in the cache */
   /* replace231_0_1 -> 829 in the cache */
   /* replace231_0 -> 830 in the cache */
   /* replace231_1_0 -> 16 in the cache */
   /* replace231_1_1_0 -> 36 in the cache */
   /* replace231_1_1_1 -> 133 in the cache */
   /* replace231_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 788 },
      -1,
   } },
   /* replace231_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 830, 835, 120 },
      -1,
   } },

   /* ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 31)) */
   /* search232_0_0 -> 16 in the cache */
   /* search232_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search232_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 837, 294 },
      -1,
   } },

   /* replace232_0 -> 16 in the cache */
   /* replace232_1_0_0_0 -> 36 in the cache */
   /* replace232_1_0_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 19 },
      -1,
   } },
   /* replace232_1_0_1_0 -> 133 in the cache */
   /* replace232_1_0_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 133, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 839, 840 },
      -1,
   } },
   /* replace232_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 841, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 16, 842 },
      -1,
   } },

   /* ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search233_0_0 -> 21 in the cache */
   /* search233_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search233_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 844, 294 },
      -1,
   } },

   /* replace233_0_0_0_0 -> 36 in the cache */
   /* replace233_0_0_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 24 },
      -1,
   } },
   /* replace233_0_0_1_0 -> 133 in the cache */
   /* replace233_0_0_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 133, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 846, 847 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x40 /* 64 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 848, 849 },
      -1,
   } },
   /* replace233_1_0 -> 21 in the cache */
   /* replace233_1_1_0 -> 36 in the cache */
   /* replace233_1_1_1 -> 133 in the cache */
   /* replace233_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 21, 788 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 850, 851, 852 },
      -1,
   } },

   /* ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search234_0_0 -> 21 in the cache */
   /* search234_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search234_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 854, 294 },
      -1,
   } },

   /* replace234_0_0_0_0 -> 36 in the cache */
   /* replace234_0_0_0_1 -> 24 in the cache */
   /* replace234_0_0_0 -> 846 in the cache */
   /* replace234_0_0_1_0 -> 133 in the cache */
   /* replace234_0_0_1_1 -> 24 in the cache */
   /* replace234_0_0_1 -> 847 in the cache */
   /* replace234_0_0 -> 848 in the cache */
   /* replace234_0_1 -> 849 in the cache */
   /* replace234_0 -> 850 in the cache */
   /* replace234_1_0 -> 21 in the cache */
   /* replace234_1_1_0 -> 36 in the cache */
   /* replace234_1_1_1 -> 133 in the cache */
   /* replace234_1_1 -> 788 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 788 },
      -1,
   } },
   /* replace234_2 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 850, 856, 852 },
      -1,
   } },

   /* ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 63)) */
   /* search235_0_0 -> 21 in the cache */
   /* search235_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search235_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 858, 294 },
      -1,
   } },

   /* replace235_0 -> 21 in the cache */
   /* replace235_1_0_0_0 -> 36 in the cache */
   /* replace235_1_0_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 24 },
      -1,
   } },
   /* replace235_1_0_1_0 -> 133 in the cache */
   /* replace235_1_0_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 133, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 860, 861 },
      -1,
   } },
   /* replace235_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 862, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 21, 863 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search236_0_0 -> 6 in the cache */
   /* search236_0_1 -> 33 in the cache */
   /* search236_0 -> 792 in the cache */
   /* search236_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 792, 36 },
      -1,
   } },

   /* replace236_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace236_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 866, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 867 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search237_0_0 -> 6 in the cache */
   /* search237_0_1 -> 33 in the cache */
   /* search237_0 -> 796 in the cache */
   /* search237_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 796, 36 },
      -1,
   } },

   /* replace237_0 -> 6 in the cache */
   /* replace237_1_0 -> 866 in the cache */
   /* replace237_1_1 -> 36 in the cache */
   /* replace237_1 -> 867 in the cache */
   /* replace237 -> 868 in the cache */

   /* ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b')) */
   /* search238_0_0 -> 6 in the cache */
   /* search238_0_1 -> 33 in the cache */
   /* search238_0 -> 781 in the cache */
   /* search238_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 781, 36 },
      -1,
   } },

   /* replace238_0 -> 6 in the cache */
   /* replace238_1_0 -> 866 in the cache */
   /* replace238_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 866, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 871 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search239_0_0 -> 11 in the cache */
   /* search239_0_1 -> 33 in the cache */
   /* search239_0 -> 813 in the cache */
   /* search239_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 813, 36 },
      -1,
   } },

   /* replace239_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace239_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 874, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 875 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search240_0_0 -> 11 in the cache */
   /* search240_0_1 -> 33 in the cache */
   /* search240_0 -> 817 in the cache */
   /* search240_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 817, 36 },
      -1,
   } },

   /* replace240_0 -> 11 in the cache */
   /* replace240_1_0 -> 874 in the cache */
   /* replace240_1_1 -> 36 in the cache */
   /* replace240_1 -> 875 in the cache */
   /* replace240 -> 876 in the cache */

   /* ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b')) */
   /* search241_0_0 -> 11 in the cache */
   /* search241_0_1 -> 33 in the cache */
   /* search241_0 -> 803 in the cache */
   /* search241_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 803, 36 },
      -1,
   } },

   /* replace241_0 -> 11 in the cache */
   /* replace241_1_0 -> 874 in the cache */
   /* replace241_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 874, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 879 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search242_0_0 -> 16 in the cache */
   /* search242_0_1 -> 33 in the cache */
   /* search242_0 -> 833 in the cache */
   /* search242_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 833, 36 },
      -1,
   } },

   /* replace242_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   /* replace242_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 882, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 883 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search243_0_0 -> 16 in the cache */
   /* search243_0_1 -> 33 in the cache */
   /* search243_0 -> 837 in the cache */
   /* search243_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 837, 36 },
      -1,
   } },

   /* replace243_0 -> 16 in the cache */
   /* replace243_1_0 -> 882 in the cache */
   /* replace243_1_1 -> 36 in the cache */
   /* replace243_1 -> 883 in the cache */
   /* replace243 -> 884 in the cache */

   /* ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b')) */
   /* search244_0_0 -> 16 in the cache */
   /* search244_0_1 -> 33 in the cache */
   /* search244_0 -> 824 in the cache */
   /* search244_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 824, 36 },
      -1,
   } },

   /* replace244_0 -> 16 in the cache */
   /* replace244_1_0 -> 882 in the cache */
   /* replace244_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 882, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 887 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search245_0_0 -> 21 in the cache */
   /* search245_0_1 -> 33 in the cache */
   /* search245_0 -> 854 in the cache */
   /* search245_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 854, 36 },
      -1,
   } },

   /* replace245_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffffffffffff /* 18446744073709551615 */ },
   } },
   /* replace245_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 890, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 891 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search246_0_0 -> 21 in the cache */
   /* search246_0_1 -> 33 in the cache */
   /* search246_0 -> 858 in the cache */
   /* search246_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 858, 36 },
      -1,
   } },

   /* replace246_0 -> 21 in the cache */
   /* replace246_1_0 -> 890 in the cache */
   /* replace246_1_1 -> 36 in the cache */
   /* replace246_1 -> 891 in the cache */
   /* replace246 -> 892 in the cache */

   /* ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b')) */
   /* search247_0_0 -> 21 in the cache */
   /* search247_0_1 -> 33 in the cache */
   /* search247_0 -> 844 in the cache */
   /* search247_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 844, 36 },
      -1,
   } },

   /* replace247_0 -> 21 in the cache */
   /* replace247_1_0 -> 890 in the cache */
   /* replace247_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 890, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 895 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b') */
   /* search248_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 897 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 898, 899 },
      -1,
   } },

   /* replace248_0 -> 16 in the cache */
   /* replace248_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b') */
   /* search249_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 902 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 903, 904 },
      -1,
   } },

   /* replace249_0 -> 0 in the cache */
   /* replace249_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b') */
   /* search250_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      11,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 907 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffe /* 4294967294 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 908, 909 },
      -1,
   } },

   /* replace250_0_0 -> 16 in the cache */
   /* replace250_0_1 -> 909 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 909 },
      -1,
   } },
   /* replace250_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 911, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b') */
   /* search251_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 913 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffc /* 4294967292 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 914, 915 },
      -1,
   } },

   /* replace251_0_0 -> 16 in the cache */
   /* replace251_0_1 -> 915 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 915 },
      -1,
   } },
   /* replace251_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 917, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b') */
   /* search252_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      12,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 919 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff8 /* 4294967288 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 920, 921 },
      -1,
   } },

   /* replace252_0_0 -> 16 in the cache */
   /* replace252_0_1 -> 921 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 921 },
      -1,
   } },
   /* replace252_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 923, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b') */
   /* search253_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 925 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff0 /* 4294967280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 926, 927 },
      -1,
   } },

   /* replace253_0_0 -> 16 in the cache */
   /* replace253_0_1 -> 927 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 927 },
      -1,
   } },
   /* replace253_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 929, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b') */
   /* search254_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      14,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 931 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffe0 /* 4294967264 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 932, 933 },
      -1,
   } },

   /* replace254_0_0 -> 16 in the cache */
   /* replace254_0_1 -> 933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 933 },
      -1,
   } },
   /* replace254_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 935, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b') */
   /* search255_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      15,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 937 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffc0 /* 4294967232 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 938, 939 },
      -1,
   } },

   /* replace255_0_0 -> 16 in the cache */
   /* replace255_0_1 -> 939 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 939 },
      -1,
   } },
   /* replace255_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 941, 36 },
      -1,
   } },

   /* ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1) */
   /* search256_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 943 },
      -1,
   } },
   /* search256_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 944, 377 },
      -1,
   } },

   /* replace256_0 -> 16 in the cache */
   /* replace256_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 377 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1) */
   /* search257_0_0 -> 16 in the cache */
   /* search257_0_1 -> 377 in the cache */
   /* search257_0 -> 946 in the cache */
   /* search257_1 -> 909 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 946, 909 },
      -1,
   } },

   /* replace257_0 -> 16 in the cache */
   /* replace257_1 -> 377 in the cache */
   /* replace257 -> 946 in the cache */

   /* ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1) */
   /* search258_0_0 -> 16 in the cache */
   /* search258_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 377 },
      -1,
   } },
   /* search258_1 -> 943 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 948, 943 },
      -1,
   } },

   /* replace258_0 -> 16 in the cache */
   /* replace258_1 -> 377 in the cache */
   /* replace258 -> 948 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2) */
   /* search259_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffff /* 1073741823 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 950 },
      -1,
   } },
   /* search259_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 951, 382 },
      -1,
   } },

   /* replace259_0 -> 16 in the cache */
   /* replace259_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 382 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2) */
   /* search260_0_0 -> 16 in the cache */
   /* search260_0_1 -> 382 in the cache */
   /* search260_0 -> 953 in the cache */
   /* search260_1 -> 915 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 953, 915 },
      -1,
   } },

   /* replace260_0 -> 16 in the cache */
   /* replace260_1 -> 382 in the cache */
   /* replace260 -> 953 in the cache */

   /* ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2) */
   /* search261_0_0 -> 16 in the cache */
   /* search261_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 382 },
      -1,
   } },
   /* search261_1 -> 950 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 955, 950 },
      -1,
   } },

   /* replace261_0 -> 16 in the cache */
   /* replace261_1 -> 382 in the cache */
   /* replace261 -> 955 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16) */
   /* search262_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 957 },
      -1,
   } },
   /* search262_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 958, 808 },
      -1,
   } },

   /* replace262_0 -> 16 in the cache */
   /* replace262_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 808 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16) */
   /* search263_0_0 -> 16 in the cache */
   /* search263_0_1 -> 808 in the cache */
   /* search263_0 -> 960 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff0000 /* 4294901760 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 960, 961 },
      -1,
   } },

   /* replace263_0 -> 16 in the cache */
   /* replace263_1 -> 808 in the cache */
   /* replace263 -> 960 in the cache */

   /* ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16) */
   /* search264_0_0 -> 16 in the cache */
   /* search264_0_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 808 },
      -1,
   } },
   /* search264_1 -> 957 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 963, 957 },
      -1,
   } },

   /* replace264_0 -> 16 in the cache */
   /* replace264_1 -> 808 in the cache */
   /* replace264 -> 963 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24) */
   /* search265_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 965 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 966, 967 },
      -1,
   } },

   /* replace265_0 -> 16 in the cache */
   /* replace265_1 -> 967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 967 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24) */
   /* search266_0_0 -> 16 in the cache */
   /* search266_0_1 -> 967 in the cache */
   /* search266_0 -> 969 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 969, 970 },
      -1,
   } },

   /* replace266_0 -> 16 in the cache */
   /* replace266_1 -> 967 in the cache */
   /* replace266 -> 969 in the cache */

   /* ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24) */
   /* search267_0_0 -> 16 in the cache */
   /* search267_0_1 -> 967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 967 },
      -1,
   } },
   /* search267_1 -> 965 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 972, 965 },
      -1,
   } },

   /* replace267_0 -> 16 in the cache */
   /* replace267_1 -> 967 in the cache */
   /* replace267 -> 972 in the cache */

   /* ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c')) */
   /* search268_0_0 -> 0 in the cache */
   /* search268_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 776 },
      -1,
   } },
   /* search268_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 974, 294 },
      -1,
   } },

   /* replace268_0_0 -> 0 in the cache */
   /* replace268_0_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 133 },
      -1,
   } },
   /* replace268_1_0 -> 3 in the cache */
   /* replace268_1_1 -> 133 in the cache */
   /* replace268_1 -> 779 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 976, 779 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c')) */
   /* search269_0_0 -> 124 in the cache */
   /* search269_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 124, 268 },
      0,
   } },
   /* search269_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 978, 769 },
      -1,
   } },

   /* replace269_0_0 -> 124 in the cache */
   /* replace269_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace269_1_0 -> 125 in the cache */
   /* replace269_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 980, 981 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd')) */
   /* search270_0_0_0 -> 147 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 147, 983 },
      0,
   } },
   /* search270_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 2,
      { 984, 150 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 985, 986 },
      -1,
   } },

   /* replace270_0_0_0 -> 147 in the cache */
   /* replace270_0_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 147, 150 },
      -1,
   } },
   /* replace270_0_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 2,
      { 988, 151 },
      -1,
   } },
   /* replace270_1_0 -> 148 in the cache */
   /* replace270_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 989, 990 },
      -1,
   } },

   /* ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd')) */
   /* search271_0_0_0 -> 124 in the cache */
   /* search271_0_0_1 -> 268 in the cache */
   /* search271_0_0 -> 978 in the cache */
   /* search271_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 978, 127 },
      0,
   } },
   /* search271_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 992, 296 },
      -1,
   } },

   /* replace271_0_0_0 -> 124 in the cache */
   /* replace271_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace271_0_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 994, 161 },
      -1,
   } },
   /* replace271_1_0 -> 125 in the cache */
   /* replace271_1_1 -> 161 in the cache */
   /* replace271_1 -> 772 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 995, 772 },
      -1,
   } },

   /* ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 997, 998 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 999 },
      -1,
   } },

   /* replace272_0 -> 0 in the cache */
   /* replace272_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b') */
   /* search273_0_0 -> 997 in the cache */
   /* search273_0_1 -> 998 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 997, 998 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1002 },
      -1,
   } },

   /* replace273_0 -> 0 in the cache */
   /* replace273_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b') */
   /* search274_0_0 -> 0 in the cache */
   /* search274_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1005 },
      -1,
   } },

   /* replace274_0 -> 0 in the cache */
   /* replace274_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b') */
   /* search275_0_0 -> 0 in the cache */
   /* search275_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1008 },
      -1,
   } },

   /* replace275_0 -> 0 in the cache */
   /* replace275_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b') */
   /* search276_0_0 -> 0 in the cache */
   /* search276_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1011 },
      -1,
   } },

   /* replace276_0 -> 0 in the cache */
   /* replace276_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b') */
   /* search277_0_0 -> 0 in the cache */
   /* search277_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1014 },
      -1,
   } },

   /* replace277_0 -> 0 in the cache */
   /* replace277_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b') */
   /* search278_0_0 -> 0 in the cache */
   /* search278_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1017 },
      -1,
   } },

   /* replace278_0 -> 0 in the cache */
   /* replace278_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b') */
   /* search279_0_0 -> 0 in the cache */
   /* search279_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1020 },
      -1,
   } },

   /* replace279_0 -> 0 in the cache */
   /* replace279_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b') */
   /* search280_0_0 -> 0 in the cache */
   /* search280_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1023 },
      -1,
   } },

   /* replace280_0 -> 0 in the cache */
   /* replace280_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b') */
   /* search281_0_0 -> 0 in the cache */
   /* search281_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1026 },
      -1,
   } },

   /* replace281_0 -> 0 in the cache */
   /* replace281_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False */
   /* search282_0_0 -> 0 in the cache */
   /* search282_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search282_1_0 -> 0 in the cache */
   /* search282_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1029, 1030 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_FALSE /* False */ },
   } },

   /* ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False */
   /* search283_0_0 -> 0 in the cache */
   /* search283_0_1 -> 3 in the cache */
   /* search283_0 -> 1004 in the cache */
   /* search283_1_0 -> 3 in the cache */
   /* search283_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1004, 1033 },
      -1,
   } },

   /* replace283 -> 1032 in the cache */

   /* ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False */
   /* search284_0_0 -> 0 in the cache */
   /* search284_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search284_1_0 -> 0 in the cache */
   /* search284_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1035, 1036 },
      -1,
   } },

   /* replace284 -> 1032 in the cache */

   /* ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False */
   /* search285_0_0 -> 0 in the cache */
   /* search285_0_1 -> 3 in the cache */
   /* search285_0 -> 1019 in the cache */
   /* search285_1_0 -> 3 in the cache */
   /* search285_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1019, 1038 },
      -1,
   } },

   /* replace285 -> 1032 in the cache */

   /* ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False */
   /* search286_0_0 -> 0 in the cache */
   /* search286_0_1 -> 3 in the cache */
   /* search286_0 -> 1022 in the cache */
   /* search286_1_0 -> 3 in the cache */
   /* search286_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1022, 1040 },
      -1,
   } },

   /* replace286 -> 1032 in the cache */

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search287_0_0 -> 0 in the cache */
   /* search287_0 -> 197 in the cache */
   /* search287_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 197, 1042 },
      -1,
   } },

   /* replace287_0 -> 3 in the cache */
   /* replace287_1 -> 0 in the cache */
   /* replace287 -> 1033 in the cache */

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search288_0_0 -> 0 in the cache */
   /* search288_0 -> 197 in the cache */
   /* search288_1_0 -> 3 in the cache */
   /* search288_1 -> 1042 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 197, 1042 },
      -1,
   } },

   /* replace288_0 -> 3 in the cache */
   /* replace288_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search289_0_0 -> 0 in the cache */
   /* search289_0 -> 197 in the cache */
   /* search289_1_0 -> 3 in the cache */
   /* search289_1 -> 1042 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 197, 1042 },
      -1,
   } },

   /* replace289_0 -> 3 in the cache */
   /* replace289_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search290_0_0 -> 0 in the cache */
   /* search290_0 -> 197 in the cache */
   /* search290_1_0 -> 3 in the cache */
   /* search290_1 -> 1042 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 197, 1042 },
      -1,
   } },

   /* replace290_0 -> 3 in the cache */
   /* replace290_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search291_0_0 -> 32 in the cache */
   /* search291_0 -> 98 in the cache */
   /* search291_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 98, 232 },
      -1,
   } },

   /* replace291_0 -> 226 in the cache */
   /* replace291_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 226, 32 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search292_0 -> 232 in the cache */
   /* search292_1_0 -> 32 in the cache */
   /* search292_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 232, 98 },
      -1,
   } },

   /* replace292_0 -> 32 in the cache */
   /* replace292_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 226 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search293_0_0 -> 32 in the cache */
   /* search293_0 -> 98 in the cache */
   /* search293_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 98, 232 },
      -1,
   } },

   /* replace293_0 -> 226 in the cache */
   /* replace293_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 226, 32 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search294_0 -> 232 in the cache */
   /* search294_1_0 -> 32 in the cache */
   /* search294_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 232, 98 },
      -1,
   } },

   /* replace294_0 -> 32 in the cache */
   /* replace294_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 226 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search295_0_0 -> 32 in the cache */
   /* search295_0 -> 98 in the cache */
   /* search295_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 98, 232 },
      -1,
   } },

   /* replace295_0 -> 226 in the cache */
   /* replace295_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 226, 32 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search296_0 -> 232 in the cache */
   /* search296_1_0 -> 32 in the cache */
   /* search296_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 232, 98 },
      -1,
   } },

   /* replace296_0 -> 32 in the cache */
   /* replace296_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 226 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1063 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1062, 1064 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace297_1 -> 1063 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1066, 1063 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search298_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1068, 1069 },
      -1,
   } },

   /* replace298_0 -> 0 in the cache */
   /* replace298_1 -> 3 in the cache */
   /* replace298 -> 1001 in the cache */

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search299_0_0 -> 0 in the cache */
   /* search299_0 -> 1068 in the cache */
   /* search299_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1068, 1069 },
      -1,
   } },

   /* replace299_0 -> 0 in the cache */
   /* replace299_1 -> 3 in the cache */
   /* replace299 -> 1010 in the cache */

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search300_0_0 -> 0 in the cache */
   /* search300_0 -> 1068 in the cache */
   /* search300_1 -> 1069 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1068, 1069 },
      -1,
   } },

   /* replace300_0 -> 0 in the cache */
   /* replace300_1 -> 3 in the cache */
   /* replace300 -> 1007 in the cache */

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search301_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      0,
   } },
   /* search301_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1073, 226 },
      -1,
   } },

   /* replace301_0 -> 32 in the cache */
   /* replace301_1 -> 226 in the cache */
   /* replace301 -> 1057 in the cache */

   /* ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a') */
   /* search302_0 -> 113 in the cache */
   /* search302_1_0 -> 32 in the cache */
   /* search302_1 -> 1073 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 1073 },
      -1,
   } },

   /* replace302_0 -> 113 in the cache */
   /* replace302_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 32 },
      -1,
   } },

   /* ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a') */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search303_1_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 715 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1077, 1078 },
      -1,
   } },

   /* replace303_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a') */
   /* search304_0_0_0 -> 715 in the cache */
   /* search304_0_0 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1078 },
      -1,
   } },
   /* search304_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1081, 1077 },
      -1,
   } },

   /* replace304_0 -> 715 in the cache */
   /* replace304 -> 1080 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search305_0_0_0 -> 715 in the cache */
   /* search305_0_0 -> 1078 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1078, 1084 },
      -1,
   } },
   /* search305_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1085, 1077 },
      -1,
   } },

   /* replace305_0 -> 715 in the cache */
   /* replace305_1 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 715, 1083 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search306_0_0 -> 715 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search306_0_2_0 -> 1083 in the cache */
   /* search306_0_2 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1088, 1084 },
      -1,
   } },
   /* search306_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1089, 1077 },
      -1,
   } },

   /* replace306_0 -> 715 in the cache */
   /* replace306_1 -> 1083 in the cache */
   /* replace306 -> 1087 in the cache */

   /* ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search307_0_0 -> 715 in the cache */
   /* search307_0 -> 1078 in the cache */
   /* search307_1_0_0 -> 1083 in the cache */
   /* search307_1_0 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1084 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1078, 1091 },
      -1,
   } },

   /* replace307_0 -> 715 in the cache */
   /* replace307_1 -> 1083 in the cache */
   /* replace307 -> 1087 in the cache */

   /* ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b') */
   /* search308_0_0_0 -> 715 in the cache */
   /* search308_0_0 -> 1078 in the cache */
   /* search308_0_1_0 -> 1083 in the cache */
   /* search308_0_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 1078, 1084 },
      -1,
   } },
   /* search308_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1093, 1077 },
      -1,
   } },

   /* replace308_0 -> 715 in the cache */
   /* replace308_1 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 715, 1083 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b') */
   /* search309_0_0 -> 715 in the cache */
   /* search309_0_1_0 -> 1083 in the cache */
   /* search309_0_1 -> 1084 in the cache */
   /* search309_0_2 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1084, 1077 },
      -1,
   } },
   /* search309_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1096, 1077 },
      -1,
   } },

   /* replace309_0 -> 715 in the cache */
   /* replace309_1 -> 1083 in the cache */
   /* replace309 -> 1095 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b') */
   /* search310_0_0_0 -> 715 in the cache */
   /* search310_0_0 -> 1078 in the cache */
   /* search310_0_1_0_0 -> 1083 in the cache */
   /* search310_0_1_0 -> 1084 in the cache */
   /* search310_0_1 -> 1091 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1078, 1091 },
      -1,
   } },
   /* search310_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1098, 1077 },
      -1,
   } },

   /* replace310_0 -> 715 in the cache */
   /* replace310_1 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 715, 1083 },
      -1,
   } },

   /* ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b') */
   /* search311_0_0 -> 715 in the cache */
   /* search311_0 -> 1078 in the cache */
   /* search311_1_0 -> 1083 in the cache */
   /* search311_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1078, 1084 },
      -1,
   } },

   /* replace311_0 -> 715 in the cache */
   /* replace311_1 -> 1083 in the cache */
   /* replace311 -> 1100 in the cache */

   /* ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b') */
   /* search312_0_0_0 -> 715 in the cache */
   /* search312_0_0 -> 1078 in the cache */
   /* search312_0 -> 1081 in the cache */
   /* search312_1_0_0 -> 1083 in the cache */
   /* search312_1_0 -> 1084 in the cache */
   /* search312_1 -> 1091 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1081, 1091 },
      -1,
   } },

   /* replace312_0 -> 715 in the cache */
   /* replace312_1 -> 1083 in the cache */
   /* replace312 -> 1100 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search313_0_0_0 -> 715 in the cache */
   /* search313_0_0 -> 1078 in the cache */
   /* search313_0_1_0 -> 1083 in the cache */
   /* search313_0_1 -> 1084 in the cache */
   /* search313_0 -> 1085 in the cache */
   /* search313_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1085, 1077 },
      -1,
   } },

   /* replace313_0_0 -> 715 in the cache */
   /* replace313_0_1 -> 1083 in the cache */
   /* replace313_0 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1087 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search314_0_0 -> 715 in the cache */
   /* search314_0_1 -> 1088 in the cache */
   /* search314_0_2_0 -> 1083 in the cache */
   /* search314_0_2 -> 1084 in the cache */
   /* search314_0 -> 1089 in the cache */
   /* search314_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1089, 1077 },
      -1,
   } },

   /* replace314_0_0 -> 715 in the cache */
   /* replace314_0_1 -> 1083 in the cache */
   /* replace314_0 -> 1087 in the cache */
   /* replace314 -> 1104 in the cache */

   /* ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search315_0_0 -> 715 in the cache */
   /* search315_0 -> 1078 in the cache */
   /* search315_1_0_0 -> 1083 in the cache */
   /* search315_1_0 -> 1084 in the cache */
   /* search315_1 -> 1091 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1078, 1091 },
      -1,
   } },

   /* replace315_0_0 -> 715 in the cache */
   /* replace315_0_1 -> 1083 in the cache */
   /* replace315_0 -> 1087 in the cache */
   /* replace315 -> 1104 in the cache */

   /* ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search316_0_0_0 -> 715 in the cache */
   /* search316_0_0 -> 1078 in the cache */
   /* search316_0_1_0 -> 1083 in the cache */
   /* search316_0_1 -> 1084 in the cache */
   /* search316_0 -> 1093 in the cache */
   /* search316_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1093, 1077 },
      -1,
   } },

   /* replace316_0_0 -> 715 in the cache */
   /* replace316_0_1 -> 1083 in the cache */
   /* replace316_0 -> 1095 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1095 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search317_0_0 -> 715 in the cache */
   /* search317_0_1_0 -> 1083 in the cache */
   /* search317_0_1 -> 1084 in the cache */
   /* search317_0_2 -> 1077 in the cache */
   /* search317_0 -> 1096 in the cache */
   /* search317_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1096, 1077 },
      -1,
   } },

   /* replace317_0_0 -> 715 in the cache */
   /* replace317_0_1 -> 1083 in the cache */
   /* replace317_0 -> 1095 in the cache */
   /* replace317 -> 1108 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b') */
   /* search318_0_0_0 -> 715 in the cache */
   /* search318_0_0 -> 1078 in the cache */
   /* search318_0_1_0_0 -> 1083 in the cache */
   /* search318_0_1_0 -> 1084 in the cache */
   /* search318_0_1 -> 1091 in the cache */
   /* search318_0 -> 1098 in the cache */
   /* search318_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1098, 1077 },
      -1,
   } },

   /* replace318_0 -> 715 in the cache */
   /* replace318_1 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 715, 1083 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b') */
   /* search319_0_0 -> 715 in the cache */
   /* search319_0 -> 1078 in the cache */
   /* search319_1_0 -> 1083 in the cache */
   /* search319_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1078, 1084 },
      -1,
   } },

   /* replace319_0 -> 715 in the cache */
   /* replace319_1 -> 1083 in the cache */
   /* replace319 -> 1111 in the cache */

   /* ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b') */
   /* search320_0_0_0 -> 715 in the cache */
   /* search320_0_0 -> 1078 in the cache */
   /* search320_0 -> 1081 in the cache */
   /* search320_1_0_0 -> 1083 in the cache */
   /* search320_1_0 -> 1084 in the cache */
   /* search320_1 -> 1091 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1081, 1091 },
      -1,
   } },

   /* replace320_0 -> 715 in the cache */
   /* replace320_1 -> 1083 in the cache */
   /* replace320 -> 1111 in the cache */

   /* ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b') */
   /* search321_0_0_0_0 -> 715 in the cache */
   /* search321_0_0_0 -> 1078 in the cache */
   /* search321_0_0_1_0 -> 1083 in the cache */
   /* search321_0_0_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1078, 1084 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1114 },
      -1,
   } },
   /* search321_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1115, 1077 },
      -1,
   } },

   /* replace321_0 -> 715 in the cache */
   /* replace321_1 -> 1083 in the cache */
   /* replace321 -> 1087 in the cache */

   /* ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search322_0 -> 1077 in the cache */
   /* search322_1_0_0 -> 715 in the cache */
   /* search322_1_0 -> 1078 in the cache */
   /* search322_1_1_0 -> 1083 in the cache */
   /* search322_1_1 -> 1084 in the cache */
   /* search322_1 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1077, 1114 },
      -1,
   } },

   /* replace322_0 -> 715 in the cache */
   /* replace322_1 -> 1083 in the cache */
   /* replace322 -> 1087 in the cache */

   /* ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search323_0_0_0_0 -> 715 in the cache */
   /* search323_0_0_0 -> 1078 in the cache */
   /* search323_0_0_1_0 -> 1083 in the cache */
   /* search323_0_0_1 -> 1084 in the cache */
   /* search323_0_0 -> 1114 in the cache */
   /* search323_0 -> 1115 in the cache */
   /* search323_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1115, 1077 },
      -1,
   } },

   /* replace323_0_0 -> 715 in the cache */
   /* replace323_0_1 -> 1083 in the cache */
   /* replace323_0 -> 1087 in the cache */
   /* replace323 -> 1104 in the cache */

   /* ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search324_0 -> 1077 in the cache */
   /* search324_1_0_0 -> 715 in the cache */
   /* search324_1_0 -> 1078 in the cache */
   /* search324_1_1_0 -> 1083 in the cache */
   /* search324_1_1 -> 1084 in the cache */
   /* search324_1 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1077, 1114 },
      -1,
   } },

   /* replace324_0_0 -> 715 in the cache */
   /* replace324_0_1 -> 1083 in the cache */
   /* replace324_0 -> 1087 in the cache */
   /* replace324 -> 1104 in the cache */

   /* ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0) */
   /* search325_0 -> 32 in the cache */
   /* search325_1_0 -> 32 in the cache */
   /* search325_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace325_0 -> 32 in the cache */
   /* replace325_1 -> 113 in the cache */
   /* replace325 -> 670 in the cache */

   /* ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0) */
   /* search326_0 -> 32 in the cache */
   /* search326_1_0 -> 32 in the cache */
   /* search326_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace326_0 -> 32 in the cache */
   /* replace326_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 113 },
      -1,
   } },

   /* ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1124 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1126 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1125, 1127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1123, 1129 },
      -1,
   } },
   /* search327_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 1130, 113 },
      -1,
   } },

   /* replace327_0_0 -> 1123 in the cache */
   /* replace327_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1123, 113 },
      -1,
   } },
   /* replace327_1_0 -> 1124 in the cache */
   /* replace327_1_1 -> 1126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1124, 1126 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1132, 1133 },
      -1,
   } },

   /* ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0) */
   /* search328_0_0 -> 0 in the cache */
   /* search328_0_1 -> 3 in the cache */
   /* search328_0 -> 257 in the cache */
   /* search328_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 257, 0 },
      -1,
   } },

   /* replace328_0 -> 3 in the cache */
   /* replace328_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3, 241 },
      -1,
   } },

   /* ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0) */
   /* search329_0_0 -> 0 in the cache */
   /* search329_0_1 -> 3 in the cache */
   /* search329_0 -> 257 in the cache */
   /* search329_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 257, 0 },
      -1,
   } },

   /* replace329_0 -> 3 in the cache */
   /* replace329_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3, 241 },
      -1,
   } },

   /* ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0) */
   /* search330_0_0 -> 0 in the cache */
   /* search330_0_1 -> 3 in the cache */
   /* search330_0 -> 198 in the cache */
   /* search330_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 198, 0 },
      -1,
   } },

   /* replace330_0 -> 3 in the cache */
   /* replace330_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3, 241 },
      -1,
   } },

   /* ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0) */
   /* search331_0_0 -> 0 in the cache */
   /* search331_0_1 -> 3 in the cache */
   /* search331_0 -> 198 in the cache */
   /* search331_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 198, 0 },
      -1,
   } },

   /* replace331_0 -> 3 in the cache */
   /* replace331_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3, 241 },
      -1,
   } },

   /* ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search332_0_0 -> 124 in the cache */
   /* search332_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 124, 268 },
      0,
   } },
   /* search332_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1143, 769 },
      -1,
   } },

   /* replace332_0 -> 124 in the cache */
   /* replace332_1_0 -> 127 in the cache */
   /* replace332_1_1_0 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 127, 1145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 124, 1146 },
      -1,
   } },

   /* ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search333_0_0_0 -> 124 in the cache */
   /* search333_0_0_1 -> 268 in the cache */
   /* search333_0_0 -> 1143 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1143 },
      0,
   } },
   /* search333_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1148, 769 },
      -1,
   } },

   /* replace333_0_0_0 -> 127 in the cache */
   /* replace333_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 127, 125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1150 },
      -1,
   } },
   /* replace333_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1151, 124 },
      -1,
   } },

   /* ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search334_0_0 -> 124 in the cache */
   /* search334_0_1 -> 268 in the cache */
   /* search334_0 -> 1143 in the cache */
   /* search334_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1143, 769 },
      -1,
   } },

   /* replace334_0 -> 124 in the cache */
   /* replace334_1_0 -> 127 in the cache */
   /* replace334_1_1_0 -> 125 in the cache */
   /* replace334_1_1 -> 1145 in the cache */
   /* replace334_1 -> 1146 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 124, 1146 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search335_0_0_0 -> 124 in the cache */
   /* search335_0_0_1 -> 268 in the cache */
   /* search335_0_0 -> 1143 in the cache */
   /* search335_0 -> 1148 in the cache */
   /* search335_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1148, 769 },
      -1,
   } },

   /* replace335_0_0_0 -> 127 in the cache */
   /* replace335_0_0_1 -> 125 in the cache */
   /* replace335_0_0 -> 1150 in the cache */
   /* replace335_0 -> 1151 in the cache */
   /* replace335_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1151, 124 },
      -1,
   } },

   /* ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search336_0_0 -> 124 in the cache */
   /* search336_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 124, 268 },
      0,
   } },
   /* search336_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1157, 769 },
      -1,
   } },

   /* replace336_0 -> 124 in the cache */
   /* replace336_1_0 -> 127 in the cache */
   /* replace336_1_1_0 -> 125 in the cache */
   /* replace336_1_1 -> 1145 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 127, 1145 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 124, 1159 },
      -1,
   } },

   /* ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search337_0_0_0 -> 124 in the cache */
   /* search337_0_0_1 -> 268 in the cache */
   /* search337_0_0 -> 1157 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1157 },
      0,
   } },
   /* search337_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1161, 769 },
      -1,
   } },

   /* replace337_0_0_0 -> 127 in the cache */
   /* replace337_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 127, 125 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1163 },
      -1,
   } },
   /* replace337_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1164, 124 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search338_0_0 -> 124 in the cache */
   /* search338_0_1 -> 268 in the cache */
   /* search338_0 -> 1157 in the cache */
   /* search338_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1157, 769 },
      -1,
   } },

   /* replace338_0 -> 124 in the cache */
   /* replace338_1_0 -> 127 in the cache */
   /* replace338_1_1_0 -> 125 in the cache */
   /* replace338_1_1 -> 1145 in the cache */
   /* replace338_1 -> 1159 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 124, 1159 },
      -1,
   } },

   /* ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search339_0_0_0 -> 124 in the cache */
   /* search339_0_0_1 -> 268 in the cache */
   /* search339_0_0 -> 1157 in the cache */
   /* search339_0 -> 1161 in the cache */
   /* search339_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1161, 769 },
      -1,
   } },

   /* replace339_0_0_0 -> 127 in the cache */
   /* replace339_0_0_1 -> 125 in the cache */
   /* replace339_0_0 -> 1163 in the cache */
   /* replace339_0 -> 1164 in the cache */
   /* replace339_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1164, 124 },
      -1,
   } },

   /* ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0) */
   /* search340_0_0 -> 0 in the cache */
   /* search340_0_1 -> 3 in the cache */
   /* search340_0 -> 193 in the cache */
   /* search340_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 193, 0 },
      -1,
   } },

   /* replace340_0 -> 3 in the cache */
   /* replace340_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0) */
   /* search341_0_0 -> 0 in the cache */
   /* search341_0_1 -> 3 in the cache */
   /* search341_0 -> 193 in the cache */
   /* search341_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 193, 0 },
      -1,
   } },

   /* replace341_0 -> 3 in the cache */
   /* replace341_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a') */
   /* search342_0_0 -> 715 in the cache */
   /* search342_0 -> 1078 in the cache */
   /* search342_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1078, 1077 },
      -1,
   } },

   /* replace342_0 -> 715 in the cache */
   /* replace342 -> 1080 in the cache */

   /* ('fneu', ('b2f', 'a@1'), 0.0) => a */
   /* search343_0_0 -> 715 in the cache */
   /* search343_0 -> 1078 in the cache */
   /* search343_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1078, 1077 },
      -1,
   } },

   /* replace343 -> 715 in the cache */

   /* ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a') */
   /* search344_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 715 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1176, 1177 },
      -1,
   } },

   /* replace344_0 -> 715 in the cache */
   /* replace344 -> 1080 in the cache */

   /* ('ine', ('b2i', 'a@1'), 0) => a */
   /* search345_0_0 -> 715 in the cache */
   /* search345_0 -> 1176 in the cache */
   /* search345_1 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1176, 1177 },
      -1,
   } },

   /* replace345 -> 715 in the cache */

   /* ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search346_0_0 -> 32 in the cache */
   /* search346_0 -> 104 in the cache */
   /* search346_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 104, 1077 },
      -1,
   } },

   /* replace346_0 -> 32 in the cache */
   /* replace346_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search347_0_0 -> 32 in the cache */
   /* search347_0 -> 104 in the cache */
   /* search347_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 104, 1077 },
      -1,
   } },

   /* replace347_0 -> 32 in the cache */
   /* replace347_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('fge', ('u2f', 'a'), 0.0) => True */
   /* search348_0_0 -> 32 in the cache */
   /* search348_0 -> 104 in the cache */
   /* search348_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 104, 1077 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_TRUE /* True */ },
   } },

   /* ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a') */
   /* search349_0 -> 1077 in the cache */
   /* search349_1_0 -> 32 in the cache */
   /* search349_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1077, 104 },
      -1,
   } },

   /* replace349_0 -> 61 in the cache */
   /* replace349_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('u2f', 'a'), 0.0) => False */
   /* search350_0_0 -> 32 in the cache */
   /* search350_0 -> 104 in the cache */
   /* search350_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 104, 1077 },
      -1,
   } },

   /* replace350 -> 1032 in the cache */

   /* ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a') */
   /* search351_0 -> 1077 in the cache */
   /* search351_1_0 -> 32 in the cache */
   /* search351_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1077, 104 },
      -1,
   } },

   /* replace351_0 -> 61 in the cache */
   /* replace351_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search352_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search352_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1191, 1077 },
      -1,
   } },

   /* replace352_0 -> 32 in the cache */
   /* replace352_1 -> 61 in the cache */
   /* replace352 -> 1181 in the cache */

   /* ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search353_0_0 -> 32 in the cache */
   /* search353_0 -> 1191 in the cache */
   /* search353_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1191, 1077 },
      -1,
   } },

   /* replace353_0 -> 32 in the cache */
   /* replace353_1 -> 61 in the cache */
   /* replace353 -> 1183 in the cache */

   /* ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0) */
   /* search354_0_0 -> 32 in the cache */
   /* search354_0 -> 1191 in the cache */
   /* search354_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1191, 1077 },
      -1,
   } },

   /* replace354_0 -> 32 in the cache */
   /* replace354_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a') */
   /* search355_0 -> 1077 in the cache */
   /* search355_1_0 -> 32 in the cache */
   /* search355_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1077, 1191 },
      -1,
   } },

   /* replace355_0 -> 61 in the cache */
   /* replace355_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0) */
   /* search356_0_0 -> 32 in the cache */
   /* search356_0 -> 1191 in the cache */
   /* search356_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1191, 1077 },
      -1,
   } },

   /* replace356_0 -> 32 in the cache */
   /* replace356_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a') */
   /* search357_0 -> 1077 in the cache */
   /* search357_1_0 -> 32 in the cache */
   /* search357_1 -> 1191 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1077, 1191 },
      -1,
   } },

   /* replace357_0 -> 61 in the cache */
   /* replace357_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0) */
   /* search358_0 -> 113 in the cache */
   /* search358_1_0 -> 32 in the cache */
   /* search358_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 103 },
      -1,
   } },

   /* replace358_0 -> 32 in the cache */
   /* replace358_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0) */
   /* search359_0_0_0 -> 32 in the cache */
   /* search359_0_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 103 },
      -1,
   } },
   /* search359_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1204, 113 },
      -1,
   } },

   /* replace359_0 -> 32 in the cache */
   /* replace359_1 -> 113 in the cache */
   /* replace359 -> 1203 in the cache */

   /* ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0) */
   /* search360_0 -> 113 in the cache */
   /* search360_1_0 -> 32 in the cache */
   /* search360_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 113, 103 },
      -1,
   } },

   /* replace360_0 -> 32 in the cache */
   /* replace360_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 113 },
      -1,
   } },

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search361_0_0_0 -> 32 in the cache */
   /* search361_0_0 -> 103 in the cache */
   /* search361_0 -> 1204 in the cache */
   /* search361_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1204, 113 },
      -1,
   } },

   /* replace361_0 -> 32 in the cache */
   /* replace361_1 -> 113 in the cache */
   /* replace361 -> 1207 in the cache */

   /* ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a')) */
   /* search362_0_0 -> 32 in the cache */
   /* search362_0_1 -> 113 in the cache */
   /* search362_0 -> 1122 in the cache */
   /* search362_1_0 -> 226 in the cache */
   /* search362_1_1 -> 32 in the cache */
   /* search362_1 -> 1055 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1122, 1055 },
      -1,
   } },

   /* replace362_0 -> 32 in the cache */
   /* replace362_1_0 -> 32 in the cache */
   /* replace362_1 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 202 },
      -1,
   } },

   /* ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b')) */
   /* search363_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 715 },
      0,
   } },
   /* search363_1_0 -> 1083 in the cache */
   /* search363_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1211, 1084 },
      -1,
   } },

   /* replace363_0_0 -> 715 in the cache */
   /* replace363_0_1 -> 1083 in the cache */
   /* replace363_0 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1087 },
      -1,
   } },

   /* ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b'))) */
   /* search364_0_0_0 -> 715 in the cache */
   /* search364_0_0 -> 1211 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1211 },
      0,
   } },
   /* search364_1_0_0 -> 1083 in the cache */
   /* search364_1_0 -> 1084 in the cache */
   /* search364_1 -> 1091 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1214, 1091 },
      -1,
   } },

   /* replace364_0_0_0 -> 715 in the cache */
   /* replace364_0_0_1 -> 1083 in the cache */
   /* replace364_0_0 -> 1095 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1095 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1216 },
      -1,
   } },

   /* ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search365_0_0 -> 715 in the cache */
   /* search365_0 -> 1211 in the cache */
   /* search365_1_0 -> 1083 in the cache */
   /* search365_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1211, 1084 },
      -1,
   } },

   /* replace365_0_0 -> 715 in the cache */
   /* replace365_0_1 -> 1083 in the cache */
   /* replace365_0 -> 1095 in the cache */
   /* replace365 -> 1216 in the cache */

   /* ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b'))) */
   /* search366_0_0_0 -> 715 in the cache */
   /* search366_0_0 -> 1211 in the cache */
   /* search366_0 -> 1214 in the cache */
   /* search366_1_0_0 -> 1083 in the cache */
   /* search366_1_0 -> 1084 in the cache */
   /* search366_1 -> 1091 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1214, 1091 },
      -1,
   } },

   /* replace366_0_0_0 -> 715 in the cache */
   /* replace366_0_0_1 -> 1083 in the cache */
   /* replace366_0_0 -> 1087 in the cache */
   /* replace366_0 -> 1213 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1213 },
      -1,
   } },

   /* ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0)) */
   /* search367_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search367_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1221, 776 },
      -1,
   } },

   /* replace367_0 -> 715 in the cache */
   /* replace367_1_0 -> 3 in the cache */
   /* replace367_1_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 3, 255 },
      -1,
   } },
   /* replace367_2_0 -> 3 in the cache */
   /* replace367_2_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 3, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 1223, 1224 },
      -1,
   } },

   /* ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b') */
   /* search368_0_0 -> 0 in the cache */
   /* search368_0_1_0 -> 3 in the cache */
   /* search368_0_1 -> 1042 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1042 },
      0,
   } },
   /* search368_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1226, 241 },
      -1,
   } },

   /* replace368_0 -> 0 in the cache */
   /* replace368_1 -> 3 in the cache */
   /* replace368 -> 1004 in the cache */

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search369_0_0_0 -> 32 in the cache */
   /* search369_0_0 -> 103 in the cache */
   /* search369_0 -> 1204 in the cache */
   /* search369_1 -> 113 in the cache */
   /* search369 -> 1208 in the cache */

   /* replace369_0 -> 32 in the cache */
   /* replace369_1 -> 113 in the cache */
   /* replace369 -> 1207 in the cache */

   /* ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search370_0_0 -> 1066 in the cache */
   /* search370_0_1 -> 1063 in the cache */
   /* search370_0 -> 1067 in the cache */
   /* search370_1 -> 1066 in the cache */
   /* search370_2 -> 1063 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1067, 1066, 1063 },
      -1,
   } },

   /* replace370_0 -> 1063 in the cache */
   /* replace370_1 -> 1066 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1063, 1066 },
      -1,
   } },

   /* ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search371_0_0 -> 0 in the cache */
   /* search371_0_1 -> 3 in the cache */
   /* search371_0 -> 1004 in the cache */
   /* search371_1 -> 3 in the cache */
   /* search371_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1004, 3, 0 },
      -1,
   } },

   /* replace371_0 -> 0 in the cache */
   /* replace371_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search372_0_0 -> 0 in the cache */
   /* search372_0_1 -> 3 in the cache */
   /* search372_0 -> 1001 in the cache */
   /* search372_1 -> 3 in the cache */
   /* search372_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1001, 3, 0 },
      -1,
   } },

   /* replace372_0 -> 0 in the cache */
   /* replace372_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search373_0_0 -> 1066 in the cache */
   /* search373_0_1 -> 1063 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1066, 1063 },
      -1,
   } },
   /* search373_1 -> 1066 in the cache */
   /* search373_2 -> 1063 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1234, 1066, 1063 },
      -1,
   } },

   /* replace373_0 -> 1063 in the cache */
   /* replace373_1 -> 1066 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1063, 1066 },
      -1,
   } },

   /* ('bcsel', ('i2b', 'a'), 'b', 'c') => ('bcsel', ('ine', 'a', 0), 'b', 'c') */
   /* search374_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search374_1 -> 125 in the cache */
   /* search374_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1237, 125, 127 },
      -1,
   } },

   /* replace374_0_0 -> 32 in the cache */
   /* replace374_0_1 -> 61 in the cache */
   /* replace374_0 -> 1181 in the cache */
   /* replace374_1 -> 125 in the cache */
   /* replace374_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1181, 125, 127 },
      -1,
   } },

   /* ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b') */
   /* search375_0_0 -> 715 in the cache */
   /* search375_0 -> 1080 in the cache */
   /* search375_1 -> 125 in the cache */
   /* search375_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1080, 125, 127 },
      -1,
   } },

   /* replace375_0 -> 715 in the cache */
   /* replace375_1 -> 127 in the cache */
   /* replace375_2 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 127, 125 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd') */
   /* search376_0 -> 715 in the cache */
   /* search376_1_0 -> 715 in the cache */
   /* search376_1_1 -> 148 in the cache */
   /* search376_1_2 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 148, 150 },
      -1,
   } },
   /* search376_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1242, 151 },
      -1,
   } },

   /* replace376_0 -> 715 in the cache */
   /* replace376_1 -> 148 in the cache */
   /* replace376_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 148, 151 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd') */
   /* search377_0 -> 715 in the cache */
   /* search377_1 -> 148 in the cache */
   /* search377_2_0 -> 715 in the cache */
   /* search377_2_1 -> 150 in the cache */
   /* search377_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 148, 1245 },
      -1,
   } },

   /* replace377_0 -> 715 in the cache */
   /* replace377_1 -> 148 in the cache */
   /* replace377_2 -> 151 in the cache */
   /* replace377 -> 1244 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search378_0 -> 715 in the cache */
   /* search378_1_0 -> 1083 in the cache */
   /* search378_1_1 -> 708 in the cache */
   /* search378_1_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1083, 708, 717 },
      -1,
   } },
   /* search378_2_0 -> 1083 in the cache */
   /* search378_2_1 -> 708 in the cache */
   /* search378_2_2 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1083, 708, 719 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1247, 1248 },
      -1,
   } },

   /* replace378_0 -> 1083 in the cache */
   /* replace378_1 -> 708 in the cache */
   /* replace378_2_0 -> 715 in the cache */
   /* replace378_2_1 -> 717 in the cache */
   /* replace378_2_2 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 717, 719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1083, 708, 1250 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search379_0 -> 715 in the cache */
   /* search379_1_0 -> 1083 in the cache */
   /* search379_1_1 -> 708 in the cache */
   /* search379_1_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1083, 708, 717 },
      0,
   } },
   /* search379_2_0 -> 1083 in the cache */
   /* search379_2_1 -> 708 in the cache */
   /* search379_2_2 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1083, 708, 719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1252, 1253 },
      -1,
   } },

   /* replace379_0 -> 1083 in the cache */
   /* replace379_1 -> 708 in the cache */
   /* replace379_2_0 -> 715 in the cache */
   /* replace379_2_1 -> 717 in the cache */
   /* replace379_2_2 -> 719 in the cache */
   /* replace379_2 -> 1250 in the cache */
   /* replace379 -> 1251 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search380_0 -> 715 in the cache */
   /* search380_1_0 -> 1083 in the cache */
   /* search380_1_1 -> 150 in the cache */
   /* search380_1_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1083, 150, 151 },
      -1,
   } },
   /* search380_2_0 -> 1083 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search380_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1083, 1256, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1255, 1257 },
      -1,
   } },

   /* replace380_0 -> 1083 in the cache */
   /* replace380_1_0 -> 715 in the cache */
   /* replace380_1_1 -> 150 in the cache */
   /* replace380_1_2 -> 1256 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 150, 1256 },
      -1,
   } },
   /* replace380_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1083, 1259, 151 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search381_0 -> 715 in the cache */
   /* search381_1_0 -> 1083 in the cache */
   /* search381_1_1 -> 150 in the cache */
   /* search381_1_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1083, 150, 151 },
      0,
   } },
   /* search381_2_0 -> 1083 in the cache */
   /* search381_2_1 -> 1256 in the cache */
   /* search381_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1083, 1256, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1261, 1262 },
      -1,
   } },

   /* replace381_0 -> 1083 in the cache */
   /* replace381_1_0 -> 715 in the cache */
   /* replace381_1_1 -> 150 in the cache */
   /* replace381_1_2 -> 1256 in the cache */
   /* replace381_1 -> 1259 in the cache */
   /* replace381_2 -> 151 in the cache */
   /* replace381 -> 1260 in the cache */

   /* ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b') */
   /* search382_0 -> 715 in the cache */
   /* search382_1 -> 1185 in the cache */
   /* search382_2 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1185, 1083 },
      -1,
   } },

   /* replace382_0 -> 715 in the cache */
   /* replace382_1 -> 1083 in the cache */
   /* replace382 -> 1087 in the cache */

   /* ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b') */
   /* search383_0 -> 715 in the cache */
   /* search383_1 -> 715 in the cache */
   /* search383_2 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 715, 1083 },
      -1,
   } },

   /* replace383_0 -> 715 in the cache */
   /* replace383_1 -> 1083 in the cache */
   /* replace383 -> 1087 in the cache */

   /* ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b') */
   /* search384_0 -> 715 in the cache */
   /* search384_1 -> 1083 in the cache */
   /* search384_2 -> 1032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1083, 1032 },
      -1,
   } },

   /* replace384_0 -> 715 in the cache */
   /* replace384_1 -> 1083 in the cache */
   /* replace384 -> 1095 in the cache */

   /* ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b') */
   /* search385_0 -> 715 in the cache */
   /* search385_1 -> 1083 in the cache */
   /* search385_2 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1083, 715 },
      -1,
   } },

   /* replace385_0 -> 715 in the cache */
   /* replace385_1 -> 1083 in the cache */
   /* replace385 -> 1095 in the cache */

   /* ('~fmin', 'a', 'a') => a */
   /* search386_0 -> 32 in the cache */
   /* search386_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace386 -> 32 in the cache */

   /* ('~fmax', 'a', 'a') => a */
   /* search387_0 -> 32 in the cache */
   /* search387_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace387 -> 32 in the cache */

   /* ('imin', 'a', 'a') => a */
   /* search388_0 -> 32 in the cache */
   /* search388_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace388 -> 32 in the cache */

   /* ('imax', 'a', 'a') => a */
   /* search389_0 -> 32 in the cache */
   /* search389_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace389 -> 32 in the cache */

   /* ('umin', 'a', 'a') => a */
   /* search390_0 -> 32 in the cache */
   /* search390_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace390 -> 32 in the cache */

   /* ('umin', 'a', 0) => 0 */
   /* search391_0 -> 32 in the cache */
   /* search391_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace391 -> 61 in the cache */

   /* ('umin', 'a', -1) => a */
   /* search392_0 -> 32 in the cache */
   /* search392_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace392 -> 32 in the cache */

   /* ('umax', 'a', 'a') => a */
   /* search393_0 -> 32 in the cache */
   /* search393_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace393 -> 32 in the cache */

   /* ('umax', 'a', 0) => a */
   /* search394_0 -> 32 in the cache */
   /* search394_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace394 -> 32 in the cache */

   /* ('umax', 'a', -1) => -1 */
   /* search395_0 -> 32 in the cache */
   /* search395_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace395 -> 63 in the cache */

   /* ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b') */
   /* search396_0_0 -> 0 in the cache */
   /* search396_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search396_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1278, 3 },
      -1,
   } },

   /* replace396_0 -> 0 in the cache */
   /* replace396_1 -> 3 in the cache */
   /* replace396 -> 1231 in the cache */

   /* ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b') */
   /* search397_0_0 -> 0 in the cache */
   /* search397_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search397_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1280, 3 },
      -1,
   } },

   /* replace397_0 -> 0 in the cache */
   /* replace397_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b') */
   /* search398_0_0 -> 0 in the cache */
   /* search398_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search398_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1283, 3 },
      -1,
   } },

   /* replace398_0 -> 0 in the cache */
   /* replace398_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b') */
   /* search399_0_0 -> 0 in the cache */
   /* search399_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search399_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1286, 3 },
      -1,
   } },

   /* replace399_0 -> 0 in the cache */
   /* replace399_1 -> 3 in the cache */
   /* replace399 -> 1233 in the cache */

   /* ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b') */
   /* search400_0_0 -> 0 in the cache */
   /* search400_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search400_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1288, 3 },
      -1,
   } },

   /* replace400_0 -> 0 in the cache */
   /* replace400_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b') */
   /* search401_0_0 -> 0 in the cache */
   /* search401_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search401_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1291, 3 },
      -1,
   } },

   /* replace401_0 -> 0 in the cache */
   /* replace401_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c') */
   /* search402_0_0_0 -> 124 in the cache */
   /* search402_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search402_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 2,
      { 1294, 127 },
      -1,
   } },
   /* search402_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 1295, 124 },
      -1,
   } },

   /* replace402_0_0 -> 124 in the cache */
   /* replace402_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace402_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1297, 127 },
      -1,
   } },

   /* ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c') */
   /* search403_0_0_0 -> 124 in the cache */
   /* search403_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search403_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 2,
      { 1299, 127 },
      -1,
   } },
   /* search403_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 3,
      { 1300, 124 },
      -1,
   } },

   /* replace403_0_0 -> 124 in the cache */
   /* replace403_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace403_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1302, 127 },
      -1,
   } },

   /* ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c') */
   /* search404_0_0_0 -> 124 in the cache */
   /* search404_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search404_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 2,
      { 1304, 127 },
      -1,
   } },
   /* search404_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 3,
      { 1305, 124 },
      -1,
   } },

   /* replace404_0_0 -> 124 in the cache */
   /* replace404_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace404_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1307, 127 },
      -1,
   } },

   /* ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c') */
   /* search405_0_0_0 -> 124 in the cache */
   /* search405_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search405_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 1309, 127 },
      -1,
   } },
   /* search405_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 1310, 124 },
      -1,
   } },

   /* replace405_0_0 -> 124 in the cache */
   /* replace405_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace405_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1312, 127 },
      -1,
   } },

   /* ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c') */
   /* search406_0_0_0 -> 124 in the cache */
   /* search406_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search406_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      1, 2,
      { 1314, 127 },
      -1,
   } },
   /* search406_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 1315, 124 },
      -1,
   } },

   /* replace406_0_0 -> 124 in the cache */
   /* replace406_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace406_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1317, 127 },
      -1,
   } },

   /* ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c') */
   /* search407_0_0_0 -> 124 in the cache */
   /* search407_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      2, 1,
      { 124, 125 },
      -1,
   } },
   /* search407_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      1, 2,
      { 1319, 127 },
      -1,
   } },
   /* search407_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 3,
      { 1320, 124 },
      -1,
   } },

   /* replace407_0_0 -> 124 in the cache */
   /* replace407_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 124, 125 },
      -1,
   } },
   /* replace407_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1322, 127 },
      -1,
   } },

   /* ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b') */
   /* search408_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search408_1_0 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 1083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1324, 1325 },
      -1,
   } },

   /* replace408_0 -> 715 in the cache */
   /* replace408_1 -> 1083 in the cache */
   /* replace408 -> 1111 in the cache */

   /* ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b') */
   /* search409_0_0 -> 715 in the cache */
   /* search409_0 -> 1324 in the cache */
   /* search409_1_0 -> 1083 in the cache */
   /* search409_1 -> 1325 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1324, 1325 },
      -1,
   } },

   /* replace409_0 -> 715 in the cache */
   /* replace409_1 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 715, 1083 },
      -1,
   } },

   /* ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search410_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search410_1_0 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1329, 1330 },
      -1,
   } },

   /* replace410_0 -> 715 in the cache */
   /* replace410_1 -> 1083 in the cache */
   /* replace410 -> 1111 in the cache */

   /* ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b') */
   /* search411_0_0 -> 715 in the cache */
   /* search411_0 -> 1329 in the cache */
   /* search411_1_0 -> 1083 in the cache */
   /* search411_1 -> 1330 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1329, 1330 },
      -1,
   } },

   /* replace411_0 -> 715 in the cache */
   /* replace411_1 -> 1083 in the cache */
   /* replace411 -> 1328 in the cache */

   /* ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search412_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search412_1_0 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1333, 1334 },
      -1,
   } },

   /* replace412_0 -> 715 in the cache */
   /* replace412_1 -> 1083 in the cache */
   /* replace412 -> 1111 in the cache */

   /* ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b') */
   /* search413_0_0 -> 715 in the cache */
   /* search413_0 -> 1333 in the cache */
   /* search413_1_0 -> 1083 in the cache */
   /* search413_1 -> 1334 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1333, 1334 },
      -1,
   } },

   /* replace413_0 -> 715 in the cache */
   /* replace413_1 -> 1083 in the cache */
   /* replace413 -> 1328 in the cache */

   /* ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search414_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search414_1_0 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1337, 1338 },
      -1,
   } },

   /* replace414_0 -> 715 in the cache */
   /* replace414_1 -> 1083 in the cache */
   /* replace414 -> 1111 in the cache */

   /* ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b') */
   /* search415_0_0 -> 715 in the cache */
   /* search415_0 -> 1337 in the cache */
   /* search415_1_0 -> 1083 in the cache */
   /* search415_1 -> 1338 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1337, 1338 },
      -1,
   } },

   /* replace415_0 -> 715 in the cache */
   /* replace415_1 -> 1083 in the cache */
   /* replace415 -> 1328 in the cache */

   /* ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search416_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search416_1_0 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1341, 1342 },
      -1,
   } },

   /* replace416_0 -> 715 in the cache */
   /* replace416_1 -> 1083 in the cache */
   /* replace416 -> 1111 in the cache */

   /* ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b') */
   /* search417_0_0 -> 715 in the cache */
   /* search417_0 -> 1341 in the cache */
   /* search417_1_0 -> 1083 in the cache */
   /* search417_1 -> 1342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1341, 1342 },
      -1,
   } },

   /* replace417_0 -> 715 in the cache */
   /* replace417_1 -> 1083 in the cache */
   /* replace417 -> 1328 in the cache */

   /* ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search418_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search418_1_0 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1345, 1346 },
      -1,
   } },

   /* replace418_0 -> 715 in the cache */
   /* replace418_1 -> 1083 in the cache */
   /* replace418 -> 1111 in the cache */

   /* ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b') */
   /* search419_0_0 -> 715 in the cache */
   /* search419_0 -> 1345 in the cache */
   /* search419_1_0 -> 1083 in the cache */
   /* search419_1 -> 1346 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1345, 1346 },
      -1,
   } },

   /* replace419_0 -> 715 in the cache */
   /* replace419_1 -> 1083 in the cache */
   /* replace419 -> 1328 in the cache */

   /* ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search420_0_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 715 },
      -1,
   } },
   /* search420_1_0 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1349, 1350 },
      -1,
   } },

   /* replace420_0 -> 715 in the cache */
   /* replace420_1 -> 1083 in the cache */
   /* replace420 -> 1111 in the cache */

   /* ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b') */
   /* search421_0_0 -> 715 in the cache */
   /* search421_0 -> 1349 in the cache */
   /* search421_1_0 -> 1083 in the cache */
   /* search421_1 -> 1350 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1349, 1350 },
      -1,
   } },

   /* replace421_0 -> 715 in the cache */
   /* replace421_1 -> 1083 in the cache */
   /* replace421 -> 1328 in the cache */

   /* ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0) */
   /* search422_0 -> 6 in the cache */
   /* search422_1_0_0 -> 6 in the cache */
   /* search422_1_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 1354 },
      -1,
   } },

   /* replace422_0 -> 6 in the cache */
   /* replace422_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 6, 790 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0) */
   /* search423_0_0 -> 6 in the cache */
   /* search423_0_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 6, 7 },
      -1,
   } },
   /* search423_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1357, 790 },
      -1,
   } },

   /* replace423_0 -> 6 in the cache */
   /* replace423_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 790 },
      -1,
   } },

   /* ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0) */
   /* search424_0_0 -> 6 in the cache */
   /* search424_0_1 -> 7 in the cache */
   /* search424_0 -> 1357 in the cache */
   /* search424_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1357, 7 },
      -1,
   } },

   /* replace424_0 -> 6 in the cache */
   /* replace424_1 -> 790 in the cache */
   /* replace424 -> 1359 in the cache */

   /* ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0) */
   /* search425_0_0 -> 6 in the cache */
   /* search425_0_1 -> 7 in the cache */
   /* search425_0 -> 1357 in the cache */
   /* search425_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1357, 790 },
      -1,
   } },

   /* replace425_0 -> 6 in the cache */
   /* replace425_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 790 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0) */
   /* search426_0_0 -> 6 in the cache */
   /* search426_0_1 -> 7 in the cache */
   /* search426_0 -> 1357 in the cache */
   /* search426_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1357, 7 },
      -1,
   } },

   /* replace426_0 -> 6 in the cache */
   /* replace426_1 -> 790 in the cache */
   /* replace426 -> 1362 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search427_0_0 -> 6 in the cache */
   /* search427_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   /* search427_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1364, 790 },
      -1,
   } },

   /* replace427_0 -> 6 in the cache */
   /* replace427_1 -> 790 in the cache */
   /* replace427 -> 1362 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search428_0_0 -> 6 in the cache */
   /* search428_0_1 -> 9 in the cache */
   /* search428_0 -> 1364 in the cache */
   /* search428_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1364, 790 },
      -1,
   } },

   /* replace428_0 -> 6 in the cache */
   /* replace428_1 -> 790 in the cache */
   /* replace428 -> 1359 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0) */
   /* search429_0_0 -> 6 in the cache */
   /* search429_0_1 -> 9 in the cache */
   /* search429_0 -> 1364 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1364, 1367 },
      -1,
   } },

   /* replace429_0 -> 6 in the cache */
   /* replace429_1 -> 790 in the cache */
   /* replace429 -> 1362 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0) */
   /* search430_0_0 -> 6 in the cache */
   /* search430_0_1 -> 9 in the cache */
   /* search430_0 -> 1364 in the cache */
   /* search430_1 -> 1367 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1364, 1367 },
      -1,
   } },

   /* replace430_0 -> 6 in the cache */
   /* replace430_1 -> 790 in the cache */
   /* replace430 -> 1359 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search431_0_0 -> 6 in the cache */
   /* search431_0_1 -> 9 in the cache */
   /* search431_0 -> 1353 in the cache */
   /* search431_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1353, 790 },
      -1,
   } },

   /* replace431_0 -> 6 in the cache */
   /* replace431_1 -> 790 in the cache */
   /* replace431 -> 1362 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search432_0_0 -> 6 in the cache */
   /* search432_0_1 -> 9 in the cache */
   /* search432_0 -> 1353 in the cache */
   /* search432_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1353, 790 },
      -1,
   } },

   /* replace432_0 -> 6 in the cache */
   /* replace432_1 -> 790 in the cache */
   /* replace432 -> 1359 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0) */
   /* search433_0_0 -> 6 in the cache */
   /* search433_0_1 -> 9 in the cache */
   /* search433_0 -> 1353 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1353, 1372 },
      -1,
   } },

   /* replace433_0 -> 6 in the cache */
   /* replace433_1 -> 790 in the cache */
   /* replace433 -> 1362 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0) */
   /* search434_0_0 -> 6 in the cache */
   /* search434_0_1 -> 9 in the cache */
   /* search434_0 -> 1353 in the cache */
   /* search434_1 -> 1372 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1353, 1372 },
      -1,
   } },

   /* replace434_0 -> 6 in the cache */
   /* replace434_1 -> 790 in the cache */
   /* replace434 -> 1359 in the cache */

   /* ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0) */
   /* search435_0 -> 11 in the cache */
   /* search435_1_0_0 -> 11 in the cache */
   /* search435_1_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1375 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1376 },
      -1,
   } },

   /* replace435_0 -> 11 in the cache */
   /* replace435_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 11, 811 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0) */
   /* search436_0_0 -> 11 in the cache */
   /* search436_0_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 11, 12 },
      -1,
   } },
   /* search436_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1379, 811 },
      -1,
   } },

   /* replace436_0 -> 11 in the cache */
   /* replace436_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 811 },
      -1,
   } },

   /* ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0) */
   /* search437_0_0 -> 11 in the cache */
   /* search437_0_1 -> 12 in the cache */
   /* search437_0 -> 1379 in the cache */
   /* search437_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1379, 12 },
      -1,
   } },

   /* replace437_0 -> 11 in the cache */
   /* replace437_1 -> 811 in the cache */
   /* replace437 -> 1381 in the cache */

   /* ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0) */
   /* search438_0_0 -> 11 in the cache */
   /* search438_0_1 -> 12 in the cache */
   /* search438_0 -> 1379 in the cache */
   /* search438_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1379, 811 },
      -1,
   } },

   /* replace438_0 -> 11 in the cache */
   /* replace438_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 811 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0) */
   /* search439_0_0 -> 11 in the cache */
   /* search439_0_1 -> 12 in the cache */
   /* search439_0 -> 1379 in the cache */
   /* search439_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1379, 12 },
      -1,
   } },

   /* replace439_0 -> 11 in the cache */
   /* replace439_1 -> 811 in the cache */
   /* replace439 -> 1384 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search440_0_0 -> 11 in the cache */
   /* search440_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   /* search440_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1386, 811 },
      -1,
   } },

   /* replace440_0 -> 11 in the cache */
   /* replace440_1 -> 811 in the cache */
   /* replace440 -> 1384 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search441_0_0 -> 11 in the cache */
   /* search441_0_1 -> 14 in the cache */
   /* search441_0 -> 1386 in the cache */
   /* search441_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1386, 811 },
      -1,
   } },

   /* replace441_0 -> 11 in the cache */
   /* replace441_1 -> 811 in the cache */
   /* replace441 -> 1381 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0) */
   /* search442_0_0 -> 11 in the cache */
   /* search442_0_1 -> 14 in the cache */
   /* search442_0 -> 1386 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1386, 1389 },
      -1,
   } },

   /* replace442_0 -> 11 in the cache */
   /* replace442_1 -> 811 in the cache */
   /* replace442 -> 1384 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0) */
   /* search443_0_0 -> 11 in the cache */
   /* search443_0_1 -> 14 in the cache */
   /* search443_0 -> 1386 in the cache */
   /* search443_1 -> 1389 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1386, 1389 },
      -1,
   } },

   /* replace443_0 -> 11 in the cache */
   /* replace443_1 -> 811 in the cache */
   /* replace443 -> 1381 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search444_0_0 -> 11 in the cache */
   /* search444_0_1 -> 14 in the cache */
   /* search444_0 -> 1375 in the cache */
   /* search444_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1375, 811 },
      -1,
   } },

   /* replace444_0 -> 11 in the cache */
   /* replace444_1 -> 811 in the cache */
   /* replace444 -> 1384 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search445_0_0 -> 11 in the cache */
   /* search445_0_1 -> 14 in the cache */
   /* search445_0 -> 1375 in the cache */
   /* search445_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1375, 811 },
      -1,
   } },

   /* replace445_0 -> 11 in the cache */
   /* replace445_1 -> 811 in the cache */
   /* replace445 -> 1381 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0) */
   /* search446_0_0 -> 11 in the cache */
   /* search446_0_1 -> 14 in the cache */
   /* search446_0 -> 1375 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1375, 1394 },
      -1,
   } },

   /* replace446_0 -> 11 in the cache */
   /* replace446_1 -> 811 in the cache */
   /* replace446 -> 1384 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0) */
   /* search447_0_0 -> 11 in the cache */
   /* search447_0_1 -> 14 in the cache */
   /* search447_0 -> 1375 in the cache */
   /* search447_1 -> 1394 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1375, 1394 },
      -1,
   } },

   /* replace447_0 -> 11 in the cache */
   /* replace447_1 -> 811 in the cache */
   /* replace447 -> 1381 in the cache */

   /* ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0) */
   /* search448_0 -> 16 in the cache */
   /* search448_1_0_0 -> 16 in the cache */
   /* search448_1_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 1398 },
      -1,
   } },

   /* replace448_0 -> 16 in the cache */
   /* replace448_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0) */
   /* search449_0_0 -> 16 in the cache */
   /* search449_0_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 17 },
      -1,
   } },
   /* search449_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1401, 120 },
      -1,
   } },

   /* replace449_0 -> 16 in the cache */
   /* replace449_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 120 },
      -1,
   } },

   /* ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0) */
   /* search450_0_0 -> 16 in the cache */
   /* search450_0_1 -> 17 in the cache */
   /* search450_0 -> 1401 in the cache */
   /* search450_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1401, 17 },
      -1,
   } },

   /* replace450_0 -> 16 in the cache */
   /* replace450_1 -> 120 in the cache */
   /* replace450 -> 1403 in the cache */

   /* ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0) */
   /* search451_0_0 -> 16 in the cache */
   /* search451_0_1 -> 17 in the cache */
   /* search451_0 -> 1401 in the cache */
   /* search451_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1401, 120 },
      -1,
   } },

   /* replace451_0 -> 16 in the cache */
   /* replace451_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 120 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0) */
   /* search452_0_0 -> 16 in the cache */
   /* search452_0_1 -> 17 in the cache */
   /* search452_0 -> 1401 in the cache */
   /* search452_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1401, 17 },
      -1,
   } },

   /* replace452_0 -> 16 in the cache */
   /* replace452_1 -> 120 in the cache */
   /* replace452 -> 1406 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search453_0_0 -> 16 in the cache */
   /* search453_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   /* search453_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1408, 120 },
      -1,
   } },

   /* replace453_0 -> 16 in the cache */
   /* replace453_1 -> 120 in the cache */
   /* replace453 -> 1406 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search454_0_0 -> 16 in the cache */
   /* search454_0_1 -> 19 in the cache */
   /* search454_0 -> 1408 in the cache */
   /* search454_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1408, 120 },
      -1,
   } },

   /* replace454_0 -> 16 in the cache */
   /* replace454_1 -> 120 in the cache */
   /* replace454 -> 1403 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0) */
   /* search455_0_0 -> 16 in the cache */
   /* search455_0_1 -> 19 in the cache */
   /* search455_0 -> 1408 in the cache */
   /* search455_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1408, 377 },
      -1,
   } },

   /* replace455_0 -> 16 in the cache */
   /* replace455_1 -> 120 in the cache */
   /* replace455 -> 1406 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0) */
   /* search456_0_0 -> 16 in the cache */
   /* search456_0_1 -> 19 in the cache */
   /* search456_0 -> 1408 in the cache */
   /* search456_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1408, 377 },
      -1,
   } },

   /* replace456_0 -> 16 in the cache */
   /* replace456_1 -> 120 in the cache */
   /* replace456 -> 1403 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search457_0_0 -> 16 in the cache */
   /* search457_0_1 -> 19 in the cache */
   /* search457_0 -> 1397 in the cache */
   /* search457_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1397, 120 },
      -1,
   } },

   /* replace457_0 -> 16 in the cache */
   /* replace457_1 -> 120 in the cache */
   /* replace457 -> 1406 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search458_0_0 -> 16 in the cache */
   /* search458_0_1 -> 19 in the cache */
   /* search458_0 -> 1397 in the cache */
   /* search458_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1397, 120 },
      -1,
   } },

   /* replace458_0 -> 16 in the cache */
   /* replace458_1 -> 120 in the cache */
   /* replace458 -> 1403 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0) */
   /* search459_0_0 -> 16 in the cache */
   /* search459_0_1 -> 19 in the cache */
   /* search459_0 -> 1397 in the cache */
   /* search459_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1397, 122 },
      -1,
   } },

   /* replace459_0 -> 16 in the cache */
   /* replace459_1 -> 120 in the cache */
   /* replace459 -> 1406 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0) */
   /* search460_0_0 -> 16 in the cache */
   /* search460_0_1 -> 19 in the cache */
   /* search460_0 -> 1397 in the cache */
   /* search460_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1397, 122 },
      -1,
   } },

   /* replace460_0 -> 16 in the cache */
   /* replace460_1 -> 120 in the cache */
   /* replace460 -> 1403 in the cache */

   /* ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0) */
   /* search461_0 -> 21 in the cache */
   /* search461_1_0_0 -> 21 in the cache */
   /* search461_1_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1417 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 1418 },
      -1,
   } },

   /* replace461_0 -> 21 in the cache */
   /* replace461_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 21, 852 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0) */
   /* search462_0_0 -> 21 in the cache */
   /* search462_0_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 21, 22 },
      -1,
   } },
   /* search462_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1421, 852 },
      -1,
   } },

   /* replace462_0 -> 21 in the cache */
   /* replace462_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 852 },
      -1,
   } },

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0) */
   /* search463_0_0 -> 21 in the cache */
   /* search463_0_1 -> 22 in the cache */
   /* search463_0 -> 1421 in the cache */
   /* search463_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1421, 22 },
      -1,
   } },

   /* replace463_0 -> 21 in the cache */
   /* replace463_1 -> 852 in the cache */
   /* replace463 -> 1423 in the cache */

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0) */
   /* search464_0_0 -> 21 in the cache */
   /* search464_0_1 -> 22 in the cache */
   /* search464_0 -> 1421 in the cache */
   /* search464_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1421, 852 },
      -1,
   } },

   /* replace464_0 -> 21 in the cache */
   /* replace464_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 852 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0) */
   /* search465_0_0 -> 21 in the cache */
   /* search465_0_1 -> 22 in the cache */
   /* search465_0 -> 1421 in the cache */
   /* search465_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1421, 22 },
      -1,
   } },

   /* replace465_0 -> 21 in the cache */
   /* replace465_1 -> 852 in the cache */
   /* replace465 -> 1426 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search466_0_0 -> 21 in the cache */
   /* search466_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   /* search466_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1428, 852 },
      -1,
   } },

   /* replace466_0 -> 21 in the cache */
   /* replace466_1 -> 852 in the cache */
   /* replace466 -> 1426 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search467_0_0 -> 21 in the cache */
   /* search467_0_1 -> 24 in the cache */
   /* search467_0 -> 1428 in the cache */
   /* search467_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1428, 852 },
      -1,
   } },

   /* replace467_0 -> 21 in the cache */
   /* replace467_1 -> 852 in the cache */
   /* replace467 -> 1423 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0) */
   /* search468_0_0 -> 21 in the cache */
   /* search468_0_1 -> 24 in the cache */
   /* search468_0 -> 1428 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1428, 1431 },
      -1,
   } },

   /* replace468_0 -> 21 in the cache */
   /* replace468_1 -> 852 in the cache */
   /* replace468 -> 1426 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0) */
   /* search469_0_0 -> 21 in the cache */
   /* search469_0_1 -> 24 in the cache */
   /* search469_0 -> 1428 in the cache */
   /* search469_1 -> 1431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1428, 1431 },
      -1,
   } },

   /* replace469_0 -> 21 in the cache */
   /* replace469_1 -> 852 in the cache */
   /* replace469 -> 1423 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search470_0_0 -> 21 in the cache */
   /* search470_0_1 -> 24 in the cache */
   /* search470_0 -> 1417 in the cache */
   /* search470_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1417, 852 },
      -1,
   } },

   /* replace470_0 -> 21 in the cache */
   /* replace470_1 -> 852 in the cache */
   /* replace470 -> 1426 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search471_0_0 -> 21 in the cache */
   /* search471_0_1 -> 24 in the cache */
   /* search471_0 -> 1417 in the cache */
   /* search471_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1417, 852 },
      -1,
   } },

   /* replace471_0 -> 21 in the cache */
   /* replace471_1 -> 852 in the cache */
   /* replace471 -> 1423 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0) */
   /* search472_0_0 -> 21 in the cache */
   /* search472_0_1 -> 24 in the cache */
   /* search472_0 -> 1417 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1417, 1436 },
      -1,
   } },

   /* replace472_0 -> 21 in the cache */
   /* replace472_1 -> 852 in the cache */
   /* replace472 -> 1426 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0) */
   /* search473_0_0 -> 21 in the cache */
   /* search473_0_1 -> 24 in the cache */
   /* search473_0 -> 1417 in the cache */
   /* search473_1 -> 1436 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1417, 1436 },
      -1,
   } },

   /* replace473_0 -> 21 in the cache */
   /* replace473_1 -> 852 in the cache */
   /* replace473 -> 1423 in the cache */

   /* ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a')) */
   /* search474_0 -> 32 in the cache */
   /* search474_1_0 -> 32 in the cache */
   /* search474_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace474_0_0 -> 32 in the cache */
   /* replace474_0 -> 103 in the cache */
   /* replace474 -> 1204 in the cache */

   /* ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a')) */
   /* search475_0 -> 32 in the cache */
   /* search475_1_0 -> 32 in the cache */
   /* search475_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace475_0_0 -> 32 in the cache */
   /* replace475_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 106 },
      -1,
   } },

   /* ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a')) */
   /* search476_0 -> 32 in the cache */
   /* search476_1_0_0 -> 32 in the cache */
   /* search476_1_0 -> 103 in the cache */
   /* search476_1 -> 1204 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 1204 },
      -1,
   } },

   /* replace476_0_0 -> 32 in the cache */
   /* replace476_0 -> 103 in the cache */
   /* replace476 -> 1204 in the cache */

   /* ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a')) */
   /* search477_0 -> 32 in the cache */
   /* search477_1_0_0 -> 32 in the cache */
   /* search477_1_0 -> 106 in the cache */
   /* search477_1 -> 1441 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 1441 },
      -1,
   } },

   /* replace477_0_0 -> 32 in the cache */
   /* replace477_0 -> 106 in the cache */
   /* replace477 -> 1441 in the cache */

   /* ('~fmin', 'a', ('fabs', 'a')) => a */
   /* search478_0 -> 32 in the cache */
   /* search478_1_0 -> 32 in the cache */
   /* search478_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace478 -> 32 in the cache */

   /* ('imin', 'a', ('iabs', 'a')) => a */
   /* search479_0 -> 32 in the cache */
   /* search479_1_0 -> 32 in the cache */
   /* search479_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace479 -> 32 in the cache */

   /* ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a */
   /* search480_0 -> 32 in the cache */
   /* search480_1_0_0 -> 32 in the cache */
   /* search480_1_0 -> 103 in the cache */
   /* search480_1 -> 1204 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 1204 },
      -1,
   } },

   /* replace480 -> 32 in the cache */

   /* ('imax', 'a', ('ineg', ('iabs', 'a'))) => a */
   /* search481_0 -> 32 in the cache */
   /* search481_1_0_0 -> 32 in the cache */
   /* search481_1_0 -> 106 in the cache */
   /* search481_1 -> 1441 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 1441 },
      -1,
   } },

   /* replace481 -> 32 in the cache */

   /* ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a') */
   /* search482_0 -> 32 in the cache */
   /* search482_1_0 -> 32 in the cache */
   /* search482_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace482_0 -> 32 in the cache */
   /* replace482 -> 103 in the cache */

   /* ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a') */
   /* search483_0 -> 32 in the cache */
   /* search483_1_0 -> 32 in the cache */
   /* search483_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace483_0 -> 32 in the cache */
   /* replace483 -> 106 in the cache */

   /* ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a') */
   /* search484_0 -> 32 in the cache */
   /* search484_1_0 -> 32 in the cache */
   /* search484_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace484_0 -> 32 in the cache */
   /* replace484 -> 103 in the cache */

   /* ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a') */
   /* search485_0 -> 32 in the cache */
   /* search485_1_0 -> 32 in the cache */
   /* search485_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace485_0 -> 32 in the cache */
   /* replace485 -> 106 in the cache */

   /* ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a') */
   /* search486_0_0 -> 32 in the cache */
   /* search486_0 -> 103 in the cache */
   /* search486_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 103, 113 },
      -1,
   } },

   /* replace486_0 -> 32 in the cache */
   /* replace486 -> 103 in the cache */

   /* ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a') */
   /* search487_0_0 -> 32 in the cache */
   /* search487_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 32, 113 },
      -1,
   } },
   /* search487_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1453, 226 },
      -1,
   } },

   /* replace487_0 -> 32 in the cache */
   /* replace487 -> 202 in the cache */

   /* ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a') */
   /* search488_0_0 -> 32 in the cache */
   /* search488_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 32, 226 },
      -1,
   } },
   /* search488_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1455, 113 },
      -1,
   } },

   /* replace488_0 -> 32 in the cache */
   /* replace488 -> 202 in the cache */

   /* ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search489_0_0 -> 32 in the cache */
   /* search489_0_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 32, 232 },
      -1,
   } },
   /* search489_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1457, 113 },
      -1,
   } },

   /* replace489_0_0_0 -> 32 in the cache */
   /* replace489_0_0 -> 98 in the cache */
   /* replace489_0 -> 203 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 203 },
      -1,
   } },

   /* ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search490_0_0 -> 32 in the cache */
   /* search490_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 32, 113 },
      -1,
   } },
   /* search490_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1460, 232 },
      -1,
   } },

   /* replace490_0_0_0 -> 32 in the cache */
   /* replace490_0_0 -> 98 in the cache */
   /* replace490_0 -> 203 in the cache */
   /* replace490 -> 1459 in the cache */

   /* ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a')) */
   /* search491_0_0 -> 32 in the cache */
   /* search491_0 -> 235 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 235 },
      -1,
   } },

   /* replace491_0_0 -> 113 in the cache */
   /* replace491_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1463 },
      -1,
   } },

   /* ('fsat', ('b2f', 'a')) => ('b2f', 'a') */
   /* search492_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1465 },
      -1,
   } },

   /* replace492_0 -> 32 in the cache */
   /* replace492 -> 1465 in the cache */

   /* ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0) */
   /* search493_0 -> 32 in the cache */
   /* search493 -> 202 in the cache */

   /* replace493_0_0 -> 32 in the cache */
   /* replace493_0_1 -> 113 in the cache */
   /* replace493_0 -> 1453 in the cache */
   /* replace493_1 -> 226 in the cache */
   /* replace493 -> 1454 in the cache */

   /* ('fsat', ('fsat', 'a')) => ('fsat', 'a') */
   /* search494_0_0 -> 32 in the cache */
   /* search494_0 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 202 },
      -1,
   } },

   /* replace494_0 -> 32 in the cache */
   /* replace494 -> 202 in the cache */

   /* ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b'))) */
   /* search495_0_0_0 -> 0 in the cache */
   /* search495_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1468 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1469 },
      -1,
   } },

   /* replace495_0_0_0 -> 0 in the cache */
   /* replace495_0_0 -> 197 in the cache */
   /* replace495_0_1_0 -> 3 in the cache */
   /* replace495_0_1 -> 1042 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 197, 1042 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1471 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b')) */
   /* search496_0_0_0 -> 0 in the cache */
   /* search496_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1473 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1474 },
      -1,
   } },

   /* replace496_0_0_0 -> 0 in the cache */
   /* replace496_0_0 -> 197 in the cache */
   /* replace496_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 197, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1476 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b')) */
   /* search497_0_0_0 -> 16 in the cache */
   /* search497_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1478 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1479 },
      -1,
   } },

   /* replace497_0_0_0 -> 16 in the cache */
   /* replace497_0_0 -> 265 in the cache */
   /* replace497_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 265, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1481 },
      -1,
   } },

   /* ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b'))) */
   /* search498_0_0_0 -> 0 in the cache */
   /* search498_0_0_1 -> 3 in the cache */
   /* search498_0_0 -> 1473 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 1473 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1483 },
      -1,
   } },

   /* replace498_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace498_0_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1485, 1486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1487 },
      -1,
   } },

   /* ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c') */
   /* search499_0_0_0_0 -> 124 in the cache */
   /* search499_0_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      3, 1,
      { 124, 125 },
      -1,
   } },
   /* search499_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      2, 2,
      { 1489, 127 },
      -1,
   } },
   /* search499_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 3,
      { 1490, 125 },
      -1,
   } },
   /* search499_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 4,
      { 1491, 127 },
      -1,
   } },

   /* replace499_0_0 -> 124 in the cache */
   /* replace499_0_1 -> 125 in the cache */
   /* replace499_0 -> 1297 in the cache */
   /* replace499_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1297, 127 },
      -1,
   } },

   /* ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c') */
   /* search500_0_0_0_0 -> 124 in the cache */
   /* search500_0_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      3, 1,
      { 124, 125 },
      -1,
   } },
   /* search500_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      2, 2,
      { 1494, 127 },
      -1,
   } },
   /* search500_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 3,
      { 1495, 125 },
      -1,
   } },
   /* search500_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 1496, 127 },
      -1,
   } },

   /* replace500_0_0 -> 124 in the cache */
   /* replace500_0_1 -> 125 in the cache */
   /* replace500_0 -> 1307 in the cache */
   /* replace500_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1307, 127 },
      -1,
   } },

   /* ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c') */
   /* search501_0_0_0_0 -> 124 in the cache */
   /* search501_0_0_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      3, 1,
      { 124, 125 },
      -1,
   } },
   /* search501_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      2, 2,
      { 1499, 127 },
      -1,
   } },
   /* search501_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 3,
      { 1500, 125 },
      -1,
   } },
   /* search501_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 4,
      { 1501, 127 },
      -1,
   } },

   /* replace501_0_0 -> 124 in the cache */
   /* replace501_0_1 -> 125 in the cache */
   /* replace501_0 -> 1302 in the cache */
   /* replace501_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1302, 127 },
      -1,
   } },

   /* ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b')) */
   /* search502_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      18,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1504, 1505 },
      -1,
   } },

   /* replace502_0_0 -> 0 in the cache */
   /* replace502_0_1 -> 3 in the cache */
   /* replace502_0 -> 1231 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1231 },
      -1,
   } },

   /* ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b')) */
   /* search503_0_0 -> 0 in the cache */
   /* search503_0 -> 1504 in the cache */
   /* search503_1 -> 1505 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1504, 1505 },
      -1,
   } },

   /* replace503_0_0 -> 0 in the cache */
   /* replace503_0_1 -> 3 in the cache */
   /* replace503_0 -> 1233 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1233 },
      -1,
   } },

   /* ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a')) */
   /* search504_0_0_0 -> 1066 in the cache */
   /* search504_0_0_1 -> 1063 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 1066, 1063 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1510 },
      -1,
   } },
   /* search504_1 -> 1066 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1511, 1066 },
      -1,
   } },

   /* replace504_0_0 -> 1066 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1066 },
      -1,
   } },
   /* replace504_1_0 -> 1063 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1063 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1513, 1514 },
      -1,
   } },

   /* ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a')) */
   /* search505_0_0_0 -> 1066 in the cache */
   /* search505_0_0_1 -> 1063 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 1066, 1063 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1516 },
      -1,
   } },
   /* search505_1 -> 1066 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1517, 1066 },
      -1,
   } },

   /* replace505_0_0_0 -> 1066 in the cache */
   /* replace505_0_0 -> 1513 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1513 },
      -1,
   } },
   /* replace505_1_0 -> 1063 in the cache */
   /* replace505_1 -> 1514 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1519, 1514 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1521 },
      -1,
   } },
   /* search506_0_1 -> 1505 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1522, 1505 },
      0,
   } },
   /* search506_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1523, 241 },
      -1,
   } },

   /* replace506_0_0_0 -> 0 in the cache */
   /* replace506_0_0 -> 197 in the cache */
   /* replace506_0_1 -> 3 in the cache */
   /* replace506_0 -> 262 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 262 },
      -1,
   } },

   /* ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255) */
   /* search507_0_0_0 -> 32 in the cache */
   /* search507_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 32, 61 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1526, 1527 },
      -1,
   } },
   /* search507_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 2,
      { 1528, 61 },
      -1,
   } },

   /* replace507_0_0 -> 32 in the cache */
   /* replace507_0_1 -> 61 in the cache */
   /* replace507_0 -> 1526 in the cache */
   /* replace507_1 -> 1527 in the cache */
   /* replace507 -> 1528 in the cache */

   /* ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search508_0_0 -> 124 in the cache */
   /* search508_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search508_1_0 -> 124 in the cache */
   /* search508_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1530, 1531 },
      -1,
   } },

   /* replace508_0 -> 124 in the cache */
   /* replace508_1_0 -> 125 in the cache */
   /* replace508_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      nir_op_fmax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 124, 1533 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   /* search509_0_0 -> 0 in the cache */
   /* search509_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 665 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search509_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1536, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1535, 1537 },
      -1,
   } },

   /* replace509_0_0 -> 0 in the cache */
   /* replace509_0_1 -> 1536 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1536 },
      -1,
   } },
   /* replace509_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1539, 665 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search510_0_0 -> 124 in the cache */
   /* search510_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search510_1_0 -> 124 in the cache */
   /* search510_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1541, 1542 },
      -1,
   } },

   /* replace510_0 -> 124 in the cache */
   /* replace510_1_0 -> 125 in the cache */
   /* replace510_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      nir_op_fmin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 124, 1544 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search511_0_0 -> 0 in the cache */
   /* search511_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search511_1_0 -> 1536 in the cache */
   /* search511_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1536, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1546, 1547 },
      -1,
   } },

   /* replace511_0_0 -> 0 in the cache */
   /* replace511_0_1 -> 1536 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1536 },
      -1,
   } },
   /* replace511_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1549, 665 },
      -1,
   } },

   /* ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search512_0_0 -> 124 in the cache */
   /* search512_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 268 },
      -1,
   } },
   /* search512_1_0 -> 124 in the cache */
   /* search512_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1551, 1552 },
      -1,
   } },

   /* replace512_0 -> 124 in the cache */
   /* replace512_1_0 -> 125 in the cache */
   /* replace512_1_1 -> 127 in the cache */
   /* replace512_1 -> 1533 in the cache */
   /* replace512 -> 1534 in the cache */

   /* ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search513_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1554, 665 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search513_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1556, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1555, 1557 },
      -1,
   } },

   /* replace513_0_0 -> 0 in the cache */
   /* replace513_0_1 -> 1536 in the cache */
   /* replace513_0 -> 1539 in the cache */
   /* replace513_1 -> 665 in the cache */
   /* replace513 -> 1540 in the cache */

   /* ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search514_0_0 -> 124 in the cache */
   /* search514_0_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 268 },
      -1,
   } },
   /* search514_1_0 -> 124 in the cache */
   /* search514_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1559, 1560 },
      -1,
   } },

   /* replace514_0 -> 124 in the cache */
   /* replace514_1_0 -> 125 in the cache */
   /* replace514_1_1 -> 127 in the cache */
   /* replace514_1 -> 1544 in the cache */
   /* replace514 -> 1545 in the cache */

   /* ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search515_0_0 -> 1554 in the cache */
   /* search515_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1554, 665 },
      -1,
   } },
   /* search515_1_0 -> 1556 in the cache */
   /* search515_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1556, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1562, 1563 },
      -1,
   } },

   /* replace515_0_0 -> 0 in the cache */
   /* replace515_0_1 -> 1536 in the cache */
   /* replace515_0 -> 1549 in the cache */
   /* replace515_1 -> 665 in the cache */
   /* replace515 -> 1550 in the cache */

   /* ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search516_0_0 -> 124 in the cache */
   /* search516_0_1 -> 125 in the cache */
   /* search516_0 -> 1530 in the cache */
   /* search516_1_0 -> 124 in the cache */
   /* search516_1_1 -> 127 in the cache */
   /* search516_1 -> 1531 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1530, 1531 },
      -1,
   } },

   /* replace516_0 -> 124 in the cache */
   /* replace516_1_0 -> 125 in the cache */
   /* replace516_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 124, 1566 },
      -1,
   } },

   /* ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   /* search517_0_0 -> 0 in the cache */
   /* search517_0_1 -> 665 in the cache */
   /* search517_0 -> 1535 in the cache */
   /* search517_1_0 -> 1536 in the cache */
   /* search517_1_1 -> 665 in the cache */
   /* search517_1 -> 1537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1535, 1537 },
      -1,
   } },

   /* replace517_0_0 -> 0 in the cache */
   /* replace517_0_1 -> 1536 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1536 },
      -1,
   } },
   /* replace517_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1569, 665 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search518_0_0 -> 124 in the cache */
   /* search518_0_1 -> 125 in the cache */
   /* search518_0 -> 1541 in the cache */
   /* search518_1_0 -> 124 in the cache */
   /* search518_1_1 -> 127 in the cache */
   /* search518_1 -> 1542 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1541, 1542 },
      -1,
   } },

   /* replace518_0 -> 124 in the cache */
   /* replace518_1_0 -> 125 in the cache */
   /* replace518_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 124, 1572 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search519_0_0 -> 0 in the cache */
   /* search519_0_1 -> 665 in the cache */
   /* search519_0 -> 1546 in the cache */
   /* search519_1_0 -> 1536 in the cache */
   /* search519_1_1 -> 665 in the cache */
   /* search519_1 -> 1547 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1546, 1547 },
      -1,
   } },

   /* replace519_0_0 -> 0 in the cache */
   /* replace519_0_1 -> 1536 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1536 },
      -1,
   } },
   /* replace519_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1575, 665 },
      -1,
   } },

   /* ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search520_0_0 -> 124 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 1577 },
      -1,
   } },
   /* search520_1_0 -> 124 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 124, 1579 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1578, 1580 },
      -1,
   } },

   /* replace520_0 -> 124 in the cache */
   /* replace520_1_0 -> 125 in the cache */
   /* replace520_1_1 -> 127 in the cache */
   /* replace520_1 -> 1566 in the cache */
   /* replace520 -> 1567 in the cache */

   /* ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search521_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1582, 665 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search521_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1584, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1583, 1585 },
      -1,
   } },

   /* replace521_0_0 -> 0 in the cache */
   /* replace521_0_1 -> 1536 in the cache */
   /* replace521_0 -> 1569 in the cache */
   /* replace521_1 -> 665 in the cache */
   /* replace521 -> 1570 in the cache */

   /* ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search522_0_0 -> 124 in the cache */
   /* search522_0_1 -> 1577 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 1577 },
      -1,
   } },
   /* search522_1_0 -> 124 in the cache */
   /* search522_1_1 -> 1579 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 124, 1579 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1587, 1588 },
      -1,
   } },

   /* replace522_0 -> 124 in the cache */
   /* replace522_1_0 -> 125 in the cache */
   /* replace522_1_1 -> 127 in the cache */
   /* replace522_1 -> 1572 in the cache */
   /* replace522 -> 1573 in the cache */

   /* ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search523_0_0 -> 1582 in the cache */
   /* search523_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1582, 665 },
      -1,
   } },
   /* search523_1_0 -> 1584 in the cache */
   /* search523_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1584, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1590, 1591 },
      -1,
   } },

   /* replace523_0_0 -> 0 in the cache */
   /* replace523_0_1 -> 1536 in the cache */
   /* replace523_0 -> 1575 in the cache */
   /* replace523_1 -> 665 in the cache */
   /* replace523 -> 1576 in the cache */

   /* ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c')) */
   /* search524_0_0 -> 124 in the cache */
   /* search524_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search524_1_0 -> 124 in the cache */
   /* search524_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1593, 1594 },
      -1,
   } },

   /* replace524_0 -> 124 in the cache */
   /* replace524_1_0 -> 125 in the cache */
   /* replace524_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 124, 1596 },
      -1,
   } },

   /* ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c') */
   /* search525_0_0 -> 0 in the cache */
   /* search525_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search525_1_0 -> 1536 in the cache */
   /* search525_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1536, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1598, 1599 },
      -1,
   } },

   /* replace525_0_0 -> 0 in the cache */
   /* replace525_0_1 -> 1536 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 1536 },
      -1,
   } },
   /* replace525_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1601, 665 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c')) */
   /* search526_0_0 -> 124 in the cache */
   /* search526_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search526_1_0 -> 124 in the cache */
   /* search526_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1603, 1604 },
      -1,
   } },

   /* replace526_0 -> 124 in the cache */
   /* replace526_1_0 -> 125 in the cache */
   /* replace526_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 124, 1606 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c') */
   /* search527_0_0 -> 0 in the cache */
   /* search527_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search527_1_0 -> 1536 in the cache */
   /* search527_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1536, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1608, 1609 },
      -1,
   } },

   /* replace527_0_0 -> 0 in the cache */
   /* replace527_0_1 -> 1536 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 1536 },
      -1,
   } },
   /* replace527_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1611, 665 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c')) */
   /* search528_0_0 -> 124 in the cache */
   /* search528_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search528_1_0 -> 124 in the cache */
   /* search528_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1613, 1614 },
      -1,
   } },

   /* replace528_0 -> 124 in the cache */
   /* replace528_1_0 -> 125 in the cache */
   /* replace528_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 124, 1616 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c') */
   /* search529_0_0 -> 0 in the cache */
   /* search529_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search529_1_0 -> 1536 in the cache */
   /* search529_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1536, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1618, 1619 },
      -1,
   } },

   /* replace529_0_0 -> 0 in the cache */
   /* replace529_0_1 -> 1536 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 1536 },
      -1,
   } },
   /* replace529_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1621, 665 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c')) */
   /* search530_0_0 -> 124 in the cache */
   /* search530_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 124, 125 },
      0,
   } },
   /* search530_1_0 -> 124 in the cache */
   /* search530_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 124, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1623, 1624 },
      -1,
   } },

   /* replace530_0 -> 124 in the cache */
   /* replace530_1_0 -> 125 in the cache */
   /* replace530_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 124, 1626 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c') */
   /* search531_0_0 -> 0 in the cache */
   /* search531_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 665 },
      0,
   } },
   /* search531_1_0 -> 1536 in the cache */
   /* search531_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1536, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1628, 1629 },
      -1,
   } },

   /* replace531_0_0 -> 0 in the cache */
   /* replace531_0_1 -> 1536 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 1536 },
      -1,
   } },
   /* replace531_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1631, 665 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c')) */
   /* search532_0_0 -> 124 in the cache */
   /* search532_0_1 -> 125 in the cache */
   /* search532_0 -> 1593 in the cache */
   /* search532_1_0 -> 124 in the cache */
   /* search532_1_1 -> 127 in the cache */
   /* search532_1 -> 1594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1593, 1594 },
      -1,
   } },

   /* replace532_0 -> 124 in the cache */
   /* replace532_1_0 -> 125 in the cache */
   /* replace532_1_1 -> 127 in the cache */
   /* replace532_1 -> 1606 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 124, 1606 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c') */
   /* search533_0_0 -> 0 in the cache */
   /* search533_0_1 -> 665 in the cache */
   /* search533_0 -> 1598 in the cache */
   /* search533_1_0 -> 1536 in the cache */
   /* search533_1_1 -> 665 in the cache */
   /* search533_1 -> 1599 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1598, 1599 },
      -1,
   } },

   /* replace533_0_0 -> 0 in the cache */
   /* replace533_0_1 -> 1536 in the cache */
   /* replace533_0 -> 1611 in the cache */
   /* replace533_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1611, 665 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c')) */
   /* search534_0_0 -> 124 in the cache */
   /* search534_0_1 -> 125 in the cache */
   /* search534_0 -> 1603 in the cache */
   /* search534_1_0 -> 124 in the cache */
   /* search534_1_1 -> 127 in the cache */
   /* search534_1 -> 1604 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1603, 1604 },
      -1,
   } },

   /* replace534_0 -> 124 in the cache */
   /* replace534_1_0 -> 125 in the cache */
   /* replace534_1_1 -> 127 in the cache */
   /* replace534_1 -> 1596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 124, 1596 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c') */
   /* search535_0_0 -> 0 in the cache */
   /* search535_0_1 -> 665 in the cache */
   /* search535_0 -> 1608 in the cache */
   /* search535_1_0 -> 1536 in the cache */
   /* search535_1_1 -> 665 in the cache */
   /* search535_1 -> 1609 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1608, 1609 },
      -1,
   } },

   /* replace535_0_0 -> 0 in the cache */
   /* replace535_0_1 -> 1536 in the cache */
   /* replace535_0 -> 1601 in the cache */
   /* replace535_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1601, 665 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c')) */
   /* search536_0_0 -> 124 in the cache */
   /* search536_0_1 -> 125 in the cache */
   /* search536_0 -> 1613 in the cache */
   /* search536_1_0 -> 124 in the cache */
   /* search536_1_1 -> 127 in the cache */
   /* search536_1 -> 1614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1613, 1614 },
      -1,
   } },

   /* replace536_0 -> 124 in the cache */
   /* replace536_1_0 -> 125 in the cache */
   /* replace536_1_1 -> 127 in the cache */
   /* replace536_1 -> 1626 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 124, 1626 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c') */
   /* search537_0_0 -> 0 in the cache */
   /* search537_0_1 -> 665 in the cache */
   /* search537_0 -> 1618 in the cache */
   /* search537_1_0 -> 1536 in the cache */
   /* search537_1_1 -> 665 in the cache */
   /* search537_1 -> 1619 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1618, 1619 },
      -1,
   } },

   /* replace537_0_0 -> 0 in the cache */
   /* replace537_0_1 -> 1536 in the cache */
   /* replace537_0 -> 1631 in the cache */
   /* replace537_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1631, 665 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c')) */
   /* search538_0_0 -> 124 in the cache */
   /* search538_0_1 -> 125 in the cache */
   /* search538_0 -> 1623 in the cache */
   /* search538_1_0 -> 124 in the cache */
   /* search538_1_1 -> 127 in the cache */
   /* search538_1 -> 1624 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1623, 1624 },
      -1,
   } },

   /* replace538_0 -> 124 in the cache */
   /* replace538_1_0 -> 125 in the cache */
   /* replace538_1_1 -> 127 in the cache */
   /* replace538_1 -> 1616 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 124, 1616 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c') */
   /* search539_0_0 -> 0 in the cache */
   /* search539_0_1 -> 665 in the cache */
   /* search539_0 -> 1628 in the cache */
   /* search539_1_0 -> 1536 in the cache */
   /* search539_1_1 -> 665 in the cache */
   /* search539_1 -> 1629 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1628, 1629 },
      -1,
   } },

   /* replace539_0_0 -> 0 in the cache */
   /* replace539_0_1 -> 1536 in the cache */
   /* replace539_0 -> 1621 in the cache */
   /* replace539_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1621, 665 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search540_0_0_0 -> 0 in the cache */
   /* search540_0_0_1 -> 665 in the cache */
   /* search540_0_0 -> 1535 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1535, 1649 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search540_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1651, 665 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1650, 1652 },
      -1,
   } },

   /* replace540_0_0_0 -> 0 in the cache */
   /* replace540_0_0_1 -> 1651 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 1651 },
      -1,
   } },
   /* replace540_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1654, 665 },
      -1,
   } },
   /* replace540_1 -> 1649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1655, 1649 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search541_0_0_0 -> 0 in the cache */
   /* search541_0_0_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 665 },
      -1,
   } },
   /* search541_0_1 -> 1649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1657, 1649 },
      0,
   } },
   /* search541_1_0 -> 1651 in the cache */
   /* search541_1_1 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1651, 665 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1658, 1659 },
      -1,
   } },

   /* replace541_0_0_0 -> 0 in the cache */
   /* replace541_0_0_1 -> 1651 in the cache */
   /* replace541_0_0 -> 1654 in the cache */
   /* replace541_0_1 -> 665 in the cache */
   /* replace541_0 -> 1655 in the cache */
   /* replace541_1 -> 1649 in the cache */
   /* replace541 -> 1656 in the cache */

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search542_0_0_0 -> 147 in the cache */
   /* search542_0_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 147, 148 },
      0,
   } },
   /* search542_0_1 -> 1649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1661, 1649 },
      0,
   } },
   /* search542_1_0 -> 147 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 147, 1663 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1662, 1664 },
      -1,
   } },

   /* replace542_0_0 -> 147 in the cache */
   /* replace542_0_1_0 -> 148 in the cache */
   /* replace542_0_1_1 -> 1663 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      true,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 1663 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 147, 1666 },
      -1,
   } },
   /* replace542_1 -> 1649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1667, 1649 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search543_0_0_0 -> 147 in the cache */
   /* search543_0_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 147, 148 },
      -1,
   } },
   /* search543_0_1 -> 1649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1669, 1649 },
      0,
   } },
   /* search543_1_0 -> 147 in the cache */
   /* search543_1_1 -> 1663 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 147, 1663 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1670, 1671 },
      -1,
   } },

   /* replace543_0_0 -> 147 in the cache */
   /* replace543_0_1_0 -> 148 in the cache */
   /* replace543_0_1_1 -> 1663 in the cache */
   /* replace543_0_1 -> 1666 in the cache */
   /* replace543_0 -> 1667 in the cache */
   /* replace543_1 -> 1649 in the cache */
   /* replace543 -> 1668 in the cache */

   /* ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b') */
   /* search544_0_0 -> 997 in the cache */
   /* search544_0_1 -> 998 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 997, 998 },
      -1,
   } },
   /* search544_1_0 -> 3 in the cache */
   /* search544_1_1 -> 0 in the cache */
   /* search544_1 -> 1033 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1673, 1033 },
      -1,
   } },

   /* replace544_0 -> 0 in the cache */
   /* replace544_1 -> 3 in the cache */
   /* replace544 -> 1007 in the cache */

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search545_0_0 -> 115 in the cache */
   /* search545_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 115, 11 },
      0,
   } },
   /* search545_1_0 -> 243 in the cache */
   /* search545_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 243, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1675, 1676 },
      -1,
   } },

   /* replace545_0 -> 115 in the cache */
   /* replace545_1_0 -> 11 in the cache */
   /* replace545_1_1_0 -> 243 in the cache */
   /* replace545_1_1 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 11, 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 115, 1678 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search546_0_0 -> 115 in the cache */
   /* search546_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 115, 11 },
      -1,
   } },
   /* search546_1_0 -> 243 in the cache */
   /* search546_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 243, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1680, 1681 },
      -1,
   } },

   /* replace546_0 -> 115 in the cache */
   /* replace546_1_0 -> 11 in the cache */
   /* replace546_1_1_0 -> 243 in the cache */
   /* replace546_1_1 -> 515 in the cache */
   /* replace546_1 -> 1678 in the cache */
   /* replace546 -> 1679 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search547_0_0 -> 115 in the cache */
   /* search547_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 115, 11 },
      0,
   } },
   /* search547_1_0 -> 243 in the cache */
   /* search547_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 243, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1683, 1684 },
      -1,
   } },

   /* replace547_0 -> 115 in the cache */
   /* replace547_1_0 -> 11 in the cache */
   /* replace547_1_1_0 -> 243 in the cache */
   /* replace547_1_1 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 11, 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 115, 1686 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search548_0_0 -> 115 in the cache */
   /* search548_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 115, 11 },
      -1,
   } },
   /* search548_1_0 -> 243 in the cache */
   /* search548_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 243, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1688, 1689 },
      -1,
   } },

   /* replace548_0 -> 115 in the cache */
   /* replace548_1_0 -> 11 in the cache */
   /* replace548_1_1_0 -> 243 in the cache */
   /* replace548_1_1 -> 515 in the cache */
   /* replace548_1 -> 1686 in the cache */
   /* replace548 -> 1687 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search549_0_0 -> 115 in the cache */
   /* search549_0_1 -> 11 in the cache */
   /* search549_0 -> 1675 in the cache */
   /* search549_1_0 -> 243 in the cache */
   /* search549_1_1 -> 115 in the cache */
   /* search549_1 -> 1676 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1675, 1676 },
      -1,
   } },

   /* replace549_0 -> 115 in the cache */
   /* replace549_1_0 -> 11 in the cache */
   /* replace549_1_1_0 -> 243 in the cache */
   /* replace549_1_1 -> 515 in the cache */
   /* replace549_1 -> 1686 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 115, 1686 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search550_0_0 -> 115 in the cache */
   /* search550_0_1 -> 11 in the cache */
   /* search550_0 -> 1680 in the cache */
   /* search550_1_0 -> 243 in the cache */
   /* search550_1_1 -> 115 in the cache */
   /* search550_1 -> 1681 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1680, 1681 },
      -1,
   } },

   /* replace550_0 -> 115 in the cache */
   /* replace550_1_0 -> 11 in the cache */
   /* replace550_1_1_0 -> 243 in the cache */
   /* replace550_1_1 -> 515 in the cache */
   /* replace550_1 -> 1686 in the cache */
   /* replace550 -> 1692 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search551_0_0 -> 115 in the cache */
   /* search551_0_1 -> 11 in the cache */
   /* search551_0 -> 1683 in the cache */
   /* search551_1_0 -> 243 in the cache */
   /* search551_1_1 -> 115 in the cache */
   /* search551_1 -> 1684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1683, 1684 },
      -1,
   } },

   /* replace551_0 -> 115 in the cache */
   /* replace551_1_0 -> 11 in the cache */
   /* replace551_1_1_0 -> 243 in the cache */
   /* replace551_1_1 -> 515 in the cache */
   /* replace551_1 -> 1678 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 115, 1678 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search552_0_0 -> 115 in the cache */
   /* search552_0_1 -> 11 in the cache */
   /* search552_0 -> 1688 in the cache */
   /* search552_1_0 -> 243 in the cache */
   /* search552_1_1 -> 115 in the cache */
   /* search552_1 -> 1689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1688, 1689 },
      -1,
   } },

   /* replace552_0 -> 115 in the cache */
   /* replace552_1_0 -> 11 in the cache */
   /* replace552_1_1_0 -> 243 in the cache */
   /* replace552_1_1 -> 515 in the cache */
   /* replace552_1 -> 1678 in the cache */
   /* replace552 -> 1695 in the cache */

   /* ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search553_0_0 -> 11 in the cache */
   /* search553_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 115 },
      -1,
   } },
   /* search553_1 -> 462 in the cache */
   /* search553_2_0_0_0_0 -> 115 in the cache */
   /* search553_2_0_0_0_1 -> 11 in the cache */
   /* search553_2_0_0_0 -> 1680 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1680 },
      -1,
   } },
   /* search553_2_0_1_0_0_0 -> 11 in the cache */
   /* search553_2_0_1_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1699 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1700 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1698, 1701 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1702 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1697, 462, 1703 },
      -1,
   } },

   /* replace553_0_0_0_0 -> 11 in the cache */
   /* replace553_0_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1705 },
      -1,
   } },
   /* replace553_0_1_0_0_0 -> 11 in the cache */
   /* replace553_0_1_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1707 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1708 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1706, 1709 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1710 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search554_0 -> 715 in the cache */
   /* search554_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 243 },
      0,
   } },
   /* search554_2_0 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1712, 1713 },
      -1,
   } },

   /* replace554_0_0 -> 715 in the cache */
   /* replace554_0_1 -> 243 in the cache */
   /* replace554_0_2 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 243, 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1715 },
      -1,
   } },

   /* ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a') */
   /* search555_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1717 },
      -1,
   } },

   /* replace555_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('~f2i16', ('i2f', 'a@16')) => a */
   /* search556_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1720 },
      -1,
   } },

   /* replace556 -> 11 in the cache */

   /* ('~f2i16', ('u2f', 'a@16')) => a */
   /* search557_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1722 },
      -1,
   } },

   /* replace557 -> 11 in the cache */

   /* ('~f2u16', ('i2f', 'a@16')) => a */
   /* search558_0_0 -> 11 in the cache */
   /* search558_0 -> 1720 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1720 },
      -1,
   } },

   /* replace558 -> 11 in the cache */

   /* ('~f2u16', ('u2f', 'a@16')) => a */
   /* search559_0_0 -> 11 in the cache */
   /* search559_0 -> 1722 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1722 },
      -1,
   } },

   /* replace559 -> 11 in the cache */

   /* ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a') */
   /* search560_0_0_0 -> 115 in the cache */
   /* search560_0_0_1 -> 11 in the cache */
   /* search560_0_0 -> 1680 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1680 },
      -1,
   } },
   /* search560_1_0_0_0 -> 11 in the cache */
   /* search560_1_0_0_1 -> 115 in the cache */
   /* search560_1_0_0 -> 1699 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1699 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1727 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1726, 1728 },
      -1,
   } },

   /* replace560_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a')) */
   /* search561_0_0_0 -> 811 in the cache */
   /* search561_0_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 811, 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1731 },
      -1,
   } },
   /* search561_1_0_0_0 -> 11 in the cache */
   /* search561_1_0_0_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 811 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1733 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1734 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1732, 1735 },
      -1,
   } },

   /* replace561_0_0 -> 11 in the cache */
   /* replace561_0 -> 1730 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1730 },
      -1,
   } },

   /* ('f2f16', ('f2f32', 'a@16')) => a */
   /* search562_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1738 },
      -1,
   } },

   /* replace562 -> 11 in the cache */

   /* ('i2i16', ('i2i32', 'a@16')) => a */
   /* search563_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1740 },
      -1,
   } },

   /* replace563 -> 11 in the cache */

   /* ('u2u16', ('u2u32', 'a@16')) => a */
   /* search564_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1742 },
      -1,
   } },

   /* replace564 -> 11 in the cache */

   /* ('f2f16', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search565_0_0 -> 715 in the cache */
   /* search565_0 -> 1345 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1345 },
      -1,
   } },

   /* replace565_0 -> 715 in the cache */
   /* replace565 -> 1341 in the cache */

   /* ('i2i16', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search566_0_0 -> 715 in the cache */
   /* search566_0 -> 1333 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1333 },
      -1,
   } },

   /* replace566_0 -> 715 in the cache */
   /* replace566 -> 1329 in the cache */

   /* ('u2u16', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search567_0_0 -> 715 in the cache */
   /* search567_0 -> 1333 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1333 },
      -1,
   } },

   /* replace567_0 -> 715 in the cache */
   /* replace567 -> 1329 in the cache */

   /* ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a') */
   /* search568_0_0 -> 11 in the cache */
   /* search568_0 -> 1738 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1738 },
      -1,
   } },

   /* replace568_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a') */
   /* search569_0_0 -> 11 in the cache */
   /* search569_0 -> 1738 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1738 },
      -1,
   } },

   /* replace569_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a') */
   /* search570_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1751 },
      -1,
   } },

   /* replace570_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a') */
   /* search571_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1754 },
      -1,
   } },

   /* replace571_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a') */
   /* search572_0_0 -> 11 in the cache */
   /* search572_0 -> 1742 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 1742 },
      -1,
   } },

   /* replace572_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a') */
   /* search573_0_0 -> 11 in the cache */
   /* search573_0 -> 1740 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 1740 },
      -1,
   } },

   /* replace573_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('f2f64', 'a@16')) => a */
   /* search574_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1761 },
      -1,
   } },

   /* replace574 -> 11 in the cache */

   /* ('i2i16', ('i2i64', 'a@16')) => a */
   /* search575_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1763 },
      -1,
   } },

   /* replace575 -> 11 in the cache */

   /* ('u2u16', ('u2u64', 'a@16')) => a */
   /* search576_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1765 },
      -1,
   } },

   /* replace576 -> 11 in the cache */

   /* ('f2f16', ('b2f64', 'a@1')) => ('b2f16', 'a') */
   /* search577_0_0 -> 715 in the cache */
   /* search577_0 -> 1349 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1349 },
      -1,
   } },

   /* replace577_0 -> 715 in the cache */
   /* replace577 -> 1341 in the cache */

   /* ('i2i16', ('b2i64', 'a@1')) => ('b2i16', 'a') */
   /* search578_0_0 -> 715 in the cache */
   /* search578_0 -> 1337 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1337 },
      -1,
   } },

   /* replace578_0 -> 715 in the cache */
   /* replace578 -> 1329 in the cache */

   /* ('u2u16', ('b2i64', 'a@1')) => ('b2i16', 'a') */
   /* search579_0_0 -> 715 in the cache */
   /* search579_0 -> 1337 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1337 },
      -1,
   } },

   /* replace579_0 -> 715 in the cache */
   /* replace579 -> 1329 in the cache */

   /* ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a') */
   /* search580_0_0 -> 11 in the cache */
   /* search580_0 -> 1761 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1761 },
      -1,
   } },

   /* replace580_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a') */
   /* search581_0_0 -> 11 in the cache */
   /* search581_0 -> 1761 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1761 },
      -1,
   } },

   /* replace581_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a') */
   /* search582_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1774 },
      -1,
   } },

   /* replace582_0 -> 32 in the cache */
   /* replace582 -> 1753 in the cache */

   /* ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a') */
   /* search583_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1776 },
      -1,
   } },

   /* replace583_0 -> 32 in the cache */
   /* replace583 -> 1756 in the cache */

   /* ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a') */
   /* search584_0_0 -> 11 in the cache */
   /* search584_0 -> 1765 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 1765 },
      -1,
   } },

   /* replace584_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a') */
   /* search585_0_0 -> 11 in the cache */
   /* search585_0 -> 1763 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1763 },
      -1,
   } },

   /* replace585_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search586_0_0 -> 117 in the cache */
   /* search586_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 117, 16 },
      0,
   } },
   /* search586_1_0 -> 36 in the cache */
   /* search586_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1782, 1783 },
      -1,
   } },

   /* replace586_0 -> 117 in the cache */
   /* replace586_1_0 -> 16 in the cache */
   /* replace586_1_1_0 -> 36 in the cache */
   /* replace586_1_1 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 16, 581 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 117, 1785 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search587_0_0 -> 117 in the cache */
   /* search587_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 117, 16 },
      -1,
   } },
   /* search587_1_0 -> 36 in the cache */
   /* search587_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 117 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1787, 1788 },
      -1,
   } },

   /* replace587_0 -> 117 in the cache */
   /* replace587_1_0 -> 16 in the cache */
   /* replace587_1_1_0 -> 36 in the cache */
   /* replace587_1_1 -> 581 in the cache */
   /* replace587_1 -> 1785 in the cache */
   /* replace587 -> 1786 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search588_0_0 -> 117 in the cache */
   /* search588_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 117, 16 },
      0,
   } },
   /* search588_1_0 -> 36 in the cache */
   /* search588_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 36, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1790, 1791 },
      -1,
   } },

   /* replace588_0 -> 117 in the cache */
   /* replace588_1_0 -> 16 in the cache */
   /* replace588_1_1_0 -> 36 in the cache */
   /* replace588_1_1 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 16, 581 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 117, 1793 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search589_0_0 -> 117 in the cache */
   /* search589_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 117, 16 },
      -1,
   } },
   /* search589_1_0 -> 36 in the cache */
   /* search589_1_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 36, 117 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1795, 1796 },
      -1,
   } },

   /* replace589_0 -> 117 in the cache */
   /* replace589_1_0 -> 16 in the cache */
   /* replace589_1_1_0 -> 36 in the cache */
   /* replace589_1_1 -> 581 in the cache */
   /* replace589_1 -> 1793 in the cache */
   /* replace589 -> 1794 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search590_0_0 -> 117 in the cache */
   /* search590_0_1 -> 16 in the cache */
   /* search590_0 -> 1782 in the cache */
   /* search590_1_0 -> 36 in the cache */
   /* search590_1_1 -> 117 in the cache */
   /* search590_1 -> 1783 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1782, 1783 },
      -1,
   } },

   /* replace590_0 -> 117 in the cache */
   /* replace590_1_0 -> 16 in the cache */
   /* replace590_1_1_0 -> 36 in the cache */
   /* replace590_1_1 -> 581 in the cache */
   /* replace590_1 -> 1793 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 117, 1793 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search591_0_0 -> 117 in the cache */
   /* search591_0_1 -> 16 in the cache */
   /* search591_0 -> 1787 in the cache */
   /* search591_1_0 -> 36 in the cache */
   /* search591_1_1 -> 117 in the cache */
   /* search591_1 -> 1788 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1787, 1788 },
      -1,
   } },

   /* replace591_0 -> 117 in the cache */
   /* replace591_1_0 -> 16 in the cache */
   /* replace591_1_1_0 -> 36 in the cache */
   /* replace591_1_1 -> 581 in the cache */
   /* replace591_1 -> 1793 in the cache */
   /* replace591 -> 1799 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search592_0_0 -> 117 in the cache */
   /* search592_0_1 -> 16 in the cache */
   /* search592_0 -> 1790 in the cache */
   /* search592_1_0 -> 36 in the cache */
   /* search592_1_1 -> 117 in the cache */
   /* search592_1 -> 1791 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1790, 1791 },
      -1,
   } },

   /* replace592_0 -> 117 in the cache */
   /* replace592_1_0 -> 16 in the cache */
   /* replace592_1_1_0 -> 36 in the cache */
   /* replace592_1_1 -> 581 in the cache */
   /* replace592_1 -> 1785 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 117, 1785 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search593_0_0 -> 117 in the cache */
   /* search593_0_1 -> 16 in the cache */
   /* search593_0 -> 1795 in the cache */
   /* search593_1_0 -> 36 in the cache */
   /* search593_1_1 -> 117 in the cache */
   /* search593_1 -> 1796 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1795, 1796 },
      -1,
   } },

   /* replace593_0 -> 117 in the cache */
   /* replace593_1_0 -> 16 in the cache */
   /* replace593_1_1_0 -> 36 in the cache */
   /* replace593_1_1 -> 581 in the cache */
   /* replace593_1 -> 1785 in the cache */
   /* replace593 -> 1802 in the cache */

   /* ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search594_0_0 -> 16 in the cache */
   /* search594_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 117 },
      -1,
   } },
   /* search594_1 -> 228 in the cache */
   /* search594_2_0_0_0_0 -> 117 in the cache */
   /* search594_2_0_0_0_1 -> 16 in the cache */
   /* search594_2_0_0_0 -> 1787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1787 },
      -1,
   } },
   /* search594_2_0_1_0_0_0 -> 16 in the cache */
   /* search594_2_0_1_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1806 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1807 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1805, 1808 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1809 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1804, 228, 1810 },
      -1,
   } },

   /* replace594_0_0_0_0 -> 16 in the cache */
   /* replace594_0_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1812 },
      -1,
   } },
   /* replace594_0_1_0_0_0 -> 16 in the cache */
   /* replace594_0_1_0_0_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 117 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1815 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1813, 1816 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1817 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search595_0 -> 715 in the cache */
   /* search595_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 36 },
      0,
   } },
   /* search595_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1819, 1820 },
      -1,
   } },

   /* replace595_0_0 -> 715 in the cache */
   /* replace595_0_1 -> 36 in the cache */
   /* replace595_0_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 36, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1822 },
      -1,
   } },

   /* ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a') */
   /* search596_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 1824 },
      -1,
   } },

   /* replace596_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('~f2i32', ('i2f', 'a@32')) => a */
   /* search597_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1827 },
      -1,
   } },

   /* replace597 -> 16 in the cache */

   /* ('~f2i32', ('u2f', 'a@32')) => a */
   /* search598_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1829 },
      -1,
   } },

   /* replace598 -> 16 in the cache */

   /* ('~f2u32', ('i2f', 'a@32')) => a */
   /* search599_0_0 -> 16 in the cache */
   /* search599_0 -> 1827 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1827 },
      -1,
   } },

   /* replace599 -> 16 in the cache */

   /* ('~f2u32', ('u2f', 'a@32')) => a */
   /* search600_0_0 -> 16 in the cache */
   /* search600_0 -> 1829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1829 },
      -1,
   } },

   /* replace600 -> 16 in the cache */

   /* ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a') */
   /* search601_0_0_0 -> 117 in the cache */
   /* search601_0_0_1 -> 16 in the cache */
   /* search601_0_0 -> 1787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1787 },
      -1,
   } },
   /* search601_1_0_0_0 -> 16 in the cache */
   /* search601_1_0_0_1 -> 117 in the cache */
   /* search601_1_0_0 -> 1806 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1806 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1834 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1833, 1835 },
      -1,
   } },

   /* replace601_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a')) */
   /* search602_0_0_0 -> 120 in the cache */
   /* search602_0_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1838 },
      -1,
   } },
   /* search602_1_0_0_0 -> 16 in the cache */
   /* search602_1_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1840 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1841 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1839, 1842 },
      -1,
   } },

   /* replace602_0_0 -> 16 in the cache */
   /* replace602_0 -> 1837 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1837 },
      -1,
   } },

   /* ('f2f32', ('f2f64', 'a@32')) => a */
   /* search603_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1845 },
      -1,
   } },

   /* replace603 -> 16 in the cache */

   /* ('i2i32', ('i2i64', 'a@32')) => a */
   /* search604_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1847 },
      -1,
   } },

   /* replace604 -> 16 in the cache */

   /* ('u2u32', ('u2u64', 'a@32')) => a */
   /* search605_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1849 },
      -1,
   } },

   /* replace605 -> 16 in the cache */

   /* ('f2f32', ('b2f64', 'a@1')) => ('b2f32', 'a') */
   /* search606_0_0 -> 715 in the cache */
   /* search606_0 -> 1349 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1349 },
      -1,
   } },

   /* replace606_0 -> 715 in the cache */
   /* replace606 -> 1345 in the cache */

   /* ('i2i32', ('b2i64', 'a@1')) => ('b2i32', 'a') */
   /* search607_0_0 -> 715 in the cache */
   /* search607_0 -> 1337 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1337 },
      -1,
   } },

   /* replace607_0 -> 715 in the cache */
   /* replace607 -> 1333 in the cache */

   /* ('u2u32', ('b2i64', 'a@1')) => ('b2i32', 'a') */
   /* search608_0_0 -> 715 in the cache */
   /* search608_0 -> 1337 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1337 },
      -1,
   } },

   /* replace608_0 -> 715 in the cache */
   /* replace608 -> 1333 in the cache */

   /* ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a') */
   /* search609_0_0 -> 16 in the cache */
   /* search609_0 -> 1845 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1845 },
      -1,
   } },

   /* replace609_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a') */
   /* search610_0_0 -> 16 in the cache */
   /* search610_0 -> 1845 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1845 },
      -1,
   } },

   /* replace610_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a') */
   /* search611_0_0 -> 32 in the cache */
   /* search611_0 -> 1774 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1774 },
      -1,
   } },

   /* replace611_0 -> 32 in the cache */
   /* replace611 -> 1751 in the cache */

   /* ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a') */
   /* search612_0_0 -> 32 in the cache */
   /* search612_0 -> 1776 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1776 },
      -1,
   } },

   /* replace612_0 -> 32 in the cache */
   /* replace612 -> 1754 in the cache */

   /* ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a') */
   /* search613_0_0 -> 16 in the cache */
   /* search613_0 -> 1849 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 1849 },
      -1,
   } },

   /* replace613_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a') */
   /* search614_0_0 -> 16 in the cache */
   /* search614_0 -> 1847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1847 },
      -1,
   } },

   /* replace614_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search615_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1864, 21 },
      0,
   } },
   /* search615_1_0 -> 41 in the cache */
   /* search615_1_1 -> 1864 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 41, 1864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1865, 1866 },
      -1,
   } },

   /* replace615_0 -> 1864 in the cache */
   /* replace615_1_0 -> 21 in the cache */
   /* replace615_1_1_0 -> 41 in the cache */
   /* replace615_1_1 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 21, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1864, 1868 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search616_0_0 -> 1864 in the cache */
   /* search616_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1864, 21 },
      -1,
   } },
   /* search616_1_0 -> 41 in the cache */
   /* search616_1_1 -> 1864 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 41, 1864 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1870, 1871 },
      -1,
   } },

   /* replace616_0 -> 1864 in the cache */
   /* replace616_1_0 -> 21 in the cache */
   /* replace616_1_1_0 -> 41 in the cache */
   /* replace616_1_1 -> 654 in the cache */
   /* replace616_1 -> 1868 in the cache */
   /* replace616 -> 1869 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search617_0_0 -> 1864 in the cache */
   /* search617_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1864, 21 },
      0,
   } },
   /* search617_1_0 -> 41 in the cache */
   /* search617_1_1 -> 1864 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 41, 1864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1873, 1874 },
      -1,
   } },

   /* replace617_0 -> 1864 in the cache */
   /* replace617_1_0 -> 21 in the cache */
   /* replace617_1_1_0 -> 41 in the cache */
   /* replace617_1_1 -> 654 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 21, 654 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1864, 1876 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search618_0_0 -> 1864 in the cache */
   /* search618_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1864, 21 },
      -1,
   } },
   /* search618_1_0 -> 41 in the cache */
   /* search618_1_1 -> 1864 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 41, 1864 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1878, 1879 },
      -1,
   } },

   /* replace618_0 -> 1864 in the cache */
   /* replace618_1_0 -> 21 in the cache */
   /* replace618_1_1_0 -> 41 in the cache */
   /* replace618_1_1 -> 654 in the cache */
   /* replace618_1 -> 1876 in the cache */
   /* replace618 -> 1877 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search619_0_0 -> 1864 in the cache */
   /* search619_0_1 -> 21 in the cache */
   /* search619_0 -> 1865 in the cache */
   /* search619_1_0 -> 41 in the cache */
   /* search619_1_1 -> 1864 in the cache */
   /* search619_1 -> 1866 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1865, 1866 },
      -1,
   } },

   /* replace619_0 -> 1864 in the cache */
   /* replace619_1_0 -> 21 in the cache */
   /* replace619_1_1_0 -> 41 in the cache */
   /* replace619_1_1 -> 654 in the cache */
   /* replace619_1 -> 1876 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1864, 1876 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search620_0_0 -> 1864 in the cache */
   /* search620_0_1 -> 21 in the cache */
   /* search620_0 -> 1870 in the cache */
   /* search620_1_0 -> 41 in the cache */
   /* search620_1_1 -> 1864 in the cache */
   /* search620_1 -> 1871 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1870, 1871 },
      -1,
   } },

   /* replace620_0 -> 1864 in the cache */
   /* replace620_1_0 -> 21 in the cache */
   /* replace620_1_1_0 -> 41 in the cache */
   /* replace620_1_1 -> 654 in the cache */
   /* replace620_1 -> 1876 in the cache */
   /* replace620 -> 1882 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search621_0_0 -> 1864 in the cache */
   /* search621_0_1 -> 21 in the cache */
   /* search621_0 -> 1873 in the cache */
   /* search621_1_0 -> 41 in the cache */
   /* search621_1_1 -> 1864 in the cache */
   /* search621_1 -> 1874 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1873, 1874 },
      -1,
   } },

   /* replace621_0 -> 1864 in the cache */
   /* replace621_1_0 -> 21 in the cache */
   /* replace621_1_1_0 -> 41 in the cache */
   /* replace621_1_1 -> 654 in the cache */
   /* replace621_1 -> 1868 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1864, 1868 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search622_0_0 -> 1864 in the cache */
   /* search622_0_1 -> 21 in the cache */
   /* search622_0 -> 1878 in the cache */
   /* search622_1_0 -> 41 in the cache */
   /* search622_1_1 -> 1864 in the cache */
   /* search622_1 -> 1879 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1878, 1879 },
      -1,
   } },

   /* replace622_0 -> 1864 in the cache */
   /* replace622_1_0 -> 21 in the cache */
   /* replace622_1_1_0 -> 41 in the cache */
   /* replace622_1_1 -> 654 in the cache */
   /* replace622_1 -> 1868 in the cache */
   /* replace622 -> 1885 in the cache */

   /* ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search623_0_0 -> 21 in the cache */
   /* search623_0_1 -> 1864 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 21, 1864 },
      -1,
   } },
   /* search623_1 -> 603 in the cache */
   /* search623_2_0_0_0_0 -> 1864 in the cache */
   /* search623_2_0_0_0_1 -> 21 in the cache */
   /* search623_2_0_0_0 -> 1870 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1870 },
      -1,
   } },
   /* search623_2_0_1_0_0_0 -> 21 in the cache */
   /* search623_2_0_1_0_0_1 -> 1864 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 1864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1890 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1888, 1891 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 1892 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1887, 603, 1893 },
      -1,
   } },

   /* replace623_0_0_0_0 -> 21 in the cache */
   /* replace623_0_0_0_1 -> 1864 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 21, 1864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1895 },
      -1,
   } },
   /* replace623_0_1_0_0_0 -> 21 in the cache */
   /* replace623_0_1_0_0_1 -> 1864 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 1864 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1898 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1896, 1899 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 1900 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search624_0 -> 715 in the cache */
   /* search624_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 41 },
      0,
   } },
   /* search624_2_0 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 591 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1902, 1903 },
      -1,
   } },

   /* replace624_0_0 -> 715 in the cache */
   /* replace624_0_1 -> 41 in the cache */
   /* replace624_0_2 -> 591 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 41, 591 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1905 },
      -1,
   } },

   /* ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a') */
   /* search625_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1907 },
      -1,
   } },

   /* replace625_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('~f2i64', ('i2f', 'a@64')) => a */
   /* search626_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1910 },
      -1,
   } },

   /* replace626 -> 21 in the cache */

   /* ('~f2i64', ('u2f', 'a@64')) => a */
   /* search627_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1912 },
      -1,
   } },

   /* replace627 -> 21 in the cache */

   /* ('~f2u64', ('i2f', 'a@64')) => a */
   /* search628_0_0 -> 21 in the cache */
   /* search628_0 -> 1910 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1910 },
      -1,
   } },

   /* replace628 -> 21 in the cache */

   /* ('~f2u64', ('u2f', 'a@64')) => a */
   /* search629_0_0 -> 21 in the cache */
   /* search629_0 -> 1912 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1912 },
      -1,
   } },

   /* replace629 -> 21 in the cache */

   /* ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a') */
   /* search630_0_0_0 -> 1864 in the cache */
   /* search630_0_0_1 -> 21 in the cache */
   /* search630_0_0 -> 1870 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1870 },
      -1,
   } },
   /* search630_1_0_0_0 -> 21 in the cache */
   /* search630_1_0_0_1 -> 1864 in the cache */
   /* search630_1_0_0 -> 1889 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1889 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1917 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1916, 1918 },
      -1,
   } },

   /* replace630_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a')) */
   /* search631_0_0_0 -> 852 in the cache */
   /* search631_0_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 852, 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1921 },
      -1,
   } },
   /* search631_1_0_0_0 -> 21 in the cache */
   /* search631_1_0_0_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1923 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1924 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1922, 1925 },
      -1,
   } },

   /* replace631_0_0 -> 21 in the cache */
   /* replace631_0 -> 1920 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1920 },
      -1,
   } },

   /* ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a') */
   /* search632_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1928 },
      -1,
   } },

   /* replace632_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a') */
   /* search633_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1931 },
      -1,
   } },

   /* replace633_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a') */
   /* search634_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1934 },
      -1,
   } },

   /* replace634_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a') */
   /* search635_0_0 -> 16 in the cache */
   /* search635_0 -> 1934 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1934 },
      -1,
   } },

   /* replace635_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a') */
   /* search636_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1939 },
      -1,
   } },

   /* replace636_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a') */
   /* search637_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1942 },
      -1,
   } },

   /* replace637_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a') */
   /* search638_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 1945 },
      -1,
   } },

   /* replace638_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a') */
   /* search639_0_0 -> 16 in the cache */
   /* search639_0 -> 1945 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1945 },
      -1,
   } },

   /* replace639_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255)) */
   /* search640_0_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1950 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1951, 1952 },
      -1,
   } },

   /* replace640_0 -> 11 in the cache */
   /* replace640_1_0 -> 243 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 243, 1954 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 11, 1955 },
      -1,
   } },

   /* ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255)) */
   /* search641_0_0_0 -> 11 in the cache */
   /* search641_0_0_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1952 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1957 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 1,
      { 1958 },
      -1,
   } },

   /* replace641_0 -> 11 in the cache */
   /* replace641_1_0 -> 243 in the cache */
   /* replace641_1_1 -> 1954 in the cache */
   /* replace641_1 -> 1955 in the cache */
   /* replace641 -> 1956 in the cache */

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search642_0_0_0_0 -> 11 in the cache */
   /* search642_0_0_0 -> 1950 in the cache */
   /* search642_0_0 -> 1951 in the cache */
   /* search642_0_1_0_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1960 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1951, 1961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1962 },
      -1,
   } },

   /* replace642_0_0 -> 11 in the cache */
   /* replace642_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1964 },
      -1,
   } },

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search643_0_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1966 },
      -1,
   } },
   /* search643_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1968 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1967, 1969 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1970 },
      -1,
   } },

   /* replace643_0_0 -> 16 in the cache */
   /* replace643_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 1972 },
      -1,
   } },

   /* ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b') */
   /* search644_0_0 -> 0 in the cache */
   /* search644_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 776 },
      -1,
   } },
   /* search644_1_0 -> 138 in the cache */
   /* search644_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 138, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1974, 1975 },
      -1,
   } },

   /* replace644_0_0 -> 0 in the cache */
   /* replace644_0_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 138 },
      -1,
   } },
   /* replace644_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 1977, 3 },
      -1,
   } },

   /* ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b') */
   /* search645_0_0 -> 0 in the cache */
   /* search645_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 776 },
      -1,
   } },
   /* search645_1_0 -> 138 in the cache */
   /* search645_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 138, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1979, 1980 },
      -1,
   } },

   /* replace645_0_0 -> 0 in the cache */
   /* replace645_0_1 -> 138 in the cache */
   /* replace645_0 -> 1977 in the cache */
   /* replace645_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 1977, 3 },
      -1,
   } },

   /* ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b') */
   /* search646_0_0 -> 0 in the cache */
   /* search646_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 776 },
      -1,
   } },
   /* search646_1_0 -> 138 in the cache */
   /* search646_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 138, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1983, 1984 },
      -1,
   } },

   /* replace646_0_0 -> 0 in the cache */
   /* replace646_0_1 -> 138 in the cache */
   /* replace646_0 -> 1977 in the cache */
   /* replace646_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 1977, 3 },
      -1,
   } },

   /* ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b') */
   /* search647_0_0 -> 0 in the cache */
   /* search647_0_1 -> 776 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 776 },
      -1,
   } },
   /* search647_1_0 -> 138 in the cache */
   /* search647_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 138, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1987, 1988 },
      -1,
   } },

   /* replace647_0_0 -> 0 in the cache */
   /* replace647_0_1 -> 138 in the cache */
   /* replace647_0 -> 1977 in the cache */
   /* replace647_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 1977, 3 },
      -1,
   } },

   /* ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b') */
   /* search648_0_0 -> 124 in the cache */
   /* search648_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 124, 33 },
      0,
   } },
   /* search648_1_0 -> 127 in the cache */
   /* search648_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 127, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1991, 1992 },
      -1,
   } },

   /* replace648_0_0 -> 124 in the cache */
   /* replace648_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 124, 127 },
      -1,
   } },
   /* replace648_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 1994, 36 },
      -1,
   } },

   /* ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b') */
   /* search649_0_0 -> 124 in the cache */
   /* search649_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 124, 33 },
      0,
   } },
   /* search649_1_0 -> 127 in the cache */
   /* search649_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 127, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1996, 1997 },
      -1,
   } },

   /* replace649_0_0 -> 124 in the cache */
   /* replace649_0_1 -> 127 in the cache */
   /* replace649_0 -> 1994 in the cache */
   /* replace649_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 1994, 36 },
      -1,
   } },

   /* ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b') */
   /* search650_0_0 -> 124 in the cache */
   /* search650_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 124, 33 },
      0,
   } },
   /* search650_1_0 -> 127 in the cache */
   /* search650_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 127, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2000, 2001 },
      -1,
   } },

   /* replace650_0_0 -> 124 in the cache */
   /* replace650_0_1 -> 127 in the cache */
   /* replace650_0 -> 1994 in the cache */
   /* replace650_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1994, 36 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search651_0_0_0_0 -> 11 in the cache */
   /* search651_0_0_0 -> 1950 in the cache */
   /* search651_0_0 -> 1951 in the cache */
   /* search651_0_1_0_0 -> 243 in the cache */
   /* search651_0_1_0 -> 1960 in the cache */
   /* search651_0_1 -> 1961 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1951, 1961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2004 },
      -1,
   } },

   /* replace651_0_0 -> 11 in the cache */
   /* replace651_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2006 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search652_0_0_0_0 -> 16 in the cache */
   /* search652_0_0_0 -> 1966 in the cache */
   /* search652_0_0 -> 1967 in the cache */
   /* search652_0_1_0_0 -> 36 in the cache */
   /* search652_0_1_0 -> 1968 in the cache */
   /* search652_0_1 -> 1969 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1967, 1969 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2008 },
      -1,
   } },

   /* replace652_0_0 -> 16 in the cache */
   /* replace652_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2010 },
      -1,
   } },

   /* ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b') */
   /* search653_0_0 -> 0 in the cache */
   /* search653_0_1 -> 776 in the cache */
   /* search653_0 -> 1974 in the cache */
   /* search653_1_0 -> 138 in the cache */
   /* search653_1_1 -> 3 in the cache */
   /* search653_1 -> 1975 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1974, 1975 },
      -1,
   } },

   /* replace653_0_0 -> 0 in the cache */
   /* replace653_0_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 138 },
      -1,
   } },
   /* replace653_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2013, 3 },
      -1,
   } },

   /* ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b') */
   /* search654_0_0 -> 0 in the cache */
   /* search654_0_1 -> 776 in the cache */
   /* search654_0 -> 1979 in the cache */
   /* search654_1_0 -> 138 in the cache */
   /* search654_1_1 -> 3 in the cache */
   /* search654_1 -> 1980 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1979, 1980 },
      -1,
   } },

   /* replace654_0_0 -> 0 in the cache */
   /* replace654_0_1 -> 138 in the cache */
   /* replace654_0 -> 2013 in the cache */
   /* replace654_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2013, 3 },
      -1,
   } },

   /* ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b') */
   /* search655_0_0 -> 0 in the cache */
   /* search655_0_1 -> 776 in the cache */
   /* search655_0 -> 1983 in the cache */
   /* search655_1_0 -> 138 in the cache */
   /* search655_1_1 -> 3 in the cache */
   /* search655_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1983, 1984 },
      -1,
   } },

   /* replace655_0_0 -> 0 in the cache */
   /* replace655_0_1 -> 138 in the cache */
   /* replace655_0 -> 2013 in the cache */
   /* replace655_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2013, 3 },
      -1,
   } },

   /* ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b') */
   /* search656_0_0 -> 0 in the cache */
   /* search656_0_1 -> 776 in the cache */
   /* search656_0 -> 1987 in the cache */
   /* search656_1_0 -> 138 in the cache */
   /* search656_1_1 -> 3 in the cache */
   /* search656_1 -> 1988 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1987, 1988 },
      -1,
   } },

   /* replace656_0_0 -> 0 in the cache */
   /* replace656_0_1 -> 138 in the cache */
   /* replace656_0 -> 2013 in the cache */
   /* replace656_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2013, 3 },
      -1,
   } },

   /* ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b') */
   /* search657_0_0 -> 124 in the cache */
   /* search657_0_1 -> 33 in the cache */
   /* search657_0 -> 1991 in the cache */
   /* search657_1_0 -> 127 in the cache */
   /* search657_1_1 -> 36 in the cache */
   /* search657_1 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1991, 1992 },
      -1,
   } },

   /* replace657_0_0 -> 124 in the cache */
   /* replace657_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 124, 127 },
      -1,
   } },
   /* replace657_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2022, 36 },
      -1,
   } },

   /* ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b') */
   /* search658_0_0 -> 124 in the cache */
   /* search658_0_1 -> 33 in the cache */
   /* search658_0 -> 1996 in the cache */
   /* search658_1_0 -> 127 in the cache */
   /* search658_1_1 -> 36 in the cache */
   /* search658_1 -> 1997 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1996, 1997 },
      -1,
   } },

   /* replace658_0_0 -> 124 in the cache */
   /* replace658_0_1 -> 127 in the cache */
   /* replace658_0 -> 2022 in the cache */
   /* replace658_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2022, 36 },
      -1,
   } },

   /* ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b') */
   /* search659_0_0 -> 124 in the cache */
   /* search659_0_1 -> 33 in the cache */
   /* search659_0 -> 2000 in the cache */
   /* search659_1_0 -> 127 in the cache */
   /* search659_1_1 -> 36 in the cache */
   /* search659_1 -> 2001 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2000, 2001 },
      -1,
   } },

   /* replace659_0_0 -> 124 in the cache */
   /* replace659_0_1 -> 127 in the cache */
   /* replace659_0 -> 2022 in the cache */
   /* replace659_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2022, 36 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search660_0_0_0_0 -> 11 in the cache */
   /* search660_0_0_0 -> 1950 in the cache */
   /* search660_0_0 -> 1951 in the cache */
   /* search660_0_1_0_0 -> 243 in the cache */
   /* search660_0_1_0 -> 1960 in the cache */
   /* search660_0_1 -> 1961 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1951, 1961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2028 },
      -1,
   } },

   /* replace660_0_0 -> 11 in the cache */
   /* replace660_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2030 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search661_0_0_0_0 -> 16 in the cache */
   /* search661_0_0_0 -> 1966 in the cache */
   /* search661_0_0 -> 1967 in the cache */
   /* search661_0_1_0_0 -> 36 in the cache */
   /* search661_0_1_0 -> 1968 in the cache */
   /* search661_0_1 -> 1969 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1967, 1969 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2032 },
      -1,
   } },

   /* replace661_0_0 -> 16 in the cache */
   /* replace661_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2034 },
      -1,
   } },

   /* ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b') */
   /* search662_0_0 -> 0 in the cache */
   /* search662_0_1 -> 776 in the cache */
   /* search662_0 -> 1974 in the cache */
   /* search662_1_0 -> 138 in the cache */
   /* search662_1_1 -> 3 in the cache */
   /* search662_1 -> 1975 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1974, 1975 },
      -1,
   } },

   /* replace662_0_0 -> 0 in the cache */
   /* replace662_0_1 -> 138 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 0, 138 },
      -1,
   } },
   /* replace662_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2037, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b') */
   /* search663_0_0 -> 0 in the cache */
   /* search663_0_1 -> 776 in the cache */
   /* search663_0 -> 1979 in the cache */
   /* search663_1_0 -> 138 in the cache */
   /* search663_1_1 -> 3 in the cache */
   /* search663_1 -> 1980 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1979, 1980 },
      -1,
   } },

   /* replace663_0_0 -> 0 in the cache */
   /* replace663_0_1 -> 138 in the cache */
   /* replace663_0 -> 2037 in the cache */
   /* replace663_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2037, 3 },
      -1,
   } },

   /* ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b') */
   /* search664_0_0 -> 0 in the cache */
   /* search664_0_1 -> 776 in the cache */
   /* search664_0 -> 1983 in the cache */
   /* search664_1_0 -> 138 in the cache */
   /* search664_1_1 -> 3 in the cache */
   /* search664_1 -> 1984 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1983, 1984 },
      -1,
   } },

   /* replace664_0_0 -> 0 in the cache */
   /* replace664_0_1 -> 138 in the cache */
   /* replace664_0 -> 2037 in the cache */
   /* replace664_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2037, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b') */
   /* search665_0_0 -> 0 in the cache */
   /* search665_0_1 -> 776 in the cache */
   /* search665_0 -> 1987 in the cache */
   /* search665_1_0 -> 138 in the cache */
   /* search665_1_1 -> 3 in the cache */
   /* search665_1 -> 1988 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1987, 1988 },
      -1,
   } },

   /* replace665_0_0 -> 0 in the cache */
   /* replace665_0_1 -> 138 in the cache */
   /* replace665_0 -> 2037 in the cache */
   /* replace665_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2037, 3 },
      -1,
   } },

   /* ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b') */
   /* search666_0_0 -> 124 in the cache */
   /* search666_0_1 -> 33 in the cache */
   /* search666_0 -> 1991 in the cache */
   /* search666_1_0 -> 127 in the cache */
   /* search666_1_1 -> 36 in the cache */
   /* search666_1 -> 1992 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1991, 1992 },
      -1,
   } },

   /* replace666_0_0 -> 124 in the cache */
   /* replace666_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 124, 127 },
      -1,
   } },
   /* replace666_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2046, 36 },
      -1,
   } },

   /* ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b') */
   /* search667_0_0 -> 124 in the cache */
   /* search667_0_1 -> 33 in the cache */
   /* search667_0 -> 1996 in the cache */
   /* search667_1_0 -> 127 in the cache */
   /* search667_1_1 -> 36 in the cache */
   /* search667_1 -> 1997 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1996, 1997 },
      -1,
   } },

   /* replace667_0_0 -> 124 in the cache */
   /* replace667_0_1 -> 127 in the cache */
   /* replace667_0 -> 2046 in the cache */
   /* replace667_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2046, 36 },
      -1,
   } },

   /* ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b') */
   /* search668_0_0 -> 124 in the cache */
   /* search668_0_1 -> 33 in the cache */
   /* search668_0 -> 2000 in the cache */
   /* search668_1_0 -> 127 in the cache */
   /* search668_1_1 -> 36 in the cache */
   /* search668_1 -> 2001 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2000, 2001 },
      -1,
   } },

   /* replace668_0_0 -> 124 in the cache */
   /* replace668_0_1 -> 127 in the cache */
   /* replace668_0 -> 2046 in the cache */
   /* replace668_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2046, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search669_0_0 -> 6 in the cache */
   /* search669_0_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 790 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search669_1_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2053, 790 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2052, 2054 },
      -1,
   } },

   /* replace669_0_0 -> 6 in the cache */
   /* replace669_0_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 6, 2053 },
      -1,
   } },
   /* replace669_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2056, 790 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search670_0_0 -> 6 in the cache */
   /* search670_0_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 790 },
      -1,
   } },
   /* search670_1_0 -> 2053 in the cache */
   /* search670_1_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 2053, 790 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2058, 2059 },
      -1,
   } },

   /* replace670_0_0 -> 6 in the cache */
   /* replace670_0_1 -> 2053 in the cache */
   /* replace670_0 -> 2056 in the cache */
   /* replace670_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2056, 790 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search671_0_0 -> 6 in the cache */
   /* search671_0_1 -> 790 in the cache */
   /* search671_0 -> 2052 in the cache */
   /* search671_1_0 -> 2053 in the cache */
   /* search671_1_1 -> 790 in the cache */
   /* search671_1 -> 2054 in the cache */
   /* search671 -> 2055 in the cache */

   /* replace671_0_0 -> 6 in the cache */
   /* replace671_0_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 6, 2053 },
      -1,
   } },
   /* replace671_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2062, 790 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search672_0_0 -> 6 in the cache */
   /* search672_0_1 -> 790 in the cache */
   /* search672_0 -> 2052 in the cache */
   /* search672_1_0 -> 2053 in the cache */
   /* search672_1_1 -> 790 in the cache */
   /* search672_1 -> 2054 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2052, 2054 },
      -1,
   } },

   /* replace672_0_0 -> 6 in the cache */
   /* replace672_0_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 6, 2053 },
      -1,
   } },
   /* replace672_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2065, 790 },
      -1,
   } },

   /* ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search673_0_0 -> 6 in the cache */
   /* search673_0_1 -> 790 in the cache */
   /* search673_0 -> 2058 in the cache */
   /* search673_1_0 -> 2053 in the cache */
   /* search673_1_1 -> 790 in the cache */
   /* search673_1 -> 2059 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2058, 2059 },
      -1,
   } },

   /* replace673_0_0 -> 6 in the cache */
   /* replace673_0_1 -> 2053 in the cache */
   /* replace673_0 -> 2065 in the cache */
   /* replace673_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2065, 790 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search674_0_0 -> 6 in the cache */
   /* search674_0_1 -> 790 in the cache */
   /* search674_0 -> 2058 in the cache */
   /* search674_1_0 -> 2053 in the cache */
   /* search674_1_1 -> 790 in the cache */
   /* search674_1 -> 2059 in the cache */
   /* search674 -> 2060 in the cache */

   /* replace674_0_0 -> 6 in the cache */
   /* replace674_0_1 -> 2053 in the cache */
   /* replace674_0 -> 2062 in the cache */
   /* replace674_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2062, 790 },
      -1,
   } },

   /* ('ineg', ('b2i8', 'a@8')) => a */
   /* search675_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2070 },
      -1,
   } },

   /* replace675 -> 6 in the cache */

   /* ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b') */
   /* search676_0 -> 6 in the cache */
   /* search676_1_0 -> 9 in the cache */
   /* search676_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 9, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 6, 2072 },
      -1,
   } },

   /* replace676_0 -> 6 in the cache */
   /* replace676_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b') */
   /* search677_0 -> 6 in the cache */
   /* search677_1_0 -> 9 in the cache */
   /* search677_1_1 -> 36 in the cache */
   /* search677_1 -> 2072 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 6, 2072 },
      -1,
   } },

   /* replace677_0 -> 6 in the cache */
   /* replace677_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b') */
   /* search678_0 -> 6 in the cache */
   /* search678_1_0 -> 9 in the cache */
   /* search678_1_1 -> 36 in the cache */
   /* search678_1 -> 2072 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 2072 },
      -1,
   } },

   /* replace678_0 -> 6 in the cache */
   /* replace678_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search679_0_0 -> 11 in the cache */
   /* search679_0_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 811 },
      -1,
   } },
   /* search679_1_0 -> 243 in the cache */
   /* search679_1_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 243, 811 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2079, 2080 },
      -1,
   } },

   /* replace679_0_0 -> 11 in the cache */
   /* replace679_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 11, 243 },
      -1,
   } },
   /* replace679_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2082, 811 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search680_0_0 -> 11 in the cache */
   /* search680_0_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 811 },
      -1,
   } },
   /* search680_1_0 -> 243 in the cache */
   /* search680_1_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 243, 811 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2084, 2085 },
      -1,
   } },

   /* replace680_0_0 -> 11 in the cache */
   /* replace680_0_1 -> 243 in the cache */
   /* replace680_0 -> 2082 in the cache */
   /* replace680_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2082, 811 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search681_0_0 -> 11 in the cache */
   /* search681_0_1 -> 811 in the cache */
   /* search681_0 -> 2079 in the cache */
   /* search681_1_0 -> 243 in the cache */
   /* search681_1_1 -> 811 in the cache */
   /* search681_1 -> 2080 in the cache */
   /* search681 -> 2081 in the cache */

   /* replace681_0_0 -> 11 in the cache */
   /* replace681_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 11, 243 },
      -1,
   } },
   /* replace681_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2088, 811 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search682_0_0 -> 11 in the cache */
   /* search682_0_1 -> 811 in the cache */
   /* search682_0 -> 2079 in the cache */
   /* search682_1_0 -> 243 in the cache */
   /* search682_1_1 -> 811 in the cache */
   /* search682_1 -> 2080 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2079, 2080 },
      -1,
   } },

   /* replace682_0_0 -> 11 in the cache */
   /* replace682_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 11, 243 },
      -1,
   } },
   /* replace682_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2091, 811 },
      -1,
   } },

   /* ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search683_0_0 -> 11 in the cache */
   /* search683_0_1 -> 811 in the cache */
   /* search683_0 -> 2084 in the cache */
   /* search683_1_0 -> 243 in the cache */
   /* search683_1_1 -> 811 in the cache */
   /* search683_1 -> 2085 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2084, 2085 },
      -1,
   } },

   /* replace683_0_0 -> 11 in the cache */
   /* replace683_0_1 -> 243 in the cache */
   /* replace683_0 -> 2091 in the cache */
   /* replace683_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2091, 811 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search684_0_0 -> 11 in the cache */
   /* search684_0_1 -> 811 in the cache */
   /* search684_0 -> 2084 in the cache */
   /* search684_1_0 -> 243 in the cache */
   /* search684_1_1 -> 811 in the cache */
   /* search684_1 -> 2085 in the cache */
   /* search684 -> 2086 in the cache */

   /* replace684_0_0 -> 11 in the cache */
   /* replace684_0_1 -> 243 in the cache */
   /* replace684_0 -> 2088 in the cache */
   /* replace684_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2088, 811 },
      -1,
   } },

   /* ('ineg', ('b2i16', 'a@16')) => a */
   /* search685_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2096 },
      -1,
   } },

   /* replace685 -> 11 in the cache */

   /* ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b') */
   /* search686_0 -> 11 in the cache */
   /* search686_1_0 -> 14 in the cache */
   /* search686_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 14, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 2098 },
      -1,
   } },

   /* replace686_0 -> 11 in the cache */
   /* replace686_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b') */
   /* search687_0 -> 11 in the cache */
   /* search687_1_0 -> 14 in the cache */
   /* search687_1_1 -> 36 in the cache */
   /* search687_1 -> 2098 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 11, 2098 },
      -1,
   } },

   /* replace687_0 -> 11 in the cache */
   /* replace687_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b') */
   /* search688_0 -> 11 in the cache */
   /* search688_1_0 -> 14 in the cache */
   /* search688_1_1 -> 36 in the cache */
   /* search688_1 -> 2098 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2098 },
      -1,
   } },

   /* replace688_0 -> 11 in the cache */
   /* replace688_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search689_0_0 -> 16 in the cache */
   /* search689_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 120 },
      -1,
   } },
   /* search689_1_0 -> 36 in the cache */
   /* search689_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2105, 2106 },
      -1,
   } },

   /* replace689_0_0 -> 16 in the cache */
   /* replace689_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace689_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2108, 120 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search690_0_0 -> 16 in the cache */
   /* search690_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 120 },
      -1,
   } },
   /* search690_1_0 -> 36 in the cache */
   /* search690_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 36, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2110, 2111 },
      -1,
   } },

   /* replace690_0_0 -> 16 in the cache */
   /* replace690_0_1 -> 36 in the cache */
   /* replace690_0 -> 2108 in the cache */
   /* replace690_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2108, 120 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search691_0_0 -> 16 in the cache */
   /* search691_0_1 -> 120 in the cache */
   /* search691_0 -> 2105 in the cache */
   /* search691_1_0 -> 36 in the cache */
   /* search691_1_1 -> 120 in the cache */
   /* search691_1 -> 2106 in the cache */
   /* search691 -> 2107 in the cache */

   /* replace691_0_0 -> 16 in the cache */
   /* replace691_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace691_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2114, 120 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search692_0_0 -> 16 in the cache */
   /* search692_0_1 -> 120 in the cache */
   /* search692_0 -> 2105 in the cache */
   /* search692_1_0 -> 36 in the cache */
   /* search692_1_1 -> 120 in the cache */
   /* search692_1 -> 2106 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2105, 2106 },
      -1,
   } },

   /* replace692_0_0 -> 16 in the cache */
   /* replace692_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace692_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2117, 120 },
      -1,
   } },

   /* ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search693_0_0 -> 16 in the cache */
   /* search693_0_1 -> 120 in the cache */
   /* search693_0 -> 2110 in the cache */
   /* search693_1_0 -> 36 in the cache */
   /* search693_1_1 -> 120 in the cache */
   /* search693_1 -> 2111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2110, 2111 },
      -1,
   } },

   /* replace693_0_0 -> 16 in the cache */
   /* replace693_0_1 -> 36 in the cache */
   /* replace693_0 -> 2117 in the cache */
   /* replace693_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2117, 120 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search694_0_0 -> 16 in the cache */
   /* search694_0_1 -> 120 in the cache */
   /* search694_0 -> 2110 in the cache */
   /* search694_1_0 -> 36 in the cache */
   /* search694_1_1 -> 120 in the cache */
   /* search694_1 -> 2111 in the cache */
   /* search694 -> 2112 in the cache */

   /* replace694_0_0 -> 16 in the cache */
   /* replace694_0_1 -> 36 in the cache */
   /* replace694_0 -> 2114 in the cache */
   /* replace694_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2114, 120 },
      -1,
   } },

   /* ('ineg', ('b2i32', 'a@32')) => a */
   /* search695_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2122 },
      -1,
   } },

   /* replace695 -> 16 in the cache */

   /* ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b') */
   /* search696_0 -> 16 in the cache */
   /* search696_1_0 -> 19 in the cache */
   /* search696_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 2124 },
      -1,
   } },

   /* replace696_0 -> 16 in the cache */
   /* replace696_1 -> 36 in the cache */
   /* replace696 -> 901 in the cache */

   /* ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b') */
   /* search697_0 -> 16 in the cache */
   /* search697_1_0 -> 19 in the cache */
   /* search697_1_1 -> 36 in the cache */
   /* search697_1 -> 2124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 16, 2124 },
      -1,
   } },

   /* replace697_0 -> 16 in the cache */
   /* replace697_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b') */
   /* search698_0 -> 16 in the cache */
   /* search698_1_0 -> 19 in the cache */
   /* search698_1_1 -> 36 in the cache */
   /* search698_1 -> 2124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2124 },
      -1,
   } },

   /* replace698_0 -> 16 in the cache */
   /* replace698_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search699_0_0 -> 21 in the cache */
   /* search699_0_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 21, 852 },
      -1,
   } },
   /* search699_1_0 -> 41 in the cache */
   /* search699_1_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 41, 852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2130, 2131 },
      -1,
   } },

   /* replace699_0_0 -> 21 in the cache */
   /* replace699_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace699_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2133, 852 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search700_0_0 -> 21 in the cache */
   /* search700_0_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 21, 852 },
      -1,
   } },
   /* search700_1_0 -> 41 in the cache */
   /* search700_1_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 41, 852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2135, 2136 },
      -1,
   } },

   /* replace700_0_0 -> 21 in the cache */
   /* replace700_0_1 -> 41 in the cache */
   /* replace700_0 -> 2133 in the cache */
   /* replace700_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2133, 852 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search701_0_0 -> 21 in the cache */
   /* search701_0_1 -> 852 in the cache */
   /* search701_0 -> 2130 in the cache */
   /* search701_1_0 -> 41 in the cache */
   /* search701_1_1 -> 852 in the cache */
   /* search701_1 -> 2131 in the cache */
   /* search701 -> 2132 in the cache */

   /* replace701_0_0 -> 21 in the cache */
   /* replace701_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace701_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2139, 852 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search702_0_0 -> 21 in the cache */
   /* search702_0_1 -> 852 in the cache */
   /* search702_0 -> 2130 in the cache */
   /* search702_1_0 -> 41 in the cache */
   /* search702_1_1 -> 852 in the cache */
   /* search702_1 -> 2131 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2130, 2131 },
      -1,
   } },

   /* replace702_0_0 -> 21 in the cache */
   /* replace702_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace702_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2142, 852 },
      -1,
   } },

   /* ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search703_0_0 -> 21 in the cache */
   /* search703_0_1 -> 852 in the cache */
   /* search703_0 -> 2135 in the cache */
   /* search703_1_0 -> 41 in the cache */
   /* search703_1_1 -> 852 in the cache */
   /* search703_1 -> 2136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2135, 2136 },
      -1,
   } },

   /* replace703_0_0 -> 21 in the cache */
   /* replace703_0_1 -> 41 in the cache */
   /* replace703_0 -> 2142 in the cache */
   /* replace703_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2142, 852 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search704_0_0 -> 21 in the cache */
   /* search704_0_1 -> 852 in the cache */
   /* search704_0 -> 2135 in the cache */
   /* search704_1_0 -> 41 in the cache */
   /* search704_1_1 -> 852 in the cache */
   /* search704_1 -> 2136 in the cache */
   /* search704 -> 2137 in the cache */

   /* replace704_0_0 -> 21 in the cache */
   /* replace704_0_1 -> 41 in the cache */
   /* replace704_0 -> 2139 in the cache */
   /* replace704_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2139, 852 },
      -1,
   } },

   /* ('ineg', ('b2i64', 'a@64')) => a */
   /* search705_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2147 },
      -1,
   } },

   /* replace705 -> 21 in the cache */

   /* ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b') */
   /* search706_0 -> 21 in the cache */
   /* search706_1_0 -> 24 in the cache */
   /* search706_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 24, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 21, 2149 },
      -1,
   } },

   /* replace706_0 -> 21 in the cache */
   /* replace706_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b') */
   /* search707_0 -> 21 in the cache */
   /* search707_1_0 -> 24 in the cache */
   /* search707_1_1 -> 36 in the cache */
   /* search707_1 -> 2149 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 21, 2149 },
      -1,
   } },

   /* replace707_0 -> 21 in the cache */
   /* replace707_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b') */
   /* search708_0 -> 21 in the cache */
   /* search708_1_0 -> 24 in the cache */
   /* search708_1_1 -> 36 in the cache */
   /* search708_1 -> 2149 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 2149 },
      -1,
   } },

   /* replace708_0 -> 21 in the cache */
   /* replace708_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a') */
   /* search709_0_0 -> 32 in the cache */
   /* search709_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 61 },
      -1,
   } },
   /* search709_1_0 -> 32 in the cache */
   /* search709_1_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2156, 2157 },
      -1,
   } },

   /* replace709_0 -> 35 in the cache */
   /* replace709_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 35, 32 },
      -1,
   } },

   /* ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a') */
   /* search710_0_0 -> 35 in the cache */
   /* search710_0_1 -> 32 in the cache */
   /* search710_0 -> 2159 in the cache */
   /* search710_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 2160 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2159, 2161 },
      -1,
   } },

   /* replace710_0 -> 2160 in the cache */
   /* replace710_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2160, 32 },
      -1,
   } },

   /* ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a') */
   /* search711_0_0 -> 2160 in the cache */
   /* search711_0_1 -> 32 in the cache */
   /* search711_0 -> 2163 in the cache */
   /* search711_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 2164 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2163, 2165 },
      -1,
   } },

   /* replace711_0 -> 2164 in the cache */
   /* replace711_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2164, 32 },
      -1,
   } },

   /* ('ior', 'a', ('ieq', 'a', False)) => True */
   /* search712_0 -> 715 in the cache */
   /* search712_1_0 -> 715 in the cache */
   /* search712_1_1 -> 1032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 715, 1032 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 715, 2168 },
      -1,
   } },

   /* replace712 -> 1185 in the cache */

   /* ('ior', 'a', ('inot', 'a')) => -1 */
   /* search713_0 -> 32 in the cache */
   /* search713_1_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 2170 },
      -1,
   } },

   /* replace713 -> 63 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b') */
   /* search714_0_0_0 -> 715 in the cache */
   /* search714_0_0 -> 1176 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1176 },
      -1,
   } },
   /* search714_1_0_0 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1083 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2173 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2172, 2174 },
      -1,
   } },

   /* replace714_0 -> 715 in the cache */
   /* replace714_1 -> 1083 in the cache */
   /* replace714 -> 1328 in the cache */

   /* ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b')) */
   /* search715_0_0 -> 715 in the cache */
   /* search715_0_1 -> 1083 in the cache */
   /* search715_0 -> 1328 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1328 },
      -1,
   } },

   /* replace715_0_0 -> 715 in the cache */
   /* replace715_0_1 -> 1083 in the cache */
   /* replace715_0 -> 1100 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1100 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0)) */
   /* search716_0_0_0_0_0 -> 32 in the cache */
   /* search716_0_0_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 32, 61 },
      -1,
   } },
   /* search716_0_0_0_1 -> 1083 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 2178, 1083 },
      -1,
   } },
   /* search716_0_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2179, 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2180 },
      -1,
   } },
   /* search716_1_0 -> 32 in the cache */
   /* search716_1_1 -> 61 in the cache */
   /* search716_1 -> 1199 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2181, 1199 },
      -1,
   } },

   /* replace716_0_0_0 -> 1083 in the cache */
   /* replace716_0_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1083, 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2183 },
      -1,
   } },
   /* replace716_1_0 -> 32 in the cache */
   /* replace716_1_1 -> 61 in the cache */
   /* replace716_1 -> 1199 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2184, 1199 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0)) */
   /* search717_0_0_0_0_0 -> 0 in the cache */
   /* search717_0_0_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      3, 1,
      { 0, 3 },
      -1,
   } },
   /* search717_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 2,
      { 2186, 86 },
      -1,
   } },
   /* search717_0_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2187, 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2188 },
      -1,
   } },
   /* search717_1_0 -> 0 in the cache */
   /* search717_1_1 -> 86 in the cache */
   /* search717_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2189, 90 },
      -1,
   } },

   /* replace717_0_0_0_0 -> 3 in the cache */
   /* replace717_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3, 86 },
      -1,
   } },
   /* replace717_0_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 2,
      { 2191, 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 2,
      { 2192 },
      -1,
   } },
   /* replace717_1_0 -> 0 in the cache */
   /* replace717_1_1 -> 86 in the cache */
   /* replace717_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2193, 90 },
      -1,
   } },

   /* ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b') */
   /* search718_0 -> 32 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search718_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 2195, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 32, 2196 },
      -1,
   } },

   /* replace718_0 -> 32 in the cache */
   /* replace718_1 -> 2195 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 2195 },
      -1,
   } },

   /* ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a') */
   /* search719_0_0 -> 0 in the cache */
   /* search719_0_1 -> 3 in the cache */
   /* search719_0 -> 1233 in the cache */
   /* search719_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1233, 0 },
      -1,
   } },

   /* replace719_0 -> 3 in the cache */
   /* replace719_1 -> 0 in the cache */
   /* replace719 -> 1033 in the cache */

   /* ('~fge', 'a', ('fmin', 'b', 'a')) => True */
   /* search720_0 -> 32 in the cache */
   /* search720_1_0 -> 2195 in the cache */
   /* search720_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 2195, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 32, 2200 },
      -1,
   } },

   /* replace720 -> 1185 in the cache */

   /* ('~fge', ('fmax', 'a', 'b'), 'a') => True */
   /* search721_0_0 -> 0 in the cache */
   /* search721_0_1 -> 3 in the cache */
   /* search721_0 -> 1231 in the cache */
   /* search721_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1231, 0 },
      -1,
   } },

   /* replace721 -> 1185 in the cache */

   /* ('flt', 'a', ('fmin', 'b', 'a')) => False */
   /* search722_0 -> 32 in the cache */
   /* search722_1_0 -> 2195 in the cache */
   /* search722_1_1 -> 32 in the cache */
   /* search722_1 -> 2200 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 32, 2200 },
      -1,
   } },

   /* replace722 -> 1032 in the cache */

   /* ('flt', ('fmax', 'a', 'b'), 'a') => False */
   /* search723_0_0 -> 0 in the cache */
   /* search723_0_1 -> 3 in the cache */
   /* search723_0 -> 1231 in the cache */
   /* search723_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1231, 0 },
      -1,
   } },

   /* replace723 -> 1032 in the cache */

   /* ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b') */
   /* search724_0 -> 32 in the cache */
   /* search724_1_0 -> 2195 in the cache */
   /* search724_1_1 -> 32 in the cache */
   /* search724_1 -> 2196 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 32, 2196 },
      -1,
   } },

   /* replace724_0 -> 32 in the cache */
   /* replace724_1 -> 2195 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 2195 },
      -1,
   } },

   /* ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a') */
   /* search725_0_0 -> 0 in the cache */
   /* search725_0_1 -> 3 in the cache */
   /* search725_0 -> 1233 in the cache */
   /* search725_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1233, 0 },
      -1,
   } },

   /* replace725_0 -> 3 in the cache */
   /* replace725_1 -> 0 in the cache */
   /* replace725 -> 1045 in the cache */

   /* ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b') */
   /* search726_0 -> 32 in the cache */
   /* search726_1_0 -> 2195 in the cache */
   /* search726_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2195, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 32, 2208 },
      -1,
   } },

   /* replace726_0 -> 32 in the cache */
   /* replace726_1 -> 2195 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 2195 },
      -1,
   } },

   /* ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a') */
   /* search727_0_0 -> 0 in the cache */
   /* search727_0_1 -> 3 in the cache */
   /* search727_0 -> 1293 in the cache */
   /* search727_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1293, 0 },
      -1,
   } },

   /* replace727_0 -> 3 in the cache */
   /* replace727_1 -> 0 in the cache */
   /* replace727 -> 1038 in the cache */

   /* ('ige', 'a', ('imin', 'b', 'a')) => True */
   /* search728_0 -> 32 in the cache */
   /* search728_1_0 -> 2195 in the cache */
   /* search728_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2195, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 32, 2212 },
      -1,
   } },

   /* replace728 -> 1185 in the cache */

   /* ('ige', ('imax', 'a', 'b'), 'a') => True */
   /* search729_0_0 -> 0 in the cache */
   /* search729_0_1 -> 3 in the cache */
   /* search729_0 -> 1285 in the cache */
   /* search729_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1285, 0 },
      -1,
   } },

   /* replace729 -> 1185 in the cache */

   /* ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b') */
   /* search730_0 -> 32 in the cache */
   /* search730_1_0 -> 2195 in the cache */
   /* search730_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2195, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2215 },
      -1,
   } },

   /* replace730_0 -> 32 in the cache */
   /* replace730_1 -> 2195 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 2195 },
      -1,
   } },

   /* ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a') */
   /* search731_0_0 -> 0 in the cache */
   /* search731_0_1 -> 3 in the cache */
   /* search731_0 -> 1290 in the cache */
   /* search731_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1290, 0 },
      -1,
   } },

   /* replace731_0 -> 3 in the cache */
   /* replace731_1 -> 0 in the cache */
   /* replace731 -> 1040 in the cache */

   /* ('uge', 'a', ('umin', 'b', 'a')) => True */
   /* search732_0 -> 32 in the cache */
   /* search732_1_0 -> 2195 in the cache */
   /* search732_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2195, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2219 },
      -1,
   } },

   /* replace732 -> 1185 in the cache */

   /* ('uge', ('umax', 'a', 'b'), 'a') => True */
   /* search733_0_0 -> 0 in the cache */
   /* search733_0_1 -> 3 in the cache */
   /* search733_0 -> 1282 in the cache */
   /* search733_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1282, 0 },
      -1,
   } },

   /* replace733 -> 1185 in the cache */

   /* ('ilt', 'a', ('imin', 'b', 'a')) => False */
   /* search734_0 -> 32 in the cache */
   /* search734_1_0 -> 2195 in the cache */
   /* search734_1_1 -> 32 in the cache */
   /* search734_1 -> 2212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 32, 2212 },
      -1,
   } },

   /* replace734 -> 1032 in the cache */

   /* ('ilt', ('imax', 'a', 'b'), 'a') => False */
   /* search735_0_0 -> 0 in the cache */
   /* search735_0_1 -> 3 in the cache */
   /* search735_0 -> 1285 in the cache */
   /* search735_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1285, 0 },
      -1,
   } },

   /* replace735 -> 1032 in the cache */

   /* ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b') */
   /* search736_0 -> 32 in the cache */
   /* search736_1_0 -> 2195 in the cache */
   /* search736_1_1 -> 32 in the cache */
   /* search736_1 -> 2208 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 32, 2208 },
      -1,
   } },

   /* replace736_0 -> 32 in the cache */
   /* replace736_1 -> 2195 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 2195 },
      -1,
   } },

   /* ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a') */
   /* search737_0_0 -> 0 in the cache */
   /* search737_0_1 -> 3 in the cache */
   /* search737_0 -> 1293 in the cache */
   /* search737_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1293, 0 },
      -1,
   } },

   /* replace737_0 -> 3 in the cache */
   /* replace737_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('umin', 'b', 'a')) => False */
   /* search738_0 -> 32 in the cache */
   /* search738_1_0 -> 2195 in the cache */
   /* search738_1_1 -> 32 in the cache */
   /* search738_1 -> 2219 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2219 },
      -1,
   } },

   /* replace738 -> 1032 in the cache */

   /* ('ult', ('umax', 'a', 'b'), 'a') => False */
   /* search739_0_0 -> 0 in the cache */
   /* search739_0_1 -> 3 in the cache */
   /* search739_0 -> 1282 in the cache */
   /* search739_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1282, 0 },
      -1,
   } },

   /* replace739 -> 1032 in the cache */

   /* ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b') */
   /* search740_0 -> 32 in the cache */
   /* search740_1_0 -> 2195 in the cache */
   /* search740_1_1 -> 32 in the cache */
   /* search740_1 -> 2215 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2215 },
      -1,
   } },

   /* replace740_0 -> 32 in the cache */
   /* replace740_1 -> 2195 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 32, 2195 },
      -1,
   } },

   /* ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a') */
   /* search741_0_0 -> 0 in the cache */
   /* search741_0_1 -> 3 in the cache */
   /* search741_0 -> 1290 in the cache */
   /* search741_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1290, 0 },
      -1,
   } },

   /* replace741_0 -> 3 in the cache */
   /* replace741_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('iand', 'b', 'a')) => False */
   /* search742_0 -> 32 in the cache */
   /* search742_1_0 -> 2195 in the cache */
   /* search742_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2195, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2234 },
      -1,
   } },

   /* replace742 -> 1032 in the cache */

   /* ('ult', ('ior', 'a', 'b'), 'a') => False */
   /* search743_0_0 -> 0 in the cache */
   /* search743_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* search743_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2236, 0 },
      -1,
   } },

   /* replace743 -> 1032 in the cache */

   /* ('uge', 'a', ('iand', 'b', 'a')) => True */
   /* search744_0 -> 32 in the cache */
   /* search744_1_0 -> 2195 in the cache */
   /* search744_1_1 -> 32 in the cache */
   /* search744_1 -> 2234 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2234 },
      -1,
   } },

   /* replace744 -> 1185 in the cache */

   /* ('uge', ('ior', 'a', 'b'), 'a') => True */
   /* search745_0_0 -> 0 in the cache */
   /* search745_0_1 -> 3 in the cache */
   /* search745_0 -> 2236 in the cache */
   /* search745_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2236, 0 },
      -1,
   } },

   /* replace745 -> 1185 in the cache */

   /* ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search746_0 -> 267 in the cache */
   /* search746_1_0 -> 268 in the cache */
   /* search746_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 268, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 267, 2240 },
      -1,
   } },

   /* replace746_0_0 -> 124 in the cache */
   /* replace746_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace746_1_0 -> 124 in the cache */
   /* replace746_1_1 -> 127 in the cache */
   /* replace746_1 -> 1594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2242, 1594 },
      -1,
   } },

   /* ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search747_0_0 -> 267 in the cache */
   /* search747_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 267, 125 },
      -1,
   } },
   /* search747_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2244, 769 },
      -1,
   } },

   /* replace747_0_0 -> 124 in the cache */
   /* replace747_0_1 -> 127 in the cache */
   /* replace747_0 -> 1594 in the cache */
   /* replace747_1_0 -> 125 in the cache */
   /* replace747_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1594, 2246 },
      -1,
   } },

   /* ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search748_0 -> 267 in the cache */
   /* search748_1_0 -> 268 in the cache */
   /* search748_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 268, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 267, 2248 },
      -1,
   } },

   /* replace748_0_0 -> 124 in the cache */
   /* replace748_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace748_1_0 -> 124 in the cache */
   /* replace748_1_1 -> 127 in the cache */
   /* replace748_1 -> 1604 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2250, 1604 },
      -1,
   } },

   /* ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search749_0_0 -> 267 in the cache */
   /* search749_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 267, 125 },
      -1,
   } },
   /* search749_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2252, 769 },
      -1,
   } },

   /* replace749_0_0 -> 124 in the cache */
   /* replace749_0_1 -> 127 in the cache */
   /* replace749_0 -> 1604 in the cache */
   /* replace749_1_0 -> 125 in the cache */
   /* replace749_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1604, 2254 },
      -1,
   } },

   /* ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search750_0 -> 267 in the cache */
   /* search750_1_0 -> 268 in the cache */
   /* search750_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 268, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 267, 2256 },
      -1,
   } },

   /* replace750_0_0 -> 124 in the cache */
   /* replace750_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace750_1_0 -> 124 in the cache */
   /* replace750_1_1 -> 127 in the cache */
   /* replace750_1 -> 1614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2258, 1614 },
      -1,
   } },

   /* ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search751_0_0 -> 267 in the cache */
   /* search751_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 267, 125 },
      -1,
   } },
   /* search751_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2260, 769 },
      -1,
   } },

   /* replace751_0_0 -> 124 in the cache */
   /* replace751_0_1 -> 127 in the cache */
   /* replace751_0 -> 1614 in the cache */
   /* replace751_1_0 -> 125 in the cache */
   /* replace751_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1614, 2262 },
      -1,
   } },

   /* ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search752_0 -> 267 in the cache */
   /* search752_1_0 -> 268 in the cache */
   /* search752_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 268, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 267, 2264 },
      -1,
   } },

   /* replace752_0_0 -> 124 in the cache */
   /* replace752_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 124, 125 },
      -1,
   } },
   /* replace752_1_0 -> 124 in the cache */
   /* replace752_1_1 -> 127 in the cache */
   /* replace752_1 -> 1624 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2266, 1624 },
      -1,
   } },

   /* ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search753_0_0 -> 267 in the cache */
   /* search753_0_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 267, 125 },
      -1,
   } },
   /* search753_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2268, 769 },
      -1,
   } },

   /* replace753_0_0 -> 124 in the cache */
   /* replace753_0_1 -> 127 in the cache */
   /* replace753_0 -> 1624 in the cache */
   /* replace753_1_0 -> 125 in the cache */
   /* replace753_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1624, 2270 },
      -1,
   } },

   /* ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search754_0 -> 267 in the cache */
   /* search754_1_0 -> 268 in the cache */
   /* search754_1_1 -> 127 in the cache */
   /* search754_1 -> 2248 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 267, 2248 },
      -1,
   } },

   /* replace754_0_0 -> 124 in the cache */
   /* replace754_0_1 -> 125 in the cache */
   /* replace754_0 -> 2242 in the cache */
   /* replace754_1_0 -> 124 in the cache */
   /* replace754_1_1 -> 127 in the cache */
   /* replace754_1 -> 1594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2242, 1594 },
      -1,
   } },

   /* ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search755_0_0 -> 267 in the cache */
   /* search755_0_1 -> 125 in the cache */
   /* search755_0 -> 2252 in the cache */
   /* search755_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2252, 769 },
      -1,
   } },

   /* replace755_0_0 -> 124 in the cache */
   /* replace755_0_1 -> 127 in the cache */
   /* replace755_0 -> 1594 in the cache */
   /* replace755_1_0 -> 125 in the cache */
   /* replace755_1_1 -> 127 in the cache */
   /* replace755_1 -> 2246 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1594, 2246 },
      -1,
   } },

   /* ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search756_0 -> 267 in the cache */
   /* search756_1_0 -> 268 in the cache */
   /* search756_1_1 -> 127 in the cache */
   /* search756_1 -> 2240 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 267, 2240 },
      -1,
   } },

   /* replace756_0_0 -> 124 in the cache */
   /* replace756_0_1 -> 125 in the cache */
   /* replace756_0 -> 2250 in the cache */
   /* replace756_1_0 -> 124 in the cache */
   /* replace756_1_1 -> 127 in the cache */
   /* replace756_1 -> 1604 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2250, 1604 },
      -1,
   } },

   /* ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search757_0_0 -> 267 in the cache */
   /* search757_0_1 -> 125 in the cache */
   /* search757_0 -> 2244 in the cache */
   /* search757_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2244, 769 },
      -1,
   } },

   /* replace757_0_0 -> 124 in the cache */
   /* replace757_0_1 -> 127 in the cache */
   /* replace757_0 -> 1604 in the cache */
   /* replace757_1_0 -> 125 in the cache */
   /* replace757_1_1 -> 127 in the cache */
   /* replace757_1 -> 2254 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1604, 2254 },
      -1,
   } },

   /* ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search758_0 -> 267 in the cache */
   /* search758_1_0 -> 268 in the cache */
   /* search758_1_1 -> 127 in the cache */
   /* search758_1 -> 2264 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 267, 2264 },
      -1,
   } },

   /* replace758_0_0 -> 124 in the cache */
   /* replace758_0_1 -> 125 in the cache */
   /* replace758_0 -> 2258 in the cache */
   /* replace758_1_0 -> 124 in the cache */
   /* replace758_1_1 -> 127 in the cache */
   /* replace758_1 -> 1614 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2258, 1614 },
      -1,
   } },

   /* ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search759_0_0 -> 267 in the cache */
   /* search759_0_1 -> 125 in the cache */
   /* search759_0 -> 2268 in the cache */
   /* search759_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2268, 769 },
      -1,
   } },

   /* replace759_0_0 -> 124 in the cache */
   /* replace759_0_1 -> 127 in the cache */
   /* replace759_0 -> 1614 in the cache */
   /* replace759_1_0 -> 125 in the cache */
   /* replace759_1_1 -> 127 in the cache */
   /* replace759_1 -> 2262 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1614, 2262 },
      -1,
   } },

   /* ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search760_0 -> 267 in the cache */
   /* search760_1_0 -> 268 in the cache */
   /* search760_1_1 -> 127 in the cache */
   /* search760_1 -> 2256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 267, 2256 },
      -1,
   } },

   /* replace760_0_0 -> 124 in the cache */
   /* replace760_0_1 -> 125 in the cache */
   /* replace760_0 -> 2266 in the cache */
   /* replace760_1_0 -> 124 in the cache */
   /* replace760_1_1 -> 127 in the cache */
   /* replace760_1 -> 1624 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2266, 1624 },
      -1,
   } },

   /* ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search761_0_0 -> 267 in the cache */
   /* search761_0_1 -> 125 in the cache */
   /* search761_0 -> 2260 in the cache */
   /* search761_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2260, 769 },
      -1,
   } },

   /* replace761_0_0 -> 124 in the cache */
   /* replace761_0_1 -> 127 in the cache */
   /* replace761_0 -> 1624 in the cache */
   /* replace761_1_0 -> 125 in the cache */
   /* replace761_1_1 -> 127 in the cache */
   /* replace761_1 -> 2270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1624, 2270 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b')) */
   /* search762_0_0 -> 32 in the cache */
   /* search762_0_1 -> 61 in the cache */
   /* search762_0 -> 1199 in the cache */
   /* search762_1_0_0 -> 32 in the cache */
   /* search762_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 32, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2288 },
      -1,
   } },
   /* search762_2_0 -> 32 in the cache */
   /* search762_2_1 -> 36 in the cache */
   /* search762_2 -> 2288 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1199, 2289, 2288 },
      -1,
   } },

   /* replace762_0_0 -> 32 in the cache */
   /* replace762_0_1 -> 36 in the cache */
   /* replace762_0 -> 2288 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2288 },
      -1,
   } },

   /* ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b') */
   /* search763_0_0_0 -> 32 in the cache */
   /* search763_0_0 -> 106 in the cache */
   /* search763_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 106, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2292 },
      -1,
   } },

   /* replace763_0_0 -> 32 in the cache */
   /* replace763_0 -> 106 in the cache */
   /* replace763_1 -> 36 in the cache */
   /* replace763 -> 2292 in the cache */

   /* ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b') */
   /* search764_0_0 -> 0 in the cache */
   /* search764_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2294 },
      -1,
   } },

   /* replace764_0 -> 0 in the cache */
   /* replace764_1 -> 3 in the cache */
   /* replace764 -> 2294 in the cache */

   /* ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b') */
   /* search765_0_0 -> 0 in the cache */
   /* search765_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2296 },
      -1,
   } },

   /* replace765_0 -> 0 in the cache */
   /* replace765_1 -> 3 in the cache */
   /* replace765 -> 2296 in the cache */

   /* ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b') */
   /* search766_0_0 -> 0 in the cache */
   /* search766_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2298 },
      -1,
   } },

   /* replace766_0 -> 0 in the cache */
   /* replace766_1 -> 3 in the cache */
   /* replace766 -> 2298 in the cache */

   /* ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b') */
   /* search767_0_0 -> 0 in the cache */
   /* search767_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2300 },
      -1,
   } },

   /* replace767_0 -> 0 in the cache */
   /* replace767_1 -> 3 in the cache */
   /* replace767 -> 2300 in the cache */

   /* ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b')) */
   /* search768_0 -> 0 in the cache */
   /* search768_1 -> 3 in the cache */
   /* search768 -> 2294 in the cache */

   /* replace768_0_0 -> 0 in the cache */
   /* replace768_0_1 -> 3 in the cache */
   /* replace768_0 -> 1004 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1004 },
      -1,
   } },

   /* ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b')) */
   /* search769_0 -> 0 in the cache */
   /* search769_1 -> 3 in the cache */
   /* search769 -> 2296 in the cache */

   /* replace769_0_0 -> 0 in the cache */
   /* replace769_0_1 -> 3 in the cache */
   /* replace769_0 -> 1001 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1001 },
      -1,
   } },

   /* ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b')) */
   /* search770_0 -> 0 in the cache */
   /* search770_1 -> 3 in the cache */
   /* search770 -> 2298 in the cache */

   /* replace770_0_0 -> 0 in the cache */
   /* replace770_0_1 -> 3 in the cache */
   /* replace770_0 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1010 },
      -1,
   } },

   /* ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b')) */
   /* search771_0 -> 0 in the cache */
   /* search771_1 -> 3 in the cache */
   /* search771 -> 2300 in the cache */

   /* replace771_0_0 -> 0 in the cache */
   /* replace771_0_1 -> 3 in the cache */
   /* replace771_0 -> 1007 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1007 },
      -1,
   } },

   /* ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search772_0_0 -> 0 in the cache */
   /* search772_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search772_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2306, 255 },
      -1,
   } },

   /* replace772_0 -> 0 in the cache */
   /* replace772_1 -> 3 in the cache */
   /* replace772 -> 2298 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search773_0_0 -> 0 in the cache */
   /* search773_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search773_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2308, 255 },
      -1,
   } },

   /* replace773_0 -> 0 in the cache */
   /* replace773_1 -> 3 in the cache */
   /* replace773 -> 2300 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search774_0_0 -> 0 in the cache */
   /* search774_0_1 -> 3 in the cache */
   /* search774_0 -> 2294 in the cache */
   /* search774_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2294, 255 },
      -1,
   } },

   /* replace774_0 -> 0 in the cache */
   /* replace774_1 -> 3 in the cache */
   /* replace774 -> 2294 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search775_0_0 -> 0 in the cache */
   /* search775_0_1 -> 3 in the cache */
   /* search775_0 -> 2296 in the cache */
   /* search775_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2296, 255 },
      -1,
   } },

   /* replace775_0 -> 0 in the cache */
   /* replace775_1 -> 3 in the cache */
   /* replace775 -> 2296 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search776_0_0 -> 0 in the cache */
   /* search776_0_1 -> 3 in the cache */
   /* search776_0 -> 2306 in the cache */
   /* search776_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2306, 241 },
      -1,
   } },

   /* replace776_0 -> 0 in the cache */
   /* replace776_1 -> 3 in the cache */
   /* replace776 -> 2298 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search777_0_0 -> 0 in the cache */
   /* search777_0_1 -> 3 in the cache */
   /* search777_0 -> 2308 in the cache */
   /* search777_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2308, 241 },
      -1,
   } },

   /* replace777_0 -> 0 in the cache */
   /* replace777_1 -> 3 in the cache */
   /* replace777 -> 2300 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search778_0_0 -> 0 in the cache */
   /* search778_0_1 -> 3 in the cache */
   /* search778_0 -> 2294 in the cache */
   /* search778_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2294, 241 },
      -1,
   } },

   /* replace778_0 -> 0 in the cache */
   /* replace778_1 -> 3 in the cache */
   /* replace778 -> 2294 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search779_0_0 -> 0 in the cache */
   /* search779_0_1 -> 3 in the cache */
   /* search779_0 -> 2296 in the cache */
   /* search779_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2296, 241 },
      -1,
   } },

   /* replace779_0 -> 0 in the cache */
   /* replace779_1 -> 3 in the cache */
   /* replace779 -> 2296 in the cache */

   /* ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search780_0_0 -> 0 in the cache */
   /* search780_0_1 -> 3 in the cache */
   /* search780_0 -> 2306 in the cache */
   /* search780_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2306, 241 },
      -1,
   } },

   /* replace780_0 -> 0 in the cache */
   /* replace780_1 -> 3 in the cache */
   /* replace780 -> 2300 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search781_0_0 -> 0 in the cache */
   /* search781_0_1 -> 3 in the cache */
   /* search781_0 -> 2308 in the cache */
   /* search781_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2308, 241 },
      -1,
   } },

   /* replace781_0 -> 0 in the cache */
   /* replace781_1 -> 3 in the cache */
   /* replace781 -> 2298 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search782_0_0 -> 0 in the cache */
   /* search782_0_1 -> 3 in the cache */
   /* search782_0 -> 2294 in the cache */
   /* search782_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2294, 241 },
      -1,
   } },

   /* replace782_0 -> 0 in the cache */
   /* replace782_1 -> 3 in the cache */
   /* replace782 -> 2296 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search783_0_0 -> 0 in the cache */
   /* search783_0_1 -> 3 in the cache */
   /* search783_0 -> 2296 in the cache */
   /* search783_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2296, 241 },
      -1,
   } },

   /* replace783_0 -> 0 in the cache */
   /* replace783_1 -> 3 in the cache */
   /* replace783 -> 2294 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search784_0_0 -> 0 in the cache */
   /* search784_0_1 -> 3 in the cache */
   /* search784_0 -> 2306 in the cache */
   /* search784_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2306, 255 },
      -1,
   } },

   /* replace784_0 -> 0 in the cache */
   /* replace784_1 -> 3 in the cache */
   /* replace784 -> 2300 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search785_0_0 -> 0 in the cache */
   /* search785_0_1 -> 3 in the cache */
   /* search785_0 -> 2308 in the cache */
   /* search785_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2308, 255 },
      -1,
   } },

   /* replace785_0 -> 0 in the cache */
   /* replace785_1 -> 3 in the cache */
   /* replace785 -> 2298 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search786_0_0 -> 0 in the cache */
   /* search786_0_1 -> 3 in the cache */
   /* search786_0 -> 2294 in the cache */
   /* search786_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2294, 255 },
      -1,
   } },

   /* replace786_0 -> 0 in the cache */
   /* replace786_1 -> 3 in the cache */
   /* replace786 -> 2296 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search787_0_0 -> 0 in the cache */
   /* search787_0_1 -> 3 in the cache */
   /* search787_0 -> 2296 in the cache */
   /* search787_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2296, 255 },
      -1,
   } },

   /* replace787_0 -> 0 in the cache */
   /* replace787_1 -> 3 in the cache */
   /* replace787 -> 2294 in the cache */

   /* ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y')) */
   /* search788_0 -> 16 in the cache */
   /* search788_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2325, 2326 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 2328, 2329 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      -1, 2,
      { 2327, 2330 },
      -1,
   } },

   /* ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0) */
   /* search789_0 -> 16 in the cache */
   /* search789_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace789_0_0 -> 16 in the cache */
   /* replace789_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal3,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace789_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2333, 117 },
      -1,
   } },

   /* ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0) */
   /* search790_0 -> 16 in the cache */
   /* search790_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace790_0_0 -> 16 in the cache */
   /* replace790_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal4,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace790_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2336, 117 },
      -1,
   } },

   /* ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y')) */
   /* search791_0 -> 16 in the cache */
   /* search791_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace791_0_0 -> 2325 in the cache */
   /* replace791_0_1 -> 2326 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2325, 2326 },
      -1,
   } },
   /* replace791_1_0 -> 2328 in the cache */
   /* replace791_1_1 -> 2329 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 2328, 2329 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      -1, 2,
      { 2339, 2340 },
      -1,
   } },

   /* ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search792_0 -> 16 in the cache */
   /* search792_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace792_0_0_0 -> 16 in the cache */
   /* replace792_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* replace792_0_1_0 -> 16 in the cache */
   /* replace792_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot3,
      -1, 2,
      { 2343, 2344 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2345 },
      -1,
   } },

   /* ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search793_0 -> 16 in the cache */
   /* search793_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace793_0_0_0 -> 16 in the cache */
   /* replace793_0_0_1 -> 36 in the cache */
   /* replace793_0_0 -> 2343 in the cache */
   /* replace793_0_1_0 -> 16 in the cache */
   /* replace793_0_1_1 -> 36 in the cache */
   /* replace793_0_1 -> 2344 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot4,
      -1, 2,
      { 2343, 2344 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2348 },
      -1,
   } },

   /* ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')) */
   /* search794_0 -> 0 in the cache */
   /* search794_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace794_0_0 -> 724 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 724, 2351 },
      -1,
   } },
   /* replace794_1_0 -> 725 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 725, 2353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2352, 2354 },
      -1,
   } },

   /* ('ball_iequal3', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('ieq', 'a.z', 'b.z')) */
   /* search795_0 -> 0 in the cache */
   /* search795_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace795_0_0_0 -> 724 in the cache */
   /* replace795_0_0_1 -> 2351 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 724, 2351 },
      -1,
   } },
   /* replace795_0_1_0 -> 725 in the cache */
   /* replace795_0_1_1 -> 2353 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 725, 2353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2357, 2358 },
      -1,
   } },
   /* replace795_1_0 -> 726 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 726, 2360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2359, 2361 },
      -1,
   } },

   /* ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w'))) */
   /* search796_0 -> 0 in the cache */
   /* search796_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace796_0_0_0 -> 724 in the cache */
   /* replace796_0_0_1 -> 2351 in the cache */
   /* replace796_0_0 -> 2352 in the cache */
   /* replace796_0_1_0 -> 725 in the cache */
   /* replace796_0_1_1 -> 2353 in the cache */
   /* replace796_0_1 -> 2354 in the cache */
   /* replace796_0 -> 2355 in the cache */
   /* replace796_1_0_0 -> 726 in the cache */
   /* replace796_1_0_1 -> 2360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 726, 2360 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 2365, 2366 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2364, 2367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2355, 2368 },
      -1,
   } },

   /* ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')) */
   /* search797_0 -> 0 in the cache */
   /* search797_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace797_0_0 -> 724 in the cache */
   /* replace797_0_1 -> 2351 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 724, 2351 },
      -1,
   } },
   /* replace797_1_0 -> 725 in the cache */
   /* replace797_1_1 -> 2353 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 725, 2353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2371, 2372 },
      -1,
   } },

   /* ('bany_inequal3', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ine', 'a.z', 'b.z')) */
   /* search798_0 -> 0 in the cache */
   /* search798_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace798_0_0_0 -> 724 in the cache */
   /* replace798_0_0_1 -> 2351 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 724, 2351 },
      -1,
   } },
   /* replace798_0_1_0 -> 725 in the cache */
   /* replace798_0_1_1 -> 2353 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 725, 2353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2375, 2376 },
      -1,
   } },
   /* replace798_1_0 -> 726 in the cache */
   /* replace798_1_1 -> 2360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 726, 2360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2377, 2378 },
      -1,
   } },

   /* ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w'))) */
   /* search799_0 -> 0 in the cache */
   /* search799_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace799_0_0_0 -> 724 in the cache */
   /* replace799_0_0_1 -> 2351 in the cache */
   /* replace799_0_0 -> 2371 in the cache */
   /* replace799_0_1_0 -> 725 in the cache */
   /* replace799_0_1_1 -> 2353 in the cache */
   /* replace799_0_1 -> 2372 in the cache */
   /* replace799_0 -> 2373 in the cache */
   /* replace799_1_0_0 -> 726 in the cache */
   /* replace799_1_0_1 -> 2360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 726, 2360 },
      -1,
   } },
   /* replace799_1_1_0 -> 2365 in the cache */
   /* replace799_1_1_1 -> 2366 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 2365, 2366 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2381, 2382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2373, 2383 },
      -1,
   } },

   /* ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')) */
   /* search800_0 -> 0 in the cache */
   /* search800_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace800_0_0 -> 724 in the cache */
   /* replace800_0_1 -> 2351 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 724, 2351 },
      -1,
   } },
   /* replace800_1_0 -> 725 in the cache */
   /* replace800_1_1 -> 2353 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 725, 2353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2386, 2387 },
      -1,
   } },

   /* ('ball_fequal3', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('feq', 'a.z', 'b.z')) */
   /* search801_0 -> 0 in the cache */
   /* search801_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace801_0_0_0 -> 724 in the cache */
   /* replace801_0_0_1 -> 2351 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 724, 2351 },
      -1,
   } },
   /* replace801_0_1_0 -> 725 in the cache */
   /* replace801_0_1_1 -> 2353 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 725, 2353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2390, 2391 },
      -1,
   } },
   /* replace801_1_0 -> 726 in the cache */
   /* replace801_1_1 -> 2360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 726, 2360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2392, 2393 },
      -1,
   } },

   /* ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w'))) */
   /* search802_0 -> 0 in the cache */
   /* search802_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace802_0_0_0 -> 724 in the cache */
   /* replace802_0_0_1 -> 2351 in the cache */
   /* replace802_0_0 -> 2386 in the cache */
   /* replace802_0_1_0 -> 725 in the cache */
   /* replace802_0_1_1 -> 2353 in the cache */
   /* replace802_0_1 -> 2387 in the cache */
   /* replace802_0 -> 2388 in the cache */
   /* replace802_1_0_0 -> 726 in the cache */
   /* replace802_1_0_1 -> 2360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 726, 2360 },
      -1,
   } },
   /* replace802_1_1_0 -> 2365 in the cache */
   /* replace802_1_1_1 -> 2366 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 2365, 2366 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2396, 2397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2388, 2398 },
      -1,
   } },

   /* ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')) */
   /* search803_0 -> 0 in the cache */
   /* search803_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace803_0_0 -> 724 in the cache */
   /* replace803_0_1 -> 2351 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 724, 2351 },
      -1,
   } },
   /* replace803_1_0 -> 725 in the cache */
   /* replace803_1_1 -> 2353 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 725, 2353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2401, 2402 },
      -1,
   } },

   /* ('bany_fnequal3', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('fneu', 'a.z', 'b.z')) */
   /* search804_0 -> 0 in the cache */
   /* search804_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace804_0_0_0 -> 724 in the cache */
   /* replace804_0_0_1 -> 2351 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 724, 2351 },
      -1,
   } },
   /* replace804_0_1_0 -> 725 in the cache */
   /* replace804_0_1_1 -> 2353 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 725, 2353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2405, 2406 },
      -1,
   } },
   /* replace804_1_0 -> 726 in the cache */
   /* replace804_1_1 -> 2360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 726, 2360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2407, 2408 },
      -1,
   } },

   /* ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w'))) */
   /* search805_0 -> 0 in the cache */
   /* search805_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace805_0_0_0 -> 724 in the cache */
   /* replace805_0_0_1 -> 2351 in the cache */
   /* replace805_0_0 -> 2401 in the cache */
   /* replace805_0_1_0 -> 725 in the cache */
   /* replace805_0_1_1 -> 2353 in the cache */
   /* replace805_0_1 -> 2402 in the cache */
   /* replace805_0 -> 2403 in the cache */
   /* replace805_1_0_0 -> 726 in the cache */
   /* replace805_1_0_1 -> 2360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 726, 2360 },
      -1,
   } },
   /* replace805_1_1_0 -> 2365 in the cache */
   /* replace805_1_1_1 -> 2366 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 2365, 2366 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2411, 2412 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2403, 2413 },
      -1,
   } },

   /* ('feq', ('seq', 'a', 'b'), 1.0) => ('feq', 'a', 'b') */
   /* search806_0_0 -> 0 in the cache */
   /* search806_0_1 -> 3 in the cache */
   /* search806_0 -> 2306 in the cache */
   /* search806_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2306, 255 },
      -1,
   } },

   /* replace806_0 -> 0 in the cache */
   /* replace806_1 -> 3 in the cache */
   /* replace806 -> 1010 in the cache */

   /* ('feq', ('sne', 'a', 'b'), 1.0) => ('fneu', 'a', 'b') */
   /* search807_0_0 -> 0 in the cache */
   /* search807_0_1 -> 3 in the cache */
   /* search807_0 -> 2308 in the cache */
   /* search807_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2308, 255 },
      -1,
   } },

   /* replace807_0 -> 0 in the cache */
   /* replace807_1 -> 3 in the cache */
   /* replace807 -> 1007 in the cache */

   /* ('feq', ('slt', 'a', 'b'), 1.0) => ('flt', 'a', 'b') */
   /* search808_0_0 -> 0 in the cache */
   /* search808_0_1 -> 3 in the cache */
   /* search808_0 -> 2294 in the cache */
   /* search808_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2294, 255 },
      -1,
   } },

   /* replace808_0 -> 0 in the cache */
   /* replace808_1 -> 3 in the cache */
   /* replace808 -> 1004 in the cache */

   /* ('feq', ('sge', 'a', 'b'), 1.0) => ('fge', 'a', 'b') */
   /* search809_0_0 -> 0 in the cache */
   /* search809_0_1 -> 3 in the cache */
   /* search809_0 -> 2296 in the cache */
   /* search809_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2296, 255 },
      -1,
   } },

   /* replace809_0 -> 0 in the cache */
   /* replace809_1 -> 3 in the cache */
   /* replace809 -> 1001 in the cache */

   /* ('fneu', ('seq', 'a', 'b'), 0.0) => ('feq', 'a', 'b') */
   /* search810_0_0 -> 0 in the cache */
   /* search810_0_1 -> 3 in the cache */
   /* search810_0 -> 2306 in the cache */
   /* search810_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2306, 241 },
      -1,
   } },

   /* replace810_0 -> 0 in the cache */
   /* replace810_1 -> 3 in the cache */
   /* replace810 -> 1010 in the cache */

   /* ('fneu', ('sne', 'a', 'b'), 0.0) => ('fneu', 'a', 'b') */
   /* search811_0_0 -> 0 in the cache */
   /* search811_0_1 -> 3 in the cache */
   /* search811_0 -> 2308 in the cache */
   /* search811_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2308, 241 },
      -1,
   } },

   /* replace811_0 -> 0 in the cache */
   /* replace811_1 -> 3 in the cache */
   /* replace811 -> 1007 in the cache */

   /* ('fneu', ('slt', 'a', 'b'), 0.0) => ('flt', 'a', 'b') */
   /* search812_0_0 -> 0 in the cache */
   /* search812_0_1 -> 3 in the cache */
   /* search812_0 -> 2294 in the cache */
   /* search812_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2294, 241 },
      -1,
   } },

   /* replace812_0 -> 0 in the cache */
   /* replace812_1 -> 3 in the cache */
   /* replace812 -> 1004 in the cache */

   /* ('fneu', ('sge', 'a', 'b'), 0.0) => ('fge', 'a', 'b') */
   /* search813_0_0 -> 0 in the cache */
   /* search813_0_1 -> 3 in the cache */
   /* search813_0 -> 2296 in the cache */
   /* search813_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2296, 241 },
      -1,
   } },

   /* replace813_0 -> 0 in the cache */
   /* replace813_1 -> 3 in the cache */
   /* replace813 -> 1001 in the cache */

   /* ('feq', ('seq', 'a', 'b'), 0.0) => ('fneu', 'a', 'b') */
   /* search814_0_0 -> 0 in the cache */
   /* search814_0_1 -> 3 in the cache */
   /* search814_0 -> 2306 in the cache */
   /* search814_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2306, 241 },
      -1,
   } },

   /* replace814_0 -> 0 in the cache */
   /* replace814_1 -> 3 in the cache */
   /* replace814 -> 1007 in the cache */

   /* ('feq', ('sne', 'a', 'b'), 0.0) => ('feq', 'a', 'b') */
   /* search815_0_0 -> 0 in the cache */
   /* search815_0_1 -> 3 in the cache */
   /* search815_0 -> 2308 in the cache */
   /* search815_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2308, 241 },
      -1,
   } },

   /* replace815_0 -> 0 in the cache */
   /* replace815_1 -> 3 in the cache */
   /* replace815 -> 1010 in the cache */

   /* ('feq', ('slt', 'a', 'b'), 0.0) => ('fge', 'a', 'b') */
   /* search816_0_0 -> 0 in the cache */
   /* search816_0_1 -> 3 in the cache */
   /* search816_0 -> 2294 in the cache */
   /* search816_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2294, 241 },
      -1,
   } },

   /* replace816_0 -> 0 in the cache */
   /* replace816_1 -> 3 in the cache */
   /* replace816 -> 1001 in the cache */

   /* ('feq', ('sge', 'a', 'b'), 0.0) => ('flt', 'a', 'b') */
   /* search817_0_0 -> 0 in the cache */
   /* search817_0_1 -> 3 in the cache */
   /* search817_0 -> 2296 in the cache */
   /* search817_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2296, 241 },
      -1,
   } },

   /* replace817_0 -> 0 in the cache */
   /* replace817_1 -> 3 in the cache */
   /* replace817 -> 1004 in the cache */

   /* ('fneu', ('seq', 'a', 'b'), 1.0) => ('fneu', 'a', 'b') */
   /* search818_0_0 -> 0 in the cache */
   /* search818_0_1 -> 3 in the cache */
   /* search818_0 -> 2306 in the cache */
   /* search818_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2306, 255 },
      -1,
   } },

   /* replace818_0 -> 0 in the cache */
   /* replace818_1 -> 3 in the cache */
   /* replace818 -> 1007 in the cache */

   /* ('fneu', ('sne', 'a', 'b'), 1.0) => ('feq', 'a', 'b') */
   /* search819_0_0 -> 0 in the cache */
   /* search819_0_1 -> 3 in the cache */
   /* search819_0 -> 2308 in the cache */
   /* search819_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2308, 255 },
      -1,
   } },

   /* replace819_0 -> 0 in the cache */
   /* replace819_1 -> 3 in the cache */
   /* replace819 -> 1010 in the cache */

   /* ('fneu', ('slt', 'a', 'b'), 1.0) => ('fge', 'a', 'b') */
   /* search820_0_0 -> 0 in the cache */
   /* search820_0_1 -> 3 in the cache */
   /* search820_0 -> 2294 in the cache */
   /* search820_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2294, 255 },
      -1,
   } },

   /* replace820_0 -> 0 in the cache */
   /* replace820_1 -> 3 in the cache */
   /* replace820 -> 1001 in the cache */

   /* ('fneu', ('sge', 'a', 'b'), 1.0) => ('flt', 'a', 'b') */
   /* search821_0_0 -> 0 in the cache */
   /* search821_0_1 -> 3 in the cache */
   /* search821_0 -> 2296 in the cache */
   /* search821_1 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2296, 255 },
      -1,
   } },

   /* replace821_0 -> 0 in the cache */
   /* replace821_1 -> 3 in the cache */
   /* replace821 -> 1004 in the cache */

   /* ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0) */
   /* search822_0_0 -> 32 in the cache */
   /* search822_0 -> 98 in the cache */
   /* search822_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace822_0 -> 32 in the cache */
   /* replace822_1 -> 113 in the cache */
   /* replace822 -> 1203 in the cache */

   /* ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0) */
   /* search823_0_0 -> 32 in the cache */
   /* search823_0 -> 98 in the cache */
   /* search823_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace823_0 -> 32 in the cache */
   /* replace823_1 -> 113 in the cache */
   /* replace823 -> 1207 in the cache */

   /* ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search824_0_0 -> 715 in the cache */
   /* search824_0 -> 1176 in the cache */
   /* search824_1_0 -> 1083 in the cache */
   /* search824_1 -> 2173 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 1176, 2173 },
      -1,
   } },

   /* replace824_0_0 -> 715 in the cache */
   /* replace824_0_1 -> 1083 in the cache */
   /* replace824_0 -> 1095 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1095 },
      -1,
   } },

   /* ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search825_0_0 -> 715 in the cache */
   /* search825_0 -> 1176 in the cache */
   /* search825_1_0 -> 1083 in the cache */
   /* search825_1 -> 2173 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1176, 2173 },
      -1,
   } },

   /* replace825_0_0 -> 715 in the cache */
   /* replace825_0_1 -> 1083 in the cache */
   /* replace825_0 -> 1095 in the cache */
   /* replace825 -> 2434 in the cache */

   /* ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b')) */
   /* search826_0_0 -> 715 in the cache */
   /* search826_0 -> 1176 in the cache */
   /* search826_1_0 -> 1083 in the cache */
   /* search826_1 -> 2173 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1176, 2173 },
      -1,
   } },

   /* replace826_0_0 -> 715 in the cache */
   /* replace826_0_1 -> 1083 in the cache */
   /* replace826_0 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1087 },
      -1,
   } },

   /* ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search827_0_0 -> 715 in the cache */
   /* search827_0 -> 1078 in the cache */
   /* search827_1_0 -> 1083 in the cache */
   /* search827_1 -> 1084 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1078, 1084 },
      -1,
   } },

   /* replace827_0_0 -> 715 in the cache */
   /* replace827_0_1 -> 1083 in the cache */
   /* replace827_0 -> 1095 in the cache */
   /* replace827 -> 1216 in the cache */

   /* ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b')) */
   /* search828_0_0_0 -> 715 in the cache */
   /* search828_0_0 -> 1078 in the cache */
   /* search828_0_1_0 -> 1083 in the cache */
   /* search828_0_1 -> 1084 in the cache */
   /* search828_0 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1114 },
      -1,
   } },

   /* replace828_0_0 -> 715 in the cache */
   /* replace828_0_1 -> 1083 in the cache */
   /* replace828_0 -> 1087 in the cache */
   /* replace828 -> 1213 in the cache */

   /* ('iand', 'a@bool16', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search829_1 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2440, 462 },
      -1,
   } },

   /* replace829_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iand', 'a@bool32', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search830_1 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2443, 228 },
      -1,
   } },

   /* replace830_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('flt', ('fneg', ('b2f', 'a@1')), 0) => a */
   /* search831_0_0_0 -> 715 in the cache */
   /* search831_0_0 -> 1078 in the cache */
   /* search831_0 -> 1081 in the cache */
   /* search831_1 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1081, 1177 },
      -1,
   } },

   /* replace831 -> 715 in the cache */

   /* ('ilt', 'a', 'a') => False */
   /* search832_0 -> 32 in the cache */
   /* search832_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace832 -> 1032 in the cache */

   /* ('ige', 'a', 'a') => True */
   /* search833_0 -> 32 in the cache */
   /* search833_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace833 -> 1185 in the cache */

   /* ('ieq', 'a', 'a') => True */
   /* search834_0 -> 32 in the cache */
   /* search834_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace834 -> 1185 in the cache */

   /* ('ine', 'a', 'a') => False */
   /* search835_0 -> 32 in the cache */
   /* search835_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace835 -> 1032 in the cache */

   /* ('ult', 'a', 'a') => False */
   /* search836_0 -> 32 in the cache */
   /* search836_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace836 -> 1032 in the cache */

   /* ('uge', 'a', 'a') => True */
   /* search837_0 -> 32 in the cache */
   /* search837_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace837 -> 1185 in the cache */

   /* ('flt', 'a', 'a') => False */
   /* search838_0 -> 32 in the cache */
   /* search838_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace838 -> 1032 in the cache */

   /* ('fge', 'a(is_a_number)', 'a') => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search839_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2454, 32 },
      -1,
   } },

   /* replace839 -> 1185 in the cache */

   /* ('feq', 'a(is_a_number)', 'a') => True */
   /* search840_0 -> 2454 in the cache */
   /* search840_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 2454, 32 },
      -1,
   } },

   /* replace840 -> 1185 in the cache */

   /* ('fneu', 'a(is_a_number)', 'a') => False */
   /* search841_0 -> 2454 in the cache */
   /* search841_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 2454, 32 },
      -1,
   } },

   /* replace841 -> 1032 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search842_0 -> 32 in the cache */
   /* search842_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace842 -> 32 in the cache */

   /* ('iand', 'a', -1) => a */
   /* search843_0 -> 32 in the cache */
   /* search843_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace843 -> 32 in the cache */

   /* ('iand', 'a', 0) => 0 */
   /* search844_0 -> 32 in the cache */
   /* search844_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace844 -> 61 in the cache */

   /* ('ior', 'a', 'a') => a */
   /* search845_0 -> 32 in the cache */
   /* search845_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace845 -> 32 in the cache */

   /* ('ior', 'a', 0) => a */
   /* search846_0 -> 32 in the cache */
   /* search846_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace846 -> 32 in the cache */

   /* ('ior', 'a', True) => True */
   /* search847_0 -> 715 in the cache */
   /* search847_1 -> 1185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 715, 1185 },
      -1,
   } },

   /* replace847 -> 1185 in the cache */

   /* ('ixor', 'a', 'a') => 0 */
   /* search848_0 -> 32 in the cache */
   /* search848_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace848 -> 61 in the cache */

   /* ('ixor', 'a', 0) => a */
   /* search849_0 -> 32 in the cache */
   /* search849_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace849 -> 32 in the cache */

   /* ('inot', ('inot', 'a')) => a */
   /* search850_0_0 -> 32 in the cache */
   /* search850_0 -> 2170 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 2170 },
      -1,
   } },

   /* replace850 -> 32 in the cache */

   /* ('ior', ('iand', 'a', 'b'), 'b') => b */
   /* search851_0_0 -> 0 in the cache */
   /* search851_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search851_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2467, 3 },
      -1,
   } },

   /* replace851 -> 3 in the cache */

   /* ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b') */
   /* search852_0_0 -> 0 in the cache */
   /* search852_0_1 -> 3 in the cache */
   /* search852_0 -> 84 in the cache */
   /* search852_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace852_0 -> 0 in the cache */
   /* replace852_1 -> 3 in the cache */
   /* replace852 -> 2236 in the cache */

   /* ('iand', ('ior', 'a', 'b'), 'b') => b */
   /* search853_0_0 -> 0 in the cache */
   /* search853_0_1 -> 3 in the cache */
   /* search853_0 -> 84 in the cache */
   /* search853_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace853 -> 3 in the cache */

   /* ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b') */
   /* search854_0_0 -> 0 in the cache */
   /* search854_0_1 -> 3 in the cache */
   /* search854_0 -> 2467 in the cache */
   /* search854_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2467, 3 },
      -1,
   } },

   /* replace854_0 -> 0 in the cache */
   /* replace854_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b')) */
   /* search855_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search855_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2473, 2474 },
      -1,
   } },

   /* replace855_0_0 -> 0 in the cache */
   /* replace855_0_1 -> 3 in the cache */
   /* replace855_0 -> 2236 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2236 },
      -1,
   } },

   /* ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b')) */
   /* search856_0_0 -> 0 in the cache */
   /* search856_0 -> 2473 in the cache */
   /* search856_1_0 -> 3 in the cache */
   /* search856_1 -> 2474 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2473, 2474 },
      -1,
   } },

   /* replace856_0_0 -> 0 in the cache */
   /* replace856_0_1 -> 3 in the cache */
   /* replace856_0 -> 2472 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2472 },
      -1,
   } },

   /* ('ishl', 0, 'a') => 0 */
   /* search857_0 -> 1177 in the cache */
   /* search857_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1177, 16 },
      -1,
   } },

   /* replace857 -> 1177 in the cache */

   /* ('ishl', 'a', 0) => a */
   /* search858_0 -> 32 in the cache */
   /* search858_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 32, 120 },
      -1,
   } },

   /* replace858 -> 32 in the cache */

   /* ('ishr', 0, 'a') => 0 */
   /* search859_0 -> 1177 in the cache */
   /* search859_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 1177, 16 },
      -1,
   } },

   /* replace859 -> 1177 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search860_0 -> 32 in the cache */
   /* search860_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 32, 120 },
      -1,
   } },

   /* replace860 -> 32 in the cache */

   /* ('ushr', 0, 'a') => 0 */
   /* search861_0 -> 1177 in the cache */
   /* search861_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1177, 16 },
      -1,
   } },

   /* replace861 -> 1177 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search862_0 -> 32 in the cache */
   /* search862_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 32, 120 },
      -1,
   } },

   /* replace862 -> 32 in the cache */

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search863_0_0 -> 11 in the cache */
   /* search863_0_1 -> 36 in the cache */
   /* search863_0 -> 2100 in the cache */
   /* search863_1_0 -> 11 in the cache */
   /* search863_1_1_0 -> 808 in the cache */
   /* search863_1_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 808, 2485 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2100, 2487 },
      -1,
   } },

   /* replace863_0 -> 11 in the cache */
   /* replace863_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b') */
   /* search864_0_0 -> 11 in the cache */
   /* search864_0_1 -> 36 in the cache */
   /* search864_0 -> 2100 in the cache */
   /* search864_1_0 -> 11 in the cache */
   /* search864_1_1_0 -> 808 in the cache */
   /* search864_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 808, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 2490 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2100, 2491 },
      -1,
   } },

   /* replace864_0 -> 11 in the cache */
   /* replace864_1 -> 36 in the cache */
   /* replace864 -> 2489 in the cache */

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search865_0_0 -> 16 in the cache */
   /* search865_0_1 -> 36 in the cache */
   /* search865_0 -> 901 in the cache */
   /* search865_1_0 -> 16 in the cache */
   /* search865_1_1_0 -> 829 in the cache */
   /* search865_1_1_1_0 -> 36 in the cache */
   /* search865_1_1_1 -> 2485 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 829, 2485 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 901, 2494 },
      -1,
   } },

   /* replace865_0 -> 16 in the cache */
   /* replace865_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b') */
   /* search866_0_0 -> 16 in the cache */
   /* search866_0_1 -> 36 in the cache */
   /* search866_0 -> 901 in the cache */
   /* search866_1_0 -> 16 in the cache */
   /* search866_1_1_0 -> 829 in the cache */
   /* search866_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 829, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 2497 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 901, 2498 },
      -1,
   } },

   /* replace866_0 -> 16 in the cache */
   /* replace866_1 -> 36 in the cache */
   /* replace866 -> 2496 in the cache */

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search867_0_0 -> 11 in the cache */
   /* search867_0_1 -> 36 in the cache */
   /* search867_0 -> 2104 in the cache */
   /* search867_1_0 -> 11 in the cache */
   /* search867_1_1_0 -> 808 in the cache */
   /* search867_1_1_1_0 -> 36 in the cache */
   /* search867_1_1_1 -> 2485 in the cache */
   /* search867_1_1 -> 2486 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 2486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2104, 2500 },
      -1,
   } },

   /* replace867_0 -> 11 in the cache */
   /* replace867_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b') */
   /* search868_0_0 -> 11 in the cache */
   /* search868_0_1 -> 36 in the cache */
   /* search868_0 -> 2104 in the cache */
   /* search868_1_0 -> 11 in the cache */
   /* search868_1_1_0 -> 808 in the cache */
   /* search868_1_1_1 -> 36 in the cache */
   /* search868_1_1 -> 2490 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 2490 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2104, 2503 },
      -1,
   } },

   /* replace868_0 -> 11 in the cache */
   /* replace868_1 -> 36 in the cache */
   /* replace868 -> 2502 in the cache */

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search869_0_0 -> 16 in the cache */
   /* search869_0_1 -> 36 in the cache */
   /* search869_0 -> 2129 in the cache */
   /* search869_1_0 -> 16 in the cache */
   /* search869_1_1_0 -> 829 in the cache */
   /* search869_1_1_1_0 -> 36 in the cache */
   /* search869_1_1_1 -> 2485 in the cache */
   /* search869_1_1 -> 2493 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 2493 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2129, 2505 },
      -1,
   } },

   /* replace869_0 -> 16 in the cache */
   /* replace869_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b') */
   /* search870_0_0 -> 16 in the cache */
   /* search870_0_1 -> 36 in the cache */
   /* search870_0 -> 2129 in the cache */
   /* search870_1_0 -> 16 in the cache */
   /* search870_1_1_0 -> 829 in the cache */
   /* search870_1_1_1 -> 36 in the cache */
   /* search870_1_1 -> 2497 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 2497 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2129, 2508 },
      -1,
   } },

   /* replace870_0 -> 16 in the cache */
   /* replace870_1 -> 36 in the cache */
   /* replace870 -> 2507 in the cache */

   /* ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b'))) */
   /* search871_0 -> 11 in the cache */
   /* search871_1 -> 36 in the cache */
   /* search871 -> 2489 in the cache */

   /* replace871_0_0 -> 11 in the cache */
   /* replace871_0_1 -> 36 in the cache */
   /* replace871_0 -> 2100 in the cache */
   /* replace871_1_0 -> 11 in the cache */
   /* replace871_1_1_0 -> 808 in the cache */
   /* replace871_1_1_1 -> 36 in the cache */
   /* replace871_1_1 -> 2490 in the cache */
   /* replace871_1 -> 2491 in the cache */
   /* replace871 -> 2492 in the cache */

   /* ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b'))) */
   /* search872_0 -> 16 in the cache */
   /* search872_1 -> 36 in the cache */
   /* search872 -> 2496 in the cache */

   /* replace872_0_0 -> 16 in the cache */
   /* replace872_0_1 -> 36 in the cache */
   /* replace872_0 -> 901 in the cache */
   /* replace872_1_0 -> 16 in the cache */
   /* replace872_1_1_0 -> 829 in the cache */
   /* replace872_1_1_1 -> 36 in the cache */
   /* replace872_1_1 -> 2497 in the cache */
   /* replace872_1 -> 2498 in the cache */
   /* replace872 -> 2499 in the cache */

   /* ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b'))) */
   /* search873_0 -> 11 in the cache */
   /* search873_1 -> 36 in the cache */
   /* search873 -> 2502 in the cache */

   /* replace873_0_0 -> 11 in the cache */
   /* replace873_0_1 -> 36 in the cache */
   /* replace873_0 -> 2104 in the cache */
   /* replace873_1_0 -> 11 in the cache */
   /* replace873_1_1_0 -> 808 in the cache */
   /* replace873_1_1_1 -> 36 in the cache */
   /* replace873_1_1 -> 2490 in the cache */
   /* replace873_1 -> 2503 in the cache */
   /* replace873 -> 2504 in the cache */

   /* ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b'))) */
   /* search874_0 -> 16 in the cache */
   /* search874_1 -> 36 in the cache */
   /* search874 -> 2507 in the cache */

   /* replace874_0_0 -> 16 in the cache */
   /* replace874_0_1 -> 36 in the cache */
   /* replace874_0 -> 2129 in the cache */
   /* replace874_1_0 -> 16 in the cache */
   /* replace874_1_1_0 -> 829 in the cache */
   /* replace874_1_1_1 -> 36 in the cache */
   /* replace874_1_1 -> 2497 in the cache */
   /* replace874_1 -> 2508 in the cache */
   /* replace874 -> 2509 in the cache */

   /* ('~fexp2', ('flog2', 'a')) => a */
   /* search875_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 2510 },
      -1,
   } },

   /* replace875 -> 32 in the cache */

   /* ('~flog2', ('fexp2', 'a')) => a */
   /* search876_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2512 },
      -1,
   } },

   /* replace876 -> 32 in the cache */

   /* ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b')) */
   /* search877_0 -> 0 in the cache */
   /* search877_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace877_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace877_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2515, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2516 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b') */
   /* search878_0_0_0 -> 0 in the cache */
   /* search878_0_0 -> 2515 in the cache */
   /* search878_0_1 -> 3 in the cache */
   /* search878_0 -> 2516 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2516 },
      -1,
   } },

   /* replace878_0 -> 0 in the cache */
   /* replace878_1 -> 3 in the cache */
   /* replace878 -> 2514 in the cache */

   /* ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd')) */
   /* search879_0_0_0_0 -> 147 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 147 },
      -1,
   } },
   /* search879_0_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 2519, 148 },
      -1,
   } },
   /* search879_0_1_0_0 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 150 },
      -1,
   } },
   /* search879_0_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 2521, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 2520, 2522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 3,
      { 2523 },
      -1,
   } },

   /* replace879_0_0 -> 147 in the cache */
   /* replace879_0_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 147, 148 },
      -1,
   } },
   /* replace879_1_0 -> 150 in the cache */
   /* replace879_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2525, 2526 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a') */
   /* search880_0_0_0 -> 32 in the cache */
   /* search880_0_0 -> 2510 in the cache */
   /* search880_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2510, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2528 },
      -1,
   } },

   /* replace880_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a') */
   /* search881_0_0_0 -> 32 in the cache */
   /* search881_0_0 -> 2510 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2510, 2531 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2532 },
      -1,
   } },

   /* replace881_0 -> 32 in the cache */
   /* replace881_1 -> 32 in the cache */
   /* replace881 -> 236 in the cache */

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search882_0_0_0 -> 32 in the cache */
   /* search882_0_0 -> 2510 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4010000000000000 /* 4.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2510, 2534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2535 },
      -1,
   } },

   /* replace882_0_0 -> 32 in the cache */
   /* replace882_0_1 -> 32 in the cache */
   /* replace882_0 -> 236 in the cache */
   /* replace882_1_0 -> 32 in the cache */
   /* replace882_1_1 -> 32 in the cache */
   /* replace882_1 -> 236 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 236, 236 },
      -1,
   } },

   /* ('~fpow', 'a', 1.0) => a */
   /* search883_0 -> 32 in the cache */
   /* search883_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 226 },
      -1,
   } },

   /* replace883 -> 32 in the cache */

   /* ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a') */
   /* search884_0 -> 32 in the cache */
   /* search884_1 -> 2531 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2531 },
      -1,
   } },

   /* replace884_0 -> 32 in the cache */
   /* replace884_1 -> 32 in the cache */
   /* replace884 -> 236 in the cache */

   /* ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search885_0 -> 32 in the cache */
   /* search885_1 -> 2534 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2534 },
      -1,
   } },

   /* replace885_0_0 -> 32 in the cache */
   /* replace885_0_1 -> 32 in the cache */
   /* replace885_0 -> 236 in the cache */
   /* replace885_1_0 -> 32 in the cache */
   /* replace885_1_1 -> 32 in the cache */
   /* replace885_1 -> 236 in the cache */
   /* replace885 -> 2537 in the cache */

   /* ('~fpow', 2.0, 'a') => ('fexp2', 'a') */
   /* search886_0 -> 2531 in the cache */
   /* search886_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2531, 32 },
      -1,
   } },

   /* replace886_0 -> 32 in the cache */
   /* replace886 -> 2512 in the cache */

   /* ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a */
   /* search887_0_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x400199999999999a /* 2.2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2542 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fdd1743e963dc48 /* 0.454545 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2543, 2544 },
      -1,
   } },

   /* replace887 -> 32 in the cache */

   /* ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a') */
   /* search888_0_0_0 -> 32 in the cache */
   /* search888_0_0_1 -> 2542 in the cache */
   /* search888_0_0 -> 2543 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2543 },
      -1,
   } },
   /* search888_1 -> 2544 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2546, 2544 },
      -1,
   } },

   /* replace888_0 -> 32 in the cache */
   /* replace888 -> 103 in the cache */

   /* ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a')) */
   /* search889_0_0 -> 32 in the cache */
   /* search889_0 -> 2512 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 2512 },
      -1,
   } },

   /* replace889_0_0 -> 676 in the cache */
   /* replace889_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 676, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2549 },
      -1,
   } },

   /* ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a')) */
   /* search890_0_0 -> 32 in the cache */
   /* search890_0 -> 2512 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2512 },
      -1,
   } },

   /* replace890_0_0 -> 32 in the cache */
   /* replace890_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 98 },
      -1,
   } },

   /* ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a')) */
   /* search891_0_0 -> 32 in the cache */
   /* search891_0 -> 2512 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 2512 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbfe0000000000000 /* -0.5 */ },
   } },
   /* replace891_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2554, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2555 },
      -1,
   } },

   /* ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a')) */
   /* search892_0_0 -> 32 in the cache */
   /* search892_0 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2530 },
      -1,
   } },

   /* replace892_0 -> 676 in the cache */
   /* replace892_1_0 -> 32 in the cache */
   /* replace892_1 -> 2510 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 676, 2510 },
      -1,
   } },

   /* ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a')) */
   /* search893_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2559 },
      -1,
   } },

   /* replace893_0_0 -> 32 in the cache */
   /* replace893_0 -> 2510 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2510 },
      -1,
   } },

   /* ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a')) */
   /* search894_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2562 },
      -1,
   } },

   /* replace894_0 -> 2554 in the cache */
   /* replace894_1_0 -> 32 in the cache */
   /* replace894_1 -> 2510 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2554, 2510 },
      -1,
   } },

   /* ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a')) */
   /* search895_0_0 -> 0 in the cache */
   /* search895_0_1 -> 3 in the cache */
   /* search895_0 -> 2514 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2514 },
      -1,
   } },

   /* replace895_0 -> 3 in the cache */
   /* replace895_1_0 -> 0 in the cache */
   /* replace895_1 -> 2515 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 2515 },
      -1,
   } },

   /* ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b')) */
   /* search896_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 0 },
      0,
   } },
   /* search896_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2567, 2568 },
      -1,
   } },

   /* replace896_0_0 -> 0 in the cache */
   /* replace896_0_1 -> 3 in the cache */
   /* replace896_0 -> 257 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 257 },
      -1,
   } },

   /* ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0)) */
   /* search897_0_0 -> 32 in the cache */
   /* search897_0_1 -> 113 in the cache */
   /* search897_0 -> 670 in the cache */
   /* search897_1 -> 113 in the cache */
   /* search897_2_0 -> 32 in the cache */
   /* search897_2 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 670, 113, 2530 },
      -1,
   } },

   /* replace897_0_0 -> 32 in the cache */
   /* replace897_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 1,
      { 2572 },
      -1,
   } },

   /* ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search898_0_0 -> 32 in the cache */
   /* search898_0 -> 2530 in the cache */
   /* search898_1_0 -> 32 in the cache */
   /* search898_1 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 2530, 2530 },
      -1,
   } },

   /* replace898_0 -> 32 in the cache */
   /* replace898 -> 103 in the cache */

   /* ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search899_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search899_1_0 -> 16 in the cache */
   /* search899_1 -> 2575 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 2575, 2575 },
      -1,
   } },

   /* replace899_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('~fdiv', 1.0, 'a') => ('frcp', 'a') */
   /* search900_0 -> 226 in the cache */
   /* search900_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 226, 32 },
      -1,
   } },

   /* replace900_0 -> 32 in the cache */
   /* replace900 -> 2559 in the cache */

   /* ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b')) */
   /* search901_0 -> 0 in the cache */
   /* search901_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace901_0 -> 0 in the cache */
   /* replace901_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2580 },
      -1,
   } },

   /* ('~frcp', ('frcp', 'a')) => a */
   /* search902_0_0 -> 32 in the cache */
   /* search902_0 -> 2559 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2559 },
      -1,
   } },

   /* replace902 -> 32 in the cache */

   /* ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a') */
   /* search903_0_0 -> 32 in the cache */
   /* search903_0 -> 2530 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2530 },
      -1,
   } },

   /* replace903_0 -> 32 in the cache */
   /* replace903 -> 2562 in the cache */

   /* ('fsqrt', 'a') => ('frcp', ('frsq', 'a')) */
   /* search904_0 -> 32 in the cache */
   /* search904 -> 2530 in the cache */

   /* replace904_0_0 -> 32 in the cache */
   /* replace904_0 -> 2562 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2562 },
      -1,
   } },

   /* ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a') */
   /* search905_0_0 -> 32 in the cache */
   /* search905_0 -> 2562 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2562 },
      -1,
   } },

   /* replace905_0 -> 32 in the cache */
   /* replace905 -> 2530 in the cache */

   /* ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)) */
   /* search906_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace906_0_0_0_0_0_0 -> 2531 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fc45f306dc9c883 /* 0.15915494309189535 */ },
   } },
   /* replace906_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      5, 1,
      { 2587, 32 },
      -1,
   } },
   /* replace906_0_0_0_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 2588, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2589 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 2531, 2590 },
      -1,
   } },
   /* replace906_0_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2591, 226 },
      -1,
   } },
   /* replace906_0_0_0_1_0_0_0 -> 2531 in the cache */
   /* replace906_0_0_0_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace906_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      9, 1,
      { 2587, 32 },
      -1,
   } },
   /* replace906_0_0_0_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 2593, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2594 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 2531, 2595 },
      -1,
   } },
   /* replace906_0_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2596, 226 },
      -1,
   } },
   /* replace906_0_0_0_1_1_0_0_0 -> 2531 in the cache */
   /* replace906_0_0_0_1_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace906_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      12, 1,
      { 2587, 32 },
      -1,
   } },
   /* replace906_0_0_0_1_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 2598, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2599 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 2531, 2600 },
      -1,
   } },
   /* replace906_0_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2601, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2602 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 2597, 2603 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2592, 2604 },
      -1,
   } },
   /* replace906_0_0_1 -> 2534 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 2605, 2534 },
      -1,
   } },
   /* replace906_0_1_0_0_0_0_0 -> 2531 in the cache */
   /* replace906_0_1_0_0_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace906_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      16, 1,
      { 2587, 32 },
      -1,
   } },
   /* replace906_0_1_0_0_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 2607, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2608 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 2531, 2609 },
      -1,
   } },
   /* replace906_0_1_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2610, 226 },
      -1,
   } },
   /* replace906_0_1_0_0_1_0_0_0 -> 2531 in the cache */
   /* replace906_0_1_0_0_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace906_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      20, 1,
      { 2587, 32 },
      -1,
   } },
   /* replace906_0_1_0_0_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 2612, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2613 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 2531, 2614 },
      -1,
   } },
   /* replace906_0_1_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2615, 226 },
      -1,
   } },
   /* replace906_0_1_0_0_1_1_0_0_0 -> 2531 in the cache */
   /* replace906_0_1_0_0_1_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace906_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      23, 1,
      { 2587, 32 },
      -1,
   } },
   /* replace906_0_1_0_0_1_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 2617, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2618 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 2531, 2619 },
      -1,
   } },
   /* replace906_0_1_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2620, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2621 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 2616, 2622 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2611, 2623 },
      -1,
   } },
   /* replace906_0_1_0_1 -> 2534 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 2624, 2534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 2625 },
      -1,
   } },
   /* replace906_0_2_0_0_0_0_0 -> 2531 in the cache */
   /* replace906_0_2_0_0_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace906_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      27, 1,
      { 2587, 32 },
      -1,
   } },
   /* replace906_0_2_0_0_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 2627, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2628 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 2531, 2629 },
      -1,
   } },
   /* replace906_0_2_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2630, 226 },
      -1,
   } },
   /* replace906_0_2_0_0_1_0_0_0 -> 2531 in the cache */
   /* replace906_0_2_0_0_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace906_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      31, 1,
      { 2587, 32 },
      -1,
   } },
   /* replace906_0_2_0_0_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 2632, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2633 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 2531, 2634 },
      -1,
   } },
   /* replace906_0_2_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2635, 226 },
      -1,
   } },
   /* replace906_0_2_0_0_1_1_0_0_0 -> 2531 in the cache */
   /* replace906_0_2_0_0_1_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace906_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      34, 1,
      { 2587, 32 },
      -1,
   } },
   /* replace906_0_2_0_0_1_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 2637, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2638 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 2531, 2639 },
      -1,
   } },
   /* replace906_0_2_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2640, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2641 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 2636, 2642 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2631, 2643 },
      -1,
   } },
   /* replace906_0_2_0_1 -> 2534 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 2644, 2534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 2645 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 2606, 2626, 2646 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fcccccccccccccd /* 0.225 */ },
   } },
   /* replace906_2_0_0_0_0 -> 2531 in the cache */
   /* replace906_2_0_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace906_2_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      38, 1,
      { 2587, 32 },
      -1,
   } },
   /* replace906_2_0_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 2649, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2650 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 2531, 2651 },
      -1,
   } },
   /* replace906_2_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2652, 226 },
      -1,
   } },
   /* replace906_2_0_1_0_0_0 -> 2531 in the cache */
   /* replace906_2_0_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace906_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      42, 1,
      { 2587, 32 },
      -1,
   } },
   /* replace906_2_0_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 2654, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2655 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 2531, 2656 },
      -1,
   } },
   /* replace906_2_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2657, 226 },
      -1,
   } },
   /* replace906_2_0_1_1_0_0_0 -> 2531 in the cache */
   /* replace906_2_0_1_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace906_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      45, 1,
      { 2587, 32 },
      -1,
   } },
   /* replace906_2_0_1_1_0_0_1_0_1 -> 676 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 2659, 676 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2660 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 2531, 2661 },
      -1,
   } },
   /* replace906_2_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2662, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2663 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 2658, 2664 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2653, 2665 },
      -1,
   } },
   /* replace906_2_1 -> 2534 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 2666, 2534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 2647, 2648, 2667 },
      -1,
   } },

   /* ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)) */
   /* search907_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace907_0_0_0_0_0_0 -> 2531 in the cache */
   /* replace907_0_0_0_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace907_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace907_0_0_0_0_0_1_0_0 -> 2588 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe8000000000000 /* 0.75 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 2588, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2671 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 2531, 2672 },
      -1,
   } },
   /* replace907_0_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2673, 226 },
      -1,
   } },
   /* replace907_0_0_0_1_0_0_0 -> 2531 in the cache */
   /* replace907_0_0_0_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace907_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace907_0_0_0_1_0_0_1_0_0 -> 2593 in the cache */
   /* replace907_0_0_0_1_0_0_1_0_1 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 2593, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 2531, 2676 },
      -1,
   } },
   /* replace907_0_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2677, 226 },
      -1,
   } },
   /* replace907_0_0_0_1_1_0_0_0 -> 2531 in the cache */
   /* replace907_0_0_0_1_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace907_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace907_0_0_0_1_1_0_0_1_0_0 -> 2598 in the cache */
   /* replace907_0_0_0_1_1_0_0_1_0_1 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 2598, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2679 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 2531, 2680 },
      -1,
   } },
   /* replace907_0_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2681, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2682 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 2678, 2683 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2674, 2684 },
      -1,
   } },
   /* replace907_0_0_1 -> 2534 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 2685, 2534 },
      -1,
   } },
   /* replace907_0_1_0_0_0_0_0 -> 2531 in the cache */
   /* replace907_0_1_0_0_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace907_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace907_0_1_0_0_0_0_1_0_0 -> 2607 in the cache */
   /* replace907_0_1_0_0_0_0_1_0_1 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 2607, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2687 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 2531, 2688 },
      -1,
   } },
   /* replace907_0_1_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2689, 226 },
      -1,
   } },
   /* replace907_0_1_0_0_1_0_0_0 -> 2531 in the cache */
   /* replace907_0_1_0_0_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace907_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace907_0_1_0_0_1_0_0_1_0_0 -> 2612 in the cache */
   /* replace907_0_1_0_0_1_0_0_1_0_1 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 2612, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2691 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 2531, 2692 },
      -1,
   } },
   /* replace907_0_1_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2693, 226 },
      -1,
   } },
   /* replace907_0_1_0_0_1_1_0_0_0 -> 2531 in the cache */
   /* replace907_0_1_0_0_1_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace907_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace907_0_1_0_0_1_1_0_0_1_0_0 -> 2617 in the cache */
   /* replace907_0_1_0_0_1_1_0_0_1_0_1 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 2617, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2695 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 2531, 2696 },
      -1,
   } },
   /* replace907_0_1_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2697, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2698 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 2694, 2699 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2690, 2700 },
      -1,
   } },
   /* replace907_0_1_0_1 -> 2534 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 2701, 2534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 2702 },
      -1,
   } },
   /* replace907_0_2_0_0_0_0_0 -> 2531 in the cache */
   /* replace907_0_2_0_0_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace907_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace907_0_2_0_0_0_0_1_0_0 -> 2627 in the cache */
   /* replace907_0_2_0_0_0_0_1_0_1 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 2627, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 2531, 2705 },
      -1,
   } },
   /* replace907_0_2_0_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2706, 226 },
      -1,
   } },
   /* replace907_0_2_0_0_1_0_0_0 -> 2531 in the cache */
   /* replace907_0_2_0_0_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace907_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace907_0_2_0_0_1_0_0_1_0_0 -> 2632 in the cache */
   /* replace907_0_2_0_0_1_0_0_1_0_1 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 2632, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2708 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 2531, 2709 },
      -1,
   } },
   /* replace907_0_2_0_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2710, 226 },
      -1,
   } },
   /* replace907_0_2_0_0_1_1_0_0_0 -> 2531 in the cache */
   /* replace907_0_2_0_0_1_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace907_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace907_0_2_0_0_1_1_0_0_1_0_0 -> 2637 in the cache */
   /* replace907_0_2_0_0_1_1_0_0_1_0_1 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 2637, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2712 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 2531, 2713 },
      -1,
   } },
   /* replace907_0_2_0_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2714, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2715 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 2711, 2716 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2707, 2717 },
      -1,
   } },
   /* replace907_0_2_0_1 -> 2534 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 2718, 2534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 2719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 2686, 2703, 2720 },
      -1,
   } },
   /* replace907_1 -> 2648 in the cache */
   /* replace907_2_0_0_0_0 -> 2531 in the cache */
   /* replace907_2_0_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace907_2_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace907_2_0_0_0_1_0_0 -> 2649 in the cache */
   /* replace907_2_0_0_0_1_0_1 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 2649, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2722 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 2531, 2723 },
      -1,
   } },
   /* replace907_2_0_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2724, 226 },
      -1,
   } },
   /* replace907_2_0_1_0_0_0 -> 2531 in the cache */
   /* replace907_2_0_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace907_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace907_2_0_1_0_0_1_0_0 -> 2654 in the cache */
   /* replace907_2_0_1_0_0_1_0_1 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 2654, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 2531, 2727 },
      -1,
   } },
   /* replace907_2_0_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2728, 226 },
      -1,
   } },
   /* replace907_2_0_1_1_0_0_0 -> 2531 in the cache */
   /* replace907_2_0_1_1_0_0_1_0_0_0 -> 2587 in the cache */
   /* replace907_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace907_2_0_1_1_0_0_1_0_0 -> 2659 in the cache */
   /* replace907_2_0_1_1_0_0_1_0_1 -> 2670 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 2659, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2730 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 2531, 2731 },
      -1,
   } },
   /* replace907_2_0_1_1_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2732, 226 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2733 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 2729, 2734 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2725, 2735 },
      -1,
   } },
   /* replace907_2_1 -> 2534 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 2736, 2534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 2721, 2648, 2737 },
      -1,
   } },

   /* ('i2b16(is_used_by_if)', 'a') => ('ine16', 'a', 0) */
   /* search908_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2b16,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace908_0 -> 32 in the cache */
   /* replace908_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ine16,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('i2b32(is_used_by_if)', 'a') => ('ine32', 'a', 0) */
   /* search909_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2b32,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace909_0 -> 32 in the cache */
   /* replace909_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ine32,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('i2b1(is_used_by_if)', 'a') => ('ine', 'a', 0) */
   /* search910_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2b1,
      -1, 0,
      { 32 },
      2,
   } },

   /* replace910_0 -> 32 in the cache */
   /* replace910_1 -> 61 in the cache */
   /* replace910 -> 1181 in the cache */

   /* ('ieq', 'a', True) => a */
   /* search911_0 -> 715 in the cache */
   /* search911_1 -> 1185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 715, 1185 },
      -1,
   } },

   /* replace911 -> 715 in the cache */

   /* ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a') */
   /* search912_0 -> 715 in the cache */
   /* search912_1 -> 1185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 715, 1185 },
      3,
   } },

   /* replace912_0 -> 715 in the cache */
   /* replace912 -> 1080 in the cache */

   /* ('ine', 'a', False) => a */
   /* search913_0 -> 715 in the cache */
   /* search913_1 -> 1032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 715, 1032 },
      -1,
   } },

   /* replace913 -> 715 in the cache */

   /* ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a') */
   /* search914_0 -> 715 in the cache */
   /* search914_1 -> 1032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 715, 1032 },
      3,
   } },

   /* replace914_0 -> 715 in the cache */
   /* replace914 -> 1080 in the cache */

   /* ('bcsel', 'a', True, False) => a */
   /* search915_0 -> 715 in the cache */
   /* search915_1 -> 1185 in the cache */
   /* search915_2 -> 1032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1185, 1032 },
      -1,
   } },

   /* replace915 -> 715 in the cache */

   /* ('bcsel', 'a', False, True) => ('inot', 'a') */
   /* search916_0 -> 715 in the cache */
   /* search916_1 -> 1032 in the cache */
   /* search916_2 -> 1185 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1032, 1185 },
      -1,
   } },

   /* replace916_0 -> 715 in the cache */
   /* replace916 -> 1080 in the cache */

   /* ('bcsel', True, 'b', 'c') => b */
   /* search917_0 -> 1185 in the cache */
   /* search917_1 -> 1066 in the cache */
   /* search917_2 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1185, 1066, 665 },
      -1,
   } },

   /* replace917 -> 1066 in the cache */

   /* ('bcsel', False, 'b', 'c') => c */
   /* search918_0 -> 1032 in the cache */
   /* search918_1 -> 1066 in the cache */
   /* search918_2 -> 665 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1032, 1066, 665 },
      -1,
   } },

   /* replace918 -> 665 in the cache */

   /* ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search919_0 -> 715 in the cache */
   /* search919_1 -> 462 in the cache */
   /* search919_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 462, 115 },
      -1,
   } },

   /* replace919_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search920_0 -> 715 in the cache */
   /* search920_1 -> 115 in the cache */
   /* search920_2 -> 462 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 115, 462 },
      -1,
   } },

   /* replace920_0_0 -> 715 in the cache */
   /* replace920_0 -> 1080 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1080 },
      -1,
   } },

   /* ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search921_0 -> 715 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2756, 2757 },
      -1,
   } },

   /* replace921_0_0 -> 715 in the cache */
   /* replace921_0 -> 2753 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2753 },
      -1,
   } },

   /* ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search922_0 -> 715 in the cache */
   /* search922_1 -> 2757 in the cache */
   /* search922_2 -> 2756 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2757, 2756 },
      -1,
   } },

   /* replace922_0_0_0 -> 715 in the cache */
   /* replace922_0_0 -> 1080 in the cache */
   /* replace922_0 -> 2755 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2755 },
      -1,
   } },

   /* ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search923_0 -> 715 in the cache */
   /* search923_1 -> 228 in the cache */
   /* search923_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 228, 117 },
      -1,
   } },

   /* replace923_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search924_0 -> 715 in the cache */
   /* search924_1 -> 117 in the cache */
   /* search924_2 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 117, 228 },
      -1,
   } },

   /* replace924_0_0 -> 715 in the cache */
   /* replace924_0 -> 1080 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1080 },
      -1,
   } },

   /* ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search925_0 -> 715 in the cache */
   /* search925_1 -> 263 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 263, 2766 },
      -1,
   } },

   /* replace925_0_0 -> 715 in the cache */
   /* replace925_0 -> 2763 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2763 },
      -1,
   } },

   /* ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search926_0 -> 715 in the cache */
   /* search926_1 -> 2766 in the cache */
   /* search926_2 -> 263 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2766, 263 },
      -1,
   } },

   /* replace926_0_0_0 -> 715 in the cache */
   /* replace926_0_0 -> 1080 in the cache */
   /* replace926_0 -> 2765 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2765 },
      -1,
   } },

   /* ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search927_0 -> 715 in the cache */
   /* search927_1 -> 603 in the cache */
   /* search927_2 -> 1864 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 603, 1864 },
      -1,
   } },

   /* replace927_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search928_0 -> 715 in the cache */
   /* search928_1 -> 1864 in the cache */
   /* search928_2 -> 603 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1864, 603 },
      -1,
   } },

   /* replace928_0_0 -> 715 in the cache */
   /* replace928_0 -> 1080 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1080 },
      -1,
   } },

   /* ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search929_0 -> 715 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2775, 2776 },
      -1,
   } },

   /* replace929_0_0 -> 715 in the cache */
   /* replace929_0 -> 2772 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2772 },
      -1,
   } },

   /* ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search930_0 -> 715 in the cache */
   /* search930_1 -> 2776 in the cache */
   /* search930_2 -> 2775 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2776, 2775 },
      -1,
   } },

   /* replace930_0_0_0 -> 715 in the cache */
   /* replace930_0_0 -> 1080 in the cache */
   /* replace930_0 -> 2774 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2774 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', 'b') => b */
   /* search931_0 -> 715 in the cache */
   /* search931_1 -> 3 in the cache */
   /* search931_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 3, 3 },
      -1,
   } },

   /* replace931 -> 3 in the cache */

   /* ('~fcsel', 'a', 'b', 'b') => b */
   /* search932_0 -> 16 in the cache */
   /* search932_1 -> 36 in the cache */
   /* search932_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 16, 36, 36 },
      -1,
   } },

   /* replace932 -> 36 in the cache */

   /* ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1')) */
   /* search933_0 -> 715 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* search933_2 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2783, 1177 },
      -1,
   } },

   /* replace933_0_0 -> 715 in the cache */
   /* replace933_0 -> 1176 in the cache */
   /* replace933 -> 2172 in the cache */

   /* ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a'))) */
   /* search934_0 -> 715 in the cache */
   /* search934_1 -> 1177 in the cache */
   /* search934_2 -> 2783 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1177, 2783 },
      -1,
   } },

   /* replace934_0_0_0 -> 715 in the cache */
   /* replace934_0_0 -> 1080 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1080 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2786 },
      -1,
   } },

   /* ('bcsel', 'a', 1, 0) => ('b2i', 'a@1') */
   /* search935_0 -> 715 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   /* search935_2 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 2788, 1177 },
      -1,
   } },

   /* replace935_0 -> 715 in the cache */
   /* replace935 -> 1176 in the cache */

   /* ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a')) */
   /* search936_0 -> 715 in the cache */
   /* search936_1 -> 1177 in the cache */
   /* search936_2 -> 2788 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1177, 2788 },
      -1,
   } },

   /* replace936_0_0 -> 715 in the cache */
   /* replace936_0 -> 1080 in the cache */
   /* replace936 -> 2786 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search937_0_0_0 -> 715 in the cache */
   /* search937_0_0 -> 1176 in the cache */
   /* search937_0 -> 2172 in the cache */
   /* search937_1_0_0 -> 1083 in the cache */
   /* search937_1_0 -> 2173 in the cache */
   /* search937_1 -> 2174 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2172, 2174 },
      -1,
   } },

   /* replace937_0_0_0 -> 715 in the cache */
   /* replace937_0_0_1 -> 1083 in the cache */
   /* replace937_0_0 -> 1095 in the cache */
   /* replace937_0 -> 2434 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2434 },
      -1,
   } },

   /* ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search938_0_0_0 -> 715 in the cache */
   /* search938_0_0 -> 1176 in the cache */
   /* search938_0 -> 2172 in the cache */
   /* search938_1_0_0 -> 1083 in the cache */
   /* search938_1_0 -> 2173 in the cache */
   /* search938_1 -> 2174 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2172, 2174 },
      -1,
   } },

   /* replace938_0_0_0 -> 715 in the cache */
   /* replace938_0_0_1 -> 1083 in the cache */
   /* replace938_0_0 -> 1087 in the cache */
   /* replace938_0 -> 2437 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2437 },
      -1,
   } },

   /* ('ieq', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search939_0_0_0 -> 715 in the cache */
   /* search939_0_0 -> 1176 in the cache */
   /* search939_0 -> 2172 in the cache */
   /* search939_1 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2172, 1177 },
      -1,
   } },

   /* replace939_0 -> 715 in the cache */
   /* replace939 -> 1080 in the cache */

   /* ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a */
   /* search940_0_0_0 -> 715 in the cache */
   /* search940_0_0 -> 1176 in the cache */
   /* search940_0 -> 2172 in the cache */
   /* search940_1 -> 2783 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2172, 2783 },
      -1,
   } },

   /* replace940 -> 715 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search941_0_0_0 -> 715 in the cache */
   /* search941_0_0 -> 1176 in the cache */
   /* search941_0 -> 2172 in the cache */
   /* search941_1 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2172, 1177 },
      -1,
   } },

   /* replace941 -> 715 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a') */
   /* search942_0_0_0 -> 715 in the cache */
   /* search942_0_0 -> 1176 in the cache */
   /* search942_0 -> 2172 in the cache */
   /* search942_1 -> 2783 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2172, 2783 },
      -1,
   } },

   /* replace942_0 -> 715 in the cache */
   /* replace942 -> 1080 in the cache */

   /* ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search943_0_0_0 -> 715 in the cache */
   /* search943_0_0 -> 1176 in the cache */
   /* search943_0 -> 2172 in the cache */
   /* search943_1 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2172, 1177 },
      -1,
   } },

   /* replace943_0 -> 715 in the cache */
   /* replace943 -> 1080 in the cache */

   /* ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search944_0_0_0 -> 715 in the cache */
   /* search944_0_0 -> 1176 in the cache */
   /* search944_0 -> 2172 in the cache */
   /* search944_1 -> 1177 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2172, 1177 },
      -1,
   } },

   /* replace944 -> 715 in the cache */

   /* ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a */
   /* search945_0 -> 1177 in the cache */
   /* search945_1_0_0 -> 715 in the cache */
   /* search945_1_0 -> 1176 in the cache */
   /* search945_1 -> 2172 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1177, 2172 },
      -1,
   } },

   /* replace945 -> 715 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a') */
   /* search946_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2802 },
      -1,
   } },
   /* search946_1 -> 1088 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2803, 1088 },
      -1,
   } },

   /* replace946_0 -> 32 in the cache */
   /* replace946 -> 1465 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a') */
   /* search947_0_0_0 -> 32 in the cache */
   /* search947_0_0 -> 2802 in the cache */
   /* search947_0 -> 2803 in the cache */
   /* search947_1 -> 2788 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2803, 2788 },
      -1,
   } },

   /* replace947_0 -> 32 in the cache */
   /* replace947 -> 2802 in the cache */

   /* ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search948_0_0_0 -> 715 in the cache */
   /* search948_0_0 -> 1176 in the cache */
   /* search948_0 -> 2172 in the cache */
   /* search948_1_0_0 -> 1083 in the cache */
   /* search948_1_0 -> 2173 in the cache */
   /* search948_1 -> 2174 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2172, 2174 },
      -1,
   } },

   /* replace948_0_0_0 -> 715 in the cache */
   /* replace948_0_0_1 -> 1083 in the cache */
   /* replace948_0_0 -> 1095 in the cache */
   /* replace948_0 -> 2434 in the cache */
   /* replace948 -> 2792 in the cache */

   /* ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search949_0_0_0 -> 715 in the cache */
   /* search949_0_0 -> 1176 in the cache */
   /* search949_0 -> 2172 in the cache */
   /* search949_1_0_0 -> 1083 in the cache */
   /* search949_1_0 -> 2173 in the cache */
   /* search949_1 -> 2174 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2172, 2174 },
      -1,
   } },

   /* replace949_0_0_0 -> 715 in the cache */
   /* replace949_0_0_1 -> 1083 in the cache */
   /* replace949_0_0 -> 1087 in the cache */
   /* replace949_0 -> 2437 in the cache */
   /* replace949 -> 2794 in the cache */

   /* ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search950_0_0_0 -> 715 in the cache */
   /* search950_0_0 -> 1176 in the cache */
   /* search950_0 -> 2172 in the cache */
   /* search950_1_0_0 -> 1083 in the cache */
   /* search950_1_0 -> 2173 in the cache */
   /* search950_1 -> 2174 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2172, 2174 },
      -1,
   } },

   /* replace950_0_0_0 -> 715 in the cache */
   /* replace950_0_0_1 -> 1083 in the cache */
   /* replace950_0_0 -> 1087 in the cache */
   /* replace950_0 -> 2437 in the cache */
   /* replace950 -> 2794 in the cache */

   /* ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search951_0_0_0 -> 715 in the cache */
   /* search951_0_0 -> 1176 in the cache */
   /* search951_0 -> 2172 in the cache */
   /* search951_1_0_0 -> 1083 in the cache */
   /* search951_1_0 -> 2173 in the cache */
   /* search951_1 -> 2174 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2172, 2174 },
      -1,
   } },

   /* replace951_0_0_0 -> 715 in the cache */
   /* replace951_0_0_1 -> 1083 in the cache */
   /* replace951_0_0 -> 1095 in the cache */
   /* replace951_0 -> 2434 in the cache */
   /* replace951 -> 2792 in the cache */

   /* ('i2b16', ('b2i', 'a@16')) => a */
   /* search952_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2b16,
      -1, 0,
      { 2810 },
      -1,
   } },

   /* replace952 -> 11 in the cache */

   /* ('i2b32', ('b2i', 'a@32')) => a */
   /* search953_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2b32,
      -1, 0,
      { 2812 },
      -1,
   } },

   /* replace953 -> 16 in the cache */

   /* ('f2i', ('ftrunc', 'a')) => ('f2i', 'a') */
   /* search954_0_0 -> 32 in the cache */
   /* search954_0 -> 669 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 669 },
      -1,
   } },

   /* replace954_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2u', ('ftrunc', 'a')) => ('f2u', 'a') */
   /* search955_0_0 -> 32 in the cache */
   /* search955_0 -> 669 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 669 },
      -1,
   } },

   /* replace955_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2b', ('ineg', 'a')) => ('i2b', 'a') */
   /* search956_0_0 -> 32 in the cache */
   /* search956_0 -> 100 in the cache */
   /* search956 -> 111 in the cache */

   /* replace956_0 -> 32 in the cache */
   /* replace956 -> 112 in the cache */

   /* ('i2b', ('iabs', 'a')) => ('i2b', 'a') */
   /* search957_0_0 -> 32 in the cache */
   /* search957_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace957_0 -> 32 in the cache */
   /* replace957 -> 112 in the cache */

   /* ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0) */
   /* search958_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_f2b1,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 2819 },
      -1,
   } },

   /* replace958_0 -> 32 in the cache */
   /* replace958_1 -> 113 in the cache */
   /* replace958 -> 1207 in the cache */

   /* ('f2fmp', ('f2f32', 'a@16')) => a */
   /* search959_0_0 -> 11 in the cache */
   /* search959_0 -> 1738 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1738 },
      -1,
   } },

   /* replace959 -> 11 in the cache */

   /* ('i2imp', ('i2i32', 'a@16')) => a */
   /* search960_0_0 -> 11 in the cache */
   /* search960_0 -> 1740 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1740 },
      -1,
   } },

   /* replace960 -> 11 in the cache */

   /* ('i2imp', ('u2u32', 'a@16')) => a */
   /* search961_0_0 -> 11 in the cache */
   /* search961_0 -> 1742 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1742 },
      -1,
   } },

   /* replace961 -> 11 in the cache */

   /* ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a') */
   /* search962_0_0 -> 11 in the cache */
   /* search962_0 -> 1738 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1738 },
      -1,
   } },

   /* replace962_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a') */
   /* search963_0_0 -> 11 in the cache */
   /* search963_0 -> 1738 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1738 },
      -1,
   } },

   /* replace963_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a') */
   /* search964_0_0 -> 11 in the cache */
   /* search964_0 -> 1740 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1740 },
      -1,
   } },

   /* replace964_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a') */
   /* search965_0_0 -> 11 in the cache */
   /* search965_0 -> 1742 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1742 },
      -1,
   } },

   /* replace965_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search966_0_0 -> 715 in the cache */
   /* search966_0 -> 1345 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1345 },
      -1,
   } },

   /* replace966_0 -> 715 in the cache */
   /* replace966 -> 1341 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search967_0_0 -> 715 in the cache */
   /* search967_0 -> 1333 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1333 },
      -1,
   } },

   /* replace967_0 -> 715 in the cache */
   /* replace967 -> 1329 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search968_0_0 -> 715 in the cache */
   /* search968_0 -> 1333 in the cache */
   /* search968 -> 2833 in the cache */

   /* replace968_0 -> 715 in the cache */
   /* replace968 -> 1329 in the cache */

   /* ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search969_0_0 -> 715 in the cache */
   /* search969_0 -> 1345 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1345 },
      -1,
   } },

   /* replace969_0 -> 715 in the cache */
   /* replace969 -> 1329 in the cache */

   /* ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search970_0_0 -> 715 in the cache */
   /* search970_0 -> 1345 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1345 },
      -1,
   } },

   /* replace970_0 -> 715 in the cache */
   /* replace970 -> 1329 in the cache */

   /* ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search971_0_0 -> 715 in the cache */
   /* search971_0 -> 1333 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1333 },
      -1,
   } },

   /* replace971_0 -> 715 in the cache */
   /* replace971 -> 1341 in the cache */

   /* ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search972_0_0 -> 715 in the cache */
   /* search972_0 -> 1333 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1333 },
      -1,
   } },

   /* replace972_0 -> 715 in the cache */
   /* replace972 -> 1341 in the cache */

   /* ('f2f32', ('f2fmp', 'a@32')) => a */
   /* search973_0_0 -> 16 in the cache */
   /* search973_0 -> 1934 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1934 },
      -1,
   } },

   /* replace973 -> 16 in the cache */

   /* ('i2i32', ('i2imp', 'a@32')) => a */
   /* search974_0_0 -> 16 in the cache */
   /* search974_0 -> 1945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1945 },
      -1,
   } },

   /* replace974 -> 16 in the cache */

   /* ('u2u32', ('i2imp', 'a@32')) => a */
   /* search975_0_0 -> 16 in the cache */
   /* search975_0 -> 1945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1945 },
      -1,
   } },

   /* replace975 -> 16 in the cache */

   /* ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a') */
   /* search976_0_0 -> 16 in the cache */
   /* search976_0 -> 1944 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1944 },
      -1,
   } },

   /* replace976_0 -> 16 in the cache */
   /* replace976 -> 1942 in the cache */

   /* ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a') */
   /* search977_0_0 -> 16 in the cache */
   /* search977_0 -> 1941 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1941 },
      -1,
   } },

   /* replace977_0 -> 16 in the cache */
   /* replace977 -> 1939 in the cache */

   /* ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a') */
   /* search978_0_0 -> 16 in the cache */
   /* search978_0 -> 1933 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1933 },
      -1,
   } },

   /* replace978_0 -> 16 in the cache */
   /* replace978 -> 1931 in the cache */

   /* ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a') */
   /* search979_0_0 -> 16 in the cache */
   /* search979_0 -> 1930 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1930 },
      -1,
   } },

   /* replace979_0 -> 16 in the cache */
   /* replace979 -> 1928 in the cache */

   /* ('~f2f32', ('f2f64', 'a@32')) => a */
   /* search980_0_0 -> 16 in the cache */
   /* search980_0 -> 1845 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1845 },
      -1,
   } },

   /* replace980 -> 16 in the cache */

   /* ('ffloor', 'a(is_integral)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 2846 },
      -1,
   } },

   /* replace981 -> 32 in the cache */

   /* ('fceil', 'a(is_integral)') => a */
   /* search982_0 -> 2846 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 2846 },
      -1,
   } },

   /* replace982 -> 32 in the cache */

   /* ('ftrunc', 'a(is_integral)') => a */
   /* search983_0 -> 2846 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 2846 },
      -1,
   } },

   /* replace983 -> 32 in the cache */

   /* ('~ffract', 'a(is_integral)') => 0.0 */
   /* search984_0 -> 2846 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 2846 },
      -1,
   } },

   /* replace984 -> 113 in the cache */

   /* ('fabs', 'a(is_not_negative)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2851 },
      -1,
   } },

   /* replace985 -> 32 in the cache */

   /* ('iabs', 'a(is_not_negative)') => a */
   /* search986_0 -> 2851 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2851 },
      -1,
   } },

   /* replace986 -> 32 in the cache */

   /* ('fsat', 'a(is_not_positive)') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 2854 },
      -1,
   } },

   /* replace987 -> 113 in the cache */

   /* ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a') */
   /* search988_0 -> 2851 in the cache */
   /* search988_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 2851, 226 },
      -1,
   } },

   /* replace988_0 -> 32 in the cache */
   /* replace988 -> 202 in the cache */

   /* ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search989_0_0_0_0 -> 32 in the cache */
   /* search989_0_0_0 -> 202 in the cache */
   /* search989_0_0_1_0_0 -> 32 in the cache */
   /* search989_0_0_1_0 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 202 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 202, 2857 },
      -1,
   } },
   /* search989_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 2858, 226 },
      -1,
   } },
   /* search989_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 2859, 113 },
      -1,
   } },

   /* replace989 -> 1032 in the cache */

   /* ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search990_0_0_0_0_0 -> 32 in the cache */
   /* search990_0_0_0_0 -> 202 in the cache */
   /* search990_0_0_0_1_0 -> 32 in the cache */
   /* search990_0_0_0_1 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 202, 202 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2861 },
      -1,
   } },
   /* search990_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 2862, 226 },
      -1,
   } },
   /* search990_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 2863, 113 },
      -1,
   } },

   /* replace990 -> 1032 in the cache */

   /* ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0) */
   /* search991_0_0_0_0 -> 32 in the cache */
   /* search991_0_0_0 -> 202 in the cache */
   /* search991_0_0_1_0_0 -> 32 in the cache */
   /* search991_0_0_1_0 -> 202 in the cache */
   /* search991_0_0_1 -> 2857 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 202, 2857 },
      -1,
   } },
   /* search991_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 2865, 226 },
      -1,
   } },
   /* search991_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 2866, 113 },
      -1,
   } },

   /* replace991_0_0_0 -> 32 in the cache */
   /* replace991_0_0 -> 202 in the cache */
   /* replace991_0_1_0_0 -> 32 in the cache */
   /* replace991_0_1_0 -> 202 in the cache */
   /* replace991_0_1 -> 2857 in the cache */
   /* replace991_0 -> 2858 in the cache */
   /* replace991_1 -> 226 in the cache */
   /* replace991 -> 2859 in the cache */

   /* ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0) */
   /* search992_0_0_0_0_0 -> 32 in the cache */
   /* search992_0_0_0_0 -> 202 in the cache */
   /* search992_0_0_0_1_0 -> 32 in the cache */
   /* search992_0_0_0_1 -> 202 in the cache */
   /* search992_0_0_0 -> 2861 in the cache */
   /* search992_0_0 -> 2862 in the cache */
   /* search992_0_1 -> 226 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 2862, 226 },
      -1,
   } },
   /* search992_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 2868, 113 },
      -1,
   } },

   /* replace992_0_0_0_0 -> 32 in the cache */
   /* replace992_0_0_0 -> 202 in the cache */
   /* replace992_0_0_1_0 -> 32 in the cache */
   /* replace992_0_0_1 -> 202 in the cache */
   /* replace992_0_0 -> 2861 in the cache */
   /* replace992_0 -> 2862 in the cache */
   /* replace992_1 -> 226 in the cache */
   /* replace992 -> 2863 in the cache */

   /* ('fneu', 'a(is_not_zero)', 0.0) => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      22,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search993_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2870, 113 },
      -1,
   } },

   /* replace993 -> 1185 in the cache */

   /* ('feq', 'a(is_not_zero)', 0.0) => False */
   /* search994_0 -> 2870 in the cache */
   /* search994_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2870, 113 },
      -1,
   } },

   /* replace994 -> 1032 in the cache */

   /* ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2873, 2874 },
      -1,
   } },

   /* replace995 -> 1185 in the cache */

   /* ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2876, 2877 },
      -1,
   } },

   /* replace996 -> 1032 in the cache */

   /* ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      26,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2879, 2880 },
      -1,
   } },

   /* replace997 -> 1032 in the cache */

   /* ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search998_0 -> 1521 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1521, 2882 },
      -1,
   } },

   /* replace998 -> 1032 in the cache */

   /* ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      27,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2884, 2885 },
      -1,
   } },

   /* replace999 -> 1185 in the cache */

   /* ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      28,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2887, 2888 },
      -1,
   } },

   /* replace1000 -> 1185 in the cache */

   /* ('ine', 'a(is_not_zero)', 0) => True */
   /* search1001_0 -> 2870 in the cache */
   /* search1001_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2870, 61 },
      -1,
   } },

   /* replace1001 -> 1185 in the cache */

   /* ('ieq', 'a(is_not_zero)', 0) => False */
   /* search1002_0 -> 2870 in the cache */
   /* search1002_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2870, 61 },
      -1,
   } },

   /* replace1002 -> 1032 in the cache */

   /* ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True */
   /* search1003_0 -> 1521 in the cache */
   /* search1003_1 -> 2882 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1521, 2882 },
      -1,
   } },

   /* replace1003 -> 1185 in the cache */

   /* ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   /* search1004_0 -> 2876 in the cache */
   /* search1004_1 -> 2877 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2876, 2877 },
      -1,
   } },

   /* replace1004 -> 1032 in the cache */

   /* ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   /* search1005_0 -> 2879 in the cache */
   /* search1005_1 -> 2880 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2879, 2880 },
      -1,
   } },

   /* replace1005 -> 1032 in the cache */

   /* ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search1006_0 -> 1521 in the cache */
   /* search1006_1 -> 2882 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1521, 2882 },
      -1,
   } },

   /* replace1006 -> 1032 in the cache */

   /* ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True */
   /* search1007_0 -> 2876 in the cache */
   /* search1007_1 -> 2877 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2876, 2877 },
      -1,
   } },

   /* replace1007 -> 1185 in the cache */

   /* ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True */
   /* search1008_0 -> 2879 in the cache */
   /* search1008_1 -> 2880 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2879, 2880 },
      -1,
   } },

   /* replace1008 -> 1185 in the cache */

   /* ('ult', 0, 'a(is_gt_zero)') => True */
   /* search1009_0 -> 61 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 61, 2898 },
      -1,
   } },

   /* replace1009 -> 1185 in the cache */

   /* ('ult', 'a', 0) => False */
   /* search1010_0 -> 32 in the cache */
   /* search1010_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace1010 -> 1032 in the cache */

   /* ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a */
   /* search1011_0_0 -> 16 in the cache */
   /* search1011_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 2901 },
      -1,
   } },

   /* replace1011 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b */
   /* search1012_0_0 -> 16 in the cache */
   /* search1012_0_1 -> 36 in the cache */
   /* search1012_0 -> 2901 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 2901 },
      -1,
   } },

   /* replace1012 -> 36 in the cache */

   /* ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b') */
   /* search1013_0_0 -> 16 in the cache */
   /* search1013_0_1 -> 36 in the cache */
   /* search1013_0 -> 2901 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 2901 },
      -1,
   } },

   /* replace1013_0 -> 16 in the cache */
   /* replace1013_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a */
   /* search1014_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 2906 },
      -1,
   } },

   /* replace1014 -> 16 in the cache */

   /* ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a */
   /* search1015_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 2908 },
      -1,
   } },

   /* replace1015 -> 16 in the cache */

   /* ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a */
   /* search1016_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 21 },
      -1,
   } },
   /* search1016_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 2910, 2911 },
      -1,
   } },

   /* replace1016 -> 21 in the cache */

   /* ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a */
   /* search1017_0_0_0 -> 21 in the cache */
   /* search1017_0_0 -> 2910 in the cache */
   /* search1017_0_1_0 -> 21 in the cache */
   /* search1017_0_1 -> 2911 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 2910, 2911 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 2913 },
      -1,
   } },

   /* replace1017 -> 21 in the cache */

   /* ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a */
   /* search1018_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 2915 },
      -1,
   } },

   /* replace1018 -> 21 in the cache */

   /* ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a */
   /* search1019_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 2917 },
      -1,
   } },

   /* replace1019 -> 21 in the cache */

   /* ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c')) */
   /* search1020_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1020_0_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 2919, 1952 },
      -1,
   } },
   /* search1020_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2921, 2922 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2920, 2923 },
      -1,
   } },

   /* replace1020_0 -> 16 in the cache */
   /* replace1020_1_0 -> 243 in the cache */
   /* replace1020_1_1 -> 450 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 243, 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 2925 },
      -1,
   } },

   /* ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1) */
   /* search1021_0 -> 11 in the cache */
   /* search1021_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 786 },
      -1,
   } },

   /* replace1021_0 -> 11 in the cache */
   /* replace1021_1 -> 1389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 1389 },
      -1,
   } },

   /* ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3) */
   /* search1022_0 -> 16 in the cache */
   /* search1022_1 -> 967 in the cache */
   /* search1022 -> 972 in the cache */

   /* replace1022_0 -> 16 in the cache */
   /* replace1022_1 -> 386 in the cache */
   /* replace1022 -> 403 in the cache */

   /* ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7) */
   /* search1023_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x38 /* 56 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 2929 },
      -1,
   } },

   /* replace1023_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 2931 },
      -1,
   } },

   /* ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1) */
   /* search1024_0 -> 11 in the cache */
   /* search1024_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 786 },
      -1,
   } },

   /* replace1024_0 -> 11 in the cache */
   /* replace1024_1 -> 1389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 1389 },
      -1,
   } },

   /* ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3) */
   /* search1025_0 -> 16 in the cache */
   /* search1025_1 -> 967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 967 },
      -1,
   } },

   /* replace1025_0 -> 16 in the cache */
   /* replace1025_1 -> 386 in the cache */
   /* replace1025 -> 387 in the cache */

   /* ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7) */
   /* search1026_0 -> 21 in the cache */
   /* search1026_1 -> 2929 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 2929 },
      -1,
   } },

   /* replace1026_0 -> 21 in the cache */
   /* replace1026_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 2931 },
      -1,
   } },

   /* ('iand', 255, 'a') => ('extract_u8', 'a', 0) */
   /* search1027_0 -> 1527 in the cache */
   /* search1027_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1527, 32 },
      -1,
   } },

   /* replace1027_0 -> 32 in the cache */
   /* replace1027_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2)) */
   /* search1028_0_0 -> 32 in the cache */
   /* search1028_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2940 },
      -1,
   } },

   /* replace1028_0_0 -> 32 in the cache */
   /* replace1028_0_1 -> 2160 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 2160 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2942 },
      -1,
   } },

   /* ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1)) */
   /* search1029_0_0 -> 32 in the cache */
   /* search1029_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 32, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2944 },
      -1,
   } },

   /* replace1029_0_0 -> 32 in the cache */
   /* replace1029_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2946 },
      -1,
   } },

   /* ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b')) */
   /* search1030_0_0_0 -> 0 in the cache */
   /* search1030_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2948 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2949 },
      -1,
   } },

   /* replace1030_0_0 -> 0 in the cache */
   /* replace1030_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2951 },
      -1,
   } },

   /* ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b')) */
   /* search1031_0_0_0 -> 0 in the cache */
   /* search1031_0_0_1 -> 3 in the cache */
   /* search1031_0_0 -> 2948 in the cache */
   /* search1031_0 -> 2949 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2949 },
      -1,
   } },

   /* replace1031_0_0 -> 0 in the cache */
   /* replace1031_0_1 -> 3 in the cache */
   /* replace1031_0 -> 2948 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2948 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0) */
   /* search1032_0 -> 16 in the cache */
   /* search1032_1 -> 120 in the cache */
   /* search1032_2 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 120, 786 },
      -1,
   } },

   /* replace1032_0 -> 16 in the cache */
   /* replace1032_1 -> 120 in the cache */
   /* replace1032 -> 393 in the cache */

   /* ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1) */
   /* search1033_0 -> 16 in the cache */
   /* search1033_1 -> 786 in the cache */
   /* search1033_2 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 786, 786 },
      -1,
   } },

   /* replace1033_0 -> 16 in the cache */
   /* replace1033_1 -> 377 in the cache */
   /* replace1033 -> 396 in the cache */

   /* ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2) */
   /* search1034_0 -> 16 in the cache */
   /* search1034_1 -> 808 in the cache */
   /* search1034_2 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 808, 786 },
      -1,
   } },

   /* replace1034_0 -> 16 in the cache */
   /* replace1034_1 -> 382 in the cache */
   /* replace1034 -> 400 in the cache */

   /* ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3) */
   /* search1035_0 -> 16 in the cache */
   /* search1035_1 -> 967 in the cache */
   /* search1035_2 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 967, 786 },
      -1,
   } },

   /* replace1035_0 -> 16 in the cache */
   /* replace1035_1 -> 386 in the cache */
   /* replace1035 -> 403 in the cache */

   /* ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0) */
   /* search1036_0 -> 16 in the cache */
   /* search1036_1 -> 120 in the cache */
   /* search1036_2 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 120, 786 },
      -1,
   } },

   /* replace1036_0 -> 16 in the cache */
   /* replace1036_1 -> 120 in the cache */
   /* replace1036 -> 374 in the cache */

   /* ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1) */
   /* search1037_0 -> 16 in the cache */
   /* search1037_1 -> 786 in the cache */
   /* search1037_2 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 786, 786 },
      -1,
   } },

   /* replace1037_0 -> 16 in the cache */
   /* replace1037_1 -> 377 in the cache */
   /* replace1037 -> 378 in the cache */

   /* ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2) */
   /* search1038_0 -> 16 in the cache */
   /* search1038_1 -> 808 in the cache */
   /* search1038_2 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 808, 786 },
      -1,
   } },

   /* replace1038_0 -> 16 in the cache */
   /* replace1038_1 -> 382 in the cache */
   /* replace1038 -> 383 in the cache */

   /* ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3) */
   /* search1039_0 -> 16 in the cache */
   /* search1039_1 -> 967 in the cache */
   /* search1039_2 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 967, 786 },
      -1,
   } },

   /* replace1039_0 -> 16 in the cache */
   /* replace1039_1 -> 386 in the cache */
   /* replace1039 -> 387 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1040_0_0 -> 0 in the cache */
   /* search1040_0_1 -> 3 in the cache */
   /* search1040_0 -> 2951 in the cache */
   /* search1040_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2951, 86 },
      -1,
   } },

   /* replace1040_0 -> 0 in the cache */
   /* replace1040_1 -> 3 in the cache */
   /* replace1040 -> 2948 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1041_0_0 -> 0 in the cache */
   /* search1041_0_1 -> 3 in the cache */
   /* search1041_0 -> 2948 in the cache */
   /* search1041_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2948, 86 },
      -1,
   } },

   /* replace1041_0 -> 0 in the cache */
   /* replace1041_1 -> 3 in the cache */
   /* replace1041 -> 2948 in the cache */

   /* ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0) */
   /* search1042_0_0 -> 16 in the cache */
   /* search1042_0_1 -> 808 in the cache */
   /* search1042_0 -> 960 in the cache */
   /* search1042_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 960, 808 },
      -1,
   } },

   /* replace1042_0 -> 16 in the cache */
   /* replace1042_1 -> 120 in the cache */
   /* replace1042 -> 425 in the cache */

   /* ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1) */
   /* search1043_0 -> 16 in the cache */
   /* search1043_1 -> 808 in the cache */
   /* search1043 -> 963 in the cache */

   /* replace1043_0 -> 16 in the cache */
   /* replace1043_1 -> 377 in the cache */
   /* replace1043 -> 428 in the cache */

   /* ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0) */
   /* search1044_0_0 -> 16 in the cache */
   /* search1044_0_1 -> 808 in the cache */
   /* search1044_0 -> 960 in the cache */
   /* search1044_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 960, 808 },
      -1,
   } },

   /* replace1044_0 -> 16 in the cache */
   /* replace1044_1 -> 120 in the cache */
   /* replace1044 -> 417 in the cache */

   /* ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1) */
   /* search1045_0 -> 16 in the cache */
   /* search1045_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 808 },
      -1,
   } },

   /* replace1045_0 -> 16 in the cache */
   /* replace1045_1 -> 377 in the cache */
   /* replace1045 -> 420 in the cache */

   /* ('iand', 65535, 'a') => ('extract_u16', 'a', 0) */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* search1046_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2968, 32 },
      -1,
   } },

   /* replace1046_0 -> 32 in the cache */
   /* replace1046_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0) */
   /* search1047_0 -> 16 in the cache */
   /* search1047_1 -> 120 in the cache */
   /* search1047_2 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 120, 808 },
      -1,
   } },

   /* replace1047_0 -> 16 in the cache */
   /* replace1047_1 -> 120 in the cache */
   /* replace1047 -> 425 in the cache */

   /* ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1) */
   /* search1048_0 -> 16 in the cache */
   /* search1048_1 -> 808 in the cache */
   /* search1048_2 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 808, 808 },
      -1,
   } },

   /* replace1048_0 -> 16 in the cache */
   /* replace1048_1 -> 377 in the cache */
   /* replace1048 -> 428 in the cache */

   /* ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0) */
   /* search1049_0 -> 16 in the cache */
   /* search1049_1 -> 120 in the cache */
   /* search1049_2 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 120, 808 },
      -1,
   } },

   /* replace1049_0 -> 16 in the cache */
   /* replace1049_1 -> 120 in the cache */
   /* replace1049 -> 417 in the cache */

   /* ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1) */
   /* search1050_0 -> 16 in the cache */
   /* search1050_1 -> 808 in the cache */
   /* search1050_2 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 808, 808 },
      -1,
   } },

   /* replace1050_0 -> 16 in the cache */
   /* replace1050_1 -> 377 in the cache */
   /* replace1050 -> 420 in the cache */

   /* ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a')) */
   /* search1051_0_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 6 },
      -1,
   } },
   /* search1051_0_1 -> 967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2975, 967 },
      -1,
   } },
   /* search1051_1_0_0_0 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2053 },
      -1,
   } },
   /* search1051_1_0_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2977, 808 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2979 },
      -1,
   } },
   /* search1051_1_1_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2980, 786 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2982 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 2981, 2983 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 2,
      { 2978, 2984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2976, 2985 },
      -1,
   } },

   /* replace1051_0_0 -> 2982 in the cache */
   /* replace1051_0_1 -> 2979 in the cache */
   /* replace1051_0_2 -> 2053 in the cache */
   /* replace1051_0_3 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 2982, 2979, 2053, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_4x8,
      -1, 0,
      { 2987 },
      -1,
   } },

   /* ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1052_0_0 -> 0 in the cache */
   /* search1052_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   /* search1052_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 2989, 86 },
      -1,
   } },

   /* replace1052_0 -> 0 in the cache */
   /* replace1052_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1053_0_0 -> 0 in the cache */
   /* search1053_0_1 -> 3 in the cache */
   /* search1053_0 -> 2991 in the cache */
   /* search1053_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 2991, 86 },
      -1,
   } },

   /* replace1053_0 -> 0 in the cache */
   /* replace1053_1 -> 3 in the cache */
   /* replace1053 -> 2991 in the cache */

   /* ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32)) */
   /* search1054_0 -> 16 in the cache */
   /* search1054_1 -> 36 in the cache */
   /* search1054 -> 2901 in the cache */

   /* replace1054_0_0 -> 16 in the cache */
   /* replace1054_0 -> 1849 in the cache */
   /* replace1054_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 36 },
      -1,
   } },
   /* replace1054_1_1 -> 829 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2993, 829 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1849, 2994 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16)) */
   /* search1055_0 -> 11 in the cache */
   /* search1055_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 11, 243 },
      -1,
   } },

   /* replace1055_0_0 -> 11 in the cache */
   /* replace1055_0 -> 1742 in the cache */
   /* replace1055_1_0_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 243 },
      -1,
   } },
   /* replace1055_1_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 2997, 808 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1742, 2998 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a') */
   /* search1056_0 -> 21 in the cache */
   /* search1056 -> 2910 in the cache */

   /* replace1056_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32)) */
   /* search1057_0 -> 21 in the cache */
   /* search1057 -> 2911 in the cache */

   /* replace1057_0_0 -> 21 in the cache */
   /* replace1057_0_1 -> 829 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 829 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3001 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a') */
   /* search1058_0 -> 16 in the cache */
   /* search1058 -> 2919 in the cache */

   /* replace1058_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1059_0 -> 16 in the cache */
   /* search1059 -> 2921 in the cache */

   /* replace1059_0_0 -> 16 in the cache */
   /* replace1059_0_1 -> 808 in the cache */
   /* replace1059_0 -> 963 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 963 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1060_0_0 -> 16 in the cache */
   /* search1060_0_1 -> 957 in the cache */
   /* search1060_0 -> 958 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 1,
      { 958 },
      -1,
   } },

   /* replace1060_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1061_0_0 -> 16 in the cache */
   /* search1061_0_1 -> 957 in the cache */
   /* search1061_0 -> 958 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 1,
      { 958 },
      -1,
   } },

   /* replace1061_0 -> 16 in the cache */
   /* replace1061 -> 2919 in the cache */

   /* ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a') */
   /* search1062_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 3008 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 3009 },
      -1,
   } },

   /* replace1062_0 -> 21 in the cache */
   /* replace1062 -> 2910 in the cache */

   /* ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1063_0_0 -> 16 in the cache */
   /* search1063_0_1 -> 961 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 1,
      { 3011 },
      -1,
   } },

   /* replace1063_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1064_0_0 -> 16 in the cache */
   /* search1064_0_1 -> 961 in the cache */
   /* search1064_0 -> 3011 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 1,
      { 3011 },
      -1,
   } },

   /* replace1064_0 -> 16 in the cache */
   /* replace1064 -> 2921 in the cache */

   /* ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a') */
   /* search1065_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff00000000 /* 18446744069414584320 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 3015 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 1,
      { 3016 },
      -1,
   } },

   /* replace1065_0 -> 21 in the cache */
   /* replace1065 -> 2911 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1066_0_0 -> 16 in the cache */
   /* search1066_0_1 -> 120 in the cache */
   /* search1066_0 -> 425 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 425 },
      -1,
   } },

   /* replace1066_0 -> 16 in the cache */
   /* replace1066 -> 3006 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1067_0_0 -> 16 in the cache */
   /* search1067_0_1 -> 377 in the cache */
   /* search1067_0 -> 428 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 428 },
      -1,
   } },

   /* replace1067_0 -> 16 in the cache */
   /* replace1067 -> 3013 in the cache */

   /* ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1068_0_0 -> 16 in the cache */
   /* search1068_0_1 -> 808 in the cache */
   /* search1068_0 -> 963 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 963 },
      -1,
   } },

   /* replace1068_0 -> 16 in the cache */
   /* replace1068 -> 3013 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1069_0_0 -> 16 in the cache */
   /* search1069_0_1 -> 120 in the cache */
   /* search1069_0 -> 425 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 425 },
      -1,
   } },

   /* replace1069_0 -> 16 in the cache */
   /* replace1069 -> 2919 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1070_0_0 -> 16 in the cache */
   /* search1070_0_1 -> 377 in the cache */
   /* search1070_0 -> 428 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 428 },
      -1,
   } },

   /* replace1070_0 -> 16 in the cache */
   /* replace1070 -> 2921 in the cache */

   /* ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a')) */
   /* search1071_0_0_0 -> 16 in the cache */
   /* search1071_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3023 },
      -1,
   } },
   /* search1071_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3024, 808 },
      -1,
   } },

   /* replace1071_0_0 -> 120 in the cache */
   /* replace1071_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3026 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0)) */
   /* search1072_0_0_0 -> 120 in the cache */
   /* search1072_0_0_1 -> 16 in the cache */
   /* search1072_0_0 -> 3026 in the cache */
   /* search1072_0 -> 3027 in the cache */
   /* search1072_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3027, 808 },
      -1,
   } },

   /* replace1072_0_0 -> 16 in the cache */
   /* replace1072_0_1 -> 120 in the cache */
   /* replace1072_0 -> 3023 in the cache */
   /* replace1072 -> 3024 in the cache */

   /* ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1073_0_0_0 -> 16 in the cache */
   /* search1073_0_0_1 -> 120 in the cache */
   /* search1073_0_0 -> 3023 in the cache */
   /* search1073_0 -> 3024 in the cache */
   /* search1073_1_0_0 -> 120 in the cache */
   /* search1073_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3029 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3024, 3030 },
      -1,
   } },

   /* replace1073_0_0 -> 16 in the cache */
   /* replace1073_0_1 -> 36 in the cache */
   /* replace1073_0 -> 2905 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 2905 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1074_0_0_0 -> 16 in the cache */
   /* search1074_0_0_1 -> 120 in the cache */
   /* search1074_0_0 -> 3023 in the cache */
   /* search1074_0 -> 3024 in the cache */
   /* search1074_1_0_0 -> 120 in the cache */
   /* search1074_1_0_1 -> 36 in the cache */
   /* search1074_1_0 -> 3029 in the cache */
   /* search1074_1 -> 3030 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3024, 3030 },
      -1,
   } },

   /* replace1074_0_0 -> 16 in the cache */
   /* replace1074_0_1 -> 36 in the cache */
   /* replace1074_0 -> 2905 in the cache */
   /* replace1074 -> 3032 in the cache */

   /* ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a') */
   /* search1075_0_0 -> 16 in the cache */
   /* search1075_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1075_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3034, 808 },
      -1,
   } },

   /* replace1075_0 -> 120 in the cache */
   /* replace1075_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 120, 16 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0) */
   /* search1076_0_0 -> 120 in the cache */
   /* search1076_0_1 -> 16 in the cache */
   /* search1076_0 -> 3036 in the cache */
   /* search1076_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3036, 808 },
      -1,
   } },

   /* replace1076_0 -> 16 in the cache */
   /* replace1076_1 -> 120 in the cache */
   /* replace1076 -> 3034 in the cache */

   /* ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0) */
   /* search1077_0_0 -> 120 in the cache */
   /* search1077_0_1 -> 16 in the cache */
   /* search1077_0 -> 3036 in the cache */
   /* search1077_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3036, 377 },
      -1,
   } },

   /* replace1077_0 -> 16 in the cache */
   /* replace1077_1 -> 120 in the cache */
   /* replace1077 -> 3034 in the cache */

   /* ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1078_0_0 -> 16 in the cache */
   /* search1078_0_1 -> 120 in the cache */
   /* search1078_0 -> 3034 in the cache */
   /* search1078_1_0 -> 120 in the cache */
   /* search1078_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3034, 3039 },
      -1,
   } },

   /* replace1078_0 -> 16 in the cache */
   /* replace1078_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1079_0_0 -> 16 in the cache */
   /* search1079_0_1 -> 120 in the cache */
   /* search1079_0 -> 3034 in the cache */
   /* search1079_1_0 -> 120 in the cache */
   /* search1079_1_1 -> 36 in the cache */
   /* search1079_1 -> 3039 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3034, 3039 },
      -1,
   } },

   /* replace1079_0 -> 16 in the cache */
   /* replace1079_1 -> 36 in the cache */
   /* replace1079 -> 3041 in the cache */

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a') */
   /* search1080_0_0 -> 6 in the cache */
   /* search1080_0_1 -> 2053 in the cache */
   /* search1080_0_2 -> 2979 in the cache */
   /* search1080_0_3 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_4x8_split,
      -1, 0,
      { 6, 2053, 2979, 2982 },
      -1,
   } },
   /* search1080_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3043, 120 },
      -1,
   } },

   /* replace1080_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b') */
   /* search1081_0_0 -> 6 in the cache */
   /* search1081_0_1 -> 2053 in the cache */
   /* search1081_0_2 -> 2979 in the cache */
   /* search1081_0_3 -> 2982 in the cache */
   /* search1081_0 -> 3043 in the cache */
   /* search1081_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3043, 377 },
      -1,
   } },

   /* replace1081_0 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2053 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c') */
   /* search1082_0_0 -> 6 in the cache */
   /* search1082_0_1 -> 2053 in the cache */
   /* search1082_0_2 -> 2979 in the cache */
   /* search1082_0_3 -> 2982 in the cache */
   /* search1082_0 -> 3043 in the cache */
   /* search1082_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3043, 382 },
      -1,
   } },

   /* replace1082_0 -> 2979 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2979 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd') */
   /* search1083_0_0 -> 6 in the cache */
   /* search1083_0_1 -> 2053 in the cache */
   /* search1083_0_2 -> 2979 in the cache */
   /* search1083_0_3 -> 2982 in the cache */
   /* search1083_0 -> 3043 in the cache */
   /* search1083_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3043, 386 },
      -1,
   } },

   /* replace1083_0 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2982 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a') */
   /* search1084_0_0 -> 6 in the cache */
   /* search1084_0_1 -> 2053 in the cache */
   /* search1084_0_2 -> 2979 in the cache */
   /* search1084_0_3 -> 2982 in the cache */
   /* search1084_0 -> 3043 in the cache */
   /* search1084_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3043, 120 },
      -1,
   } },

   /* replace1084_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b') */
   /* search1085_0_0 -> 6 in the cache */
   /* search1085_0_1 -> 2053 in the cache */
   /* search1085_0_2 -> 2979 in the cache */
   /* search1085_0_3 -> 2982 in the cache */
   /* search1085_0 -> 3043 in the cache */
   /* search1085_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3043, 377 },
      -1,
   } },

   /* replace1085_0 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2053 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c') */
   /* search1086_0_0 -> 6 in the cache */
   /* search1086_0_1 -> 2053 in the cache */
   /* search1086_0_2 -> 2979 in the cache */
   /* search1086_0_3 -> 2982 in the cache */
   /* search1086_0 -> 3043 in the cache */
   /* search1086_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3043, 382 },
      -1,
   } },

   /* replace1086_0 -> 2979 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2979 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd') */
   /* search1087_0_0 -> 6 in the cache */
   /* search1087_0_1 -> 2053 in the cache */
   /* search1087_0_2 -> 2979 in the cache */
   /* search1087_0_3 -> 2982 in the cache */
   /* search1087_0 -> 3043 in the cache */
   /* search1087_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3043, 386 },
      -1,
   } },

   /* replace1087_0 -> 2982 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2982 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1088_0_0 -> 11 in the cache */
   /* search1088_0_1 -> 786 in the cache */
   /* search1088_0 -> 2927 in the cache */
   /* search1088_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2927, 811 },
      -1,
   } },

   /* replace1088_0 -> 11 in the cache */
   /* replace1088_1 -> 1389 in the cache */
   /* replace1088 -> 2928 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1089_0_0 -> 16 in the cache */
   /* search1089_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 786 },
      -1,
   } },
   /* search1089_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3061, 120 },
      -1,
   } },

   /* replace1089_0 -> 16 in the cache */
   /* replace1089_1 -> 377 in the cache */
   /* replace1089 -> 396 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1090_0_0 -> 16 in the cache */
   /* search1090_0_1 -> 808 in the cache */
   /* search1090_0 -> 963 in the cache */
   /* search1090_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 963, 120 },
      -1,
   } },

   /* replace1090_0 -> 16 in the cache */
   /* replace1090_1 -> 382 in the cache */
   /* replace1090 -> 400 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1091_0_0 -> 16 in the cache */
   /* search1091_0_1 -> 967 in the cache */
   /* search1091_0 -> 972 in the cache */
   /* search1091_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 972, 120 },
      -1,
   } },

   /* replace1091_0 -> 16 in the cache */
   /* replace1091_1 -> 386 in the cache */
   /* replace1091 -> 403 in the cache */

   /* ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1092_0_0 -> 21 in the cache */
   /* search1092_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 786 },
      -1,
   } },
   /* search1092_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3065, 852 },
      -1,
   } },

   /* replace1092_0 -> 21 in the cache */
   /* replace1092_1 -> 1431 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 1431 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1093_0_0 -> 21 in the cache */
   /* search1093_0_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 808 },
      -1,
   } },
   /* search1093_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3068, 852 },
      -1,
   } },

   /* replace1093_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3070 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1094_0_0 -> 21 in the cache */
   /* search1094_0_1 -> 967 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 967 },
      -1,
   } },
   /* search1094_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3072, 852 },
      -1,
   } },

   /* replace1094_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3074 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1095_0_0 -> 21 in the cache */
   /* search1095_0_1 -> 829 in the cache */
   /* search1095_0 -> 3001 in the cache */
   /* search1095_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3001, 852 },
      -1,
   } },

   /* replace1095_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3077 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1096_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x28 /* 40 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3079 },
      -1,
   } },
   /* search1096_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3080, 852 },
      -1,
   } },

   /* replace1096_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x5 /* 5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3082 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1097_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x30 /* 48 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3084 },
      -1,
   } },
   /* search1097_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3085, 852 },
      -1,
   } },

   /* replace1097_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x6 /* 6 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3087 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1098_0_0 -> 21 in the cache */
   /* search1098_0_1 -> 2929 in the cache */
   /* search1098_0 -> 2930 in the cache */
   /* search1098_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2930, 852 },
      -1,
   } },

   /* replace1098_0 -> 21 in the cache */
   /* replace1098_1 -> 2931 in the cache */
   /* replace1098 -> 2932 in the cache */

   /* ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1099_0_0 -> 11 in the cache */
   /* search1099_0_1 -> 786 in the cache */
   /* search1099_0 -> 2933 in the cache */
   /* search1099_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2933, 811 },
      -1,
   } },

   /* replace1099_0 -> 11 in the cache */
   /* replace1099_1 -> 1389 in the cache */
   /* replace1099 -> 2928 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1100_0_0 -> 16 in the cache */
   /* search1100_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 786 },
      -1,
   } },
   /* search1100_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3091, 120 },
      -1,
   } },

   /* replace1100_0 -> 16 in the cache */
   /* replace1100_1 -> 377 in the cache */
   /* replace1100 -> 396 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1101_0_0 -> 16 in the cache */
   /* search1101_0_1 -> 808 in the cache */
   /* search1101_0 -> 2967 in the cache */
   /* search1101_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2967, 120 },
      -1,
   } },

   /* replace1101_0 -> 16 in the cache */
   /* replace1101_1 -> 382 in the cache */
   /* replace1101 -> 400 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1102_0_0 -> 16 in the cache */
   /* search1102_0_1 -> 967 in the cache */
   /* search1102_0 -> 2935 in the cache */
   /* search1102_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2935, 120 },
      -1,
   } },

   /* replace1102_0 -> 16 in the cache */
   /* replace1102_1 -> 386 in the cache */
   /* replace1102 -> 403 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1103_0_0 -> 21 in the cache */
   /* search1103_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 786 },
      -1,
   } },
   /* search1103_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3095, 852 },
      -1,
   } },

   /* replace1103_0 -> 21 in the cache */
   /* replace1103_1 -> 1431 in the cache */
   /* replace1103 -> 3067 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1104_0_0 -> 21 in the cache */
   /* search1104_0_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 808 },
      -1,
   } },
   /* search1104_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3097, 852 },
      -1,
   } },

   /* replace1104_0 -> 21 in the cache */
   /* replace1104_1 -> 3070 in the cache */
   /* replace1104 -> 3071 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1105_0_0 -> 21 in the cache */
   /* search1105_0_1 -> 967 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 967 },
      -1,
   } },
   /* search1105_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3099, 852 },
      -1,
   } },

   /* replace1105_0 -> 21 in the cache */
   /* replace1105_1 -> 3074 in the cache */
   /* replace1105 -> 3075 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1106_0_0 -> 21 in the cache */
   /* search1106_0_1 -> 829 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 829 },
      -1,
   } },
   /* search1106_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3101, 852 },
      -1,
   } },

   /* replace1106_0 -> 21 in the cache */
   /* replace1106_1 -> 3077 in the cache */
   /* replace1106 -> 3078 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1107_0_0 -> 21 in the cache */
   /* search1107_0_1 -> 3079 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3079 },
      -1,
   } },
   /* search1107_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3103, 852 },
      -1,
   } },

   /* replace1107_0 -> 21 in the cache */
   /* replace1107_1 -> 3082 in the cache */
   /* replace1107 -> 3083 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1108_0_0 -> 21 in the cache */
   /* search1108_0_1 -> 3084 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3084 },
      -1,
   } },
   /* search1108_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3105, 852 },
      -1,
   } },

   /* replace1108_0 -> 21 in the cache */
   /* replace1108_1 -> 3087 in the cache */
   /* replace1108 -> 3088 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1109_0_0 -> 21 in the cache */
   /* search1109_0_1 -> 2929 in the cache */
   /* search1109_0 -> 2936 in the cache */
   /* search1109_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2936, 852 },
      -1,
   } },

   /* replace1109_0 -> 21 in the cache */
   /* replace1109_1 -> 2931 in the cache */
   /* replace1109 -> 2932 in the cache */

   /* ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2) */
   /* search1110_0_0 -> 32 in the cache */
   /* search1110_0_1 -> 35 in the cache */
   /* search1110_0 -> 2940 in the cache */
   /* search1110_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 2940, 61 },
      -1,
   } },

   /* replace1110_0 -> 32 in the cache */
   /* replace1110_1 -> 2160 in the cache */
   /* replace1110 -> 2942 in the cache */

   /* ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0) */
   /* search1111_0_0 -> 11 in the cache */
   /* search1111_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 786 },
      -1,
   } },
   /* search1111_1 -> 1389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3109, 1389 },
      -1,
   } },

   /* replace1111_0 -> 11 in the cache */
   /* replace1111_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 811 },
      -1,
   } },

   /* ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2) */
   /* search1112_0_0 -> 16 in the cache */
   /* search1112_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 786 },
      -1,
   } },
   /* search1112_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3112, 386 },
      -1,
   } },

   /* replace1112_0 -> 16 in the cache */
   /* replace1112_1 -> 382 in the cache */
   /* replace1112 -> 400 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1) */
   /* search1113_0_0 -> 16 in the cache */
   /* search1113_0_1 -> 808 in the cache */
   /* search1113_0 -> 960 in the cache */
   /* search1113_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 960, 386 },
      -1,
   } },

   /* replace1113_0 -> 16 in the cache */
   /* replace1113_1 -> 377 in the cache */
   /* replace1113 -> 396 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0) */
   /* search1114_0_0 -> 16 in the cache */
   /* search1114_0_1 -> 967 in the cache */
   /* search1114_0 -> 969 in the cache */
   /* search1114_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 969, 386 },
      -1,
   } },

   /* replace1114_0 -> 16 in the cache */
   /* replace1114_1 -> 120 in the cache */
   /* replace1114 -> 393 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6) */
   /* search1115_0_0 -> 21 in the cache */
   /* search1115_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 786 },
      -1,
   } },
   /* search1115_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3116, 2931 },
      -1,
   } },

   /* replace1115_0 -> 21 in the cache */
   /* replace1115_1 -> 3087 in the cache */
   /* replace1115 -> 3088 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5) */
   /* search1116_0_0 -> 21 in the cache */
   /* search1116_0_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 808 },
      -1,
   } },
   /* search1116_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3118, 2931 },
      -1,
   } },

   /* replace1116_0 -> 21 in the cache */
   /* replace1116_1 -> 3082 in the cache */
   /* replace1116 -> 3083 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4) */
   /* search1117_0_0 -> 21 in the cache */
   /* search1117_0_1 -> 967 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 967 },
      -1,
   } },
   /* search1117_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3120, 2931 },
      -1,
   } },

   /* replace1117_0 -> 21 in the cache */
   /* replace1117_1 -> 3077 in the cache */
   /* replace1117 -> 3078 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3) */
   /* search1118_0_0 -> 21 in the cache */
   /* search1118_0_1 -> 829 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 829 },
      -1,
   } },
   /* search1118_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3122, 2931 },
      -1,
   } },

   /* replace1118_0 -> 21 in the cache */
   /* replace1118_1 -> 3074 in the cache */
   /* replace1118 -> 3075 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2) */
   /* search1119_0_0 -> 21 in the cache */
   /* search1119_0_1 -> 3079 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3079 },
      -1,
   } },
   /* search1119_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3124, 2931 },
      -1,
   } },

   /* replace1119_0 -> 21 in the cache */
   /* replace1119_1 -> 3070 in the cache */
   /* replace1119 -> 3071 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1) */
   /* search1120_0_0 -> 21 in the cache */
   /* search1120_0_1 -> 3084 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3084 },
      -1,
   } },
   /* search1120_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3126, 2931 },
      -1,
   } },

   /* replace1120_0 -> 21 in the cache */
   /* replace1120_1 -> 1431 in the cache */
   /* replace1120 -> 3067 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0) */
   /* search1121_0_0 -> 21 in the cache */
   /* search1121_0_1 -> 2929 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 2929 },
      -1,
   } },
   /* search1121_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3128, 2931 },
      -1,
   } },

   /* replace1121_0 -> 21 in the cache */
   /* replace1121_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 852 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0) */
   /* search1122_0_0 -> 11 in the cache */
   /* search1122_0_1 -> 786 in the cache */
   /* search1122_0 -> 3109 in the cache */
   /* search1122_1 -> 1389 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3109, 1389 },
      -1,
   } },

   /* replace1122_0 -> 11 in the cache */
   /* replace1122_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 811 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2) */
   /* search1123_0_0 -> 16 in the cache */
   /* search1123_0_1 -> 786 in the cache */
   /* search1123_0 -> 3112 in the cache */
   /* search1123_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3112, 386 },
      -1,
   } },

   /* replace1123_0 -> 16 in the cache */
   /* replace1123_1 -> 382 in the cache */
   /* replace1123 -> 383 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1) */
   /* search1124_0_0 -> 16 in the cache */
   /* search1124_0_1 -> 808 in the cache */
   /* search1124_0 -> 960 in the cache */
   /* search1124_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 960, 386 },
      -1,
   } },

   /* replace1124_0 -> 16 in the cache */
   /* replace1124_1 -> 377 in the cache */
   /* replace1124 -> 378 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0) */
   /* search1125_0_0 -> 16 in the cache */
   /* search1125_0_1 -> 967 in the cache */
   /* search1125_0 -> 969 in the cache */
   /* search1125_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 969, 386 },
      -1,
   } },

   /* replace1125_0 -> 16 in the cache */
   /* replace1125_1 -> 120 in the cache */
   /* replace1125 -> 374 in the cache */

   /* ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6) */
   /* search1126_0_0 -> 21 in the cache */
   /* search1126_0_1 -> 786 in the cache */
   /* search1126_0 -> 3116 in the cache */
   /* search1126_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3116, 2931 },
      -1,
   } },

   /* replace1126_0 -> 21 in the cache */
   /* replace1126_1 -> 3087 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3087 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5) */
   /* search1127_0_0 -> 21 in the cache */
   /* search1127_0_1 -> 808 in the cache */
   /* search1127_0 -> 3118 in the cache */
   /* search1127_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3118, 2931 },
      -1,
   } },

   /* replace1127_0 -> 21 in the cache */
   /* replace1127_1 -> 3082 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3082 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4) */
   /* search1128_0_0 -> 21 in the cache */
   /* search1128_0_1 -> 967 in the cache */
   /* search1128_0 -> 3120 in the cache */
   /* search1128_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3120, 2931 },
      -1,
   } },

   /* replace1128_0 -> 21 in the cache */
   /* replace1128_1 -> 3077 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3077 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3) */
   /* search1129_0_0 -> 21 in the cache */
   /* search1129_0_1 -> 829 in the cache */
   /* search1129_0 -> 3122 in the cache */
   /* search1129_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3122, 2931 },
      -1,
   } },

   /* replace1129_0 -> 21 in the cache */
   /* replace1129_1 -> 3074 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3074 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2) */
   /* search1130_0_0 -> 21 in the cache */
   /* search1130_0_1 -> 3079 in the cache */
   /* search1130_0 -> 3124 in the cache */
   /* search1130_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3124, 2931 },
      -1,
   } },

   /* replace1130_0 -> 21 in the cache */
   /* replace1130_1 -> 3070 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3070 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1) */
   /* search1131_0_0 -> 21 in the cache */
   /* search1131_0_1 -> 3084 in the cache */
   /* search1131_0 -> 3126 in the cache */
   /* search1131_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3126, 2931 },
      -1,
   } },

   /* replace1131_0 -> 21 in the cache */
   /* replace1131_1 -> 1431 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 1431 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0) */
   /* search1132_0_0 -> 21 in the cache */
   /* search1132_0_1 -> 2929 in the cache */
   /* search1132_0 -> 3128 in the cache */
   /* search1132_1 -> 2931 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3128, 2931 },
      -1,
   } },

   /* replace1132_0 -> 21 in the cache */
   /* replace1132_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 852 },
      -1,
   } },

   /* ('ussub_4x8_vc4', 'a', 0) => a */
   /* search1133_0 -> 16 in the cache */
   /* search1133_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 120 },
      -1,
   } },

   /* replace1133 -> 16 in the cache */

   /* ('ussub_4x8_vc4', 'a', -1) => 0 */
   /* search1134_0 -> 16 in the cache */
   /* search1134_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 122 },
      -1,
   } },

   /* replace1134 -> 120 in the cache */

   /* ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b')) */
   /* search1135_0 -> 0 in the cache */
   /* search1135_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1135_0 -> 0 in the cache */
   /* replace1135_1_0 -> 3 in the cache */
   /* replace1135_1 -> 1042 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1042 },
      -1,
   } },

   /* ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b')) */
   /* search1136_0 -> 0 in the cache */
   /* search1136_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1136_0 -> 0 in the cache */
   /* replace1136_1_0 -> 3 in the cache */
   /* replace1136_1 -> 93 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 93 },
      -1,
   } },

   /* ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1137_0 -> 0 in the cache */
   /* search1137_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uabs_usub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1137_0_0 -> 0 in the cache */
   /* replace1137_0_1 -> 3 in the cache */
   /* replace1137_0 -> 1022 in the cache */
   /* replace1137_1_0_0 -> 0 in the cache */
   /* replace1137_1_0_1 -> 3 in the cache */
   /* replace1137_1_0 -> 3154 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3154 },
      -1,
   } },
   /* replace1137_2_0 -> 0 in the cache */
   /* replace1137_2_1 -> 3 in the cache */
   /* replace1137_2 -> 3154 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1022, 3157, 3154 },
      -1,
   } },

   /* ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1138_0 -> 0 in the cache */
   /* search1138_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uabs_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1138_0_0 -> 0 in the cache */
   /* replace1138_0_1 -> 3 in the cache */
   /* replace1138_0 -> 1019 in the cache */
   /* replace1138_1_0_0 -> 0 in the cache */
   /* replace1138_1_0_1 -> 3 in the cache */
   /* replace1138_1_0 -> 3154 in the cache */
   /* replace1138_1 -> 3157 in the cache */
   /* replace1138_2_0 -> 0 in the cache */
   /* replace1138_2_1 -> 3 in the cache */
   /* replace1138_2 -> 3154 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1019, 3157, 3154 },
      -1,
   } },

   /* ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b')) */
   /* search1139_0_0 -> 0 in the cache */
   /* search1139_0 -> 197 in the cache */
   /* search1139_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 197, 3 },
      4,
   } },

   /* replace1139_0_0 -> 0 in the cache */
   /* replace1139_0_1 -> 3 in the cache */
   /* replace1139_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 249 },
      -1,
   } },

   /* ('fmulz(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b')) */
   /* search1140_0_0 -> 16 in the cache */
   /* search1140_0 -> 265 in the cache */
   /* search1140_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 265, 36 },
      4,
   } },

   /* replace1140_0_0 -> 16 in the cache */
   /* replace1140_0_1 -> 36 in the cache */
   /* replace1140_0 -> 254 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 254 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   /* search1141_0_0 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 124 },
      -1,
   } },
   /* search1141_1_0 -> 125 in the cache */
   /* search1141_1 -> 1145 in the cache */
   /* search1141_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 3165, 1145, 127 },
      -1,
   } },

   /* replace1141_0 -> 124 in the cache */
   /* replace1141_1 -> 125 in the cache */
   /* replace1141_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 124, 125, 127 },
      -1,
   } },

   /* ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search1142_0_0 -> 16 in the cache */
   /* search1142_0 -> 265 in the cache */
   /* search1142_1_0 -> 36 in the cache */
   /* search1142_1 -> 581 in the cache */
   /* search1142_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 265, 581, 133 },
      -1,
   } },

   /* replace1142_0 -> 16 in the cache */
   /* replace1142_1 -> 36 in the cache */
   /* replace1142_2 -> 133 in the cache */
   /* replace1142 -> 373 in the cache */

   /* ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b')) */
   /* search1143_0_0 -> 0 in the cache */
   /* search1143_0 -> 192 in the cache */
   /* search1143_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 192, 3 },
      -1,
   } },

   /* replace1143_0_0 -> 0 in the cache */
   /* replace1143_0_1 -> 3 in the cache */
   /* replace1143_0 -> 906 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 906 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3171, 3172 },
      0,
   } },
   /* search1144_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3173, 769 },
      0,
   } },

   /* replace1144_0_0 -> 124 in the cache */
   /* replace1144_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1144_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3175, 125 },
      -1,
   } },

   /* ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1145_0_0 -> 313 in the cache */
   /* search1145_0_1 -> 323 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 313, 323 },
      0,
   } },
   /* search1145_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3177, 294 },
      0,
   } },

   /* replace1145_0_0 -> 16 in the cache */
   /* replace1145_0_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 133 },
      -1,
   } },
   /* replace1145_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3179, 36 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   /* search1146_0_0 -> 313 in the cache */
   /* search1146_0_1 -> 323 in the cache */
   /* search1146_0 -> 3177 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3177, 3181 },
      0,
   } },

   /* replace1146_0_0 -> 16 in the cache */
   /* replace1146_0_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 16, 133 },
      -1,
   } },
   /* replace1146_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3183, 36 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1147_0_0 -> 3171 in the cache */
   /* search1147_0_1 -> 3172 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 3171, 3172 },
      0,
   } },
   /* search1147_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 3185, 769 },
      0,
   } },

   /* replace1147_0_0 -> 124 in the cache */
   /* replace1147_0_1 -> 127 in the cache */
   /* replace1147_0 -> 980 in the cache */
   /* replace1147_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 980, 125 },
      -1,
   } },

   /* ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3188, 3189 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1148_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3190, 3191, 151 },
      -1,
   } },

   /* replace1148_0_0 -> 147 in the cache */
   /* replace1148_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 147, 150 },
      -1,
   } },
   /* replace1148_1 -> 148 in the cache */
   /* replace1148_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3193, 148, 151 },
      -1,
   } },

   /* ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1149_0_0 -> 313 in the cache */
   /* search1149_0_1 -> 323 in the cache */
   /* search1149_0 -> 3177 in the cache */
   /* search1149_1 -> 294 in the cache */
   /* search1149_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3177, 294, 161 },
      -1,
   } },

   /* replace1149_0_0 -> 16 in the cache */
   /* replace1149_0_1 -> 133 in the cache */
   /* replace1149_0 -> 3179 in the cache */
   /* replace1149_1 -> 36 in the cache */
   /* replace1149_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3179, 36, 161 },
      -1,
   } },

   /* ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1150_0_0 -> 313 in the cache */
   /* search1150_0_1 -> 323 in the cache */
   /* search1150_0 -> 3177 in the cache */
   /* search1150_1 -> 3181 in the cache */
   /* search1150_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3177, 3181, 161 },
      -1,
   } },

   /* replace1150_0_0 -> 16 in the cache */
   /* replace1150_0_1 -> 133 in the cache */
   /* replace1150_0 -> 3183 in the cache */
   /* replace1150_1 -> 36 in the cache */
   /* replace1150_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3183, 36, 161 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1151_0_0 -> 3171 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3171, 3199 },
      0,
   } },
   /* search1151_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3200, 769 },
      0,
   } },

   /* replace1151_0_0 -> 124 in the cache */
   /* replace1151_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1151_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3202, 125 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1152_0_0 -> 3171 in the cache */
   /* search1152_0_1 -> 3172 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3171, 3172 },
      0,
   } },
   /* search1152_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3204, 769 },
      0,
   } },

   /* replace1152_0_0 -> 124 in the cache */
   /* replace1152_0_1 -> 127 in the cache */
   /* replace1152_0 -> 3202 in the cache */
   /* replace1152_1 -> 125 in the cache */
   /* replace1152 -> 3203 in the cache */

   /* ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c') */
   /* search1153_0_0 -> 3188 in the cache */
   /* search1153_0_1 -> 148 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 3188, 148, 3206 },
      0,
   } },
   /* search1153_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3207, 986 },
      0,
   } },

   /* replace1153_0_0 -> 147 in the cache */
   /* replace1153_0_1 -> 148 in the cache */
   /* replace1153_0_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 147, 148, 151 },
      -1,
   } },
   /* replace1153_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3209, 150 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c') */
   /* search1154_0_0 -> 313 in the cache */
   /* search1154_0_1 -> 36 in the cache */
   /* search1154_0_2 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 313, 36, 332 },
      0,
   } },
   /* search1154_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3211, 296 },
      0,
   } },

   /* replace1154_0_0 -> 16 in the cache */
   /* replace1154_0_1 -> 36 in the cache */
   /* replace1154_0_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 36, 161 },
      -1,
   } },
   /* replace1154_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3213, 133 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1155_0_0 -> 3171 in the cache */
   /* search1155_0_1 -> 3172 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 3171, 3172 },
      0,
   } },
   /* search1155_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3215, 769 },
      0,
   } },

   /* replace1155_0_0 -> 124 in the cache */
   /* replace1155_0_1 -> 127 in the cache */
   /* replace1155_0 -> 994 in the cache */
   /* replace1155_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 994, 125 },
      -1,
   } },

   /* ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b') */
   /* search1156_0 -> 267 in the cache */
   /* search1156_1_0 -> 3172 in the cache */
   /* search1156_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3172, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 267, 3218 },
      -1,
   } },

   /* replace1156_0_0 -> 124 in the cache */
   /* replace1156_0_1 -> 127 in the cache */
   /* replace1156_0 -> 3175 in the cache */
   /* replace1156_1 -> 125 in the cache */
   /* replace1156 -> 3176 in the cache */

   /* ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1157_0 -> 271 in the cache */
   /* search1157_1_0 -> 323 in the cache */
   /* search1157_1_1 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 323, 294 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 271, 3220 },
      -1,
   } },

   /* replace1157_0_0 -> 16 in the cache */
   /* replace1157_0_1 -> 133 in the cache */
   /* replace1157_0 -> 3179 in the cache */
   /* replace1157_1 -> 36 in the cache */
   /* replace1157 -> 3180 in the cache */

   /* ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1158_1_0 -> 323 in the cache */
   /* search1158_1_1 -> 294 in the cache */
   /* search1158_1 -> 3220 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3222, 3220 },
      -1,
   } },

   /* replace1158_0_0 -> 16 in the cache */
   /* replace1158_0_1 -> 133 in the cache */
   /* replace1158_0 -> 3183 in the cache */
   /* replace1158_1 -> 36 in the cache */
   /* replace1158 -> 3184 in the cache */

   /* ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1159_1_0 -> 3189 in the cache */
   /* search1159_1_1 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3189, 3191 },
      -1,
   } },
   /* search1159_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3224, 3225, 151 },
      -1,
   } },

   /* replace1159_0_0 -> 147 in the cache */
   /* replace1159_0_1 -> 150 in the cache */
   /* replace1159_0 -> 3193 in the cache */
   /* replace1159_1 -> 148 in the cache */
   /* replace1159_2 -> 151 in the cache */
   /* replace1159 -> 3194 in the cache */

   /* ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1160_0 -> 271 in the cache */
   /* search1160_1_0 -> 323 in the cache */
   /* search1160_1_1 -> 294 in the cache */
   /* search1160_1 -> 3220 in the cache */
   /* search1160_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 271, 3220, 161 },
      -1,
   } },

   /* replace1160_0_0 -> 16 in the cache */
   /* replace1160_0_1 -> 133 in the cache */
   /* replace1160_0 -> 3179 in the cache */
   /* replace1160_1 -> 36 in the cache */
   /* replace1160_2 -> 161 in the cache */
   /* replace1160 -> 3196 in the cache */

   /* ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1161_0 -> 3222 in the cache */
   /* search1161_1_0 -> 323 in the cache */
   /* search1161_1_1 -> 294 in the cache */
   /* search1161_1 -> 3220 in the cache */
   /* search1161_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3222, 3220, 161 },
      -1,
   } },

   /* replace1161_0_0 -> 16 in the cache */
   /* replace1161_0_1 -> 133 in the cache */
   /* replace1161_0 -> 3183 in the cache */
   /* replace1161_1 -> 36 in the cache */
   /* replace1161_2 -> 161 in the cache */
   /* replace1161 -> 3198 in the cache */

   /* ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1162_0 -> 267 in the cache */
   /* search1162_1_0 -> 3172 in the cache */
   /* search1162_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 3172, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 267, 3229 },
      -1,
   } },

   /* replace1162_0_0 -> 124 in the cache */
   /* replace1162_0_1 -> 127 in the cache */
   /* replace1162_0 -> 980 in the cache */
   /* replace1162_1 -> 125 in the cache */
   /* replace1162 -> 3187 in the cache */

   /* ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1163_0 -> 267 in the cache */
   /* search1163_1_0 -> 3172 in the cache */
   /* search1163_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3172, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 267, 3231 },
      -1,
   } },

   /* replace1163_0_0 -> 124 in the cache */
   /* replace1163_0_1 -> 127 in the cache */
   /* replace1163_0 -> 3202 in the cache */
   /* replace1163_1 -> 125 in the cache */
   /* replace1163 -> 3203 in the cache */

   /* ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b')) */
   /* search1164_0 -> 267 in the cache */
   /* search1164_1_0_0 -> 3172 in the cache */
   /* search1164_1_0_1 -> 769 in the cache */
   /* search1164_1_0 -> 3231 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3231 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 267, 3233 },
      -1,
   } },

   /* replace1164_0_0 -> 124 in the cache */
   /* replace1164_0_1_0 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 124, 3235 },
      -1,
   } },
   /* replace1164_1_0 -> 125 in the cache */
   /* replace1164_1 -> 1145 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3236, 1145 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1165_0 -> 3224 in the cache */
   /* search1165_1_0 -> 3189 in the cache */
   /* search1165_1_1 -> 3206 in the cache */
   /* search1165_1_2 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 3189, 3206, 986 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3224, 3238 },
      -1,
   } },

   /* replace1165_0 -> 148 in the cache */
   /* replace1165_1 -> 150 in the cache */
   /* replace1165_2_0 -> 147 in the cache */
   /* replace1165_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 147, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 148, 150, 3240 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1166_0 -> 3224 in the cache */
   /* search1166_1_0_0 -> 3189 in the cache */
   /* search1166_1_0_1 -> 3206 in the cache */
   /* search1166_1_0_2 -> 986 in the cache */
   /* search1166_1_0 -> 3238 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3238 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3224, 3242 },
      -1,
   } },

   /* replace1166_0_0 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 148 },
      -1,
   } },
   /* replace1166_1 -> 150 in the cache */
   /* replace1166_2_0 -> 147 in the cache */
   /* replace1166_2_1_0 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 147, 3245 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3244, 150, 3246 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1167_0 -> 271 in the cache */
   /* search1167_1_0 -> 323 in the cache */
   /* search1167_1_1 -> 332 in the cache */
   /* search1167_1_2 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 323, 332, 296 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 271, 3248 },
      -1,
   } },

   /* replace1167_0 -> 36 in the cache */
   /* replace1167_1 -> 133 in the cache */
   /* replace1167_2_0 -> 16 in the cache */
   /* replace1167_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 36, 133, 3250 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1168_0 -> 271 in the cache */
   /* search1168_1_0_0 -> 323 in the cache */
   /* search1168_1_0_1 -> 332 in the cache */
   /* search1168_1_0_2 -> 296 in the cache */
   /* search1168_1_0 -> 3248 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3248 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 271, 3252 },
      -1,
   } },

   /* replace1168_0_0 -> 36 in the cache */
   /* replace1168_0 -> 581 in the cache */
   /* replace1168_1 -> 133 in the cache */
   /* replace1168_2_0 -> 16 in the cache */
   /* replace1168_2_1_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 3254 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 581, 133, 3255 },
      -1,
   } },

   /* ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1169_0 -> 267 in the cache */
   /* search1169_1_0 -> 3172 in the cache */
   /* search1169_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 3172, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 267, 3257 },
      -1,
   } },

   /* replace1169_0_0 -> 124 in the cache */
   /* replace1169_0_1 -> 127 in the cache */
   /* replace1169_0 -> 994 in the cache */
   /* replace1169_1 -> 125 in the cache */
   /* replace1169 -> 3217 in the cache */

   /* ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b') */
   /* search1170_0 -> 267 in the cache */
   /* search1170_1_0 -> 3172 in the cache */
   /* search1170_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3172, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 267, 3259 },
      -1,
   } },

   /* replace1170_0_0 -> 124 in the cache */
   /* replace1170_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1170_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3261, 125 },
      -1,
   } },

   /* ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b') */
   /* search1171_0 -> 267 in the cache */
   /* search1171_1_0 -> 3172 in the cache */
   /* search1171_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3172, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 267, 3263 },
      -1,
   } },

   /* replace1171_0_0 -> 124 in the cache */
   /* replace1171_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1171_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 3265, 125 },
      -1,
   } },

   /* ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b') */
   /* search1172_0 -> 267 in the cache */
   /* search1172_1_0 -> 3172 in the cache */
   /* search1172_1_1 -> 769 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 3172, 769 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 267, 3267 },
      -1,
   } },

   /* replace1172_0_0 -> 124 in the cache */
   /* replace1172_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 124, 127 },
      -1,
   } },
   /* replace1172_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 3269, 125 },
      -1,
   } },

   /* ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1173_0_1 -> 3199 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3271, 3199 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3272, 3273 },
      -1,
   } },

   /* replace1173_0_0 -> 124 in the cache */
   /* replace1173_0_1 -> 127 in the cache */
   /* replace1173_0 -> 3202 in the cache */
   /* replace1173_1 -> 125 in the cache */
   /* replace1173 -> 3203 in the cache */

   /* ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a */
   /* search1174_0_0 -> 0 in the cache */
   /* search1174_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      5,
   } },
   /* search1174_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 1,
      { 3275, 3 },
      -1,
   } },

   /* replace1174 -> 0 in the cache */

   /* ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1175_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1175_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3277, 120 },
      -1,
   } },
   /* search1175_1_0 -> 32 in the cache */
   /* search1175_1 -> 3277 in the cache */
   /* search1175_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3278, 3277, 122 },
      -1,
   } },

   /* replace1175_0 -> 32 in the cache */
   /* replace1175 -> 3277 in the cache */

   /* ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1176_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1176_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3280, 120 },
      -1,
   } },
   /* search1176_1_0 -> 16 in the cache */
   /* search1176_1 -> 3280 in the cache */
   /* search1176_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3281, 3280, 122 },
      -1,
   } },

   /* replace1176_0 -> 16 in the cache */
   /* replace1176 -> 3280 in the cache */

   /* ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1177_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1177_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3283, 120 },
      -1,
   } },
   /* search1177_1_0 -> 32 in the cache */
   /* search1177_1 -> 3283 in the cache */
   /* search1177_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3284, 3283, 122 },
      -1,
   } },

   /* replace1177_0 -> 32 in the cache */
   /* replace1177 -> 3283 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1178_0_0 -> 32 in the cache */
   /* search1178_0_1 -> 61 in the cache */
   /* search1178_0 -> 1181 in the cache */
   /* search1178_1_0 -> 32 in the cache */
   /* search1178_1 -> 3277 in the cache */
   /* search1178_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1181, 3277, 122 },
      -1,
   } },

   /* replace1178_0 -> 32 in the cache */
   /* replace1178 -> 3277 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1179_0_0 -> 16 in the cache */
   /* search1179_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 120 },
      -1,
   } },
   /* search1179_1_0 -> 16 in the cache */
   /* search1179_1 -> 3280 in the cache */
   /* search1179_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3287, 3280, 122 },
      -1,
   } },

   /* replace1179_0 -> 16 in the cache */
   /* replace1179 -> 3280 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1180_0_0 -> 32 in the cache */
   /* search1180_0_1 -> 61 in the cache */
   /* search1180_0 -> 1181 in the cache */
   /* search1180_1_0 -> 32 in the cache */
   /* search1180_1 -> 3283 in the cache */
   /* search1180_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1181, 3283, 122 },
      -1,
   } },

   /* replace1180_0 -> 32 in the cache */
   /* replace1180 -> 3283 in the cache */

   /* ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1181_0_0 -> 16 in the cache */
   /* search1181_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 122 },
      -1,
   } },
   /* search1181_1_0 -> 16 in the cache */
   /* search1181_1 -> 3280 in the cache */
   /* search1181_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3290, 3280, 122 },
      -1,
   } },

   /* replace1181_0 -> 16 in the cache */
   /* replace1181 -> 3280 in the cache */

   /* ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1182_0_0 -> 502 in the cache */
   /* search1182_0_1 -> 260 in the cache */
   /* search1182_0_2 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 260, 255 },
      0,
   } },
   /* search1182_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3292, 3 },
      -1,
   } },

   /* replace1182_0 -> 502 in the cache */
   /* replace1182_1_0 -> 3 in the cache */
   /* replace1182_1 -> 1042 in the cache */
   /* replace1182_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 1042, 3 },
      -1,
   } },

   /* ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1183_0_0 -> 502 in the cache */
   /* search1183_0_1 -> 255 in the cache */
   /* search1183_0_2 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 255, 260 },
      0,
   } },
   /* search1183_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3295, 3 },
      -1,
   } },

   /* replace1183_0 -> 502 in the cache */
   /* replace1183_1 -> 3 in the cache */
   /* replace1183_2_0 -> 3 in the cache */
   /* replace1183_2 -> 1042 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 3, 1042 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1184_0_0 -> 502 in the cache */
   /* search1184_0_1 -> 263 in the cache */
   /* search1184_0_2 -> 228 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 263, 228 },
      0,
   } },
   /* search1184_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 3298, 36 },
      -1,
   } },

   /* replace1184_0 -> 502 in the cache */
   /* replace1184_1_0 -> 36 in the cache */
   /* replace1184_1 -> 581 in the cache */
   /* replace1184_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 581, 36 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1185_0_0 -> 502 in the cache */
   /* search1185_0_1 -> 228 in the cache */
   /* search1185_0_2 -> 263 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 228, 263 },
      0,
   } },
   /* search1185_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 3301, 36 },
      -1,
   } },

   /* replace1185_0 -> 502 in the cache */
   /* replace1185_1 -> 36 in the cache */
   /* replace1185_2_0 -> 36 in the cache */
   /* replace1185_2 -> 581 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 36, 581 },
      -1,
   } },

   /* ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a') */
   /* search1186_0_0 -> 32 in the cache */
   /* search1186_0_1 -> 113 in the cache */
   /* search1186_0 -> 670 in the cache */
   /* search1186_1_0 -> 32 in the cache */
   /* search1186_1 -> 98 in the cache */
   /* search1186_2 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 670, 98, 32 },
      -1,
   } },

   /* replace1186_0 -> 32 in the cache */
   /* replace1186 -> 103 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd') */
   /* search1187_0 -> 715 in the cache */
   /* search1187_1_0 -> 1083 in the cache */
   /* search1187_1_1 -> 150 in the cache */
   /* search1187_1_2 -> 151 in the cache */
   /* search1187_1 -> 1255 in the cache */
   /* search1187_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 1255, 151 },
      -1,
   } },

   /* replace1187_0_0 -> 715 in the cache */
   /* replace1187_0_1 -> 1083 in the cache */
   /* replace1187_0 -> 1095 in the cache */
   /* replace1187_1 -> 150 in the cache */
   /* replace1187_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1095, 150, 151 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd') */
   /* search1188_0 -> 715 in the cache */
   /* search1188_1 -> 148 in the cache */
   /* search1188_2_0 -> 445 in the cache */
   /* search1188_2_1 -> 148 in the cache */
   /* search1188_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 445, 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 148, 3307 },
      -1,
   } },

   /* replace1188_0_0 -> 715 in the cache */
   /* replace1188_0_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 715, 445 },
      -1,
   } },
   /* replace1188_1 -> 148 in the cache */
   /* replace1188_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3309, 148, 151 },
      -1,
   } },

   /* ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b')))) */
   /* search1189_0 -> 0 in the cache */
   /* search1189_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1189_0 -> 0 in the cache */
   /* replace1189_1_0 -> 3 in the cache */
   /* replace1189_1_1_0_0 -> 0 in the cache */
   /* replace1189_1_1_0_1 -> 3 in the cache */
   /* replace1189_1_1_0 -> 2579 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 2579 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 3312 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 3313 },
      -1,
   } },

   /* ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b')))) */
   /* search1190_0 -> 0 in the cache */
   /* search1190_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1190_0 -> 0 in the cache */
   /* replace1190_1_0 -> 3 in the cache */
   /* replace1190_1_1_0_0 -> 0 in the cache */
   /* replace1190_1_1_0_1 -> 3 in the cache */
   /* replace1190_1_1_0 -> 2579 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 2579 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 3316 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 3317 },
      -1,
   } },

   /* ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a')) */
   /* search1191_0 -> 0 in the cache */
   /* search1191_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uadd_carry,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1191_0_0_0 -> 0 in the cache */
   /* replace1191_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1191_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3320, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 3321 },
      -1,
   } },

   /* ('usub_borrow', 'a', 'b') => ('b2i', ('ult', 'a', 'b')) */
   /* search1192_0 -> 0 in the cache */
   /* search1192_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1192_0_0 -> 0 in the cache */
   /* replace1192_0_1 -> 3 in the cache */
   /* replace1192_0 -> 1022 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1022 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* base */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* insert */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_insert,
      -1, 0,
      { 3325, 3326, 3327, 3328 },
      -1,
   } },

   /* replace1193_0_0 -> 19 in the cache */
   /* replace1193_0_1 -> 3328 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 3328 },
      -1,
   } },
   /* replace1193_1 -> 3326 in the cache */
   /* replace1193_2_0_0 -> 3328 in the cache */
   /* replace1193_2_0_1 -> 3327 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3328, 3327 },
      -1,
   } },
   /* replace1193_2_1 -> 3326 in the cache */
   /* replace1193_2_2 -> 3325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 3331, 3326, 3325 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3330, 3326, 3332 },
      -1,
   } },

   /* ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1194_0 -> 0 in the cache */
   /* search1194_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1194_0_0 -> 0 in the cache */
   /* replace1194_0_1 -> 3 in the cache */
   /* replace1194_0 -> 2467 in the cache */
   /* replace1194_1_0_0 -> 0 in the cache */
   /* replace1194_1_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1194_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3335, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 2467, 3336 },
      -1,
   } },

   /* ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1195_0 -> 0 in the cache */
   /* search1195_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1195_0_0 -> 0 in the cache */
   /* replace1195_0_1 -> 3 in the cache */
   /* replace1195_0 -> 2467 in the cache */
   /* replace1195_1_0_0 -> 0 in the cache */
   /* replace1195_1_0_1 -> 3 in the cache */
   /* replace1195_1_0 -> 3335 in the cache */
   /* replace1195_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3335, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 2467, 3339 },
      -1,
   } },

   /* ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1196_0 -> 0 in the cache */
   /* search1196_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1196_0_0 -> 0 in the cache */
   /* replace1196_0_1 -> 3 in the cache */
   /* replace1196_0 -> 2236 in the cache */
   /* replace1196_1_0_0 -> 0 in the cache */
   /* replace1196_1_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1196_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3342, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2236, 3343 },
      -1,
   } },

   /* ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1197_0 -> 0 in the cache */
   /* search1197_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1197_0_0 -> 0 in the cache */
   /* replace1197_0_1 -> 3 in the cache */
   /* replace1197_0 -> 2236 in the cache */
   /* replace1197_1_0_0 -> 0 in the cache */
   /* replace1197_1_0_1 -> 3 in the cache */
   /* replace1197_1_0 -> 3342 in the cache */
   /* replace1197_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3342, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2236, 3346 },
      -1,
   } },

   /* ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1198_0 -> 21 in the cache */
   /* search1198_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1198_0_0 -> 21 in the cache */
   /* replace1198_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1198_1_0_0 -> 21 in the cache */
   /* replace1198_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1198_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3350, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 3349, 3351 },
      -1,
   } },

   /* ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1199_0 -> 21 in the cache */
   /* search1199_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1199_0_0 -> 21 in the cache */
   /* replace1199_0_1 -> 41 in the cache */
   /* replace1199_0 -> 3349 in the cache */
   /* replace1199_1_0_0 -> 21 in the cache */
   /* replace1199_1_0_1 -> 41 in the cache */
   /* replace1199_1_0 -> 3350 in the cache */
   /* replace1199_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3350, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 3349, 3354 },
      -1,
   } },

   /* ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1200_0 -> 21 in the cache */
   /* search1200_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1200_0_0 -> 21 in the cache */
   /* replace1200_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1200_1_0_0 -> 21 in the cache */
   /* replace1200_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1200_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3358, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 3357, 3359 },
      -1,
   } },

   /* ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1201_0 -> 21 in the cache */
   /* search1201_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1201_0_0 -> 21 in the cache */
   /* replace1201_0_1 -> 41 in the cache */
   /* replace1201_0 -> 3357 in the cache */
   /* replace1201_1_0_0 -> 21 in the cache */
   /* replace1201_1_0_1 -> 41 in the cache */
   /* replace1201_1_0 -> 3358 in the cache */
   /* replace1201_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3358, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 3357, 3362 },
      -1,
   } },

   /* ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1202_0 -> 21 in the cache */
   /* search1202_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1202_0_0_0 -> 21 in the cache */
   /* replace1202_0_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1202_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3365, 21 },
      -1,
   } },
   /* replace1202_1 -> 1436 in the cache */
   /* replace1202_2_0 -> 21 in the cache */
   /* replace1202_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3366, 1436, 3367 },
      -1,
   } },

   /* ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1203_0 -> 0 in the cache */
   /* search1203_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1203_0_0_0 -> 0 in the cache */
   /* replace1203_0_0_1 -> 3 in the cache */
   /* replace1203_0_0 -> 3320 in the cache */
   /* replace1203_0_1 -> 0 in the cache */
   /* replace1203_0 -> 3321 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* replace1203_2_0 -> 0 in the cache */
   /* replace1203_2_1 -> 3 in the cache */
   /* replace1203_2 -> 193 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3321, 3370, 193 },
      -1,
   } },

   /* ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1204_0 -> 0 in the cache */
   /* search1204_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1204_0_0 -> 0 in the cache */
   /* replace1204_0_1 -> 3 in the cache */
   /* replace1204_0 -> 1022 in the cache */
   /* replace1204_1 -> 86 in the cache */
   /* replace1204_2_0 -> 0 in the cache */
   /* replace1204_2_1 -> 3 in the cache */
   /* replace1204_2 -> 3154 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1022, 86, 3154 },
      -1,
   } },

   /* ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1205_0 -> 21 in the cache */
   /* search1205_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1205_0_0 -> 21 in the cache */
   /* replace1205_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   /* replace1205_1 -> 852 in the cache */
   /* replace1205_2_0 -> 21 in the cache */
   /* replace1205_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3375, 852, 3376 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807)) */
   /* search1206_0 -> 21 in the cache */
   /* search1206_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1206_0_0_0_0 -> 21 in the cache */
   /* replace1206_0_0_0_1 -> 852 in the cache */
   /* replace1206_0_0_0 -> 1426 in the cache */
   /* replace1206_0_0_1_0 -> 41 in the cache */
   /* replace1206_0_0_1_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 41, 852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1426, 3379 },
      -1,
   } },
   /* replace1206_0_1_0_0 -> 21 in the cache */
   /* replace1206_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1206_0_1_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3381, 852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3380, 3382 },
      -1,
   } },
   /* replace1206_1 -> 22 in the cache */
   /* replace1206_2_0_0_0_0 -> 21 in the cache */
   /* replace1206_2_0_0_0_1 -> 852 in the cache */
   /* replace1206_2_0_0_0 -> 1426 in the cache */
   /* replace1206_2_0_0_1_0 -> 41 in the cache */
   /* replace1206_2_0_0_1_1 -> 852 in the cache */
   /* replace1206_2_0_0_1 -> 3379 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      4, 1,
      { 1426, 3379 },
      -1,
   } },
   /* replace1206_2_0_1_0_0 -> 21 in the cache */
   /* replace1206_2_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1206_2_0_1_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3385, 852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      3, 3,
      { 3384, 3386 },
      -1,
   } },
   /* replace1206_2_1_0 -> 21 in the cache */
   /* replace1206_2_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      6, 1,
      { 21, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffffffffffff /* 9223372036854775807 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3387, 3388, 3389 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 7,
      { 3383, 22, 3390 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807)) */
   /* search1207_0 -> 21 in the cache */
   /* search1207_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1207_0_0_0_0 -> 21 in the cache */
   /* replace1207_0_0_0_1 -> 852 in the cache */
   /* replace1207_0_0_0 -> 1426 in the cache */
   /* replace1207_0_0_1_0 -> 41 in the cache */
   /* replace1207_0_0_1_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 41, 852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1426, 3393 },
      -1,
   } },
   /* replace1207_0_1_0_0 -> 21 in the cache */
   /* replace1207_0_1_0_1 -> 41 in the cache */
   /* replace1207_0_1_0 -> 3376 in the cache */
   /* replace1207_0_1_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3376, 852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3394, 3395 },
      -1,
   } },
   /* replace1207_1 -> 22 in the cache */
   /* replace1207_2_0_0_0_0 -> 21 in the cache */
   /* replace1207_2_0_0_0_1 -> 852 in the cache */
   /* replace1207_2_0_0_0 -> 1426 in the cache */
   /* replace1207_2_0_0_1_0 -> 41 in the cache */
   /* replace1207_2_0_0_1_1 -> 852 in the cache */
   /* replace1207_2_0_0_1 -> 3393 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      3, 1,
      { 1426, 3393 },
      -1,
   } },
   /* replace1207_2_0_1_0_0 -> 21 in the cache */
   /* replace1207_2_0_1_0_1 -> 41 in the cache */
   /* replace1207_2_0_1_0 -> 3376 in the cache */
   /* replace1207_2_0_1_1 -> 852 in the cache */
   /* replace1207_2_0_1 -> 3395 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 3397, 3395 },
      -1,
   } },
   /* replace1207_2_1_0 -> 21 in the cache */
   /* replace1207_2_1_1 -> 41 in the cache */
   /* replace1207_2_1 -> 3376 in the cache */
   /* replace1207_2_2 -> 3389 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3398, 3376, 3389 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3396, 22, 3399 },
      -1,
   } },

   /* ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1208_0_0 -> 21 in the cache */
   /* search1208_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1208_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3401, 852 },
      -1,
   } },

   /* replace1208_0_0_0 -> 21 in the cache */
   /* replace1208_0_0 -> 2911 in the cache */
   /* replace1208_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2911, 3403 },
      -1,
   } },
   /* replace1208_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3404, 120 },
      -1,
   } },

   /* ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1209_0_0 -> 21 in the cache */
   /* search1209_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1209_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3406, 852 },
      -1,
   } },

   /* replace1209_0_0_0 -> 21 in the cache */
   /* replace1209_0_0 -> 2911 in the cache */
   /* replace1209_0_1_0 -> 41 in the cache */
   /* replace1209_0_1 -> 3403 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2911, 3403 },
      -1,
   } },
   /* replace1209_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3408, 120 },
      -1,
   } },

   /* ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1210_0_0 -> 21 in the cache */
   /* search1210_0_1 -> 41 in the cache */
   /* search1210_0 -> 3401 in the cache */
   /* search1210_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3401, 852 },
      -1,
   } },

   /* replace1210_0_0_0 -> 21 in the cache */
   /* replace1210_0_0 -> 2911 in the cache */
   /* replace1210_0_1_0 -> 41 in the cache */
   /* replace1210_0_1 -> 3403 in the cache */
   /* replace1210_0 -> 3404 in the cache */
   /* replace1210_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3404, 120 },
      -1,
   } },

   /* ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1211_0_0 -> 21 in the cache */
   /* search1211_0_1 -> 41 in the cache */
   /* search1211_0 -> 3406 in the cache */
   /* search1211_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3406, 852 },
      -1,
   } },

   /* replace1211_0_0_0 -> 21 in the cache */
   /* replace1211_0_0 -> 2911 in the cache */
   /* replace1211_0_1_0 -> 41 in the cache */
   /* replace1211_0_1 -> 3403 in the cache */
   /* replace1211_0 -> 3408 in the cache */
   /* replace1211_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3408, 120 },
      -1,
   } },

   /* ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1212_0 -> 21 in the cache */
   /* search1212_1 -> 852 in the cache */
   /* search1212 -> 1426 in the cache */

   /* replace1212_0_0 -> 21 in the cache */
   /* replace1212_0 -> 2911 in the cache */
   /* replace1212_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2911, 120 },
      -1,
   } },

   /* ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1213_0 -> 21 in the cache */
   /* search1213_1 -> 852 in the cache */
   /* search1213 -> 1423 in the cache */

   /* replace1213_0_0 -> 21 in the cache */
   /* replace1213_0 -> 2911 in the cache */
   /* replace1213_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2911, 120 },
      -1,
   } },

   /* ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1214_0 -> 21 in the cache */
   /* search1214_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 21, 852 },
      -1,
   } },

   /* replace1214_0_0_0 -> 21 in the cache */
   /* replace1214_0_0 -> 2910 in the cache */
   /* replace1214_0_1_0 -> 21 in the cache */
   /* replace1214_0_1 -> 2911 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 2910, 2911 },
      -1,
   } },
   /* replace1214_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3417, 120 },
      -1,
   } },

   /* ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1215_0 -> 21 in the cache */
   /* search1215_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 21, 852 },
      -1,
   } },

   /* replace1215_0_0_0 -> 21 in the cache */
   /* replace1215_0_0 -> 2910 in the cache */
   /* replace1215_0_1_0 -> 21 in the cache */
   /* replace1215_0_1 -> 2911 in the cache */
   /* replace1215_0 -> 3417 in the cache */
   /* replace1215_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3417, 120 },
      -1,
   } },

   /* ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1216_0 -> 852 in the cache */
   /* search1216_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 852, 21 },
      -1,
   } },

   /* replace1216_0_0_0 -> 21 in the cache */
   /* replace1216_0_0 -> 2910 in the cache */
   /* replace1216_0_1_0 -> 21 in the cache */
   /* replace1216_0_1 -> 2911 in the cache */
   /* replace1216_0 -> 3417 in the cache */
   /* replace1216_1 -> 120 in the cache */
   /* replace1216 -> 3418 in the cache */

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset')))) */
   /* search1217_0 -> 3325 in the cache */
   /* search1217_1 -> 3326 in the cache */
   /* search1217_2 -> 3327 in the cache */
   /* search1217_3 -> 3328 in the cache */
   /* search1217 -> 3329 in the cache */

   /* replace1217_0_0 -> 19 in the cache */
   /* replace1217_0_1 -> 3328 in the cache */
   /* replace1217_0 -> 3330 in the cache */
   /* replace1217_1 -> 3326 in the cache */
   /* replace1217_2_0_0 -> 3325 in the cache */
   /* replace1217_2_0_1_0_0_0_0 -> 377 in the cache */
   /* replace1217_2_0_1_0_0_0_1 -> 3328 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 377, 3328 },
      -1,
   } },
   /* replace1217_2_0_1_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3422, 377 },
      -1,
   } },
   /* replace1217_2_0_1_0_1 -> 3327 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3423, 3327 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3424 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3325, 3425 },
      -1,
   } },
   /* replace1217_2_1_0_0 -> 3326 in the cache */
   /* replace1217_2_1_0_1 -> 3327 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3326, 3327 },
      -1,
   } },
   /* replace1217_2_1_1_0_0_0 -> 377 in the cache */
   /* replace1217_2_1_1_0_0_1 -> 3328 in the cache */
   /* replace1217_2_1_1_0_0 -> 3422 in the cache */
   /* replace1217_2_1_1_0_1 -> 377 in the cache */
   /* replace1217_2_1_1_0 -> 3423 in the cache */
   /* replace1217_2_1_1_1 -> 3327 in the cache */
   /* replace1217_2_1_1 -> 3424 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 3427, 3424 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3426, 3428 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 3330, 3326, 3429 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base')) */
   /* search1218_0 -> 3325 in the cache */
   /* search1218_1 -> 3326 in the cache */
   /* search1218_2 -> 3327 in the cache */
   /* search1218_3 -> 3328 in the cache */
   /* search1218 -> 3329 in the cache */

   /* replace1218_0_0 -> 19 in the cache */
   /* replace1218_0_1 -> 3328 in the cache */
   /* replace1218_0 -> 3330 in the cache */
   /* replace1218_1 -> 3326 in the cache */
   /* replace1218_2_0_0 -> 3328 in the cache */
   /* replace1218_2_0_1 -> 3327 in the cache */
   /* replace1218_2_0 -> 3331 in the cache */
   /* replace1218_2_1_0 -> 3326 in the cache */
   /* replace1218_2_1_1 -> 3327 in the cache */
   /* replace1218_2_1 -> 3427 in the cache */
   /* replace1218_2_2 -> 3325 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 3331, 3427, 3325 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3330, 3326, 3431 },
      -1,
   } },

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibitfield_extract,
      -1, 0,
      { 3433, 3434, 3435 },
      -1,
   } },

   /* replace1219_0_0 -> 19 in the cache */
   /* replace1219_0_1 -> 3435 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 3435 },
      -1,
   } },
   /* replace1219_1 -> 3433 in the cache */
   /* replace1219_2_0 -> 3433 in the cache */
   /* replace1219_2_1 -> 3434 in the cache */
   /* replace1219_2_2 -> 3435 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 3433, 3434, 3435 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3437, 3433, 3438 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits')) */
   /* search1220_0 -> 3433 in the cache */
   /* search1220_1 -> 3434 in the cache */
   /* search1220_2 -> 3435 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubitfield_extract,
      -1, 0,
      { 3433, 3434, 3435 },
      -1,
   } },

   /* replace1220_0_0 -> 19 in the cache */
   /* replace1220_0_1 -> 3435 in the cache */
   /* replace1220_0 -> 3437 in the cache */
   /* replace1220_1 -> 3433 in the cache */
   /* replace1220_2_0 -> 3433 in the cache */
   /* replace1220_2_1 -> 3434 in the cache */
   /* replace1220_2_2 -> 3435 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 3433, 3434, 3435 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3437, 3433, 3441 },
      -1,
   } },

   /* ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b') */
   /* search1221_0 -> 0 in the cache */
   /* search1221_1 -> 3 in the cache */
   /* search1221_2 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 0, 3, 86 },
      -1,
   } },

   /* replace1221_0 -> 0 in the cache */
   /* replace1221_1 -> 3 in the cache */
   /* replace1221 -> 2472 in the cache */

   /* ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c') */
   /* search1222_0 -> 124 in the cache */
   /* search1222_1_0 -> 124 in the cache */
   /* search1222_1_1 -> 125 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 124, 125 },
      -1,
   } },
   /* search1222_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 1,
      { 124, 3444, 127 },
      -1,
   } },

   /* replace1222_0 -> 124 in the cache */
   /* replace1222_1 -> 125 in the cache */
   /* replace1222_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 124, 125, 127 },
      -1,
   } },

   /* ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits') */
   /* search1223_0 -> 3433 in the cache */
   /* search1223_1 -> 3434 in the cache */
   /* search1223_2_0 -> 19 in the cache */
   /* search1223_2_1 -> 3435 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3435 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 3433, 3434, 3447 },
      -1,
   } },

   /* replace1223_0 -> 3433 in the cache */
   /* replace1223_1 -> 3434 in the cache */
   /* replace1223_2 -> 3435 in the cache */
   /* replace1223 -> 3441 in the cache */

   /* ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits') */
   /* search1224_0 -> 3433 in the cache */
   /* search1224_1_0 -> 19 in the cache */
   /* search1224_1_1 -> 3434 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3434 },
      -1,
   } },
   /* search1224_2 -> 3435 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 3433, 3449, 3435 },
      -1,
   } },

   /* replace1224_0 -> 3433 in the cache */
   /* replace1224_1 -> 3434 in the cache */
   /* replace1224_2 -> 3435 in the cache */
   /* replace1224 -> 3441 in the cache */

   /* ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits') */
   /* search1225_0 -> 3433 in the cache */
   /* search1225_1 -> 3434 in the cache */
   /* search1225_2_0 -> 19 in the cache */
   /* search1225_2_1 -> 3435 in the cache */
   /* search1225_2 -> 3447 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 3433, 3434, 3447 },
      -1,
   } },

   /* replace1225_0 -> 3433 in the cache */
   /* replace1225_1 -> 3434 in the cache */
   /* replace1225_2 -> 3435 in the cache */
   /* replace1225 -> 3438 in the cache */

   /* ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits') */
   /* search1226_0 -> 3433 in the cache */
   /* search1226_1_0 -> 19 in the cache */
   /* search1226_1_1 -> 3434 in the cache */
   /* search1226_1 -> 3449 in the cache */
   /* search1226_2 -> 3435 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 3433, 3449, 3435 },
      -1,
   } },

   /* replace1226_0 -> 3433 in the cache */
   /* replace1226_1 -> 3434 in the cache */
   /* replace1226_2 -> 3435 in the cache */
   /* replace1226 -> 3438 in the cache */

   /* ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1227_1_0 -> 19 in the cache */
   /* search1227_1_1 -> 3434 in the cache */
   /* search1227_1 -> 3449 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 3453, 3449 },
      -1,
   } },

   /* replace1227_0 -> 3453 in the cache */
   /* replace1227_1 -> 3434 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3453, 3434 },
      -1,
   } },

   /* ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset') */
   /* search1228_0_0 -> 19 in the cache */
   /* search1228_0_1 -> 3453 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3453 },
      -1,
   } },
   /* search1228_1 -> 3434 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 3456, 3434 },
      -1,
   } },

   /* replace1228_0 -> 3453 in the cache */
   /* replace1228_1 -> 3434 in the cache */
   /* replace1228 -> 3455 in the cache */

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search1229_0 -> 16 in the cache */
   /* search1229_1 -> 36 in the cache */
   /* search1229_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 120 },
      -1,
   } },

   /* replace1229 -> 120 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search1230_0 -> 16 in the cache */
   /* search1230_1 -> 36 in the cache */
   /* search1230_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 120 },
      -1,
   } },

   /* replace1230 -> 120 in the cache */

   /* ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b'))) */
   /* search1231_0 -> 16 in the cache */
   /* search1231_1 -> 120 in the cache */
   /* search1231_2 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 120, 33 },
      -1,
   } },

   /* replace1231_0 -> 16 in the cache */
   /* replace1231_1_0 -> 882 in the cache */
   /* replace1231_1_1_0 -> 36 in the cache */
   /* replace1231_1_1 -> 2485 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 882, 2485 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 3461 },
      -1,
   } },

   /* ('b2i32', ('i2b', ('ubfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1) */
   /* search1232_0_0_0 -> 16 in the cache */
   /* search1232_0_0_1 -> 36 in the cache */
   /* search1232_0_0_2 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 3463 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 3464 },
      -1,
   } },

   /* replace1232_0 -> 16 in the cache */
   /* replace1232_1 -> 36 in the cache */
   /* replace1232_2 -> 377 in the cache */
   /* replace1232 -> 3463 in the cache */

   /* ('b2i32', ('i2b', ('ibfe', 'a', 'b', 1))) => ('ubfe', 'a', 'b', 1) */
   /* search1233_0_0_0 -> 16 in the cache */
   /* search1233_0_0_1 -> 36 in the cache */
   /* search1233_0_0_2 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2b,
      -1, 0,
      { 3466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 3467 },
      -1,
   } },

   /* replace1233_0 -> 16 in the cache */
   /* replace1233_1 -> 36 in the cache */
   /* replace1233_2 -> 377 in the cache */
   /* replace1233 -> 3463 in the cache */

   /* ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1234_0_0 -> 16 in the cache */
   /* search1234_0_1 -> 33 in the cache */
   /* search1234_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 33, 294 },
      0,
   } },
   /* search1234_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3469, 120 },
      -1,
   } },

   /* replace1234_0_0 -> 16 in the cache */
   /* replace1234_0_1_0_0 -> 882 in the cache */
   /* replace1234_0_1_0_1_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 882, 3471 },
      -1,
   } },
   /* replace1234_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3472, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 3473 },
      -1,
   } },
   /* replace1234_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3474, 120 },
      -1,
   } },

   /* ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1235_0_0 -> 16 in the cache */
   /* search1235_0_1 -> 33 in the cache */
   /* search1235_0_2 -> 294 in the cache */
   /* search1235_0 -> 3469 in the cache */
   /* search1235_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3469, 120 },
      -1,
   } },

   /* replace1235_0_0 -> 16 in the cache */
   /* replace1235_0_1_0_0 -> 882 in the cache */
   /* replace1235_0_1_0_1_0 -> 133 in the cache */
   /* replace1235_0_1_0_1 -> 3471 in the cache */
   /* replace1235_0_1_0 -> 3472 in the cache */
   /* replace1235_0_1_1 -> 36 in the cache */
   /* replace1235_0_1 -> 3473 in the cache */
   /* replace1235_0 -> 3474 in the cache */
   /* replace1235_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3474, 120 },
      -1,
   } },

   /* ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1236_0_0 -> 16 in the cache */
   /* search1236_0_1 -> 33 in the cache */
   /* search1236_0_2 -> 294 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 33, 294 },
      0,
   } },
   /* search1236_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3478, 120 },
      -1,
   } },

   /* replace1236_0_0 -> 16 in the cache */
   /* replace1236_0_1_0_0 -> 882 in the cache */
   /* replace1236_0_1_0_1_0 -> 133 in the cache */
   /* replace1236_0_1_0_1 -> 3471 in the cache */
   /* replace1236_0_1_0 -> 3472 in the cache */
   /* replace1236_0_1_1 -> 36 in the cache */
   /* replace1236_0_1 -> 3473 in the cache */
   /* replace1236_0 -> 3474 in the cache */
   /* replace1236_1 -> 120 in the cache */
   /* replace1236 -> 3475 in the cache */

   /* ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1237_0_0 -> 16 in the cache */
   /* search1237_0_1 -> 33 in the cache */
   /* search1237_0_2 -> 294 in the cache */
   /* search1237_0 -> 3478 in the cache */
   /* search1237_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3478, 120 },
      -1,
   } },

   /* replace1237_0_0 -> 16 in the cache */
   /* replace1237_0_1_0_0 -> 882 in the cache */
   /* replace1237_0_1_0_1_0 -> 133 in the cache */
   /* replace1237_0_1_0_1 -> 3471 in the cache */
   /* replace1237_0_1_0 -> 3472 in the cache */
   /* replace1237_0_1_1 -> 36 in the cache */
   /* replace1237_0_1 -> 3473 in the cache */
   /* replace1237_0 -> 3474 in the cache */
   /* replace1237_1 -> 120 in the cache */
   /* replace1237 -> 3477 in the cache */

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits'))) */
   /* search1238_0 -> 3433 in the cache */
   /* search1238_1 -> 3434 in the cache */
   /* search1238_2 -> 3435 in the cache */
   /* search1238 -> 3436 in the cache */

   /* replace1238_0_0 -> 120 in the cache */
   /* replace1238_0_1 -> 3435 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 120, 3435 },
      -1,
   } },
   /* replace1238_1 -> 120 in the cache */
   /* replace1238_2_0_0 -> 3433 in the cache */
   /* replace1238_2_0_1_0_0 -> 829 in the cache */
   /* replace1238_2_0_1_0_1 -> 3435 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 829, 3435 },
      -1,
   } },
   /* replace1238_2_0_1_1 -> 3434 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3482, 3434 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3433, 3483 },
      -1,
   } },
   /* replace1238_2_1_0 -> 829 in the cache */
   /* replace1238_2_1_1 -> 3435 in the cache */
   /* replace1238_2_1 -> 3482 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 3484, 3482 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3481, 120, 3485 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1))) */
   /* search1239_0 -> 3433 in the cache */
   /* search1239_1 -> 3434 in the cache */
   /* search1239_2 -> 3435 in the cache */
   /* search1239 -> 3440 in the cache */

   /* replace1239_0_0 -> 3433 in the cache */
   /* replace1239_0_1 -> 3434 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3433, 3434 },
      -1,
   } },
   /* replace1239_1_0_0 -> 3435 in the cache */
   /* replace1239_1_0_1 -> 829 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 3435, 829 },
      -1,
   } },
   /* replace1239_1_1 -> 882 in the cache */
   /* replace1239_1_2_0_0 -> 377 in the cache */
   /* replace1239_1_2_0_1 -> 3435 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 377, 3435 },
      -1,
   } },
   /* replace1239_1_2_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3489, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3488, 882, 3490 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3487, 3491 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value')) */
   /* search1240_0 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 3433 },
      -1,
   } },

   /* replace1240_0_0_0 -> 3433 in the cache */
   /* replace1240_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3433, 120 },
      -1,
   } },
   /* replace1240_0_1_0 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3433 },
      -1,
   } },
   /* replace1240_0_2 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3494, 3495, 3433 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 3496 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value')) */
   /* search1241_0 -> 3433 in the cache */
   /* search1241 -> 3493 in the cache */

   /* replace1241_0_0_0 -> 3433 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 3433 },
      -1,
   } },
   /* replace1241_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3498, 120 },
      -1,
   } },
   /* replace1241_1_0 -> 19 in the cache */
   /* replace1241_1_1_0 -> 3433 in the cache */
   /* replace1241_1_1 -> 3498 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 3498 },
      -1,
   } },
   /* replace1241_2_0 -> 3433 in the cache */
   /* replace1241_2 -> 3498 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3499, 3500, 3498 },
      -1,
   } },

   /* ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 3502 },
      -1,
   } },

   /* replace1242_0_0_0 -> 3502 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 3502 },
      -1,
   } },
   /* replace1242_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3504, 120 },
      -1,
   } },
   /* replace1242_1_0 -> 19 in the cache */
   /* replace1242_1_1_0 -> 3502 in the cache */
   /* replace1242_1_1 -> 3504 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 3504 },
      -1,
   } },
   /* replace1242_2_0 -> 3502 in the cache */
   /* replace1242_2 -> 3504 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3505, 3506, 3504 },
      -1,
   } },

   /* ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value'))) */
   /* search1243_0 -> 3502 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3502 },
      -1,
   } },

   /* replace1243_0_0 -> 3502 in the cache */
   /* replace1243_0_1_0 -> 3502 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3502 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3502, 3509 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 1,
      { 3510 },
      -1,
   } },

   /* ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24) */
   /* search1244_0 -> 16 in the cache */
   /* search1244_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1244_0_0 -> 16 in the cache */
   /* replace1244_0_1_0_0 -> 386 in the cache */
   /* replace1244_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 386, 36 },
      -1,
   } },
   /* replace1244_0_1_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3513, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 3514 },
      -1,
   } },
   /* replace1244_1 -> 967 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3515, 967 },
      -1,
   } },

   /* ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255) */
   /* search1245_0 -> 16 in the cache */
   /* search1245_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1245_0_0 -> 16 in the cache */
   /* replace1245_0_1_0 -> 36 in the cache */
   /* replace1245_0_1_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 36, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 3518 },
      -1,
   } },
   /* replace1245_1 -> 965 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3519, 965 },
      -1,
   } },

   /* ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16) */
   /* search1246_0 -> 16 in the cache */
   /* search1246_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1246_0_0 -> 16 in the cache */
   /* replace1246_0_1_0_0 -> 377 in the cache */
   /* replace1246_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 377, 36 },
      -1,
   } },
   /* replace1246_0_1_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3522, 808 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 3523 },
      -1,
   } },
   /* replace1246_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3524, 808 },
      -1,
   } },

   /* ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535) */
   /* search1247_0 -> 16 in the cache */
   /* search1247_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1247_0_0 -> 16 in the cache */
   /* replace1247_0_1_0 -> 36 in the cache */
   /* replace1247_0_1_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 36, 808 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 3527 },
      -1,
   } },
   /* replace1247_1 -> 957 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3528, 957 },
      -1,
   } },

   /* ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0)))) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* v */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_unorm_2x16,
      -1, 0,
      { 3530 },
      -1,
   } },

   /* replace1248_0_0_0_0_0 -> 3530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 3530 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40efffe000000000 /* 65535.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3532, 3533 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 3534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 3535 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 1,
      { 3536 },
      -1,
   } },

   /* ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0)))) */
   /* search1249_0 -> 3530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_unorm_4x8,
      -1, 0,
      { 3530 },
      -1,
   } },

   /* replace1249_0_0_0_0_0 -> 3530 in the cache */
   /* replace1249_0_0_0_0 -> 3532 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x406fe00000000000 /* 255.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3532, 3539 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 3540 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 3541 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 1,
      { 3542 },
      -1,
   } },

   /* ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0)))) */
   /* search1250_0 -> 3530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_snorm_2x16,
      -1, 0,
      { 3530 },
      -1,
   } },

   /* replace1250_0_0_0_0_0 -> 228 in the cache */
   /* replace1250_0_0_0_0_1_0 -> 263 in the cache */
   /* replace1250_0_0_0_0_1_1 -> 3530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 263, 3530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 228, 3545 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40dfffc000000000 /* 32767.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 3546, 3547 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 3548 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 3549 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 3,
      { 3550 },
      -1,
   } },

   /* ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0)))) */
   /* search1251_0 -> 3530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_snorm_4x8,
      -1, 0,
      { 3530 },
      -1,
   } },

   /* replace1251_0_0_0_0_0 -> 228 in the cache */
   /* replace1251_0_0_0_0_1_0 -> 263 in the cache */
   /* replace1251_0_0_0_0_1_1 -> 3530 in the cache */
   /* replace1251_0_0_0_0_1 -> 3545 in the cache */
   /* replace1251_0_0_0_0 -> 3546 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x405fc00000000000 /* 127.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 3546, 3553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 3554 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 3555 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 3,
      { 3556 },
      -1,
   } },

   /* ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0) */
   /* search1252_0 -> 3530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_unorm_2x16,
      -1, 0,
      { 3530 },
      -1,
   } },

   /* replace1252_0_0_0_0 -> 3530 in the cache */
   /* replace1252_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3530, 120 },
      -1,
   } },
   /* replace1252_0_0_1_0 -> 3530 in the cache */
   /* replace1252_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3530, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3559, 3560 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3561 },
      -1,
   } },
   /* replace1252_1 -> 3533 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3562, 3533 },
      -1,
   } },

   /* ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0) */
   /* search1253_0 -> 3530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_unorm_4x8,
      -1, 0,
      { 3530 },
      -1,
   } },

   /* replace1253_0_0_0_0 -> 3530 in the cache */
   /* replace1253_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3530, 120 },
      -1,
   } },
   /* replace1253_0_0_1_0 -> 3530 in the cache */
   /* replace1253_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3530, 377 },
      -1,
   } },
   /* replace1253_0_0_2_0 -> 3530 in the cache */
   /* replace1253_0_0_2_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3530, 382 },
      -1,
   } },
   /* replace1253_0_0_3_0 -> 3530 in the cache */
   /* replace1253_0_0_3_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3530, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3565, 3566, 3567, 3568 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3569 },
      -1,
   } },
   /* replace1253_1 -> 3539 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3570, 3539 },
      -1,
   } },

   /* ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0))) */
   /* search1254_0 -> 3530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_snorm_2x16,
      -1, 0,
      { 3530 },
      -1,
   } },

   /* replace1254_0 -> 228 in the cache */
   /* replace1254_1_0 -> 263 in the cache */
   /* replace1254_1_1_0_0_0_0 -> 3530 in the cache */
   /* replace1254_1_1_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 3530, 120 },
      -1,
   } },
   /* replace1254_1_1_0_0_1_0 -> 3530 in the cache */
   /* replace1254_1_1_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 3530, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3573, 3574 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3575 },
      -1,
   } },
   /* replace1254_1_1_1 -> 3547 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3576, 3547 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 263, 3577 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 228, 3578 },
      -1,
   } },

   /* ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0))) */
   /* search1255_0 -> 3530 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_snorm_4x8,
      -1, 0,
      { 3530 },
      -1,
   } },

   /* replace1255_0 -> 228 in the cache */
   /* replace1255_1_0 -> 263 in the cache */
   /* replace1255_1_1_0_0_0_0 -> 3530 in the cache */
   /* replace1255_1_1_0_0_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3530, 120 },
      -1,
   } },
   /* replace1255_1_1_0_0_1_0 -> 3530 in the cache */
   /* replace1255_1_1_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3530, 377 },
      -1,
   } },
   /* replace1255_1_1_0_0_2_0 -> 3530 in the cache */
   /* replace1255_1_1_0_0_2_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3530, 382 },
      -1,
   } },
   /* replace1255_1_1_0_0_3_0 -> 3530 in the cache */
   /* replace1255_1_1_0_0_3_1 -> 386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3530, 386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3581, 3582, 3583, 3584 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3585 },
      -1,
   } },
   /* replace1255_1_1_1 -> 3553 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3586, 3553 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 263, 3587 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 228, 3588 },
      -1,
   } },

   /* ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a'))) */
   /* search1256_0 -> 16 in the cache */
   /* search1256_1 -> 36 in the cache */
   /* search1256 -> 3041 in the cache */

   /* replace1256_0_0_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3590 },
      -1,
   } },
   /* replace1256_0_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3591, 808 },
      -1,
   } },
   /* replace1256_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3593 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3592, 3594 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a')) */
   /* search1257_0 -> 16 in the cache */
   /* search1257 -> 3006 in the cache */

   /* replace1257_0_0 -> 16 in the cache */
   /* replace1257_0 -> 3003 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 3003 },
      -1,
   } },

   /* ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16))) */
   /* search1258_0 -> 16 in the cache */
   /* search1258 -> 3013 in the cache */

   /* replace1258_0_0_0 -> 16 in the cache */
   /* replace1258_0_0_1 -> 808 in the cache */
   /* replace1258_0_0 -> 963 in the cache */
   /* replace1258_0 -> 3004 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 3004 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a')) */
   /* search1259_0 -> 11 in the cache */
   /* search1259_1 -> 243 in the cache */
   /* search1259 -> 2996 in the cache */

   /* replace1259_0_0_0 -> 243 in the cache */
   /* replace1259_0_0 -> 2997 in the cache */
   /* replace1259_0_1 -> 808 in the cache */
   /* replace1259_0 -> 2998 in the cache */
   /* replace1259_1_0 -> 11 in the cache */
   /* replace1259_1 -> 1742 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2998, 1742 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a') */
   /* search1260_0 -> 16 in the cache */
   /* search1260 -> 2919 in the cache */

   /* replace1260_0 -> 16 in the cache */
   /* replace1260 -> 3003 in the cache */

   /* ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1261_0 -> 16 in the cache */
   /* search1261 -> 2921 in the cache */

   /* replace1261_0_0 -> 16 in the cache */
   /* replace1261_0_1 -> 808 in the cache */
   /* replace1261_0 -> 963 in the cache */
   /* replace1261 -> 3004 in the cache */

   /* ('isign', 'a') => ('imin', ('imax', 'a', -1), 1) */
   /* search1262_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1262_0_0 -> 32 in the cache */
   /* replace1262_0_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 32, 63 },
      -1,
   } },
   /* replace1262_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 3600, 35 },
      -1,
   } },

   /* ('imin', ('imax', 'a', -1), 1) => ('isign', 'a') */
   /* search1263_0_0 -> 32 in the cache */
   /* search1263_0_1 -> 63 in the cache */
   /* search1263_0 -> 3600 in the cache */
   /* search1263_1 -> 35 in the cache */
   /* search1263 -> 3601 in the cache */

   /* replace1263_0 -> 32 in the cache */
   /* replace1263 -> 3599 in the cache */

   /* ('imax', ('imin', 'a', 1), -1) => ('isign', 'a') */
   /* search1264_0_0 -> 32 in the cache */
   /* search1264_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 32, 35 },
      -1,
   } },
   /* search1264_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 3602, 63 },
      -1,
   } },

   /* replace1264_0 -> 32 in the cache */
   /* replace1264 -> 3599 in the cache */

   /* ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0))) */
   /* search1265_0 -> 32 in the cache */
   /* search1265 -> 235 in the cache */

   /* replace1265_0_0_0 -> 113 in the cache */
   /* replace1265_0_0_1 -> 32 in the cache */
   /* replace1265_0_0 -> 1463 in the cache */
   /* replace1265_0 -> 1464 in the cache */
   /* replace1265_1_0_0 -> 32 in the cache */
   /* replace1265_1_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 3604 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 1464, 3605 },
      -1,
   } },

   /* ('amul', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1266_0 -> 0 in the cache */
   /* search1266_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_amul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1266_0 -> 0 in the cache */
   /* replace1266_1 -> 3 in the cache */
   /* replace1266 -> 906 in the cache */

   /* ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)) */
   /* search1267_0 -> 16 in the cache */
   /* search1267_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1267_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffff /* 16777215 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 3609 },
      -1,
   } },
   /* replace1267_1_0 -> 36 in the cache */
   /* replace1267_1_1 -> 3609 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 3609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 3610, 3611 },
      -1,
   } },

   /* ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c') */
   /* search1268_0 -> 16 in the cache */
   /* search1268_1 -> 36 in the cache */
   /* search1268_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umad24,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace1268_0_0_0 -> 16 in the cache */
   /* replace1268_0_0_1 -> 3609 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 16, 3609 },
      -1,
   } },
   /* replace1268_0_1_0 -> 36 in the cache */
   /* replace1268_0_1_1 -> 3609 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 36, 3609 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 3,
      { 3614, 3615 },
      -1,
   } },
   /* replace1268_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 3616, 133 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b') */
   /* search1269_0 -> 16 in the cache */
   /* search1269_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1269_0 -> 16 in the cache */
   /* replace1269_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1270_0 -> 16 in the cache */
   /* search1270_1 -> 36 in the cache */
   /* search1270 -> 3618 in the cache */

   /* replace1270_0 -> 16 in the cache */
   /* replace1270_1 -> 36 in the cache */
   /* replace1270 -> 49 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c') */
   /* search1271_0 -> 16 in the cache */
   /* search1271_1 -> 36 in the cache */
   /* search1271_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umad24_relaxed,
      0, 1,
      { 16, 36, 133 },
      -1,
   } },

   /* replace1271_0 -> 16 in the cache */
   /* replace1271_1 -> 36 in the cache */
   /* replace1271_2 -> 133 in the cache */
   /* replace1271 -> 3613 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c') */
   /* search1272_0 -> 16 in the cache */
   /* search1272_1 -> 36 in the cache */
   /* search1272_2 -> 133 in the cache */
   /* search1272 -> 3620 in the cache */

   /* replace1272_0_0 -> 16 in the cache */
   /* replace1272_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1272_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3621, 133 },
      -1,
   } },

   /* ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b') */
   /* search1273_0 -> 16 in the cache */
   /* search1273_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1273_0 -> 16 in the cache */
   /* replace1273_1 -> 36 in the cache */
   /* replace1273 -> 3608 in the cache */

   /* ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1274_0 -> 16 in the cache */
   /* search1274_1 -> 36 in the cache */
   /* search1274 -> 3623 in the cache */

   /* replace1274_0 -> 16 in the cache */
   /* replace1274_1 -> 36 in the cache */
   /* replace1274 -> 49 in the cache */

   /* ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b') */
   /* search1275_0 -> 16 in the cache */
   /* search1275_1 -> 36 in the cache */
   /* search1275_2 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 36, 120 },
      -1,
   } },

   /* replace1275_0 -> 16 in the cache */
   /* replace1275_1 -> 36 in the cache */
   /* replace1275 -> 3619 in the cache */

   /* ('imad24_ir3', 'a', 0, 'c') => c */
   /* search1276_0 -> 16 in the cache */
   /* search1276_1 -> 120 in the cache */
   /* search1276_2 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 120, 536 },
      -1,
   } },

   /* replace1276 -> 536 in the cache */

   /* ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c') */
   /* search1277_0 -> 16 in the cache */
   /* search1277_1 -> 377 in the cache */
   /* search1277_2 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 377, 536 },
      -1,
   } },

   /* replace1277_0 -> 16 in the cache */
   /* replace1277_1 -> 536 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 536 },
      -1,
   } },

   /* ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c') */
   /* search1278_0 -> 271 in the cache */
   /* search1278_1 -> 33 in the cache */
   /* search1278_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 271, 33, 133 },
      -1,
   } },

   /* replace1278_0_0 -> 16 in the cache */
   /* replace1278_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1278_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3629, 133 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   /* search1279_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 3631 },
      -1,
   } },

   /* replace1279_0 -> 16 in the cache */
   /* replace1279_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 3633 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search1280_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 3635 },
      -1,
   } },

   /* replace1280_0_0 -> 16 in the cache */
   /* replace1280_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3637 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 3638 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3639 },
      -1,
   } },

   /* ('imul24', 'a', 0) => 0 */
   /* search1281_0 -> 16 in the cache */
   /* search1281_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 120 },
      -1,
   } },

   /* replace1281 -> 120 in the cache */

   /* ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search1282_0_0 -> 120 in the cache */
   /* search1282_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1282_1 -> 36 in the cache */
   /* search1282_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 3642, 36, 133 },
      -1,
   } },

   /* replace1282_0 -> 16 in the cache */
   /* replace1282_1 -> 36 in the cache */
   /* replace1282_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c') */
   /* search1283_0_0 -> 16 in the cache */
   /* search1283_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1283_1 -> 36 in the cache */
   /* search1283_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 3645, 36, 133 },
      -1,
   } },

   /* replace1283_0_0 -> 16 in the cache */
   /* replace1283_0 -> 265 in the cache */
   /* replace1283_1 -> 36 in the cache */
   /* replace1283_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 265, 36, 133 },
      -1,
   } },

   /* ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search1284_0_0 -> 16 in the cache */
   /* search1284_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1284_1 -> 36 in the cache */
   /* search1284_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 3648, 36, 133 },
      -1,
   } },

   /* replace1284_0 -> 16 in the cache */
   /* replace1284_1 -> 36 in the cache */
   /* replace1284_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c') */
   /* search1285_0_0 -> 120 in the cache */
   /* search1285_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1285_1 -> 36 in the cache */
   /* search1285_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 3651, 36, 133 },
      -1,
   } },

   /* replace1285_0_0 -> 16 in the cache */
   /* replace1285_0 -> 265 in the cache */
   /* replace1285_1 -> 36 in the cache */
   /* replace1285_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 265, 36, 133 },
      -1,
   } },

   /* ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c') */
   /* search1286_0_0 -> 120 in the cache */
   /* search1286_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1286_1 -> 36 in the cache */
   /* search1286_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3654, 36, 133 },
      -1,
   } },

   /* replace1286_0 -> 16 in the cache */
   /* replace1286_1 -> 36 in the cache */
   /* replace1286_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b') */
   /* search1287_0_0 -> 16 in the cache */
   /* search1287_0_1 -> 120 in the cache */
   /* search1287_0 -> 1406 in the cache */
   /* search1287_1 -> 36 in the cache */
   /* search1287_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1406, 36, 133 },
      -1,
   } },

   /* replace1287_0 -> 16 in the cache */
   /* replace1287_1 -> 133 in the cache */
   /* replace1287_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 16, 133, 36 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c') */
   /* search1288_0_0 -> 16 in the cache */
   /* search1288_0_1 -> 120 in the cache */
   /* search1288_0 -> 1403 in the cache */
   /* search1288_1 -> 36 in the cache */
   /* search1288_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1403, 36, 133 },
      -1,
   } },

   /* replace1288_0 -> 16 in the cache */
   /* replace1288_1 -> 36 in the cache */
   /* replace1288_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },

   /* ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b') */
   /* search1289_0_0 -> 120 in the cache */
   /* search1289_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1289_1 -> 36 in the cache */
   /* search1289_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3661, 36, 133 },
      -1,
   } },

   /* replace1289_0 -> 16 in the cache */
   /* replace1289_1 -> 133 in the cache */
   /* replace1289_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 16, 133, 36 },
      -1,
   } },

   /* ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search1290_0_0 -> 120 in the cache */
   /* search1290_0_1 -> 16 in the cache */
   /* search1290_0 -> 1838 in the cache */
   /* search1290_1 -> 36 in the cache */
   /* search1290_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1838, 36, 133 },
      -1,
   } },

   /* replace1290_0 -> 16 in the cache */
   /* replace1290_1 -> 36 in the cache */
   /* replace1290_2 -> 133 in the cache */
   /* replace1290 -> 3644 in the cache */

   /* ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c') */
   /* search1291_0_0 -> 16 in the cache */
   /* search1291_0_1 -> 120 in the cache */
   /* search1291_0 -> 1840 in the cache */
   /* search1291_1 -> 36 in the cache */
   /* search1291_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1840, 36, 133 },
      -1,
   } },

   /* replace1291_0_0 -> 16 in the cache */
   /* replace1291_0 -> 265 in the cache */
   /* replace1291_1 -> 36 in the cache */
   /* replace1291_2 -> 133 in the cache */
   /* replace1291 -> 3647 in the cache */

   /* ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search1292_0_0 -> 16 in the cache */
   /* search1292_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* search1292_1 -> 36 in the cache */
   /* search1292_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3666, 36, 133 },
      -1,
   } },

   /* replace1292_0 -> 16 in the cache */
   /* replace1292_1 -> 36 in the cache */
   /* replace1292_2 -> 133 in the cache */
   /* replace1292 -> 3650 in the cache */

   /* ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c') */
   /* search1293_0_0 -> 120 in the cache */
   /* search1293_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 120, 16 },
      -1,
   } },
   /* search1293_1 -> 36 in the cache */
   /* search1293_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3668, 36, 133 },
      -1,
   } },

   /* replace1293_0_0 -> 16 in the cache */
   /* replace1293_0 -> 265 in the cache */
   /* replace1293_1 -> 36 in the cache */
   /* replace1293_2 -> 133 in the cache */
   /* replace1293 -> 3653 in the cache */

   /* ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b'))) */
   /* search1294_0 -> 6 in the cache */
   /* search1294_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 6, 2053 },
      -1,
   } },

   /* replace1294_0_0 -> 2053 in the cache */
   /* replace1294_0_1 -> 1367 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2053, 1367 },
      -1,
   } },
   /* replace1294_1_0_0_0 -> 6 in the cache */
   /* replace1294_1_0_0_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 6, 2053 },
      -1,
   } },
   /* replace1294_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3672, 6 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1294_1_2_0 -> 6 in the cache */
   /* replace1294_1_2_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 6, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3673, 3674, 3675 },
      -1,
   } },
   /* replace1294_2_0_0 -> 6 in the cache */
   /* replace1294_2_0_1_0 -> 6 in the cache */
   /* replace1294_2_0_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 6, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 6, 3677 },
      -1,
   } },
   /* replace1294_2_1 -> 7 in the cache */
   /* replace1294_2_2_0 -> 6 in the cache */
   /* replace1294_2_2_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 6, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3678, 7, 3679 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3671, 3676, 3680 },
      -1,
   } },

   /* ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b'))) */
   /* search1295_0 -> 6 in the cache */
   /* search1295_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 6, 2053 },
      -1,
   } },

   /* replace1295_0_0 -> 2053 in the cache */
   /* replace1295_0_1 -> 790 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2053, 790 },
      -1,
   } },
   /* replace1295_1_0_0_0 -> 6 in the cache */
   /* replace1295_1_0_0_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 6, 2053 },
      -1,
   } },
   /* replace1295_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3684, 6 },
      -1,
   } },
   /* replace1295_1_1 -> 3674 in the cache */
   /* replace1295_1_2_0 -> 6 in the cache */
   /* replace1295_1_2_1 -> 2053 in the cache */
   /* replace1295_1_2 -> 3684 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3685, 3674, 3684 },
      -1,
   } },
   /* replace1295_2_0_0 -> 6 in the cache */
   /* replace1295_2_0_1_0 -> 6 in the cache */
   /* replace1295_2_0_1_1 -> 2053 in the cache */
   /* replace1295_2_0_1 -> 3684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3684 },
      -1,
   } },
   /* replace1295_2_1 -> 7 in the cache */
   /* replace1295_2_2_0 -> 6 in the cache */
   /* replace1295_2_2_1 -> 2053 in the cache */
   /* replace1295_2_2 -> 3684 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3687, 7, 3684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3683, 3686, 3688 },
      -1,
   } },

   /* ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b'))) */
   /* search1296_0 -> 11 in the cache */
   /* search1296_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 11, 243 },
      -1,
   } },

   /* replace1296_0_0 -> 243 in the cache */
   /* replace1296_0_1 -> 1389 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 243, 1389 },
      -1,
   } },
   /* replace1296_1_0_0_0 -> 11 in the cache */
   /* replace1296_1_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 11, 243 },
      -1,
   } },
   /* replace1296_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3692, 11 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1296_1_2_0 -> 11 in the cache */
   /* replace1296_1_2_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3693, 3694, 3695 },
      -1,
   } },
   /* replace1296_2_0_0 -> 11 in the cache */
   /* replace1296_2_0_1_0 -> 11 in the cache */
   /* replace1296_2_0_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 11, 3697 },
      -1,
   } },
   /* replace1296_2_1 -> 12 in the cache */
   /* replace1296_2_2_0 -> 11 in the cache */
   /* replace1296_2_2_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 11, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3698, 12, 3699 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3691, 3696, 3700 },
      -1,
   } },

   /* ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b'))) */
   /* search1297_0 -> 11 in the cache */
   /* search1297_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 11, 243 },
      -1,
   } },

   /* replace1297_0_0 -> 243 in the cache */
   /* replace1297_0_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 243, 811 },
      -1,
   } },
   /* replace1297_1_0_0_0 -> 11 in the cache */
   /* replace1297_1_0_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 11, 243 },
      -1,
   } },
   /* replace1297_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3704, 11 },
      -1,
   } },
   /* replace1297_1_1 -> 3694 in the cache */
   /* replace1297_1_2_0 -> 11 in the cache */
   /* replace1297_1_2_1 -> 243 in the cache */
   /* replace1297_1_2 -> 3704 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3705, 3694, 3704 },
      -1,
   } },
   /* replace1297_2_0_0 -> 11 in the cache */
   /* replace1297_2_0_1_0 -> 11 in the cache */
   /* replace1297_2_0_1_1 -> 243 in the cache */
   /* replace1297_2_0_1 -> 3704 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3704 },
      -1,
   } },
   /* replace1297_2_1 -> 12 in the cache */
   /* replace1297_2_2_0 -> 11 in the cache */
   /* replace1297_2_2_1 -> 243 in the cache */
   /* replace1297_2_2 -> 3704 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3707, 12, 3704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3703, 3706, 3708 },
      -1,
   } },

   /* ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b'))) */
   /* search1298_0 -> 16 in the cache */
   /* search1298_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1298_0_0 -> 36 in the cache */
   /* replace1298_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 36, 377 },
      -1,
   } },
   /* replace1298_1_0_0_0 -> 16 in the cache */
   /* replace1298_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1298_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3712, 16 },
      -1,
   } },
   /* replace1298_1_1 -> 943 in the cache */
   /* replace1298_1_2_0 -> 16 in the cache */
   /* replace1298_1_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3713, 943, 3714 },
      -1,
   } },
   /* replace1298_2_0_0 -> 16 in the cache */
   /* replace1298_2_0_1_0 -> 16 in the cache */
   /* replace1298_2_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 16, 3716 },
      -1,
   } },
   /* replace1298_2_1 -> 17 in the cache */
   /* replace1298_2_2_0 -> 16 in the cache */
   /* replace1298_2_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3717, 17, 3718 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3711, 3715, 3719 },
      -1,
   } },

   /* ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b'))) */
   /* search1299_0 -> 16 in the cache */
   /* search1299_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1299_0_0 -> 36 in the cache */
   /* replace1299_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 36, 120 },
      -1,
   } },
   /* replace1299_1_0_0_0 -> 16 in the cache */
   /* replace1299_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   /* replace1299_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3723, 16 },
      -1,
   } },
   /* replace1299_1_1 -> 943 in the cache */
   /* replace1299_1_2_0 -> 16 in the cache */
   /* replace1299_1_2_1 -> 36 in the cache */
   /* replace1299_1_2 -> 3723 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3724, 943, 3723 },
      -1,
   } },
   /* replace1299_2_0_0 -> 16 in the cache */
   /* replace1299_2_0_1_0 -> 16 in the cache */
   /* replace1299_2_0_1_1 -> 36 in the cache */
   /* replace1299_2_0_1 -> 3723 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 3723 },
      -1,
   } },
   /* replace1299_2_1 -> 17 in the cache */
   /* replace1299_2_2_0 -> 16 in the cache */
   /* replace1299_2_2_1 -> 36 in the cache */
   /* replace1299_2_2 -> 3723 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3726, 17, 3723 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3722, 3725, 3727 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b'))) */
   /* search1300_0 -> 21 in the cache */
   /* search1300_1 -> 41 in the cache */
   /* search1300 -> 3378 in the cache */

   /* replace1300_0_0 -> 41 in the cache */
   /* replace1300_0_1 -> 1431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 41, 1431 },
      -1,
   } },
   /* replace1300_1_0_0_0 -> 21 in the cache */
   /* replace1300_1_0_0_1 -> 41 in the cache */
   /* replace1300_1_0_0 -> 3365 in the cache */
   /* replace1300_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3365, 21 },
      -1,
   } },
   /* replace1300_1_1 -> 3389 in the cache */
   /* replace1300_1_2_0 -> 21 in the cache */
   /* replace1300_1_2_1 -> 41 in the cache */
   /* replace1300_1_2 -> 3367 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3730, 3389, 3367 },
      -1,
   } },
   /* replace1300_2_0_0 -> 21 in the cache */
   /* replace1300_2_0_1_0 -> 21 in the cache */
   /* replace1300_2_0_1_1 -> 41 in the cache */
   /* replace1300_2_0_1 -> 3381 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 21, 3381 },
      -1,
   } },
   /* replace1300_2_1 -> 22 in the cache */
   /* replace1300_2_2_0 -> 21 in the cache */
   /* replace1300_2_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3732, 22, 3733 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3729, 3731, 3734 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b'))) */
   /* search1301_0 -> 21 in the cache */
   /* search1301_1 -> 41 in the cache */
   /* search1301 -> 3392 in the cache */

   /* replace1301_0_0 -> 41 in the cache */
   /* replace1301_0_1 -> 852 in the cache */
   /* replace1301_0 -> 3379 in the cache */
   /* replace1301_1_0_0_0 -> 21 in the cache */
   /* replace1301_1_0_0_1 -> 41 in the cache */
   /* replace1301_1_0_0 -> 3376 in the cache */
   /* replace1301_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3376, 21 },
      -1,
   } },
   /* replace1301_1_1 -> 3389 in the cache */
   /* replace1301_1_2_0 -> 21 in the cache */
   /* replace1301_1_2_1 -> 41 in the cache */
   /* replace1301_1_2 -> 3376 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3736, 3389, 3376 },
      -1,
   } },
   /* replace1301_2_0_0 -> 21 in the cache */
   /* replace1301_2_0_1_0 -> 21 in the cache */
   /* replace1301_2_0_1_1 -> 41 in the cache */
   /* replace1301_2_0_1 -> 3376 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 3376 },
      -1,
   } },
   /* replace1301_2_1 -> 22 in the cache */
   /* replace1301_2_2_0 -> 21 in the cache */
   /* replace1301_2_2_1 -> 41 in the cache */
   /* replace1301_2_2 -> 3376 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3738, 22, 3376 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3379, 3737, 3739 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1302_0_0_0 -> 0 in the cache */
   /* search1302_0_0_1 -> 3 in the cache */
   /* search1302_0_0 -> 1029 in the cache */
   /* search1302_0_1_0 -> 150 in the cache */
   /* search1302_0_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1029, 3741 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3742 },
      -1,
   } },

   /* replace1302_0_0 -> 0 in the cache */
   /* replace1302_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1302_1_0 -> 150 in the cache */
   /* replace1302_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3744, 3745 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1303_0_0_0 -> 0 in the cache */
   /* search1303_0_0_1 -> 3 in the cache */
   /* search1303_0_0 -> 1029 in the cache */
   /* search1303_0_1_0 -> 150 in the cache */
   /* search1303_0_1_1 -> 151 in the cache */
   /* search1303_0_1 -> 3741 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1029, 3741 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3747 },
      -1,
   } },

   /* replace1303_0_0 -> 0 in the cache */
   /* replace1303_0_1 -> 3 in the cache */
   /* replace1303_0 -> 3744 in the cache */
   /* replace1303_1_0 -> 150 in the cache */
   /* replace1303_1_1 -> 151 in the cache */
   /* replace1303_1 -> 3745 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3744, 3745 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1304_0_0_0 -> 0 in the cache */
   /* search1304_0_0_1 -> 3 in the cache */
   /* search1304_0_0 -> 1029 in the cache */
   /* search1304_0_1_0 -> 150 in the cache */
   /* search1304_0_1_1 -> 151 in the cache */
   /* search1304_0_1 -> 3745 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1029, 3745 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3750 },
      -1,
   } },

   /* replace1304_0_0 -> 0 in the cache */
   /* replace1304_0_1 -> 3 in the cache */
   /* replace1304_0 -> 3744 in the cache */
   /* replace1304_1_0 -> 150 in the cache */
   /* replace1304_1_1 -> 151 in the cache */
   /* replace1304_1 -> 3741 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3744, 3741 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1305_0_0_0 -> 0 in the cache */
   /* search1305_0_0_1 -> 3 in the cache */
   /* search1305_0_0 -> 1029 in the cache */
   /* search1305_0_1_0 -> 150 in the cache */
   /* search1305_0_1_1 -> 151 in the cache */
   /* search1305_0_1 -> 3745 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1029, 3745 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3753 },
      -1,
   } },

   /* replace1305_0_0 -> 0 in the cache */
   /* replace1305_0_1 -> 3 in the cache */
   /* replace1305_0 -> 3744 in the cache */
   /* replace1305_1_0 -> 150 in the cache */
   /* replace1305_1_1 -> 151 in the cache */
   /* replace1305_1 -> 3741 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3744, 3741 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1306_0_0_0 -> 0 in the cache */
   /* search1306_0_0_1 -> 3 in the cache */
   /* search1306_0_0 -> 3744 in the cache */
   /* search1306_0_1_0 -> 150 in the cache */
   /* search1306_0_1_1 -> 151 in the cache */
   /* search1306_0_1 -> 3745 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3744, 3745 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3756 },
      -1,
   } },

   /* replace1306_0_0 -> 0 in the cache */
   /* replace1306_0_1 -> 3 in the cache */
   /* replace1306_0 -> 1029 in the cache */
   /* replace1306_1_0 -> 150 in the cache */
   /* replace1306_1_1 -> 151 in the cache */
   /* replace1306_1 -> 3741 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1029, 3741 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1307_0_0_0 -> 0 in the cache */
   /* search1307_0_0_1 -> 3 in the cache */
   /* search1307_0_0 -> 3744 in the cache */
   /* search1307_0_1_0 -> 150 in the cache */
   /* search1307_0_1_1 -> 151 in the cache */
   /* search1307_0_1 -> 3745 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3744, 3745 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 3759 },
      -1,
   } },

   /* replace1307_0_0 -> 0 in the cache */
   /* replace1307_0_1 -> 3 in the cache */
   /* replace1307_0 -> 1029 in the cache */
   /* replace1307_1_0 -> 150 in the cache */
   /* replace1307_1_1 -> 151 in the cache */
   /* replace1307_1 -> 3741 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1029, 3741 },
      -1,
   } },

   /* ('f2b1', ('b2f', 'a@1')) => a */
   /* search1308_0_0 -> 715 in the cache */
   /* search1308_0 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_f2b1,
      -1, 0,
      { 1078 },
      -1,
   } },

   /* replace1308 -> 715 in the cache */

   /* ('i2b1', ('b2i', 'a@1')) => a */
   /* search1309_0_0 -> 715 in the cache */
   /* search1309_0 -> 1176 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2b1,
      -1, 0,
      { 1176 },
      -1,
   } },

   /* replace1309 -> 715 in the cache */

   /* ('f2b8', ('b2f', 'a@8')) => a */
   /* search1310_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_f2b8,
      -1, 0,
      { 3764 },
      -1,
   } },

   /* replace1310 -> 6 in the cache */

   /* ('i2b8', ('b2i', 'a@8')) => a */
   /* search1311_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2b8,
      -1, 0,
      { 3766 },
      -1,
   } },

   /* replace1311 -> 6 in the cache */

   /* ('f2b16', ('b2f', 'a@16')) => a */
   /* search1312_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2b16,
      -1, 0,
      { 3768 },
      -1,
   } },

   /* replace1312 -> 11 in the cache */

   /* ('i2b16', ('b2i', 'a@16')) => a */
   /* search1313_0_0 -> 11 in the cache */
   /* search1313_0 -> 2810 in the cache */
   /* search1313 -> 2811 in the cache */

   /* replace1313 -> 11 in the cache */

   /* ('f2b32', ('b2f', 'a@32')) => a */
   /* search1314_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2b32,
      -1, 0,
      { 3770 },
      -1,
   } },

   /* replace1314 -> 16 in the cache */

   /* ('i2b32', ('b2i', 'a@32')) => a */
   /* search1315_0_0 -> 16 in the cache */
   /* search1315_0 -> 2812 in the cache */
   /* search1315 -> 2813 in the cache */

   /* replace1315 -> 16 in the cache */

   /* ('f2f', ('b2f', 'a')) => ('b2f', 'a') */
   /* search1316_0_0 -> 32 in the cache */
   /* search1316_0 -> 1465 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2f,
      -1, 0,
      { 1465 },
      -1,
   } },

   /* replace1316_0 -> 32 in the cache */
   /* replace1316 -> 1465 in the cache */

   /* ('f2u', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1317_0_0 -> 32 in the cache */
   /* search1317_0 -> 1465 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 1465 },
      -1,
   } },

   /* replace1317_0 -> 32 in the cache */
   /* replace1317 -> 2802 in the cache */

   /* ('f2i', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1318_0_0 -> 32 in the cache */
   /* search1318_0 -> 1465 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 1465 },
      -1,
   } },

   /* replace1318_0 -> 32 in the cache */
   /* replace1318 -> 2802 in the cache */

   /* ('u2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1319_0_0 -> 32 in the cache */
   /* search1319_0 -> 2802 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 2802 },
      -1,
   } },

   /* replace1319_0 -> 32 in the cache */
   /* replace1319 -> 1465 in the cache */

   /* ('u2u', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1320_0_0 -> 32 in the cache */
   /* search1320_0 -> 2802 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2802 },
      -1,
   } },

   /* replace1320_0 -> 32 in the cache */
   /* replace1320 -> 2802 in the cache */

   /* ('i2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1321_0_0 -> 32 in the cache */
   /* search1321_0 -> 2802 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 2802 },
      -1,
   } },

   /* replace1321_0 -> 32 in the cache */
   /* replace1321 -> 1465 in the cache */

   /* ('i2i', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1322_0_0 -> 32 in the cache */
   /* search1322_0 -> 2802 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2802 },
      -1,
   } },

   /* replace1322_0 -> 32 in the cache */
   /* replace1322 -> 2802 in the cache */

   /* ('i2i1', 'a@1') => a */
   /* search1323_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 715 },
      -1,
   } },

   /* replace1323 -> 715 in the cache */

   /* ('i2i8', 'a@8') => a */
   /* search1324_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1324 -> 6 in the cache */

   /* ('i2i16', 'a@16') => a */
   /* search1325_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1325 -> 11 in the cache */

   /* ('i2i32', 'a@32') => a */
   /* search1326_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1326 -> 16 in the cache */

   /* ('i2i64', 'a@64') => a */
   /* search1327_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1327 -> 21 in the cache */

   /* ('u2u1', 'a@1') => a */
   /* search1328_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 715 },
      -1,
   } },

   /* replace1328 -> 715 in the cache */

   /* ('u2u8', 'a@8') => a */
   /* search1329_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1329 -> 6 in the cache */

   /* ('u2u16', 'a@16') => a */
   /* search1330_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1330 -> 11 in the cache */

   /* ('u2u32', 'a@32') => a */
   /* search1331_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1331 -> 16 in the cache */

   /* ('u2u64', 'a@64') => a */
   /* search1332_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1332 -> 21 in the cache */

   /* ('f2f16', 'a@16') => a */
   /* search1333_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1333 -> 11 in the cache */

   /* ('f2f32', 'a@32') => a */
   /* search1334_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1334 -> 16 in the cache */

   /* ('f2f64', 'a@64') => a */
   /* search1335_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1335 -> 21 in the cache */

   /* ('b2b1', 'a@1') => a */
   /* search1336_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_b2b1,
      -1, 0,
      { 715 },
      -1,
   } },

   /* replace1336 -> 715 in the cache */

   /* ('b2b8', 'a@8') => a */
   /* search1337_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2b8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1337 -> 6 in the cache */

   /* ('b2b16', 'a@16') => a */
   /* search1338_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2b16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1338 -> 11 in the cache */

   /* ('b2b32', 'a@32') => a */
   /* search1339_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2b32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1339 -> 16 in the cache */

   /* ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1340_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3796 },
      -1,
   } },

   /* replace1340_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1341_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3799 },
      -1,
   } },

   /* replace1341_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1342_0_0 -> 32 in the cache */
   /* search1342_0 -> 3796 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3796 },
      -1,
   } },

   /* replace1342_0 -> 32 in the cache */
   /* replace1342 -> 3798 in the cache */

   /* ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1343_0_0 -> 32 in the cache */
   /* search1343_0 -> 3799 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3799 },
      -1,
   } },

   /* replace1343_0 -> 32 in the cache */
   /* replace1343 -> 3801 in the cache */

   /* ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1344_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3804 },
      -1,
   } },

   /* replace1344_0 -> 32 in the cache */
   /* replace1344 -> 3798 in the cache */

   /* ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1345_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3806 },
      -1,
   } },

   /* replace1345_0 -> 32 in the cache */
   /* replace1345 -> 3801 in the cache */

   /* ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1346_0_0 -> 32 in the cache */
   /* search1346_0 -> 3804 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3804 },
      -1,
   } },

   /* replace1346_0 -> 32 in the cache */
   /* replace1346 -> 3798 in the cache */

   /* ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1347_0_0 -> 32 in the cache */
   /* search1347_0 -> 3806 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3806 },
      -1,
   } },

   /* replace1347_0 -> 32 in the cache */
   /* replace1347 -> 3801 in the cache */

   /* ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1348_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3810 },
      -1,
   } },

   /* replace1348_0 -> 32 in the cache */
   /* replace1348 -> 3798 in the cache */

   /* ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1349_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3812 },
      -1,
   } },

   /* replace1349_0 -> 32 in the cache */
   /* replace1349 -> 3801 in the cache */

   /* ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1350_0_0 -> 32 in the cache */
   /* search1350_0 -> 3810 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3810 },
      -1,
   } },

   /* replace1350_0 -> 32 in the cache */
   /* replace1350 -> 3798 in the cache */

   /* ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1351_0_0 -> 32 in the cache */
   /* search1351_0 -> 3812 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3812 },
      -1,
   } },

   /* replace1351_0 -> 32 in the cache */
   /* replace1351 -> 3801 in the cache */

   /* ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1352_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3816 },
      -1,
   } },

   /* replace1352_0 -> 32 in the cache */
   /* replace1352 -> 3798 in the cache */

   /* ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1353_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3818 },
      -1,
   } },

   /* replace1353_0 -> 32 in the cache */
   /* replace1353 -> 3801 in the cache */

   /* ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1354_0_0 -> 32 in the cache */
   /* search1354_0 -> 3816 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3816 },
      -1,
   } },

   /* replace1354_0 -> 32 in the cache */
   /* replace1354 -> 3798 in the cache */

   /* ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1355_0_0 -> 32 in the cache */
   /* search1355_0 -> 3818 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3818 },
      -1,
   } },

   /* replace1355_0 -> 32 in the cache */
   /* replace1355 -> 3801 in the cache */

   /* ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a') */
   /* search1356_0_0 -> 715 in the cache */
   /* search1356_0 -> 3779 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3779 },
      -1,
   } },

   /* replace1356_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a') */
   /* search1357_0_0 -> 715 in the cache */
   /* search1357_0 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3784 },
      -1,
   } },

   /* replace1357_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1358_0_0 -> 32 in the cache */
   /* search1358_0 -> 3804 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3804 },
      -1,
   } },

   /* replace1358_0 -> 32 in the cache */
   /* replace1358 -> 3796 in the cache */

   /* ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1359_0_0 -> 32 in the cache */
   /* search1359_0 -> 3806 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3806 },
      -1,
   } },

   /* replace1359_0 -> 32 in the cache */
   /* replace1359 -> 3799 in the cache */

   /* ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1360_0_0 -> 32 in the cache */
   /* search1360_0 -> 3804 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3804 },
      -1,
   } },

   /* replace1360_0 -> 32 in the cache */
   /* replace1360 -> 3796 in the cache */

   /* ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1361_0_0 -> 32 in the cache */
   /* search1361_0 -> 3806 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3806 },
      -1,
   } },

   /* replace1361_0 -> 32 in the cache */
   /* replace1361 -> 3799 in the cache */

   /* ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1362_0_0 -> 32 in the cache */
   /* search1362_0 -> 3810 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3810 },
      -1,
   } },

   /* replace1362_0 -> 32 in the cache */
   /* replace1362 -> 3796 in the cache */

   /* ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1363_0_0 -> 32 in the cache */
   /* search1363_0 -> 3812 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3812 },
      -1,
   } },

   /* replace1363_0 -> 32 in the cache */
   /* replace1363 -> 3799 in the cache */

   /* ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1364_0_0 -> 32 in the cache */
   /* search1364_0 -> 3810 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3810 },
      -1,
   } },

   /* replace1364_0 -> 32 in the cache */
   /* replace1364 -> 3796 in the cache */

   /* ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1365_0_0 -> 32 in the cache */
   /* search1365_0 -> 3812 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3812 },
      -1,
   } },

   /* replace1365_0 -> 32 in the cache */
   /* replace1365 -> 3799 in the cache */

   /* ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1366_0_0 -> 32 in the cache */
   /* search1366_0 -> 3816 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3816 },
      -1,
   } },

   /* replace1366_0 -> 32 in the cache */
   /* replace1366 -> 3796 in the cache */

   /* ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1367_0_0 -> 32 in the cache */
   /* search1367_0 -> 3818 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3818 },
      -1,
   } },

   /* replace1367_0 -> 32 in the cache */
   /* replace1367 -> 3799 in the cache */

   /* ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1368_0_0 -> 32 in the cache */
   /* search1368_0 -> 3816 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3816 },
      -1,
   } },

   /* replace1368_0 -> 32 in the cache */
   /* replace1368 -> 3796 in the cache */

   /* ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1369_0_0 -> 32 in the cache */
   /* search1369_0 -> 3818 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3818 },
      -1,
   } },

   /* replace1369_0 -> 32 in the cache */
   /* replace1369 -> 3799 in the cache */

   /* ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a') */
   /* search1370_0_0 -> 715 in the cache */
   /* search1370_0 -> 3779 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3779 },
      -1,
   } },

   /* replace1370_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a') */
   /* search1371_0_0 -> 715 in the cache */
   /* search1371_0 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3784 },
      -1,
   } },

   /* replace1371_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a') */
   /* search1372_0_0 -> 715 in the cache */
   /* search1372_0 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3823 },
      -1,
   } },

   /* replace1372_0 -> 715 in the cache */
   /* replace1372 -> 3839 in the cache */

   /* ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a') */
   /* search1373_0_0 -> 715 in the cache */
   /* search1373_0 -> 3825 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3825 },
      -1,
   } },

   /* replace1373_0 -> 715 in the cache */
   /* replace1373 -> 3841 in the cache */

   /* ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a') */
   /* search1374_0_0 -> 6 in the cache */
   /* search1374_0 -> 3780 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3780 },
      -1,
   } },

   /* replace1374_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a') */
   /* search1375_0_0 -> 6 in the cache */
   /* search1375_0 -> 3785 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3785 },
      -1,
   } },

   /* replace1375_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1376_0_0 -> 32 in the cache */
   /* search1376_0 -> 3810 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3810 },
      -1,
   } },

   /* replace1376_0 -> 32 in the cache */
   /* replace1376 -> 3804 in the cache */

   /* ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1377_0_0 -> 32 in the cache */
   /* search1377_0 -> 3812 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3812 },
      -1,
   } },

   /* replace1377_0 -> 32 in the cache */
   /* replace1377 -> 3806 in the cache */

   /* ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1378_0_0 -> 32 in the cache */
   /* search1378_0 -> 3810 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3810 },
      -1,
   } },

   /* replace1378_0 -> 32 in the cache */
   /* replace1378 -> 3804 in the cache */

   /* ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1379_0_0 -> 32 in the cache */
   /* search1379_0 -> 3812 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3812 },
      -1,
   } },

   /* replace1379_0 -> 32 in the cache */
   /* replace1379 -> 3806 in the cache */

   /* ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1380_0_0 -> 32 in the cache */
   /* search1380_0 -> 3816 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3816 },
      -1,
   } },

   /* replace1380_0 -> 32 in the cache */
   /* replace1380 -> 3804 in the cache */

   /* ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1381_0_0 -> 32 in the cache */
   /* search1381_0 -> 3818 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3818 },
      -1,
   } },

   /* replace1381_0 -> 32 in the cache */
   /* replace1381 -> 3806 in the cache */

   /* ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1382_0_0 -> 32 in the cache */
   /* search1382_0 -> 3816 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3816 },
      -1,
   } },

   /* replace1382_0 -> 32 in the cache */
   /* replace1382 -> 3804 in the cache */

   /* ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1383_0_0 -> 32 in the cache */
   /* search1383_0 -> 3818 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3818 },
      -1,
   } },

   /* replace1383_0 -> 32 in the cache */
   /* replace1383 -> 3806 in the cache */

   /* ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a') */
   /* search1384_0_0 -> 715 in the cache */
   /* search1384_0 -> 3779 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3779 },
      -1,
   } },

   /* replace1384_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a') */
   /* search1385_0_0 -> 715 in the cache */
   /* search1385_0 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3784 },
      -1,
   } },

   /* replace1385_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a') */
   /* search1386_0_0 -> 715 in the cache */
   /* search1386_0 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3823 },
      -1,
   } },

   /* replace1386_0 -> 715 in the cache */
   /* replace1386 -> 3857 in the cache */

   /* ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a') */
   /* search1387_0_0 -> 715 in the cache */
   /* search1387_0 -> 3825 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3825 },
      -1,
   } },

   /* replace1387_0 -> 715 in the cache */
   /* replace1387 -> 3859 in the cache */

   /* ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a') */
   /* search1388_0_0 -> 6 in the cache */
   /* search1388_0 -> 3780 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3780 },
      -1,
   } },

   /* replace1388_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a') */
   /* search1389_0_0 -> 6 in the cache */
   /* search1389_0 -> 3785 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3785 },
      -1,
   } },

   /* replace1389_0 -> 6 in the cache */
   /* replace1389 -> 2975 in the cache */

   /* ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a') */
   /* search1390_0_0 -> 715 in the cache */
   /* search1390_0 -> 3839 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3839 },
      -1,
   } },

   /* replace1390_0 -> 715 in the cache */
   /* replace1390 -> 3857 in the cache */

   /* ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a') */
   /* search1391_0_0 -> 715 in the cache */
   /* search1391_0 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3841 },
      -1,
   } },

   /* replace1391_0 -> 715 in the cache */
   /* replace1391 -> 3859 in the cache */

   /* ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a') */
   /* search1392_0_0 -> 6 in the cache */
   /* search1392_0 -> 3845 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3845 },
      -1,
   } },

   /* replace1392_0 -> 6 in the cache */
   /* replace1392 -> 3863 in the cache */

   /* ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a') */
   /* search1393_0_0 -> 6 in the cache */
   /* search1393_0 -> 3847 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3847 },
      -1,
   } },

   /* replace1393_0 -> 6 in the cache */
   /* replace1393 -> 2975 in the cache */

   /* ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a') */
   /* search1394_0_0 -> 11 in the cache */
   /* search1394_0 -> 3781 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3781 },
      -1,
   } },

   /* replace1394_0 -> 11 in the cache */
   /* replace1394 -> 1740 in the cache */

   /* ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a') */
   /* search1395_0_0 -> 11 in the cache */
   /* search1395_0 -> 3786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3786 },
      -1,
   } },

   /* replace1395_0 -> 11 in the cache */
   /* replace1395 -> 1742 in the cache */

   /* ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1396_0_0 -> 32 in the cache */
   /* search1396_0 -> 3816 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3816 },
      -1,
   } },

   /* replace1396_0 -> 32 in the cache */
   /* replace1396 -> 3810 in the cache */

   /* ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1397_0_0 -> 32 in the cache */
   /* search1397_0 -> 3818 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3818 },
      -1,
   } },

   /* replace1397_0 -> 32 in the cache */
   /* replace1397 -> 3812 in the cache */

   /* ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1398_0_0 -> 32 in the cache */
   /* search1398_0 -> 3816 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3816 },
      -1,
   } },

   /* replace1398_0 -> 32 in the cache */
   /* replace1398 -> 3810 in the cache */

   /* ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1399_0_0 -> 32 in the cache */
   /* search1399_0 -> 3818 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3818 },
      -1,
   } },

   /* replace1399_0 -> 32 in the cache */
   /* replace1399 -> 3812 in the cache */

   /* ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a') */
   /* search1400_0_0 -> 715 in the cache */
   /* search1400_0 -> 3779 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3779 },
      -1,
   } },

   /* replace1400_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a') */
   /* search1401_0_0 -> 715 in the cache */
   /* search1401_0 -> 3784 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3784 },
      -1,
   } },

   /* replace1401_0 -> 715 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 715 },
      -1,
   } },

   /* ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a') */
   /* search1402_0_0 -> 715 in the cache */
   /* search1402_0 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3823 },
      -1,
   } },

   /* replace1402_0 -> 715 in the cache */
   /* replace1402 -> 3876 in the cache */

   /* ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a') */
   /* search1403_0_0 -> 715 in the cache */
   /* search1403_0 -> 3825 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3825 },
      -1,
   } },

   /* replace1403_0 -> 715 in the cache */
   /* replace1403 -> 3878 in the cache */

   /* ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a') */
   /* search1404_0_0 -> 6 in the cache */
   /* search1404_0 -> 3780 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3780 },
      -1,
   } },

   /* replace1404_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a') */
   /* search1405_0_0 -> 6 in the cache */
   /* search1405_0 -> 3785 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3785 },
      -1,
   } },

   /* replace1405_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a') */
   /* search1406_0_0 -> 715 in the cache */
   /* search1406_0 -> 3839 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3839 },
      -1,
   } },

   /* replace1406_0 -> 715 in the cache */
   /* replace1406 -> 3876 in the cache */

   /* ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a') */
   /* search1407_0_0 -> 715 in the cache */
   /* search1407_0 -> 3841 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3841 },
      -1,
   } },

   /* replace1407_0 -> 715 in the cache */
   /* replace1407 -> 3878 in the cache */

   /* ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a') */
   /* search1408_0_0 -> 6 in the cache */
   /* search1408_0 -> 3845 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3845 },
      -1,
   } },

   /* replace1408_0 -> 6 in the cache */
   /* replace1408 -> 3882 in the cache */

   /* ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a') */
   /* search1409_0_0 -> 6 in the cache */
   /* search1409_0 -> 3847 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3847 },
      -1,
   } },

   /* replace1409_0 -> 6 in the cache */
   /* replace1409 -> 3884 in the cache */

   /* ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a') */
   /* search1410_0_0 -> 11 in the cache */
   /* search1410_0 -> 3781 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3781 },
      -1,
   } },

   /* replace1410_0 -> 11 in the cache */
   /* replace1410 -> 1763 in the cache */

   /* ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a') */
   /* search1411_0_0 -> 11 in the cache */
   /* search1411_0 -> 3786 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3786 },
      -1,
   } },

   /* replace1411_0 -> 11 in the cache */
   /* replace1411 -> 1765 in the cache */

   /* ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a') */
   /* search1412_0_0 -> 715 in the cache */
   /* search1412_0 -> 3857 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3857 },
      -1,
   } },

   /* replace1412_0 -> 715 in the cache */
   /* replace1412 -> 3876 in the cache */

   /* ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a') */
   /* search1413_0_0 -> 715 in the cache */
   /* search1413_0 -> 3859 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3859 },
      -1,
   } },

   /* replace1413_0 -> 715 in the cache */
   /* replace1413 -> 3878 in the cache */

   /* ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a') */
   /* search1414_0_0 -> 6 in the cache */
   /* search1414_0 -> 3863 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3863 },
      -1,
   } },

   /* replace1414_0 -> 6 in the cache */
   /* replace1414 -> 3882 in the cache */

   /* ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a') */
   /* search1415_0_0 -> 6 in the cache */
   /* search1415_0 -> 2975 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2975 },
      -1,
   } },

   /* replace1415_0 -> 6 in the cache */
   /* replace1415 -> 3884 in the cache */

   /* ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a') */
   /* search1416_0_0 -> 11 in the cache */
   /* search1416_0 -> 1740 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 1740 },
      -1,
   } },

   /* replace1416_0 -> 11 in the cache */
   /* replace1416 -> 1763 in the cache */

   /* ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a') */
   /* search1417_0_0 -> 11 in the cache */
   /* search1417_0 -> 1742 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 1742 },
      -1,
   } },

   /* replace1417_0 -> 11 in the cache */
   /* replace1417 -> 1765 in the cache */

   /* ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a') */
   /* search1418_0_0 -> 16 in the cache */
   /* search1418_0 -> 3782 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3782 },
      -1,
   } },

   /* replace1418_0 -> 16 in the cache */
   /* replace1418 -> 1847 in the cache */

   /* ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a') */
   /* search1419_0_0 -> 16 in the cache */
   /* search1419_0 -> 3787 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3787 },
      -1,
   } },

   /* replace1419_0 -> 16 in the cache */
   /* replace1419 -> 1849 in the cache */

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1420_0_0 -> 16 in the cache */
   /* search1420_0_1 -> 36 in the cache */
   /* search1420_0 -> 2901 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2901 },
      -1,
   } },

   /* replace1420_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1421_0_0 -> 16 in the cache */
   /* search1421_0_1 -> 36 in the cache */
   /* search1421_0 -> 2901 in the cache */
   /* search1421 -> 3899 in the cache */

   /* replace1421_0 -> 16 in the cache */
   /* replace1421 -> 3900 in the cache */

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1422_0_0 -> 16 in the cache */
   /* search1422_0_1 -> 36 in the cache */
   /* search1422_0 -> 2901 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2901 },
      -1,
   } },

   /* replace1422_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1423_0_0 -> 16 in the cache */
   /* search1423_0_1 -> 36 in the cache */
   /* search1423_0 -> 2901 in the cache */
   /* search1423 -> 3901 in the cache */

   /* replace1423_0 -> 16 in the cache */
   /* replace1423 -> 3902 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1424_0_0 -> 16 in the cache */
   /* search1424_0_1 -> 36 in the cache */
   /* search1424_0 -> 2901 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2901 },
      -1,
   } },

   /* replace1424_0 -> 16 in the cache */
   /* replace1424 -> 3782 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1425_0_0 -> 16 in the cache */
   /* search1425_0_1 -> 36 in the cache */
   /* search1425_0 -> 2901 in the cache */
   /* search1425 -> 3903 in the cache */

   /* replace1425_0 -> 16 in the cache */
   /* replace1425 -> 3782 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1426_0_0 -> 16 in the cache */
   /* search1426_0_1 -> 36 in the cache */
   /* search1426_0 -> 2901 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2901 },
      -1,
   } },

   /* replace1426_0 -> 16 in the cache */
   /* replace1426 -> 1966 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1427_0_0 -> 16 in the cache */
   /* search1427_0_1 -> 36 in the cache */
   /* search1427_0 -> 2901 in the cache */
   /* search1427 -> 3904 in the cache */

   /* replace1427_0 -> 16 in the cache */
   /* replace1427 -> 1966 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1428_0_0 -> 16 in the cache */
   /* search1428_0_1 -> 36 in the cache */
   /* search1428_0 -> 2901 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2901 },
      -1,
   } },

   /* replace1428_0 -> 16 in the cache */
   /* replace1428 -> 3003 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1429_0_0 -> 16 in the cache */
   /* search1429_0_1 -> 36 in the cache */
   /* search1429_0 -> 2901 in the cache */
   /* search1429 -> 3905 in the cache */

   /* replace1429_0 -> 16 in the cache */
   /* replace1429 -> 3003 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1430_0_0 -> 16 in the cache */
   /* search1430_0_1 -> 36 in the cache */
   /* search1430_0 -> 2901 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2901 },
      -1,
   } },

   /* replace1430_0 -> 16 in the cache */
   /* replace1430 -> 3787 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1431_0_0 -> 16 in the cache */
   /* search1431_0_1 -> 36 in the cache */
   /* search1431_0 -> 2901 in the cache */
   /* search1431 -> 3906 in the cache */

   /* replace1431_0 -> 16 in the cache */
   /* replace1431 -> 3787 in the cache */

   /* ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1432_0_0 -> 6 in the cache */
   /* search1432_0 -> 3845 in the cache */
   /* search1432_1_0 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3845, 3907 },
      -1,
   } },

   /* replace1432_0 -> 6 in the cache */
   /* replace1432_1_0 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6, 3909 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1433_0_0 -> 6 in the cache */
   /* search1433_0 -> 3845 in the cache */
   /* search1433_1_0 -> 2053 in the cache */
   /* search1433_1 -> 3907 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3845, 3907 },
      -1,
   } },

   /* replace1433_0 -> 6 in the cache */
   /* replace1433_1_0 -> 2053 in the cache */
   /* replace1433_1 -> 3909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6, 3909 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1434_0_0 -> 6 in the cache */
   /* search1434_0 -> 3845 in the cache */
   /* search1434_1_0 -> 2053 in the cache */
   /* search1434_1 -> 3907 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3845, 3907 },
      -1,
   } },

   /* replace1434_0 -> 6 in the cache */
   /* replace1434_1_0 -> 2053 in the cache */
   /* replace1434_1 -> 3909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 3909 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1435_0_0 -> 6 in the cache */
   /* search1435_0 -> 3845 in the cache */
   /* search1435_1_0 -> 2053 in the cache */
   /* search1435_1 -> 3907 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3845, 3907 },
      -1,
   } },

   /* replace1435_0 -> 6 in the cache */
   /* replace1435_1_0 -> 2053 in the cache */
   /* replace1435_1 -> 3909 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3909 },
      -1,
   } },

   /* ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3917 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3919 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3918, 3920 },
      -1,
   } },

   /* replace1436_0_0 -> 3917 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3917 },
      -1,
   } },
   /* replace1436_1 -> 3919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3922, 3919 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1437_0_0 -> 3917 in the cache */
   /* search1437_0 -> 3918 in the cache */
   /* search1437_1_0 -> 3919 in the cache */
   /* search1437_1 -> 3920 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3918, 3920 },
      -1,
   } },

   /* replace1437_0_0 -> 3917 in the cache */
   /* replace1437_0 -> 3922 in the cache */
   /* replace1437_1 -> 3919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3922, 3919 },
      -1,
   } },

   /* ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1438_0_0 -> 6 in the cache */
   /* search1438_0 -> 3845 in the cache */
   /* search1438_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3845, 1952 },
      -1,
   } },

   /* replace1438_0_0 -> 6 in the cache */
   /* replace1438_0_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 3927 },
      -1,
   } },
   /* replace1438_1_0_0_0 -> 243 in the cache */
   /* replace1438_1_0_0 -> 3927 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3927 },
      -1,
   } },
   /* replace1438_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3929, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3928, 3930 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1439_0_0 -> 6 in the cache */
   /* search1439_0 -> 3845 in the cache */
   /* search1439_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3845, 1952 },
      -1,
   } },

   /* replace1439_0_0 -> 6 in the cache */
   /* replace1439_0_1_0 -> 243 in the cache */
   /* replace1439_0_1 -> 3927 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 3927 },
      -1,
   } },
   /* replace1439_1_0_0_0 -> 243 in the cache */
   /* replace1439_1_0_0 -> 3927 in the cache */
   /* replace1439_1_0 -> 3929 in the cache */
   /* replace1439_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 3929, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3933, 3934 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1440_0_0 -> 6 in the cache */
   /* search1440_0 -> 3845 in the cache */
   /* search1440_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3845, 1952 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1440_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3937, 243 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1440_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3939, 243 },
      -1,
   } },
   /* replace1440_1_1_0 -> 6 in the cache */
   /* replace1440_1_1_1_0 -> 243 in the cache */
   /* replace1440_1_1_1 -> 3927 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3927 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3940, 3941 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3938, 3942 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1441_1_0 -> 2053 in the cache */
   /* search1441_1 -> 3907 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3944, 3907 },
      -1,
   } },

   /* replace1441_0_0 -> 11 in the cache */
   /* replace1441_0_1 -> 3939 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3939 },
      -1,
   } },
   /* replace1441_1_0_0 -> 11 in the cache */
   /* replace1441_1_0_1 -> 3937 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3937 },
      -1,
   } },
   /* replace1441_1_1_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 11 },
      -1,
   } },
   /* replace1441_1_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3948, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3947, 3949 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3946, 3950 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1442_0_0 -> 6 in the cache */
   /* search1442_0 -> 3845 in the cache */
   /* search1442_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3845, 1952 },
      -1,
   } },

   /* replace1442_0_0 -> 3939 in the cache */
   /* replace1442_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3939, 243 },
      -1,
   } },
   /* replace1442_1_0_0 -> 3937 in the cache */
   /* replace1442_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3937, 243 },
      -1,
   } },
   /* replace1442_1_1_0 -> 6 in the cache */
   /* replace1442_1_1_1_0 -> 243 in the cache */
   /* replace1442_1_1_1 -> 3927 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 3927 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3954, 3955 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3953, 3956 },
      -1,
   } },

   /* ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1443_0 -> 3944 in the cache */
   /* search1443_1_0 -> 2053 in the cache */
   /* search1443_1 -> 3907 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3944, 3907 },
      -1,
   } },

   /* replace1443_0_0 -> 11 in the cache */
   /* replace1443_0_1 -> 3937 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 3937 },
      -1,
   } },
   /* replace1443_1_0_0 -> 11 in the cache */
   /* replace1443_1_0_1 -> 3939 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 3939 },
      -1,
   } },
   /* replace1443_1_1_0_0 -> 11 in the cache */
   /* replace1443_1_1_0 -> 3948 in the cache */
   /* replace1443_1_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3948, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3960, 3961 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3959, 3962 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1444_0_0 -> 6 in the cache */
   /* search1444_0 -> 3863 in the cache */
   /* search1444_1_0 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3863, 3964 },
      -1,
   } },

   /* replace1444_0 -> 6 in the cache */
   /* replace1444_1_0 -> 2053 in the cache */
   /* replace1444_1 -> 3909 in the cache */
   /* replace1444 -> 3910 in the cache */

   /* ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1445_0_0 -> 6 in the cache */
   /* search1445_0 -> 3863 in the cache */
   /* search1445_1_0 -> 2053 in the cache */
   /* search1445_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3863, 3964 },
      -1,
   } },

   /* replace1445_0 -> 6 in the cache */
   /* replace1445_1_0 -> 2053 in the cache */
   /* replace1445_1 -> 3909 in the cache */
   /* replace1445 -> 3912 in the cache */

   /* ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1446_0_0 -> 6 in the cache */
   /* search1446_0 -> 3863 in the cache */
   /* search1446_1_0 -> 2053 in the cache */
   /* search1446_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3863, 3964 },
      -1,
   } },

   /* replace1446_0 -> 6 in the cache */
   /* replace1446_1_0 -> 2053 in the cache */
   /* replace1446_1 -> 3909 in the cache */
   /* replace1446 -> 3914 in the cache */

   /* ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1447_0_0 -> 6 in the cache */
   /* search1447_0 -> 3863 in the cache */
   /* search1447_1_0 -> 2053 in the cache */
   /* search1447_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3863, 3964 },
      -1,
   } },

   /* replace1447_0 -> 6 in the cache */
   /* replace1447_1_0 -> 2053 in the cache */
   /* replace1447_1 -> 3909 in the cache */
   /* replace1447 -> 3916 in the cache */

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1448_0_0 -> 3917 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3917 },
      -1,
   } },
   /* search1448_1_0 -> 3919 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3919 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3969, 3970 },
      -1,
   } },

   /* replace1448_0_0 -> 3917 in the cache */
   /* replace1448_0 -> 3922 in the cache */
   /* replace1448_1 -> 3919 in the cache */
   /* replace1448 -> 3923 in the cache */

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1449_0_0 -> 3917 in the cache */
   /* search1449_0 -> 3969 in the cache */
   /* search1449_1_0 -> 3919 in the cache */
   /* search1449_1 -> 3970 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3969, 3970 },
      -1,
   } },

   /* replace1449_0_0 -> 3917 in the cache */
   /* replace1449_0 -> 3922 in the cache */
   /* replace1449_1 -> 3919 in the cache */
   /* replace1449 -> 3925 in the cache */

   /* ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1450_0_0 -> 6 in the cache */
   /* search1450_0 -> 3863 in the cache */
   /* search1450_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3863, 33 },
      -1,
   } },

   /* replace1450_0_0 -> 6 in the cache */
   /* replace1450_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 3974 },
      -1,
   } },
   /* replace1450_1_0_0_0 -> 36 in the cache */
   /* replace1450_1_0_0 -> 3974 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3974 },
      -1,
   } },
   /* replace1450_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3976, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3975, 3977 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1451_0_0 -> 6 in the cache */
   /* search1451_0 -> 3863 in the cache */
   /* search1451_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3863, 33 },
      -1,
   } },

   /* replace1451_0_0 -> 6 in the cache */
   /* replace1451_0_1_0 -> 36 in the cache */
   /* replace1451_0_1 -> 3974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 3974 },
      -1,
   } },
   /* replace1451_1_0_0_0 -> 36 in the cache */
   /* replace1451_1_0_0 -> 3974 in the cache */
   /* replace1451_1_0 -> 3976 in the cache */
   /* replace1451_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 3976, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3980, 3981 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1452_0_0 -> 6 in the cache */
   /* search1452_0 -> 3863 in the cache */
   /* search1452_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3863, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1452_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3984, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1452_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3986, 36 },
      -1,
   } },
   /* replace1452_1_1_0 -> 6 in the cache */
   /* replace1452_1_1_1_0 -> 36 in the cache */
   /* replace1452_1_1_1 -> 3974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 3974 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3987, 3988 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3985, 3989 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   /* search1453_0 -> 271 in the cache */
   /* search1453_1_0 -> 2053 in the cache */
   /* search1453_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 271, 3964 },
      -1,
   } },

   /* replace1453_0_0 -> 16 in the cache */
   /* replace1453_0_1 -> 3986 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 3986 },
      -1,
   } },
   /* replace1453_1_0_0 -> 16 in the cache */
   /* replace1453_1_0_1 -> 3984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 3984 },
      -1,
   } },
   /* replace1453_1_1_0_0 -> 16 in the cache */
   /* replace1453_1_1_0 -> 3900 in the cache */
   /* replace1453_1_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3900, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3993, 3994 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3992, 3995 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1454_0_0 -> 6 in the cache */
   /* search1454_0 -> 3863 in the cache */
   /* search1454_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3863, 33 },
      -1,
   } },

   /* replace1454_0_0 -> 3986 in the cache */
   /* replace1454_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3986, 36 },
      -1,
   } },
   /* replace1454_1_0_0 -> 3984 in the cache */
   /* replace1454_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3984, 36 },
      -1,
   } },
   /* replace1454_1_1_0 -> 6 in the cache */
   /* replace1454_1_1_1_0 -> 36 in the cache */
   /* replace1454_1_1_1 -> 3974 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 3974 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3999, 4000 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3998, 4001 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1455_0 -> 271 in the cache */
   /* search1455_1_0 -> 2053 in the cache */
   /* search1455_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 271, 3964 },
      -1,
   } },

   /* replace1455_0_0 -> 16 in the cache */
   /* replace1455_0_1 -> 3984 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 3984 },
      -1,
   } },
   /* replace1455_1_0_0 -> 16 in the cache */
   /* replace1455_1_0_1 -> 3986 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 3986 },
      -1,
   } },
   /* replace1455_1_1_0_0 -> 16 in the cache */
   /* replace1455_1_1_0 -> 3900 in the cache */
   /* replace1455_1_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3900, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4005, 4006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4004, 4007 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1456_0_0 -> 6 in the cache */
   /* search1456_0 -> 3882 in the cache */
   /* search1456_1_0 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3882, 4009 },
      -1,
   } },

   /* replace1456_0 -> 6 in the cache */
   /* replace1456_1_0 -> 2053 in the cache */
   /* replace1456_1 -> 3909 in the cache */
   /* replace1456 -> 3910 in the cache */

   /* ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1457_0_0 -> 6 in the cache */
   /* search1457_0 -> 3882 in the cache */
   /* search1457_1_0 -> 2053 in the cache */
   /* search1457_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3882, 4009 },
      -1,
   } },

   /* replace1457_0 -> 6 in the cache */
   /* replace1457_1_0 -> 2053 in the cache */
   /* replace1457_1 -> 3909 in the cache */
   /* replace1457 -> 3912 in the cache */

   /* ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1458_0_0 -> 6 in the cache */
   /* search1458_0 -> 3882 in the cache */
   /* search1458_1_0 -> 2053 in the cache */
   /* search1458_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3882, 4009 },
      -1,
   } },

   /* replace1458_0 -> 6 in the cache */
   /* replace1458_1_0 -> 2053 in the cache */
   /* replace1458_1 -> 3909 in the cache */
   /* replace1458 -> 3914 in the cache */

   /* ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1459_0_0 -> 6 in the cache */
   /* search1459_0 -> 3882 in the cache */
   /* search1459_1_0 -> 2053 in the cache */
   /* search1459_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3882, 4009 },
      -1,
   } },

   /* replace1459_0 -> 6 in the cache */
   /* replace1459_1_0 -> 2053 in the cache */
   /* replace1459_1 -> 3909 in the cache */
   /* replace1459 -> 3916 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1460_0_0 -> 3917 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3917 },
      -1,
   } },
   /* search1460_1_0 -> 3919 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 3919 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4014, 4015 },
      -1,
   } },

   /* replace1460_0_0 -> 3917 in the cache */
   /* replace1460_0 -> 3922 in the cache */
   /* replace1460_1 -> 3919 in the cache */
   /* replace1460 -> 3923 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1461_0_0 -> 3917 in the cache */
   /* search1461_0 -> 4014 in the cache */
   /* search1461_1_0 -> 3919 in the cache */
   /* search1461_1 -> 4015 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4014, 4015 },
      -1,
   } },

   /* replace1461_0_0 -> 3917 in the cache */
   /* replace1461_0 -> 3922 in the cache */
   /* replace1461_1 -> 3919 in the cache */
   /* replace1461 -> 3925 in the cache */

   /* ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1462_0_0 -> 6 in the cache */
   /* search1462_0 -> 3882 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3882, 4018 },
      -1,
   } },

   /* replace1462_0_0 -> 6 in the cache */
   /* replace1462_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4020 },
      -1,
   } },
   /* replace1462_1_0_0_0 -> 41 in the cache */
   /* replace1462_1_0_0 -> 4020 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4020 },
      -1,
   } },
   /* replace1462_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4022, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4021, 4023 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1463_0_0 -> 6 in the cache */
   /* search1463_0 -> 3882 in the cache */
   /* search1463_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3882, 4018 },
      -1,
   } },

   /* replace1463_0_0 -> 6 in the cache */
   /* replace1463_0_1_0 -> 41 in the cache */
   /* replace1463_0_1 -> 4020 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4020 },
      -1,
   } },
   /* replace1463_1_0_0_0 -> 41 in the cache */
   /* replace1463_1_0_0 -> 4020 in the cache */
   /* replace1463_1_0 -> 4022 in the cache */
   /* replace1463_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4022, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4026, 4027 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1464_0_0 -> 6 in the cache */
   /* search1464_0 -> 3882 in the cache */
   /* search1464_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3882, 4018 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1464_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4030, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1464_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4032, 41 },
      -1,
   } },
   /* replace1464_1_1_0 -> 6 in the cache */
   /* replace1464_1_1_1_0 -> 41 in the cache */
   /* replace1464_1_1_1 -> 4020 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4020 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4033, 4034 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4031, 4035 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1465_1_0 -> 2053 in the cache */
   /* search1465_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4037, 4009 },
      -1,
   } },

   /* replace1465_0_0 -> 21 in the cache */
   /* replace1465_0_1 -> 4032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4032 },
      -1,
   } },
   /* replace1465_1_0_0 -> 21 in the cache */
   /* replace1465_1_0_1 -> 4030 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4030 },
      -1,
   } },
   /* replace1465_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1465_1_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4041, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4040, 4042 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4039, 4043 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1466_0_0 -> 6 in the cache */
   /* search1466_0 -> 3882 in the cache */
   /* search1466_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3882, 4018 },
      -1,
   } },

   /* replace1466_0_0 -> 4032 in the cache */
   /* replace1466_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4032, 41 },
      -1,
   } },
   /* replace1466_1_0_0 -> 4030 in the cache */
   /* replace1466_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4030, 41 },
      -1,
   } },
   /* replace1466_1_1_0 -> 6 in the cache */
   /* replace1466_1_1_1_0 -> 41 in the cache */
   /* replace1466_1_1_1 -> 4020 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4020 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4047, 4048 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4046, 4049 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1467_0 -> 4037 in the cache */
   /* search1467_1_0 -> 2053 in the cache */
   /* search1467_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4037, 4009 },
      -1,
   } },

   /* replace1467_0_0 -> 21 in the cache */
   /* replace1467_0_1 -> 4030 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4030 },
      -1,
   } },
   /* replace1467_1_0_0 -> 21 in the cache */
   /* replace1467_1_0_1 -> 4032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4032 },
      -1,
   } },
   /* replace1467_1_1_0_0 -> 21 in the cache */
   /* replace1467_1_1_0 -> 4041 in the cache */
   /* replace1467_1_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4041, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4053, 4054 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4052, 4055 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1468_0_0 -> 11 in the cache */
   /* search1468_0 -> 1740 in the cache */
   /* search1468_1_0 -> 2053 in the cache */
   /* search1468_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1740, 3964 },
      -1,
   } },

   /* replace1468_0 -> 11 in the cache */
   /* replace1468_1_0 -> 2053 in the cache */
   /* replace1468_1 -> 3907 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 3907 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1469_0_0 -> 11 in the cache */
   /* search1469_0 -> 1740 in the cache */
   /* search1469_1_0 -> 2053 in the cache */
   /* search1469_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1740, 3964 },
      -1,
   } },

   /* replace1469_0 -> 11 in the cache */
   /* replace1469_1_0 -> 2053 in the cache */
   /* replace1469_1 -> 3907 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 3907 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1470_0_0 -> 11 in the cache */
   /* search1470_0 -> 1740 in the cache */
   /* search1470_1_0 -> 2053 in the cache */
   /* search1470_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1740, 3964 },
      -1,
   } },

   /* replace1470_0 -> 11 in the cache */
   /* replace1470_1_0 -> 2053 in the cache */
   /* replace1470_1 -> 3907 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 3907 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1471_0_0 -> 11 in the cache */
   /* search1471_0 -> 1740 in the cache */
   /* search1471_1_0 -> 2053 in the cache */
   /* search1471_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1740, 3964 },
      -1,
   } },

   /* replace1471_0 -> 11 in the cache */
   /* replace1471_1_0 -> 2053 in the cache */
   /* replace1471_1 -> 3907 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 3907 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1472_0_0 -> 3917 in the cache */
   /* search1472_0 -> 3969 in the cache */
   /* search1472_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3969, 4065 },
      -1,
   } },

   /* replace1472_0_0 -> 3917 in the cache */
   /* replace1472_0 -> 3918 in the cache */
   /* replace1472_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3918, 507 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1473_0_0 -> 3917 in the cache */
   /* search1473_0 -> 3969 in the cache */
   /* search1473_1_0 -> 507 in the cache */
   /* search1473_1 -> 4065 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3969, 4065 },
      -1,
   } },

   /* replace1473_0_0 -> 3917 in the cache */
   /* replace1473_0 -> 3918 in the cache */
   /* replace1473_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3918, 507 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1474_0_0 -> 11 in the cache */
   /* search1474_0 -> 1740 in the cache */
   /* search1474_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1740, 4070 },
      -1,
   } },

   /* replace1474_0 -> 11 in the cache */
   /* replace1474_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4072 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1475_0_0 -> 11 in the cache */
   /* search1475_0 -> 1740 in the cache */
   /* search1475_1_0 -> 243 in the cache */
   /* search1475_1 -> 4070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1740, 4070 },
      -1,
   } },

   /* replace1475_0 -> 11 in the cache */
   /* replace1475_1_0 -> 243 in the cache */
   /* replace1475_1 -> 4072 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4072 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1476_0_0 -> 11 in the cache */
   /* search1476_0 -> 1740 in the cache */
   /* search1476_1_0 -> 243 in the cache */
   /* search1476_1 -> 4070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1740, 4070 },
      -1,
   } },

   /* replace1476_0 -> 11 in the cache */
   /* replace1476_1_0 -> 243 in the cache */
   /* replace1476_1 -> 4072 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4072 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1477_0_0 -> 11 in the cache */
   /* search1477_0 -> 1740 in the cache */
   /* search1477_1_0 -> 243 in the cache */
   /* search1477_1 -> 4070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1740, 4070 },
      -1,
   } },

   /* replace1477_0 -> 11 in the cache */
   /* replace1477_1_0 -> 243 in the cache */
   /* replace1477_1 -> 4072 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4072 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1478_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1478_1_0 -> 507 in the cache */
   /* search1478_1 -> 4065 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4080, 4065 },
      -1,
   } },

   /* replace1478_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 496 },
      -1,
   } },
   /* replace1478_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4082, 507 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1479_0_0 -> 496 in the cache */
   /* search1479_0 -> 4080 in the cache */
   /* search1479_1_0 -> 507 in the cache */
   /* search1479_1 -> 4065 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4080, 4065 },
      -1,
   } },

   /* replace1479_0_0 -> 496 in the cache */
   /* replace1479_0 -> 4082 in the cache */
   /* replace1479_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4082, 507 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1480_0_0 -> 11 in the cache */
   /* search1480_0 -> 1740 in the cache */
   /* search1480_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1740, 33 },
      -1,
   } },

   /* replace1480_0_0 -> 11 in the cache */
   /* replace1480_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4087 },
      -1,
   } },
   /* replace1480_1_0_0_0 -> 36 in the cache */
   /* replace1480_1_0_0 -> 4087 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4087 },
      -1,
   } },
   /* replace1480_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4089, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4088, 4090 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1481_0_0 -> 11 in the cache */
   /* search1481_0 -> 1740 in the cache */
   /* search1481_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1740, 33 },
      -1,
   } },

   /* replace1481_0_0 -> 11 in the cache */
   /* replace1481_0_1_0 -> 36 in the cache */
   /* replace1481_0_1 -> 4087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4087 },
      -1,
   } },
   /* replace1481_1_0_0_0 -> 36 in the cache */
   /* replace1481_1_0_0 -> 4087 in the cache */
   /* replace1481_1_0 -> 4089 in the cache */
   /* replace1481_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4089, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4093, 4094 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1482_0_0 -> 11 in the cache */
   /* search1482_0 -> 1740 in the cache */
   /* search1482_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1740, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1482_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4097, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1482_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4099, 36 },
      -1,
   } },
   /* replace1482_1_1_0 -> 11 in the cache */
   /* replace1482_1_1_1_0 -> 36 in the cache */
   /* replace1482_1_1_1 -> 4087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4087 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4100, 4101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4098, 4102 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1483_0 -> 271 in the cache */
   /* search1483_1_0 -> 243 in the cache */
   /* search1483_1 -> 4070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 271, 4070 },
      -1,
   } },

   /* replace1483_0_0 -> 16 in the cache */
   /* replace1483_0_1 -> 4099 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4099 },
      -1,
   } },
   /* replace1483_1_0_0 -> 16 in the cache */
   /* replace1483_1_0_1 -> 4097 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4097 },
      -1,
   } },
   /* replace1483_1_1_0_0 -> 16 in the cache */
   /* replace1483_1_1_0 -> 3902 in the cache */
   /* replace1483_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3902, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4106, 4107 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4105, 4108 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1484_0_0 -> 11 in the cache */
   /* search1484_0 -> 1740 in the cache */
   /* search1484_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1740, 33 },
      -1,
   } },

   /* replace1484_0_0 -> 4099 in the cache */
   /* replace1484_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4099, 36 },
      -1,
   } },
   /* replace1484_1_0_0 -> 4097 in the cache */
   /* replace1484_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4097, 36 },
      -1,
   } },
   /* replace1484_1_1_0 -> 11 in the cache */
   /* replace1484_1_1_1_0 -> 36 in the cache */
   /* replace1484_1_1_1 -> 4087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4087 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4112, 4113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4111, 4114 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1485_0 -> 271 in the cache */
   /* search1485_1_0 -> 243 in the cache */
   /* search1485_1 -> 4070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 271, 4070 },
      -1,
   } },

   /* replace1485_0_0 -> 16 in the cache */
   /* replace1485_0_1 -> 4097 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4097 },
      -1,
   } },
   /* replace1485_1_0_0 -> 16 in the cache */
   /* replace1485_1_0_1 -> 4099 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4099 },
      -1,
   } },
   /* replace1485_1_1_0_0 -> 16 in the cache */
   /* replace1485_1_1_0 -> 3902 in the cache */
   /* replace1485_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3902, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4118, 4119 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4117, 4120 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1486_0_0 -> 11 in the cache */
   /* search1486_0 -> 1763 in the cache */
   /* search1486_1_0 -> 2053 in the cache */
   /* search1486_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1763, 4009 },
      -1,
   } },

   /* replace1486_0 -> 11 in the cache */
   /* replace1486_1_0 -> 2053 in the cache */
   /* replace1486_1 -> 3907 in the cache */
   /* replace1486 -> 4058 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1487_0_0 -> 11 in the cache */
   /* search1487_0 -> 1763 in the cache */
   /* search1487_1_0 -> 2053 in the cache */
   /* search1487_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1763, 4009 },
      -1,
   } },

   /* replace1487_0 -> 11 in the cache */
   /* replace1487_1_0 -> 2053 in the cache */
   /* replace1487_1 -> 3907 in the cache */
   /* replace1487 -> 4060 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1488_0_0 -> 11 in the cache */
   /* search1488_0 -> 1763 in the cache */
   /* search1488_1_0 -> 2053 in the cache */
   /* search1488_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1763, 4009 },
      -1,
   } },

   /* replace1488_0 -> 11 in the cache */
   /* replace1488_1_0 -> 2053 in the cache */
   /* replace1488_1 -> 3907 in the cache */
   /* replace1488 -> 4062 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1489_0_0 -> 11 in the cache */
   /* search1489_0 -> 1763 in the cache */
   /* search1489_1_0 -> 2053 in the cache */
   /* search1489_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1763, 4009 },
      -1,
   } },

   /* replace1489_0 -> 11 in the cache */
   /* replace1489_1_0 -> 2053 in the cache */
   /* replace1489_1 -> 3907 in the cache */
   /* replace1489 -> 4064 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1490_0_0 -> 3917 in the cache */
   /* search1490_0 -> 4014 in the cache */
   /* search1490_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4014, 4126 },
      -1,
   } },

   /* replace1490_0_0 -> 3917 in the cache */
   /* replace1490_0 -> 3918 in the cache */
   /* replace1490_1 -> 507 in the cache */
   /* replace1490 -> 4067 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1491_0_0 -> 3917 in the cache */
   /* search1491_0 -> 4014 in the cache */
   /* search1491_1_0 -> 507 in the cache */
   /* search1491_1 -> 4126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4014, 4126 },
      -1,
   } },

   /* replace1491_0_0 -> 3917 in the cache */
   /* replace1491_0 -> 3918 in the cache */
   /* replace1491_1 -> 507 in the cache */
   /* replace1491 -> 4069 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1492_0_0 -> 11 in the cache */
   /* search1492_0 -> 1763 in the cache */
   /* search1492_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1763, 4129 },
      -1,
   } },

   /* replace1492_0 -> 11 in the cache */
   /* replace1492_1_0 -> 243 in the cache */
   /* replace1492_1 -> 4072 in the cache */
   /* replace1492 -> 4073 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1493_0_0 -> 11 in the cache */
   /* search1493_0 -> 1763 in the cache */
   /* search1493_1_0 -> 243 in the cache */
   /* search1493_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1763, 4129 },
      -1,
   } },

   /* replace1493_0 -> 11 in the cache */
   /* replace1493_1_0 -> 243 in the cache */
   /* replace1493_1 -> 4072 in the cache */
   /* replace1493 -> 4075 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1494_0_0 -> 11 in the cache */
   /* search1494_0 -> 1763 in the cache */
   /* search1494_1_0 -> 243 in the cache */
   /* search1494_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1763, 4129 },
      -1,
   } },

   /* replace1494_0 -> 11 in the cache */
   /* replace1494_1_0 -> 243 in the cache */
   /* replace1494_1 -> 4072 in the cache */
   /* replace1494 -> 4077 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1495_0_0 -> 11 in the cache */
   /* search1495_0 -> 1763 in the cache */
   /* search1495_1_0 -> 243 in the cache */
   /* search1495_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1763, 4129 },
      -1,
   } },

   /* replace1495_0 -> 11 in the cache */
   /* replace1495_1_0 -> 243 in the cache */
   /* replace1495_1 -> 4072 in the cache */
   /* replace1495 -> 4079 in the cache */

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1496_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1496_1_0 -> 507 in the cache */
   /* search1496_1 -> 4126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4134, 4126 },
      -1,
   } },

   /* replace1496_0_0 -> 496 in the cache */
   /* replace1496_0 -> 4082 in the cache */
   /* replace1496_1 -> 507 in the cache */
   /* replace1496 -> 4083 in the cache */

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1497_0_0 -> 496 in the cache */
   /* search1497_0 -> 4134 in the cache */
   /* search1497_1_0 -> 507 in the cache */
   /* search1497_1 -> 4126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4134, 4126 },
      -1,
   } },

   /* replace1497_0_0 -> 496 in the cache */
   /* replace1497_0 -> 4082 in the cache */
   /* replace1497_1 -> 507 in the cache */
   /* replace1497 -> 4085 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1498_0_0 -> 11 in the cache */
   /* search1498_0 -> 1763 in the cache */
   /* search1498_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1763, 4018 },
      -1,
   } },

   /* replace1498_0_0 -> 11 in the cache */
   /* replace1498_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4138 },
      -1,
   } },
   /* replace1498_1_0_0_0 -> 41 in the cache */
   /* replace1498_1_0_0 -> 4138 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4138 },
      -1,
   } },
   /* replace1498_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4140, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4139, 4141 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1499_0_0 -> 11 in the cache */
   /* search1499_0 -> 1763 in the cache */
   /* search1499_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1763, 4018 },
      -1,
   } },

   /* replace1499_0_0 -> 11 in the cache */
   /* replace1499_0_1_0 -> 41 in the cache */
   /* replace1499_0_1 -> 4138 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4138 },
      -1,
   } },
   /* replace1499_1_0_0_0 -> 41 in the cache */
   /* replace1499_1_0_0 -> 4138 in the cache */
   /* replace1499_1_0 -> 4140 in the cache */
   /* replace1499_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4140, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4144, 4145 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1500_0_0 -> 11 in the cache */
   /* search1500_0 -> 1763 in the cache */
   /* search1500_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1763, 4018 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1500_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4148, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1500_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4150, 41 },
      -1,
   } },
   /* replace1500_1_1_0 -> 11 in the cache */
   /* replace1500_1_1_1_0 -> 41 in the cache */
   /* replace1500_1_1_1 -> 4138 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4138 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4151, 4152 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4149, 4153 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1501_0 -> 4037 in the cache */
   /* search1501_1_0 -> 243 in the cache */
   /* search1501_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4037, 4129 },
      -1,
   } },

   /* replace1501_0_0 -> 21 in the cache */
   /* replace1501_0_1 -> 4150 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4150 },
      -1,
   } },
   /* replace1501_1_0_0 -> 21 in the cache */
   /* replace1501_1_0_1 -> 4148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4148 },
      -1,
   } },
   /* replace1501_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1501_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4158, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4157, 4159 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4156, 4160 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1502_0_0 -> 11 in the cache */
   /* search1502_0 -> 1763 in the cache */
   /* search1502_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1763, 4018 },
      -1,
   } },

   /* replace1502_0_0 -> 4150 in the cache */
   /* replace1502_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4150, 41 },
      -1,
   } },
   /* replace1502_1_0_0 -> 4148 in the cache */
   /* replace1502_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4148, 41 },
      -1,
   } },
   /* replace1502_1_1_0 -> 11 in the cache */
   /* replace1502_1_1_1_0 -> 41 in the cache */
   /* replace1502_1_1_1 -> 4138 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4138 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4164, 4165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4163, 4166 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1503_0 -> 4037 in the cache */
   /* search1503_1_0 -> 243 in the cache */
   /* search1503_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4037, 4129 },
      -1,
   } },

   /* replace1503_0_0 -> 21 in the cache */
   /* replace1503_0_1 -> 4148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4148 },
      -1,
   } },
   /* replace1503_1_0_0 -> 21 in the cache */
   /* replace1503_1_0_1 -> 4150 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4150 },
      -1,
   } },
   /* replace1503_1_1_0_0 -> 21 in the cache */
   /* replace1503_1_1_0 -> 4158 in the cache */
   /* replace1503_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4158, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4170, 4171 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4169, 4172 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1504_0_0 -> 16 in the cache */
   /* search1504_0 -> 1847 in the cache */
   /* search1504_1_0 -> 2053 in the cache */
   /* search1504_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1847, 4009 },
      -1,
   } },

   /* replace1504_0 -> 16 in the cache */
   /* replace1504_1_0 -> 2053 in the cache */
   /* replace1504_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 3964 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1505_0_0 -> 16 in the cache */
   /* search1505_0 -> 1847 in the cache */
   /* search1505_1_0 -> 2053 in the cache */
   /* search1505_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1847, 4009 },
      -1,
   } },

   /* replace1505_0 -> 16 in the cache */
   /* replace1505_1_0 -> 2053 in the cache */
   /* replace1505_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 3964 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1506_0_0 -> 16 in the cache */
   /* search1506_0 -> 1847 in the cache */
   /* search1506_1_0 -> 2053 in the cache */
   /* search1506_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1847, 4009 },
      -1,
   } },

   /* replace1506_0 -> 16 in the cache */
   /* replace1506_1_0 -> 2053 in the cache */
   /* replace1506_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 3964 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1507_0_0 -> 16 in the cache */
   /* search1507_0 -> 1847 in the cache */
   /* search1507_1_0 -> 2053 in the cache */
   /* search1507_1 -> 4009 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1847, 4009 },
      -1,
   } },

   /* replace1507_0 -> 16 in the cache */
   /* replace1507_1_0 -> 2053 in the cache */
   /* replace1507_1 -> 3964 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 3964 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1508_0_0 -> 3917 in the cache */
   /* search1508_0 -> 4014 in the cache */
   /* search1508_1_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4014, 4182 },
      -1,
   } },

   /* replace1508_0_0 -> 3917 in the cache */
   /* replace1508_0 -> 3969 in the cache */
   /* replace1508_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3969, 360 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1509_0_0 -> 3917 in the cache */
   /* search1509_0 -> 4014 in the cache */
   /* search1509_1_0 -> 360 in the cache */
   /* search1509_1 -> 4182 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4014, 4182 },
      -1,
   } },

   /* replace1509_0_0 -> 3917 in the cache */
   /* replace1509_0 -> 3969 in the cache */
   /* replace1509_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3969, 360 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1510_0_0 -> 16 in the cache */
   /* search1510_0 -> 1847 in the cache */
   /* search1510_1_0 -> 243 in the cache */
   /* search1510_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1847, 4129 },
      -1,
   } },

   /* replace1510_0 -> 16 in the cache */
   /* replace1510_1_0 -> 243 in the cache */
   /* replace1510_1 -> 4070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4070 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1511_0_0 -> 16 in the cache */
   /* search1511_0 -> 1847 in the cache */
   /* search1511_1_0 -> 243 in the cache */
   /* search1511_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1847, 4129 },
      -1,
   } },

   /* replace1511_0 -> 16 in the cache */
   /* replace1511_1_0 -> 243 in the cache */
   /* replace1511_1 -> 4070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4070 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1512_0_0 -> 16 in the cache */
   /* search1512_0 -> 1847 in the cache */
   /* search1512_1_0 -> 243 in the cache */
   /* search1512_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1847, 4129 },
      -1,
   } },

   /* replace1512_0 -> 16 in the cache */
   /* replace1512_1_0 -> 243 in the cache */
   /* replace1512_1 -> 4070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4070 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1513_0_0 -> 16 in the cache */
   /* search1513_0 -> 1847 in the cache */
   /* search1513_1_0 -> 243 in the cache */
   /* search1513_1 -> 4129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1847, 4129 },
      -1,
   } },

   /* replace1513_0 -> 16 in the cache */
   /* replace1513_1_0 -> 243 in the cache */
   /* replace1513_1 -> 4070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4070 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1514_0_0 -> 496 in the cache */
   /* search1514_0 -> 4134 in the cache */
   /* search1514_1_0 -> 360 in the cache */
   /* search1514_1 -> 4182 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4134, 4182 },
      -1,
   } },

   /* replace1514_0_0 -> 496 in the cache */
   /* replace1514_0 -> 4080 in the cache */
   /* replace1514_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4080, 360 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1515_0_0 -> 496 in the cache */
   /* search1515_0 -> 4134 in the cache */
   /* search1515_1_0 -> 360 in the cache */
   /* search1515_1 -> 4182 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4134, 4182 },
      -1,
   } },

   /* replace1515_0_0 -> 496 in the cache */
   /* replace1515_0 -> 4080 in the cache */
   /* replace1515_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4080, 360 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1516_0_0 -> 16 in the cache */
   /* search1516_0 -> 1847 in the cache */
   /* search1516_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1847, 4199 },
      -1,
   } },

   /* replace1516_0 -> 16 in the cache */
   /* replace1516_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4201 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1517_0_0 -> 16 in the cache */
   /* search1517_0 -> 1847 in the cache */
   /* search1517_1_0 -> 36 in the cache */
   /* search1517_1 -> 4199 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1847, 4199 },
      -1,
   } },

   /* replace1517_0 -> 16 in the cache */
   /* replace1517_1_0 -> 36 in the cache */
   /* replace1517_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4201 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1518_0_0 -> 16 in the cache */
   /* search1518_0 -> 1847 in the cache */
   /* search1518_1_0 -> 36 in the cache */
   /* search1518_1 -> 4199 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1847, 4199 },
      -1,
   } },

   /* replace1518_0 -> 16 in the cache */
   /* replace1518_1_0 -> 36 in the cache */
   /* replace1518_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4201 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1519_0_0 -> 16 in the cache */
   /* search1519_0 -> 1847 in the cache */
   /* search1519_1_0 -> 36 in the cache */
   /* search1519_1 -> 4199 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1847, 4199 },
      -1,
   } },

   /* replace1519_0 -> 16 in the cache */
   /* replace1519_1_0 -> 36 in the cache */
   /* replace1519_1 -> 4201 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4201 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1520_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 358 },
      -1,
   } },
   /* search1520_1_0 -> 360 in the cache */
   /* search1520_1 -> 4182 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4209, 4182 },
      -1,
   } },

   /* replace1520_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 358 },
      -1,
   } },
   /* replace1520_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4211, 360 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1521_0_0 -> 358 in the cache */
   /* search1521_0 -> 4209 in the cache */
   /* search1521_1_0 -> 360 in the cache */
   /* search1521_1 -> 4182 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4209, 4182 },
      -1,
   } },

   /* replace1521_0_0 -> 358 in the cache */
   /* replace1521_0 -> 4211 in the cache */
   /* replace1521_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4211, 360 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1522_0_0 -> 16 in the cache */
   /* search1522_0 -> 1847 in the cache */
   /* search1522_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1847, 4018 },
      -1,
   } },

   /* replace1522_0_0 -> 16 in the cache */
   /* replace1522_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 4216 },
      -1,
   } },
   /* replace1522_1_0_0_0 -> 41 in the cache */
   /* replace1522_1_0_0 -> 4216 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4216 },
      -1,
   } },
   /* replace1522_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4218, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4217, 4219 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1523_0_0 -> 16 in the cache */
   /* search1523_0 -> 1847 in the cache */
   /* search1523_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1847, 4018 },
      -1,
   } },

   /* replace1523_0_0 -> 16 in the cache */
   /* replace1523_0_1_0 -> 41 in the cache */
   /* replace1523_0_1 -> 4216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 4216 },
      -1,
   } },
   /* replace1523_1_0_0_0 -> 41 in the cache */
   /* replace1523_1_0_0 -> 4216 in the cache */
   /* replace1523_1_0 -> 4218 in the cache */
   /* replace1523_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4218, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4222, 4223 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b')))) */
   /* search1524_0_0 -> 16 in the cache */
   /* search1524_0 -> 1847 in the cache */
   /* search1524_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1847, 4018 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80000000 /* -2147483648 */ },
   } },
   /* replace1524_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4226, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   /* replace1524_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4228, 41 },
      -1,
   } },
   /* replace1524_1_1_0 -> 16 in the cache */
   /* replace1524_1_1_1_0 -> 41 in the cache */
   /* replace1524_1_1_1 -> 4216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4229, 4230 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4227, 4231 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b'))) */
   /* search1525_0 -> 4037 in the cache */
   /* search1525_1_0 -> 36 in the cache */
   /* search1525_1 -> 4199 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4037, 4199 },
      -1,
   } },

   /* replace1525_0_0 -> 21 in the cache */
   /* replace1525_0_1 -> 4228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4228 },
      -1,
   } },
   /* replace1525_1_0_0 -> 21 in the cache */
   /* replace1525_1_0_1 -> 4226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4226 },
      -1,
   } },
   /* replace1525_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1525_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4236, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4235, 4237 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4234, 4238 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b')))) */
   /* search1526_0_0 -> 16 in the cache */
   /* search1526_0 -> 1847 in the cache */
   /* search1526_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1847, 4018 },
      -1,
   } },

   /* replace1526_0_0 -> 4228 in the cache */
   /* replace1526_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4228, 41 },
      -1,
   } },
   /* replace1526_1_0_0 -> 4226 in the cache */
   /* replace1526_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4226, 41 },
      -1,
   } },
   /* replace1526_1_1_0 -> 16 in the cache */
   /* replace1526_1_1_1_0 -> 41 in the cache */
   /* replace1526_1_1_1 -> 4216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4242, 4243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4241, 4244 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b'))) */
   /* search1527_0 -> 4037 in the cache */
   /* search1527_1_0 -> 36 in the cache */
   /* search1527_1 -> 4199 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4037, 4199 },
      -1,
   } },

   /* replace1527_0_0 -> 21 in the cache */
   /* replace1527_0_1 -> 4226 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4226 },
      -1,
   } },
   /* replace1527_1_0_0 -> 21 in the cache */
   /* replace1527_1_0_1 -> 4228 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4228 },
      -1,
   } },
   /* replace1527_1_1_0_0 -> 21 in the cache */
   /* replace1527_1_1_0 -> 4236 in the cache */
   /* replace1527_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4236, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4248, 4249 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4247, 4250 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1528_0_0 -> 6 in the cache */
   /* search1528_0 -> 3847 in the cache */
   /* search1528_1_0 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3847, 4252 },
      -1,
   } },

   /* replace1528_0 -> 6 in the cache */
   /* replace1528_1_0 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6, 4254 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1529_0_0 -> 6 in the cache */
   /* search1529_0 -> 3847 in the cache */
   /* search1529_1_0 -> 2053 in the cache */
   /* search1529_1 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3847, 4252 },
      -1,
   } },

   /* replace1529_0 -> 6 in the cache */
   /* replace1529_1_0 -> 2053 in the cache */
   /* replace1529_1 -> 4254 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6, 4254 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1530_0_0 -> 6 in the cache */
   /* search1530_0 -> 3847 in the cache */
   /* search1530_1_0 -> 2053 in the cache */
   /* search1530_1 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3847, 4252 },
      -1,
   } },

   /* replace1530_0 -> 6 in the cache */
   /* replace1530_1_0 -> 2053 in the cache */
   /* replace1530_1 -> 4254 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 4254 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1531_0_0 -> 6 in the cache */
   /* search1531_0 -> 3847 in the cache */
   /* search1531_1_0 -> 2053 in the cache */
   /* search1531_1 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3847, 4252 },
      -1,
   } },

   /* replace1531_0 -> 6 in the cache */
   /* replace1531_1_0 -> 2053 in the cache */
   /* replace1531_1 -> 4254 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 4254 },
      -1,
   } },

   /* ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1532_0_0 -> 3917 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3917 },
      -1,
   } },
   /* search1532_1_0 -> 3919 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3919 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4262, 4263 },
      -1,
   } },

   /* replace1532_0_0 -> 3917 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3917 },
      -1,
   } },
   /* replace1532_1 -> 3919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4265, 3919 },
      -1,
   } },

   /* ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1533_0_0 -> 3917 in the cache */
   /* search1533_0 -> 4262 in the cache */
   /* search1533_1_0 -> 3919 in the cache */
   /* search1533_1 -> 4263 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4262, 4263 },
      -1,
   } },

   /* replace1533_0_0 -> 3917 in the cache */
   /* replace1533_0 -> 4265 in the cache */
   /* replace1533_1 -> 3919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4265, 3919 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1534_0_0 -> 6 in the cache */
   /* search1534_0 -> 3847 in the cache */
   /* search1534_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3847, 1952 },
      -1,
   } },

   /* replace1534_0_0 -> 6 in the cache */
   /* replace1534_0_1_0 -> 243 in the cache */
   /* replace1534_0_1 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 1960 },
      -1,
   } },
   /* replace1534_1_0_0_0 -> 243 in the cache */
   /* replace1534_1_0_0 -> 1960 in the cache */
   /* replace1534_1_0 -> 1961 in the cache */
   /* replace1534_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 1961, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4270, 4271 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1535_0_0 -> 6 in the cache */
   /* search1535_0 -> 3847 in the cache */
   /* search1535_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3847, 1952 },
      -1,
   } },

   /* replace1535_0_0 -> 6 in the cache */
   /* replace1535_0_1_0 -> 243 in the cache */
   /* replace1535_0_1 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 1960 },
      -1,
   } },
   /* replace1535_1_0_0_0 -> 243 in the cache */
   /* replace1535_1_0_0 -> 1960 in the cache */
   /* replace1535_1_0 -> 1961 in the cache */
   /* replace1535_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 1961, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4274, 4275 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1536_0_0 -> 6 in the cache */
   /* search1536_0 -> 3847 in the cache */
   /* search1536_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3847, 1952 },
      -1,
   } },

   /* replace1536_0_0 -> 811 in the cache */
   /* replace1536_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 811, 243 },
      -1,
   } },
   /* replace1536_1_0_0 -> 1954 in the cache */
   /* replace1536_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1954, 243 },
      -1,
   } },
   /* replace1536_1_1_0 -> 6 in the cache */
   /* replace1536_1_1_1_0 -> 243 in the cache */
   /* replace1536_1_1_1 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 1960 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4279, 4280 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4278, 4281 },
      -1,
   } },

   /* ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1537_0 -> 3944 in the cache */
   /* search1537_1_0 -> 2053 in the cache */
   /* search1537_1 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3944, 4252 },
      -1,
   } },

   /* replace1537_0_0 -> 11 in the cache */
   /* replace1537_0_1 -> 1954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 1954 },
      -1,
   } },
   /* replace1537_1_0_0 -> 11 in the cache */
   /* replace1537_1_0_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 811 },
      -1,
   } },
   /* replace1537_1_1_0_0 -> 11 in the cache */
   /* replace1537_1_1_0 -> 1950 in the cache */
   /* replace1537_1_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1950, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4285, 4286 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4284, 4287 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1538_0_0 -> 6 in the cache */
   /* search1538_0 -> 3847 in the cache */
   /* search1538_1 -> 1952 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3847, 1952 },
      -1,
   } },

   /* replace1538_0_0 -> 1954 in the cache */
   /* replace1538_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1954, 243 },
      -1,
   } },
   /* replace1538_1_0_0 -> 811 in the cache */
   /* replace1538_1_0_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 811, 243 },
      -1,
   } },
   /* replace1538_1_1_0 -> 6 in the cache */
   /* replace1538_1_1_1_0 -> 243 in the cache */
   /* replace1538_1_1_1 -> 1960 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 1960 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4291, 4292 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4290, 4293 },
      -1,
   } },

   /* ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1539_0 -> 3944 in the cache */
   /* search1539_1_0 -> 2053 in the cache */
   /* search1539_1 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3944, 4252 },
      -1,
   } },

   /* replace1539_0_0 -> 11 in the cache */
   /* replace1539_0_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 811 },
      -1,
   } },
   /* replace1539_1_0_0 -> 11 in the cache */
   /* replace1539_1_0_1 -> 1954 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 1954 },
      -1,
   } },
   /* replace1539_1_1_0_0 -> 11 in the cache */
   /* replace1539_1_1_0 -> 1950 in the cache */
   /* replace1539_1_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1950, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4297, 4298 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4296, 4299 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1540_0_0 -> 6 in the cache */
   /* search1540_0 -> 2975 in the cache */
   /* search1540_1_0 -> 2053 in the cache */
   /* search1540_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2975, 2977 },
      -1,
   } },

   /* replace1540_0 -> 6 in the cache */
   /* replace1540_1_0 -> 2053 in the cache */
   /* replace1540_1 -> 4254 in the cache */
   /* replace1540 -> 4255 in the cache */

   /* ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1541_0_0 -> 6 in the cache */
   /* search1541_0 -> 2975 in the cache */
   /* search1541_1_0 -> 2053 in the cache */
   /* search1541_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2975, 2977 },
      -1,
   } },

   /* replace1541_0 -> 6 in the cache */
   /* replace1541_1_0 -> 2053 in the cache */
   /* replace1541_1 -> 4254 in the cache */
   /* replace1541 -> 4257 in the cache */

   /* ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1542_0_0 -> 6 in the cache */
   /* search1542_0 -> 2975 in the cache */
   /* search1542_1_0 -> 2053 in the cache */
   /* search1542_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2975, 2977 },
      -1,
   } },

   /* replace1542_0 -> 6 in the cache */
   /* replace1542_1_0 -> 2053 in the cache */
   /* replace1542_1 -> 4254 in the cache */
   /* replace1542 -> 4259 in the cache */

   /* ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1543_0_0 -> 6 in the cache */
   /* search1543_0 -> 2975 in the cache */
   /* search1543_1_0 -> 2053 in the cache */
   /* search1543_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2975, 2977 },
      -1,
   } },

   /* replace1543_0 -> 6 in the cache */
   /* replace1543_1_0 -> 2053 in the cache */
   /* replace1543_1 -> 4254 in the cache */
   /* replace1543 -> 4261 in the cache */

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1544_0_0 -> 3917 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3917 },
      -1,
   } },
   /* search1544_1_0 -> 3919 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3919 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4305, 4306 },
      -1,
   } },

   /* replace1544_0_0 -> 3917 in the cache */
   /* replace1544_0 -> 4265 in the cache */
   /* replace1544_1 -> 3919 in the cache */
   /* replace1544 -> 4266 in the cache */

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1545_0_0 -> 3917 in the cache */
   /* search1545_0 -> 4305 in the cache */
   /* search1545_1_0 -> 3919 in the cache */
   /* search1545_1 -> 4306 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4305, 4306 },
      -1,
   } },

   /* replace1545_0_0 -> 3917 in the cache */
   /* replace1545_0 -> 4265 in the cache */
   /* replace1545_1 -> 3919 in the cache */
   /* replace1545 -> 4268 in the cache */

   /* ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1546_0_0 -> 6 in the cache */
   /* search1546_0 -> 2975 in the cache */
   /* search1546_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2975, 33 },
      -1,
   } },

   /* replace1546_0_0 -> 6 in the cache */
   /* replace1546_0_1_0 -> 36 in the cache */
   /* replace1546_0_1 -> 1968 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 1968 },
      -1,
   } },
   /* replace1546_1_0_0_0 -> 36 in the cache */
   /* replace1546_1_0_0 -> 1968 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1968 },
      -1,
   } },
   /* replace1546_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4311, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4310, 4312 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1547_0_0 -> 6 in the cache */
   /* search1547_0 -> 2975 in the cache */
   /* search1547_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2975, 33 },
      -1,
   } },

   /* replace1547_0_0 -> 6 in the cache */
   /* replace1547_0_1_0 -> 36 in the cache */
   /* replace1547_0_1 -> 1968 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 1968 },
      -1,
   } },
   /* replace1547_1_0_0_0 -> 36 in the cache */
   /* replace1547_1_0_0 -> 1968 in the cache */
   /* replace1547_1_0 -> 4311 in the cache */
   /* replace1547_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4311, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4315, 4316 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1548_0_0 -> 6 in the cache */
   /* search1548_0 -> 2975 in the cache */
   /* search1548_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2975, 33 },
      -1,
   } },

   /* replace1548_0_0 -> 120 in the cache */
   /* replace1548_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   /* replace1548_1_0_0 -> 965 in the cache */
   /* replace1548_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 965, 36 },
      -1,
   } },
   /* replace1548_1_1_0 -> 6 in the cache */
   /* replace1548_1_1_1_0 -> 36 in the cache */
   /* replace1548_1_1_1 -> 1968 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 1968 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4320, 4321 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4319, 4322 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1549_0 -> 271 in the cache */
   /* search1549_1_0 -> 2053 in the cache */
   /* search1549_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 271, 2977 },
      -1,
   } },

   /* replace1549_0_0 -> 16 in the cache */
   /* replace1549_0_1 -> 965 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 965 },
      -1,
   } },
   /* replace1549_1_0_0 -> 16 in the cache */
   /* replace1549_1_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace1549_1_1_0_0 -> 16 in the cache */
   /* replace1549_1_1_0 -> 1966 in the cache */
   /* replace1549_1_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1966, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4326, 4327 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4325, 4328 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1550_0_0 -> 6 in the cache */
   /* search1550_0 -> 2975 in the cache */
   /* search1550_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2975, 33 },
      -1,
   } },

   /* replace1550_0_0 -> 965 in the cache */
   /* replace1550_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 965, 36 },
      -1,
   } },
   /* replace1550_1_0_0 -> 120 in the cache */
   /* replace1550_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 120, 36 },
      -1,
   } },
   /* replace1550_1_1_0 -> 6 in the cache */
   /* replace1550_1_1_1_0 -> 36 in the cache */
   /* replace1550_1_1_1 -> 1968 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 1968 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4332, 4333 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4331, 4334 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1551_0 -> 271 in the cache */
   /* search1551_1_0 -> 2053 in the cache */
   /* search1551_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 271, 2977 },
      -1,
   } },

   /* replace1551_0_0 -> 16 in the cache */
   /* replace1551_0_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 120 },
      -1,
   } },
   /* replace1551_1_0_0 -> 16 in the cache */
   /* replace1551_1_0_1 -> 965 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 965 },
      -1,
   } },
   /* replace1551_1_1_0_0 -> 16 in the cache */
   /* replace1551_1_1_0 -> 1966 in the cache */
   /* replace1551_1_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1966, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4338, 4339 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4337, 4340 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1552_0_0 -> 6 in the cache */
   /* search1552_0 -> 3884 in the cache */
   /* search1552_1_0 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3884, 4342 },
      -1,
   } },

   /* replace1552_0 -> 6 in the cache */
   /* replace1552_1_0 -> 2053 in the cache */
   /* replace1552_1 -> 4254 in the cache */
   /* replace1552 -> 4255 in the cache */

   /* ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1553_0_0 -> 6 in the cache */
   /* search1553_0 -> 3884 in the cache */
   /* search1553_1_0 -> 2053 in the cache */
   /* search1553_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3884, 4342 },
      -1,
   } },

   /* replace1553_0 -> 6 in the cache */
   /* replace1553_1_0 -> 2053 in the cache */
   /* replace1553_1 -> 4254 in the cache */
   /* replace1553 -> 4257 in the cache */

   /* ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1554_0_0 -> 6 in the cache */
   /* search1554_0 -> 3884 in the cache */
   /* search1554_1_0 -> 2053 in the cache */
   /* search1554_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3884, 4342 },
      -1,
   } },

   /* replace1554_0 -> 6 in the cache */
   /* replace1554_1_0 -> 2053 in the cache */
   /* replace1554_1 -> 4254 in the cache */
   /* replace1554 -> 4259 in the cache */

   /* ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1555_0_0 -> 6 in the cache */
   /* search1555_0 -> 3884 in the cache */
   /* search1555_1_0 -> 2053 in the cache */
   /* search1555_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3884, 4342 },
      -1,
   } },

   /* replace1555_0 -> 6 in the cache */
   /* replace1555_1_0 -> 2053 in the cache */
   /* replace1555_1 -> 4254 in the cache */
   /* replace1555 -> 4261 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1556_0_0 -> 3917 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3917 },
      -1,
   } },
   /* search1556_1_0 -> 3919 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3919 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4347, 4348 },
      -1,
   } },

   /* replace1556_0_0 -> 3917 in the cache */
   /* replace1556_0 -> 4265 in the cache */
   /* replace1556_1 -> 3919 in the cache */
   /* replace1556 -> 4266 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1557_0_0 -> 3917 in the cache */
   /* search1557_0 -> 4347 in the cache */
   /* search1557_1_0 -> 3919 in the cache */
   /* search1557_1 -> 4348 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4347, 4348 },
      -1,
   } },

   /* replace1557_0_0 -> 3917 in the cache */
   /* replace1557_0 -> 4265 in the cache */
   /* replace1557_1 -> 3919 in the cache */
   /* replace1557 -> 4268 in the cache */

   /* ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1558_0_0 -> 6 in the cache */
   /* search1558_0 -> 3884 in the cache */
   /* search1558_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3884, 4018 },
      -1,
   } },

   /* replace1558_0_0 -> 6 in the cache */
   /* replace1558_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4352 },
      -1,
   } },
   /* replace1558_1_0_0_0 -> 41 in the cache */
   /* replace1558_1_0_0 -> 4352 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4352 },
      -1,
   } },
   /* replace1558_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4354, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4353, 4355 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1559_0_0 -> 6 in the cache */
   /* search1559_0 -> 3884 in the cache */
   /* search1559_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3884, 4018 },
      -1,
   } },

   /* replace1559_0_0 -> 6 in the cache */
   /* replace1559_0_1_0 -> 41 in the cache */
   /* replace1559_0_1 -> 4352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4352 },
      -1,
   } },
   /* replace1559_1_0_0_0 -> 41 in the cache */
   /* replace1559_1_0_0 -> 4352 in the cache */
   /* replace1559_1_0 -> 4354 in the cache */
   /* replace1559_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4354, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4358, 4359 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1560_0_0 -> 6 in the cache */
   /* search1560_0 -> 3884 in the cache */
   /* search1560_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3884, 4018 },
      -1,
   } },

   /* replace1560_0_0 -> 852 in the cache */
   /* replace1560_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 852, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace1560_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4363, 41 },
      -1,
   } },
   /* replace1560_1_1_0 -> 6 in the cache */
   /* replace1560_1_1_1_0 -> 41 in the cache */
   /* replace1560_1_1_1 -> 4352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 4352 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4364, 4365 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4362, 4366 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1561_0 -> 4037 in the cache */
   /* search1561_1_0 -> 2053 in the cache */
   /* search1561_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4037, 4342 },
      -1,
   } },

   /* replace1561_0_0 -> 21 in the cache */
   /* replace1561_0_1 -> 4363 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 4363 },
      -1,
   } },
   /* replace1561_1_0_0 -> 21 in the cache */
   /* replace1561_1_0_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 852 },
      -1,
   } },
   /* replace1561_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1561_1_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4371, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4370, 4372 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4369, 4373 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1562_0_0 -> 6 in the cache */
   /* search1562_0 -> 3884 in the cache */
   /* search1562_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3884, 4018 },
      -1,
   } },

   /* replace1562_0_0 -> 4363 in the cache */
   /* replace1562_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4363, 41 },
      -1,
   } },
   /* replace1562_1_0_0 -> 852 in the cache */
   /* replace1562_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 852, 41 },
      -1,
   } },
   /* replace1562_1_1_0 -> 6 in the cache */
   /* replace1562_1_1_1_0 -> 41 in the cache */
   /* replace1562_1_1_1 -> 4352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 4352 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4377, 4378 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4376, 4379 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1563_0 -> 4037 in the cache */
   /* search1563_1_0 -> 2053 in the cache */
   /* search1563_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4037, 4342 },
      -1,
   } },

   /* replace1563_0_0 -> 21 in the cache */
   /* replace1563_0_1 -> 852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 852 },
      -1,
   } },
   /* replace1563_1_0_0 -> 21 in the cache */
   /* replace1563_1_0_1 -> 4363 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 4363 },
      -1,
   } },
   /* replace1563_1_1_0_0 -> 21 in the cache */
   /* replace1563_1_1_0 -> 4371 in the cache */
   /* replace1563_1_1_1 -> 2053 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4371, 2053 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4383, 4384 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4382, 4385 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1564_0_0 -> 11 in the cache */
   /* search1564_0 -> 1742 in the cache */
   /* search1564_1_0 -> 2053 in the cache */
   /* search1564_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1742, 2977 },
      -1,
   } },

   /* replace1564_0 -> 11 in the cache */
   /* replace1564_1_0 -> 2053 in the cache */
   /* replace1564_1 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4252 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1565_0_0 -> 11 in the cache */
   /* search1565_0 -> 1742 in the cache */
   /* search1565_1_0 -> 2053 in the cache */
   /* search1565_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1742, 2977 },
      -1,
   } },

   /* replace1565_0 -> 11 in the cache */
   /* replace1565_1_0 -> 2053 in the cache */
   /* replace1565_1 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4252 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1566_0_0 -> 11 in the cache */
   /* search1566_0 -> 1742 in the cache */
   /* search1566_1_0 -> 2053 in the cache */
   /* search1566_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1742, 2977 },
      -1,
   } },

   /* replace1566_0 -> 11 in the cache */
   /* replace1566_1_0 -> 2053 in the cache */
   /* replace1566_1 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4252 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1567_0_0 -> 11 in the cache */
   /* search1567_0 -> 1742 in the cache */
   /* search1567_1_0 -> 2053 in the cache */
   /* search1567_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1742, 2977 },
      -1,
   } },

   /* replace1567_0 -> 11 in the cache */
   /* replace1567_1_0 -> 2053 in the cache */
   /* replace1567_1 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4252 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1568_0_0 -> 3917 in the cache */
   /* search1568_0 -> 4305 in the cache */
   /* search1568_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4305, 4395 },
      -1,
   } },

   /* replace1568_0_0 -> 3917 in the cache */
   /* replace1568_0 -> 4262 in the cache */
   /* replace1568_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4262, 507 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1569_0_0 -> 3917 in the cache */
   /* search1569_0 -> 4305 in the cache */
   /* search1569_1_0 -> 507 in the cache */
   /* search1569_1 -> 4395 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4305, 4395 },
      -1,
   } },

   /* replace1569_0_0 -> 3917 in the cache */
   /* replace1569_0 -> 4262 in the cache */
   /* replace1569_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4262, 507 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1570_0_0 -> 11 in the cache */
   /* search1570_0 -> 1742 in the cache */
   /* search1570_1_0 -> 243 in the cache */
   /* search1570_1 -> 2997 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1742, 2997 },
      -1,
   } },

   /* replace1570_0 -> 11 in the cache */
   /* replace1570_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4401 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1571_0_0 -> 11 in the cache */
   /* search1571_0 -> 1742 in the cache */
   /* search1571_1_0 -> 243 in the cache */
   /* search1571_1 -> 2997 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1742, 2997 },
      -1,
   } },

   /* replace1571_0 -> 11 in the cache */
   /* replace1571_1_0 -> 243 in the cache */
   /* replace1571_1 -> 4401 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4401 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1572_0_0 -> 11 in the cache */
   /* search1572_0 -> 1742 in the cache */
   /* search1572_1_0 -> 243 in the cache */
   /* search1572_1 -> 2997 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1742, 2997 },
      -1,
   } },

   /* replace1572_0 -> 11 in the cache */
   /* replace1572_1_0 -> 243 in the cache */
   /* replace1572_1 -> 4401 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4401 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1573_0_0 -> 11 in the cache */
   /* search1573_0 -> 1742 in the cache */
   /* search1573_1_0 -> 243 in the cache */
   /* search1573_1 -> 2997 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1742, 2997 },
      -1,
   } },

   /* replace1573_0 -> 11 in the cache */
   /* replace1573_1_0 -> 243 in the cache */
   /* replace1573_1 -> 4401 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4401 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1574_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1574_1_0 -> 507 in the cache */
   /* search1574_1 -> 4395 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4409, 4395 },
      -1,
   } },

   /* replace1574_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 496 },
      -1,
   } },
   /* replace1574_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4411, 507 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1575_0_0 -> 496 in the cache */
   /* search1575_0 -> 4409 in the cache */
   /* search1575_1_0 -> 507 in the cache */
   /* search1575_1 -> 4395 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4409, 4395 },
      -1,
   } },

   /* replace1575_0_0 -> 496 in the cache */
   /* replace1575_0 -> 4411 in the cache */
   /* replace1575_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4411, 507 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1576_0_0 -> 11 in the cache */
   /* search1576_0 -> 1742 in the cache */
   /* search1576_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1742, 33 },
      -1,
   } },

   /* replace1576_0_0 -> 11 in the cache */
   /* replace1576_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4416 },
      -1,
   } },
   /* replace1576_1_0_0_0 -> 36 in the cache */
   /* replace1576_1_0_0 -> 4416 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4416 },
      -1,
   } },
   /* replace1576_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4418, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4417, 4419 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1577_0_0 -> 11 in the cache */
   /* search1577_0 -> 1742 in the cache */
   /* search1577_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1742, 33 },
      -1,
   } },

   /* replace1577_0_0 -> 11 in the cache */
   /* replace1577_0_1_0 -> 36 in the cache */
   /* replace1577_0_1 -> 4416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4416 },
      -1,
   } },
   /* replace1577_1_0_0_0 -> 36 in the cache */
   /* replace1577_1_0_0 -> 4416 in the cache */
   /* replace1577_1_0 -> 4418 in the cache */
   /* replace1577_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4418, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4422, 4423 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1578_0_0 -> 11 in the cache */
   /* search1578_0 -> 1742 in the cache */
   /* search1578_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1742, 33 },
      -1,
   } },

   /* replace1578_0_0 -> 120 in the cache */
   /* replace1578_0_1 -> 36 in the cache */
   /* replace1578_0 -> 4319 in the cache */
   /* replace1578_1_0_0 -> 957 in the cache */
   /* replace1578_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 957, 36 },
      -1,
   } },
   /* replace1578_1_1_0 -> 11 in the cache */
   /* replace1578_1_1_1_0 -> 36 in the cache */
   /* replace1578_1_1_1 -> 4416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4426, 4427 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4319, 4428 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1579_0 -> 271 in the cache */
   /* search1579_1_0 -> 243 in the cache */
   /* search1579_1 -> 2997 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 271, 2997 },
      -1,
   } },

   /* replace1579_0_0 -> 16 in the cache */
   /* replace1579_0_1 -> 957 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 957 },
      -1,
   } },
   /* replace1579_1_0_0 -> 16 in the cache */
   /* replace1579_1_0_1 -> 120 in the cache */
   /* replace1579_1_0 -> 4326 in the cache */
   /* replace1579_1_1_0_0 -> 16 in the cache */
   /* replace1579_1_1_0 -> 3003 in the cache */
   /* replace1579_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3003, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4326, 4432 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4431, 4433 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1580_0_0 -> 11 in the cache */
   /* search1580_0 -> 1742 in the cache */
   /* search1580_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1742, 33 },
      -1,
   } },

   /* replace1580_0_0 -> 957 in the cache */
   /* replace1580_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 957, 36 },
      -1,
   } },
   /* replace1580_1_0_0 -> 120 in the cache */
   /* replace1580_1_0_1 -> 36 in the cache */
   /* replace1580_1_0 -> 4332 in the cache */
   /* replace1580_1_1_0 -> 11 in the cache */
   /* replace1580_1_1_1_0 -> 36 in the cache */
   /* replace1580_1_1_1 -> 4416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4332, 4437 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4436, 4438 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1581_0 -> 271 in the cache */
   /* search1581_1_0 -> 243 in the cache */
   /* search1581_1 -> 2997 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 271, 2997 },
      -1,
   } },

   /* replace1581_0_0 -> 16 in the cache */
   /* replace1581_0_1 -> 120 in the cache */
   /* replace1581_0 -> 4337 in the cache */
   /* replace1581_1_0_0 -> 16 in the cache */
   /* replace1581_1_0_1 -> 957 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 957 },
      -1,
   } },
   /* replace1581_1_1_0_0 -> 16 in the cache */
   /* replace1581_1_1_0 -> 3003 in the cache */
   /* replace1581_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3003, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4441, 4442 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4337, 4443 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1582_0_0 -> 11 in the cache */
   /* search1582_0 -> 1765 in the cache */
   /* search1582_1_0 -> 2053 in the cache */
   /* search1582_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1765, 4342 },
      -1,
   } },

   /* replace1582_0 -> 11 in the cache */
   /* replace1582_1_0 -> 2053 in the cache */
   /* replace1582_1 -> 4252 in the cache */
   /* replace1582 -> 4388 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1583_0_0 -> 11 in the cache */
   /* search1583_0 -> 1765 in the cache */
   /* search1583_1_0 -> 2053 in the cache */
   /* search1583_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1765, 4342 },
      -1,
   } },

   /* replace1583_0 -> 11 in the cache */
   /* replace1583_1_0 -> 2053 in the cache */
   /* replace1583_1 -> 4252 in the cache */
   /* replace1583 -> 4390 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1584_0_0 -> 11 in the cache */
   /* search1584_0 -> 1765 in the cache */
   /* search1584_1_0 -> 2053 in the cache */
   /* search1584_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1765, 4342 },
      -1,
   } },

   /* replace1584_0 -> 11 in the cache */
   /* replace1584_1_0 -> 2053 in the cache */
   /* replace1584_1 -> 4252 in the cache */
   /* replace1584 -> 4392 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1585_0_0 -> 11 in the cache */
   /* search1585_0 -> 1765 in the cache */
   /* search1585_1_0 -> 2053 in the cache */
   /* search1585_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1765, 4342 },
      -1,
   } },

   /* replace1585_0 -> 11 in the cache */
   /* replace1585_1_0 -> 2053 in the cache */
   /* replace1585_1 -> 4252 in the cache */
   /* replace1585 -> 4394 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1586_0_0 -> 3917 in the cache */
   /* search1586_0 -> 4347 in the cache */
   /* search1586_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4347, 4449 },
      -1,
   } },

   /* replace1586_0_0 -> 3917 in the cache */
   /* replace1586_0 -> 4262 in the cache */
   /* replace1586_1 -> 507 in the cache */
   /* replace1586 -> 4397 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1587_0_0 -> 3917 in the cache */
   /* search1587_0 -> 4347 in the cache */
   /* search1587_1_0 -> 507 in the cache */
   /* search1587_1 -> 4449 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4347, 4449 },
      -1,
   } },

   /* replace1587_0_0 -> 3917 in the cache */
   /* replace1587_0 -> 4262 in the cache */
   /* replace1587_1 -> 507 in the cache */
   /* replace1587 -> 4399 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1588_0_0 -> 11 in the cache */
   /* search1588_0 -> 1765 in the cache */
   /* search1588_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1765, 4452 },
      -1,
   } },

   /* replace1588_0 -> 11 in the cache */
   /* replace1588_1_0 -> 243 in the cache */
   /* replace1588_1 -> 4401 in the cache */
   /* replace1588 -> 4402 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1589_0_0 -> 11 in the cache */
   /* search1589_0 -> 1765 in the cache */
   /* search1589_1_0 -> 243 in the cache */
   /* search1589_1 -> 4452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1765, 4452 },
      -1,
   } },

   /* replace1589_0 -> 11 in the cache */
   /* replace1589_1_0 -> 243 in the cache */
   /* replace1589_1 -> 4401 in the cache */
   /* replace1589 -> 4404 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1590_0_0 -> 11 in the cache */
   /* search1590_0 -> 1765 in the cache */
   /* search1590_1_0 -> 243 in the cache */
   /* search1590_1 -> 4452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1765, 4452 },
      -1,
   } },

   /* replace1590_0 -> 11 in the cache */
   /* replace1590_1_0 -> 243 in the cache */
   /* replace1590_1 -> 4401 in the cache */
   /* replace1590 -> 4406 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1591_0_0 -> 11 in the cache */
   /* search1591_0 -> 1765 in the cache */
   /* search1591_1_0 -> 243 in the cache */
   /* search1591_1 -> 4452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1765, 4452 },
      -1,
   } },

   /* replace1591_0 -> 11 in the cache */
   /* replace1591_1_0 -> 243 in the cache */
   /* replace1591_1 -> 4401 in the cache */
   /* replace1591 -> 4408 in the cache */

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1592_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1592_1_0 -> 507 in the cache */
   /* search1592_1 -> 4449 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4457, 4449 },
      -1,
   } },

   /* replace1592_0_0 -> 496 in the cache */
   /* replace1592_0 -> 4411 in the cache */
   /* replace1592_1 -> 507 in the cache */
   /* replace1592 -> 4412 in the cache */

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1593_0_0 -> 496 in the cache */
   /* search1593_0 -> 4457 in the cache */
   /* search1593_1_0 -> 507 in the cache */
   /* search1593_1 -> 4449 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4457, 4449 },
      -1,
   } },

   /* replace1593_0_0 -> 496 in the cache */
   /* replace1593_0 -> 4411 in the cache */
   /* replace1593_1 -> 507 in the cache */
   /* replace1593 -> 4414 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1594_0_0 -> 11 in the cache */
   /* search1594_0 -> 1765 in the cache */
   /* search1594_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1765, 4018 },
      -1,
   } },

   /* replace1594_0_0 -> 11 in the cache */
   /* replace1594_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4461 },
      -1,
   } },
   /* replace1594_1_0_0_0 -> 41 in the cache */
   /* replace1594_1_0_0 -> 4461 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4461 },
      -1,
   } },
   /* replace1594_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4463, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4462, 4464 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1595_0_0 -> 11 in the cache */
   /* search1595_0 -> 1765 in the cache */
   /* search1595_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1765, 4018 },
      -1,
   } },

   /* replace1595_0_0 -> 11 in the cache */
   /* replace1595_0_1_0 -> 41 in the cache */
   /* replace1595_0_1 -> 4461 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4461 },
      -1,
   } },
   /* replace1595_1_0_0_0 -> 41 in the cache */
   /* replace1595_1_0_0 -> 4461 in the cache */
   /* replace1595_1_0 -> 4463 in the cache */
   /* replace1595_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4463, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4467, 4468 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1596_0_0 -> 11 in the cache */
   /* search1596_0 -> 1765 in the cache */
   /* search1596_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1765, 4018 },
      -1,
   } },

   /* replace1596_0_0 -> 852 in the cache */
   /* replace1596_0_1 -> 41 in the cache */
   /* replace1596_0 -> 4362 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace1596_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4471, 41 },
      -1,
   } },
   /* replace1596_1_1_0 -> 11 in the cache */
   /* replace1596_1_1_1_0 -> 41 in the cache */
   /* replace1596_1_1_1 -> 4461 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4472, 4473 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4362, 4474 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1597_0 -> 4037 in the cache */
   /* search1597_1_0 -> 243 in the cache */
   /* search1597_1 -> 4452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4037, 4452 },
      -1,
   } },

   /* replace1597_0_0 -> 21 in the cache */
   /* replace1597_0_1 -> 4471 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 4471 },
      -1,
   } },
   /* replace1597_1_0_0 -> 21 in the cache */
   /* replace1597_1_0_1 -> 852 in the cache */
   /* replace1597_1_0 -> 4370 in the cache */
   /* replace1597_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1597_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4478, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4370, 4479 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4477, 4480 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1598_0_0 -> 11 in the cache */
   /* search1598_0 -> 1765 in the cache */
   /* search1598_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1765, 4018 },
      -1,
   } },

   /* replace1598_0_0 -> 4471 in the cache */
   /* replace1598_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4471, 41 },
      -1,
   } },
   /* replace1598_1_0_0 -> 852 in the cache */
   /* replace1598_1_0_1 -> 41 in the cache */
   /* replace1598_1_0 -> 4377 in the cache */
   /* replace1598_1_1_0 -> 11 in the cache */
   /* replace1598_1_1_1_0 -> 41 in the cache */
   /* replace1598_1_1_1 -> 4461 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4377, 4484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4483, 4485 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1599_0 -> 4037 in the cache */
   /* search1599_1_0 -> 243 in the cache */
   /* search1599_1 -> 4452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4037, 4452 },
      -1,
   } },

   /* replace1599_0_0 -> 21 in the cache */
   /* replace1599_0_1 -> 852 in the cache */
   /* replace1599_0 -> 4382 in the cache */
   /* replace1599_1_0_0 -> 21 in the cache */
   /* replace1599_1_0_1 -> 4471 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 4471 },
      -1,
   } },
   /* replace1599_1_1_0_0 -> 21 in the cache */
   /* replace1599_1_1_0 -> 4478 in the cache */
   /* replace1599_1_1_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4478, 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4488, 4489 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4382, 4490 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1600_0_0 -> 16 in the cache */
   /* search1600_0 -> 1849 in the cache */
   /* search1600_1_0 -> 2053 in the cache */
   /* search1600_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1849, 4342 },
      -1,
   } },

   /* replace1600_0 -> 16 in the cache */
   /* replace1600_1_0 -> 2053 in the cache */
   /* replace1600_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 2977 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1601_0_0 -> 16 in the cache */
   /* search1601_0 -> 1849 in the cache */
   /* search1601_1_0 -> 2053 in the cache */
   /* search1601_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1849, 4342 },
      -1,
   } },

   /* replace1601_0 -> 16 in the cache */
   /* replace1601_1_0 -> 2053 in the cache */
   /* replace1601_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 2977 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1602_0_0 -> 16 in the cache */
   /* search1602_0 -> 1849 in the cache */
   /* search1602_1_0 -> 2053 in the cache */
   /* search1602_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1849, 4342 },
      -1,
   } },

   /* replace1602_0 -> 16 in the cache */
   /* replace1602_1_0 -> 2053 in the cache */
   /* replace1602_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 2977 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1603_0_0 -> 16 in the cache */
   /* search1603_0 -> 1849 in the cache */
   /* search1603_1_0 -> 2053 in the cache */
   /* search1603_1 -> 4342 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1849, 4342 },
      -1,
   } },

   /* replace1603_0 -> 16 in the cache */
   /* replace1603_1_0 -> 2053 in the cache */
   /* replace1603_1 -> 2977 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 2977 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1604_0_0 -> 3917 in the cache */
   /* search1604_0 -> 4347 in the cache */
   /* search1604_1_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4347, 4500 },
      -1,
   } },

   /* replace1604_0_0 -> 3917 in the cache */
   /* replace1604_0 -> 4305 in the cache */
   /* replace1604_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4305, 360 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1605_0_0 -> 3917 in the cache */
   /* search1605_0 -> 4347 in the cache */
   /* search1605_1_0 -> 360 in the cache */
   /* search1605_1 -> 4500 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4347, 4500 },
      -1,
   } },

   /* replace1605_0_0 -> 3917 in the cache */
   /* replace1605_0 -> 4305 in the cache */
   /* replace1605_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4305, 360 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1606_0_0 -> 16 in the cache */
   /* search1606_0 -> 1849 in the cache */
   /* search1606_1_0 -> 243 in the cache */
   /* search1606_1 -> 4452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1849, 4452 },
      -1,
   } },

   /* replace1606_0 -> 16 in the cache */
   /* replace1606_1_0 -> 243 in the cache */
   /* replace1606_1 -> 2997 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 2997 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1607_0_0 -> 16 in the cache */
   /* search1607_0 -> 1849 in the cache */
   /* search1607_1_0 -> 243 in the cache */
   /* search1607_1 -> 4452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1849, 4452 },
      -1,
   } },

   /* replace1607_0 -> 16 in the cache */
   /* replace1607_1_0 -> 243 in the cache */
   /* replace1607_1 -> 2997 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 2997 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1608_0_0 -> 16 in the cache */
   /* search1608_0 -> 1849 in the cache */
   /* search1608_1_0 -> 243 in the cache */
   /* search1608_1 -> 4452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1849, 4452 },
      -1,
   } },

   /* replace1608_0 -> 16 in the cache */
   /* replace1608_1_0 -> 243 in the cache */
   /* replace1608_1 -> 2997 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 2997 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1609_0_0 -> 16 in the cache */
   /* search1609_0 -> 1849 in the cache */
   /* search1609_1_0 -> 243 in the cache */
   /* search1609_1 -> 4452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1849, 4452 },
      -1,
   } },

   /* replace1609_0 -> 16 in the cache */
   /* replace1609_1_0 -> 243 in the cache */
   /* replace1609_1 -> 2997 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 2997 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1610_0_0 -> 496 in the cache */
   /* search1610_0 -> 4457 in the cache */
   /* search1610_1_0 -> 360 in the cache */
   /* search1610_1 -> 4500 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4457, 4500 },
      -1,
   } },

   /* replace1610_0_0 -> 496 in the cache */
   /* replace1610_0 -> 4409 in the cache */
   /* replace1610_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4409, 360 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1611_0_0 -> 496 in the cache */
   /* search1611_0 -> 4457 in the cache */
   /* search1611_1_0 -> 360 in the cache */
   /* search1611_1 -> 4500 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4457, 4500 },
      -1,
   } },

   /* replace1611_0_0 -> 496 in the cache */
   /* replace1611_0 -> 4409 in the cache */
   /* replace1611_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4409, 360 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1612_0_0 -> 16 in the cache */
   /* search1612_0 -> 1849 in the cache */
   /* search1612_1_0 -> 36 in the cache */
   /* search1612_1 -> 2993 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1849, 2993 },
      -1,
   } },

   /* replace1612_0 -> 16 in the cache */
   /* replace1612_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4518 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1613_0_0 -> 16 in the cache */
   /* search1613_0 -> 1849 in the cache */
   /* search1613_1_0 -> 36 in the cache */
   /* search1613_1 -> 2993 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1849, 2993 },
      -1,
   } },

   /* replace1613_0 -> 16 in the cache */
   /* replace1613_1_0 -> 36 in the cache */
   /* replace1613_1 -> 4518 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4518 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1614_0_0 -> 16 in the cache */
   /* search1614_0 -> 1849 in the cache */
   /* search1614_1_0 -> 36 in the cache */
   /* search1614_1 -> 2993 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1849, 2993 },
      -1,
   } },

   /* replace1614_0 -> 16 in the cache */
   /* replace1614_1_0 -> 36 in the cache */
   /* replace1614_1 -> 4518 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 4518 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1615_0_0 -> 16 in the cache */
   /* search1615_0 -> 1849 in the cache */
   /* search1615_1_0 -> 36 in the cache */
   /* search1615_1 -> 2993 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1849, 2993 },
      -1,
   } },

   /* replace1615_0 -> 16 in the cache */
   /* replace1615_1_0 -> 36 in the cache */
   /* replace1615_1 -> 4518 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 4518 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1616_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 358 },
      -1,
   } },
   /* search1616_1_0 -> 360 in the cache */
   /* search1616_1 -> 4500 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4526, 4500 },
      -1,
   } },

   /* replace1616_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 358 },
      -1,
   } },
   /* replace1616_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4528, 360 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1617_0_0 -> 358 in the cache */
   /* search1617_0 -> 4526 in the cache */
   /* search1617_1_0 -> 360 in the cache */
   /* search1617_1 -> 4500 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4526, 4500 },
      -1,
   } },

   /* replace1617_0_0 -> 358 in the cache */
   /* replace1617_0 -> 4528 in the cache */
   /* replace1617_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4528, 360 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1618_0_0 -> 16 in the cache */
   /* search1618_0 -> 1849 in the cache */
   /* search1618_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1849, 4018 },
      -1,
   } },

   /* replace1618_0_0 -> 16 in the cache */
   /* replace1618_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 4533 },
      -1,
   } },
   /* replace1618_1_0_0_0 -> 41 in the cache */
   /* replace1618_1_0_0 -> 4533 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4533 },
      -1,
   } },
   /* replace1618_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4535, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4534, 4536 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1619_0_0 -> 16 in the cache */
   /* search1619_0 -> 1849 in the cache */
   /* search1619_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1849, 4018 },
      -1,
   } },

   /* replace1619_0_0 -> 16 in the cache */
   /* replace1619_0_1_0 -> 41 in the cache */
   /* replace1619_0_1 -> 4533 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 4533 },
      -1,
   } },
   /* replace1619_1_0_0_0 -> 41 in the cache */
   /* replace1619_1_0_0 -> 4533 in the cache */
   /* replace1619_1_0 -> 4535 in the cache */
   /* replace1619_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4535, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4539, 4540 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b')))) */
   /* search1620_0_0 -> 16 in the cache */
   /* search1620_0 -> 1849 in the cache */
   /* search1620_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1849, 4018 },
      -1,
   } },

   /* replace1620_0_0 -> 852 in the cache */
   /* replace1620_0_1 -> 41 in the cache */
   /* replace1620_0 -> 4362 in the cache */
   /* replace1620_1_0_0 -> 3008 in the cache */
   /* replace1620_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3008, 41 },
      -1,
   } },
   /* replace1620_1_1_0 -> 16 in the cache */
   /* replace1620_1_1_1_0 -> 41 in the cache */
   /* replace1620_1_1_1 -> 4533 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 4533 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4543, 4544 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4362, 4545 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b'))) */
   /* search1621_0 -> 4037 in the cache */
   /* search1621_1_0 -> 36 in the cache */
   /* search1621_1 -> 2993 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4037, 2993 },
      -1,
   } },

   /* replace1621_0_0 -> 21 in the cache */
   /* replace1621_0_1 -> 3008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 3008 },
      -1,
   } },
   /* replace1621_1_0_0 -> 21 in the cache */
   /* replace1621_1_0_1 -> 852 in the cache */
   /* replace1621_1_0 -> 4370 in the cache */
   /* replace1621_1_1_0_0 -> 21 in the cache */
   /* replace1621_1_1_0 -> 3000 in the cache */
   /* replace1621_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3000, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4370, 4549 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4548, 4550 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b')))) */
   /* search1622_0_0 -> 16 in the cache */
   /* search1622_0 -> 1849 in the cache */
   /* search1622_1 -> 4018 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1849, 4018 },
      -1,
   } },

   /* replace1622_0_0 -> 3008 in the cache */
   /* replace1622_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3008, 41 },
      -1,
   } },
   /* replace1622_1_0_0 -> 852 in the cache */
   /* replace1622_1_0_1 -> 41 in the cache */
   /* replace1622_1_0 -> 4377 in the cache */
   /* replace1622_1_1_0 -> 16 in the cache */
   /* replace1622_1_1_1_0 -> 41 in the cache */
   /* replace1622_1_1_1 -> 4533 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 4533 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4377, 4554 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4553, 4555 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b'))) */
   /* search1623_0 -> 4037 in the cache */
   /* search1623_1_0 -> 36 in the cache */
   /* search1623_1 -> 2993 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4037, 2993 },
      -1,
   } },

   /* replace1623_0_0 -> 21 in the cache */
   /* replace1623_0_1 -> 852 in the cache */
   /* replace1623_0 -> 4382 in the cache */
   /* replace1623_1_0_0 -> 21 in the cache */
   /* replace1623_1_0_1 -> 3008 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 3008 },
      -1,
   } },
   /* replace1623_1_1_0_0 -> 21 in the cache */
   /* replace1623_1_1_0 -> 3000 in the cache */
   /* replace1623_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3000, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4558, 4559 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4382, 4560 },
      -1,
   } },

   /* ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1624_0_0 -> 11 in the cache */
   /* search1624_0 -> 1738 in the cache */
   /* search1624_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1738, 4562 },
      -1,
   } },

   /* replace1624_0 -> 11 in the cache */
   /* replace1624_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 4564 },
      -1,
   } },

   /* ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1625_0_0 -> 11 in the cache */
   /* search1625_0 -> 1738 in the cache */
   /* search1625_1_0 -> 243 in the cache */
   /* search1625_1 -> 4562 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1738, 4562 },
      -1,
   } },

   /* replace1625_0 -> 11 in the cache */
   /* replace1625_1_0 -> 243 in the cache */
   /* replace1625_1 -> 4564 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 11, 4564 },
      -1,
   } },

   /* ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1626_0_0 -> 11 in the cache */
   /* search1626_0 -> 1738 in the cache */
   /* search1626_1_0 -> 243 in the cache */
   /* search1626_1 -> 4562 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1738, 4562 },
      -1,
   } },

   /* replace1626_0 -> 11 in the cache */
   /* replace1626_1_0 -> 243 in the cache */
   /* replace1626_1 -> 4564 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 11, 4564 },
      -1,
   } },

   /* ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1627_0_0 -> 11 in the cache */
   /* search1627_0 -> 1738 in the cache */
   /* search1627_1_0 -> 243 in the cache */
   /* search1627_1 -> 4562 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1738, 4562 },
      -1,
   } },

   /* replace1627_0 -> 11 in the cache */
   /* replace1627_1_0 -> 243 in the cache */
   /* replace1627_1 -> 4564 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 4564 },
      -1,
   } },

   /* ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1628_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1628_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4572, 4573 },
      -1,
   } },

   /* replace1628_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 496 },
      -1,
   } },
   /* replace1628_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4575, 507 },
      -1,
   } },

   /* ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1629_0_0 -> 496 in the cache */
   /* search1629_0 -> 4572 in the cache */
   /* search1629_1_0 -> 507 in the cache */
   /* search1629_1 -> 4573 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4572, 4573 },
      -1,
   } },

   /* replace1629_0_0 -> 496 in the cache */
   /* replace1629_0 -> 4575 in the cache */
   /* replace1629_1 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4575, 507 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1630_0_0 -> 11 in the cache */
   /* search1630_0 -> 1761 in the cache */
   /* search1630_1_0 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 243 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1761, 4579 },
      -1,
   } },

   /* replace1630_0 -> 11 in the cache */
   /* replace1630_1_0 -> 243 in the cache */
   /* replace1630_1 -> 4564 in the cache */
   /* replace1630 -> 4565 in the cache */

   /* ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1631_0_0 -> 11 in the cache */
   /* search1631_0 -> 1761 in the cache */
   /* search1631_1_0 -> 243 in the cache */
   /* search1631_1 -> 4579 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1761, 4579 },
      -1,
   } },

   /* replace1631_0 -> 11 in the cache */
   /* replace1631_1_0 -> 243 in the cache */
   /* replace1631_1 -> 4564 in the cache */
   /* replace1631 -> 4567 in the cache */

   /* ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1632_0_0 -> 11 in the cache */
   /* search1632_0 -> 1761 in the cache */
   /* search1632_1_0 -> 243 in the cache */
   /* search1632_1 -> 4579 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1761, 4579 },
      -1,
   } },

   /* replace1632_0 -> 11 in the cache */
   /* replace1632_1_0 -> 243 in the cache */
   /* replace1632_1 -> 4564 in the cache */
   /* replace1632 -> 4569 in the cache */

   /* ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1633_0_0 -> 11 in the cache */
   /* search1633_0 -> 1761 in the cache */
   /* search1633_1_0 -> 243 in the cache */
   /* search1633_1 -> 4579 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1761, 4579 },
      -1,
   } },

   /* replace1633_0 -> 11 in the cache */
   /* replace1633_1_0 -> 243 in the cache */
   /* replace1633_1 -> 4564 in the cache */
   /* replace1633 -> 4571 in the cache */

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1634_0_0 -> 496 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 496 },
      -1,
   } },
   /* search1634_1_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4584, 4585 },
      -1,
   } },

   /* replace1634_0_0 -> 496 in the cache */
   /* replace1634_0 -> 4575 in the cache */
   /* replace1634_1 -> 507 in the cache */
   /* replace1634 -> 4576 in the cache */

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1635_0_0 -> 496 in the cache */
   /* search1635_0 -> 4584 in the cache */
   /* search1635_1_0 -> 507 in the cache */
   /* search1635_1 -> 4585 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4584, 4585 },
      -1,
   } },

   /* replace1635_0_0 -> 496 in the cache */
   /* replace1635_0 -> 4575 in the cache */
   /* replace1635_1 -> 507 in the cache */
   /* replace1635 -> 4578 in the cache */

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1636_0_0 -> 16 in the cache */
   /* search1636_0 -> 1845 in the cache */
   /* search1636_1_0 -> 243 in the cache */
   /* search1636_1 -> 4579 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1845, 4579 },
      -1,
   } },

   /* replace1636_0 -> 16 in the cache */
   /* replace1636_1_0 -> 243 in the cache */
   /* replace1636_1 -> 4562 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 4562 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1637_0_0 -> 16 in the cache */
   /* search1637_0 -> 1845 in the cache */
   /* search1637_1_0 -> 243 in the cache */
   /* search1637_1 -> 4579 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1845, 4579 },
      -1,
   } },

   /* replace1637_0 -> 16 in the cache */
   /* replace1637_1_0 -> 243 in the cache */
   /* replace1637_1 -> 4562 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 16, 4562 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1638_0_0 -> 16 in the cache */
   /* search1638_0 -> 1845 in the cache */
   /* search1638_1_0 -> 243 in the cache */
   /* search1638_1 -> 4579 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1845, 4579 },
      -1,
   } },

   /* replace1638_0 -> 16 in the cache */
   /* replace1638_1_0 -> 243 in the cache */
   /* replace1638_1 -> 4562 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 4562 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1639_0_0 -> 16 in the cache */
   /* search1639_0 -> 1845 in the cache */
   /* search1639_1_0 -> 243 in the cache */
   /* search1639_1 -> 4579 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1845, 4579 },
      -1,
   } },

   /* replace1639_0 -> 16 in the cache */
   /* replace1639_1_0 -> 243 in the cache */
   /* replace1639_1 -> 4562 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 4562 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1640_0_0 -> 496 in the cache */
   /* search1640_0 -> 4584 in the cache */
   /* search1640_1_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4584, 4596 },
      -1,
   } },

   /* replace1640_0_0 -> 496 in the cache */
   /* replace1640_0 -> 4572 in the cache */
   /* replace1640_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4572, 360 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1641_0_0 -> 496 in the cache */
   /* search1641_0 -> 4584 in the cache */
   /* search1641_1_0 -> 360 in the cache */
   /* search1641_1 -> 4596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4584, 4596 },
      -1,
   } },

   /* replace1641_0_0 -> 496 in the cache */
   /* replace1641_0 -> 4572 in the cache */
   /* replace1641_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4572, 360 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1642_0_0 -> 16 in the cache */
   /* search1642_0 -> 1845 in the cache */
   /* search1642_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1845, 4601 },
      -1,
   } },

   /* replace1642_0 -> 16 in the cache */
   /* replace1642_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 4603 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1643_0_0 -> 16 in the cache */
   /* search1643_0 -> 1845 in the cache */
   /* search1643_1_0 -> 36 in the cache */
   /* search1643_1 -> 4601 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1845, 4601 },
      -1,
   } },

   /* replace1643_0 -> 16 in the cache */
   /* replace1643_1_0 -> 36 in the cache */
   /* replace1643_1 -> 4603 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 16, 4603 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1644_0_0 -> 16 in the cache */
   /* search1644_0 -> 1845 in the cache */
   /* search1644_1_0 -> 36 in the cache */
   /* search1644_1 -> 4601 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1845, 4601 },
      -1,
   } },

   /* replace1644_0 -> 16 in the cache */
   /* replace1644_1_0 -> 36 in the cache */
   /* replace1644_1 -> 4603 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 4603 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1645_0_0 -> 16 in the cache */
   /* search1645_0 -> 1845 in the cache */
   /* search1645_1_0 -> 36 in the cache */
   /* search1645_1 -> 4601 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1845, 4601 },
      -1,
   } },

   /* replace1645_0 -> 16 in the cache */
   /* replace1645_1_0 -> 36 in the cache */
   /* replace1645_1 -> 4603 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 4603 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1646_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 358 },
      -1,
   } },
   /* search1646_1_0 -> 360 in the cache */
   /* search1646_1 -> 4596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4611, 4596 },
      -1,
   } },

   /* replace1646_0_0 -> 358 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 358 },
      -1,
   } },
   /* replace1646_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 4613, 360 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1647_0_0 -> 358 in the cache */
   /* search1647_0 -> 4611 in the cache */
   /* search1647_1_0 -> 360 in the cache */
   /* search1647_1 -> 4596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4611, 4596 },
      -1,
   } },

   /* replace1647_0_0 -> 358 in the cache */
   /* replace1647_0 -> 4613 in the cache */
   /* replace1647_1 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 4613, 360 },
      -1,
   } },

   /* ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a') */
   /* search1648_0_0 -> 21 in the cache */
   /* search1648_0_1 -> 3008 in the cache */
   /* search1648_0 -> 3009 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 1,
      { 3009 },
      -1,
   } },

   /* replace1648_0 -> 21 in the cache */
   /* replace1648 -> 3000 in the cache */

   /* ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a') */
   /* search1649_0_0 -> 16 in the cache */
   /* search1649_0_1 -> 957 in the cache */
   /* search1649_0 -> 958 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 958 },
      -1,
   } },

   /* replace1649_0 -> 16 in the cache */
   /* replace1649 -> 3003 in the cache */

   /* ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a') */
   /* search1650_0_0 -> 21 in the cache */
   /* search1650_0_1 -> 4471 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 4471 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 4619 },
      -1,
   } },

   /* replace1650_0 -> 21 in the cache */
   /* replace1650 -> 4478 in the cache */

   /* ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a') */
   /* search1651_0_0 -> 11 in the cache */
   /* search1651_0_1 -> 1954 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1954 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 4621 },
      -1,
   } },

   /* replace1651_0 -> 11 in the cache */
   /* replace1651 -> 1950 in the cache */

   /* ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a') */
   /* search1652_0_0 -> 16 in the cache */
   /* search1652_0_1 -> 965 in the cache */
   /* search1652_0 -> 966 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 966 },
      -1,
   } },

   /* replace1652_0 -> 16 in the cache */
   /* replace1652 -> 1966 in the cache */

   /* ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a') */
   /* search1653_0_0 -> 21 in the cache */
   /* search1653_0_1 -> 4363 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 4363 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 4624 },
      -1,
   } },

   /* replace1653_0 -> 21 in the cache */
   /* replace1653 -> 4371 in the cache */

   /* ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1654_0_0 -> 11 in the cache */
   /* search1654_0 -> 1950 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1950 },
      6,
   } },

   /* replace1654 -> 11 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1655_0 -> 11 in the cache */
   /* search1655_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 811 },
      6,
   } },

   /* replace1655 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1656_0 -> 502 in the cache */
   /* search1656_1_0_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4628 },
      -1,
   } },
   /* search1656_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4629, 469 },
      6,
   } },

   /* replace1656_0 -> 502 in the cache */
   /* replace1656_1 -> 507 in the cache */
   /* replace1656_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 507, 469 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1657_0 -> 502 in the cache */
   /* search1657_1_0_0 -> 507 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 507 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4632 },
      -1,
   } },
   /* search1657_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4633, 469 },
      6,
   } },

   /* replace1657_0 -> 502 in the cache */
   /* replace1657_1 -> 507 in the cache */
   /* replace1657_2 -> 469 in the cache */
   /* replace1657 -> 4631 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1658_0 -> 502 in the cache */
   /* search1658_1_0 -> 507 in the cache */
   /* search1658_1_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 507, 811 },
      -1,
   } },
   /* search1658_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4635, 469 },
      6,
   } },

   /* replace1658_0 -> 502 in the cache */
   /* replace1658_1 -> 507 in the cache */
   /* replace1658_2 -> 469 in the cache */
   /* replace1658 -> 4631 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1659_0_0_0 -> 11 in the cache */
   /* search1659_0_0 -> 1950 in the cache */
   /* search1659_0 -> 1951 in the cache */
   /* search1659_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1951, 243 },
      6,
   } },

   /* replace1659_0 -> 11 in the cache */
   /* replace1659_1 -> 243 in the cache */
   /* replace1659 -> 3692 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1660_0_0_0 -> 11 in the cache */
   /* search1660_0_0 -> 3948 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3948 },
      -1,
   } },
   /* search1660_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4638, 243 },
      6,
   } },

   /* replace1660_0 -> 11 in the cache */
   /* replace1660_1 -> 243 in the cache */
   /* replace1660 -> 3692 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1661_0_0 -> 11 in the cache */
   /* search1661_0_1 -> 811 in the cache */
   /* search1661_0 -> 3111 in the cache */
   /* search1661_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3111, 243 },
      6,
   } },

   /* replace1661_0 -> 11 in the cache */
   /* replace1661_1 -> 243 in the cache */
   /* replace1661 -> 3692 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1662_0_0_0 -> 11 in the cache */
   /* search1662_0_0 -> 1950 in the cache */
   /* search1662_0 -> 1951 in the cache */
   /* search1662_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 1951, 243 },
      6,
   } },

   /* replace1662_0 -> 11 in the cache */
   /* replace1662_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 11, 243 },
      -1,
   } },

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1663_0_0_0 -> 11 in the cache */
   /* search1663_0_0 -> 3948 in the cache */
   /* search1663_0 -> 4638 in the cache */
   /* search1663_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4638, 243 },
      6,
   } },

   /* replace1663_0 -> 11 in the cache */
   /* replace1663_1 -> 243 in the cache */
   /* replace1663 -> 4642 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1664_0_0 -> 11 in the cache */
   /* search1664_0_1 -> 811 in the cache */
   /* search1664_0 -> 3111 in the cache */
   /* search1664_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3111, 243 },
      6,
   } },

   /* replace1664_0 -> 11 in the cache */
   /* replace1664_1 -> 243 in the cache */
   /* replace1664 -> 4642 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1665_0_0_0 -> 11 in the cache */
   /* search1665_0_0 -> 1950 in the cache */
   /* search1665_0 -> 1951 in the cache */
   /* search1665_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1951, 243 },
      6,
   } },

   /* replace1665_0 -> 11 in the cache */
   /* replace1665_1 -> 243 in the cache */
   /* replace1665 -> 1964 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1666_0_0_0 -> 11 in the cache */
   /* search1666_0_0 -> 3948 in the cache */
   /* search1666_0 -> 4638 in the cache */
   /* search1666_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4638, 243 },
      6,
   } },

   /* replace1666_0 -> 11 in the cache */
   /* replace1666_1 -> 243 in the cache */
   /* replace1666 -> 1964 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1667_0_0 -> 11 in the cache */
   /* search1667_0_1 -> 811 in the cache */
   /* search1667_0 -> 3111 in the cache */
   /* search1667_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3111, 243 },
      6,
   } },

   /* replace1667_0 -> 11 in the cache */
   /* replace1667_1 -> 243 in the cache */
   /* replace1667 -> 1964 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1668_0_0_0 -> 11 in the cache */
   /* search1668_0_0 -> 1950 in the cache */
   /* search1668_0 -> 1951 in the cache */
   /* search1668_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1951, 243 },
      6,
   } },

   /* replace1668_0 -> 11 in the cache */
   /* replace1668_1 -> 243 in the cache */
   /* replace1668 -> 2006 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1669_0_0_0 -> 11 in the cache */
   /* search1669_0_0 -> 3948 in the cache */
   /* search1669_0 -> 4638 in the cache */
   /* search1669_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4638, 243 },
      6,
   } },

   /* replace1669_0 -> 11 in the cache */
   /* replace1669_1 -> 243 in the cache */
   /* replace1669 -> 2006 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1670_0_0 -> 11 in the cache */
   /* search1670_0_1 -> 811 in the cache */
   /* search1670_0 -> 3111 in the cache */
   /* search1670_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3111, 243 },
      6,
   } },

   /* replace1670_0 -> 11 in the cache */
   /* replace1670_1 -> 243 in the cache */
   /* replace1670 -> 2006 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1671_0_0_0 -> 11 in the cache */
   /* search1671_0_0 -> 1950 in the cache */
   /* search1671_0 -> 1951 in the cache */
   /* search1671_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 1951, 243 },
      6,
   } },

   /* replace1671_0 -> 11 in the cache */
   /* replace1671_1 -> 243 in the cache */
   /* replace1671 -> 2030 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1672_0_0_0 -> 11 in the cache */
   /* search1672_0_0 -> 3948 in the cache */
   /* search1672_0 -> 4638 in the cache */
   /* search1672_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4638, 243 },
      6,
   } },

   /* replace1672_0 -> 11 in the cache */
   /* replace1672_1 -> 243 in the cache */
   /* replace1672 -> 2030 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1673_0_0 -> 11 in the cache */
   /* search1673_0_1 -> 811 in the cache */
   /* search1673_0 -> 3111 in the cache */
   /* search1673_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3111, 243 },
      6,
   } },

   /* replace1673_0 -> 11 in the cache */
   /* replace1673_1 -> 243 in the cache */
   /* replace1673 -> 2030 in the cache */

   /* ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1674_0_0 -> 11 in the cache */
   /* search1674_0 -> 1950 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1950 },
      6,
   } },

   /* replace1674 -> 11 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1675_0 -> 11 in the cache */
   /* search1675_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 811 },
      6,
   } },

   /* replace1675 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1676_0 -> 502 in the cache */
   /* search1676_1_0_0 -> 507 in the cache */
   /* search1676_1_0 -> 4628 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4628 },
      -1,
   } },
   /* search1676_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4656, 469 },
      6,
   } },

   /* replace1676_0 -> 502 in the cache */
   /* replace1676_1 -> 507 in the cache */
   /* replace1676_2 -> 469 in the cache */
   /* replace1676 -> 4631 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1677_0 -> 502 in the cache */
   /* search1677_1_0_0 -> 507 in the cache */
   /* search1677_1_0 -> 4632 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4632 },
      -1,
   } },
   /* search1677_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4658, 469 },
      6,
   } },

   /* replace1677_0 -> 502 in the cache */
   /* replace1677_1 -> 507 in the cache */
   /* replace1677_2 -> 469 in the cache */
   /* replace1677 -> 4631 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1678_0 -> 502 in the cache */
   /* search1678_1_0 -> 507 in the cache */
   /* search1678_1_1 -> 811 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 507, 811 },
      -1,
   } },
   /* search1678_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4660, 469 },
      6,
   } },

   /* replace1678_0 -> 502 in the cache */
   /* replace1678_1 -> 507 in the cache */
   /* replace1678_2 -> 469 in the cache */
   /* replace1678 -> 4631 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1679_0_0_0 -> 11 in the cache */
   /* search1679_0_0 -> 1950 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1950 },
      -1,
   } },
   /* search1679_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4662, 243 },
      6,
   } },

   /* replace1679_0 -> 11 in the cache */
   /* replace1679_1 -> 243 in the cache */
   /* replace1679 -> 3692 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1680_0_0_0 -> 11 in the cache */
   /* search1680_0_0 -> 3948 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3948 },
      -1,
   } },
   /* search1680_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4664, 243 },
      6,
   } },

   /* replace1680_0 -> 11 in the cache */
   /* replace1680_1 -> 243 in the cache */
   /* replace1680 -> 3692 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1681_0_0 -> 11 in the cache */
   /* search1681_0_1 -> 811 in the cache */
   /* search1681_0 -> 3132 in the cache */
   /* search1681_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3132, 243 },
      6,
   } },

   /* replace1681_0 -> 11 in the cache */
   /* replace1681_1 -> 243 in the cache */
   /* replace1681 -> 3692 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1682_0_0_0 -> 11 in the cache */
   /* search1682_0_0 -> 1950 in the cache */
   /* search1682_0 -> 4662 in the cache */
   /* search1682_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4662, 243 },
      6,
   } },

   /* replace1682_0 -> 11 in the cache */
   /* replace1682_1 -> 243 in the cache */
   /* replace1682 -> 4642 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1683_0_0_0 -> 11 in the cache */
   /* search1683_0_0 -> 3948 in the cache */
   /* search1683_0 -> 4664 in the cache */
   /* search1683_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4664, 243 },
      6,
   } },

   /* replace1683_0 -> 11 in the cache */
   /* replace1683_1 -> 243 in the cache */
   /* replace1683 -> 4642 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1684_0_0 -> 11 in the cache */
   /* search1684_0_1 -> 811 in the cache */
   /* search1684_0 -> 3132 in the cache */
   /* search1684_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3132, 243 },
      6,
   } },

   /* replace1684_0 -> 11 in the cache */
   /* replace1684_1 -> 243 in the cache */
   /* replace1684 -> 4642 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1685_0_0_0 -> 11 in the cache */
   /* search1685_0_0 -> 1950 in the cache */
   /* search1685_0 -> 4662 in the cache */
   /* search1685_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4662, 243 },
      6,
   } },

   /* replace1685_0 -> 11 in the cache */
   /* replace1685_1 -> 243 in the cache */
   /* replace1685 -> 1964 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1686_0_0_0 -> 11 in the cache */
   /* search1686_0_0 -> 3948 in the cache */
   /* search1686_0 -> 4664 in the cache */
   /* search1686_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4664, 243 },
      6,
   } },

   /* replace1686_0 -> 11 in the cache */
   /* replace1686_1 -> 243 in the cache */
   /* replace1686 -> 1964 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1687_0_0 -> 11 in the cache */
   /* search1687_0_1 -> 811 in the cache */
   /* search1687_0 -> 3132 in the cache */
   /* search1687_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3132, 243 },
      6,
   } },

   /* replace1687_0 -> 11 in the cache */
   /* replace1687_1 -> 243 in the cache */
   /* replace1687 -> 1964 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1688_0_0_0 -> 11 in the cache */
   /* search1688_0_0 -> 1950 in the cache */
   /* search1688_0 -> 4662 in the cache */
   /* search1688_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4662, 243 },
      6,
   } },

   /* replace1688_0 -> 11 in the cache */
   /* replace1688_1 -> 243 in the cache */
   /* replace1688 -> 2006 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1689_0_0_0 -> 11 in the cache */
   /* search1689_0_0 -> 3948 in the cache */
   /* search1689_0 -> 4664 in the cache */
   /* search1689_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4664, 243 },
      6,
   } },

   /* replace1689_0 -> 11 in the cache */
   /* replace1689_1 -> 243 in the cache */
   /* replace1689 -> 2006 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1690_0_0 -> 11 in the cache */
   /* search1690_0_1 -> 811 in the cache */
   /* search1690_0 -> 3132 in the cache */
   /* search1690_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3132, 243 },
      6,
   } },

   /* replace1690_0 -> 11 in the cache */
   /* replace1690_1 -> 243 in the cache */
   /* replace1690 -> 2006 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1691_0_0_0 -> 11 in the cache */
   /* search1691_0_0 -> 1950 in the cache */
   /* search1691_0 -> 4662 in the cache */
   /* search1691_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4662, 243 },
      6,
   } },

   /* replace1691_0 -> 11 in the cache */
   /* replace1691_1 -> 243 in the cache */
   /* replace1691 -> 2030 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1692_0_0_0 -> 11 in the cache */
   /* search1692_0_0 -> 3948 in the cache */
   /* search1692_0 -> 4664 in the cache */
   /* search1692_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4664, 243 },
      6,
   } },

   /* replace1692_0 -> 11 in the cache */
   /* replace1692_1 -> 243 in the cache */
   /* replace1692 -> 2030 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1693_0_0 -> 11 in the cache */
   /* search1693_0_1 -> 811 in the cache */
   /* search1693_0 -> 3132 in the cache */
   /* search1693_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3132, 243 },
      6,
   } },

   /* replace1693_0 -> 11 in the cache */
   /* replace1693_1 -> 243 in the cache */
   /* replace1693 -> 2030 in the cache */

   /* ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1694_0_0 -> 16 in the cache */
   /* search1694_0 -> 1966 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1966 },
      6,
   } },

   /* replace1694 -> 16 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1695_0 -> 16 in the cache */
   /* search1695_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 120 },
      6,
   } },

   /* replace1695 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1696_0 -> 502 in the cache */
   /* search1696_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4681 },
      -1,
   } },
   /* search1696_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4682, 540 },
      6,
   } },

   /* replace1696_0 -> 502 in the cache */
   /* replace1696_1 -> 360 in the cache */
   /* replace1696_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 360, 540 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1697_0 -> 502 in the cache */
   /* search1697_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4685 },
      -1,
   } },
   /* search1697_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4686, 540 },
      6,
   } },

   /* replace1697_0 -> 502 in the cache */
   /* replace1697_1 -> 360 in the cache */
   /* replace1697_2 -> 540 in the cache */
   /* replace1697 -> 4684 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1698_0 -> 502 in the cache */
   /* search1698_1_0 -> 360 in the cache */
   /* search1698_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 360, 120 },
      -1,
   } },
   /* search1698_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4688, 540 },
      6,
   } },

   /* replace1698_0 -> 502 in the cache */
   /* replace1698_1 -> 360 in the cache */
   /* replace1698_2 -> 540 in the cache */
   /* replace1698 -> 4684 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1699_0_0_0 -> 16 in the cache */
   /* search1699_0_0 -> 1966 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1966 },
      -1,
   } },
   /* search1699_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4690, 36 },
      6,
   } },

   /* replace1699_0 -> 16 in the cache */
   /* replace1699_1 -> 36 in the cache */
   /* replace1699 -> 3712 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1700_0_0_0 -> 16 in the cache */
   /* search1700_0_0 -> 3900 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3900 },
      -1,
   } },
   /* search1700_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4692, 36 },
      6,
   } },

   /* replace1700_0 -> 16 in the cache */
   /* replace1700_1 -> 36 in the cache */
   /* replace1700 -> 3712 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1701_0_0 -> 16 in the cache */
   /* search1701_0_1 -> 120 in the cache */
   /* search1701_0 -> 393 in the cache */
   /* search1701_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1701_0 -> 16 in the cache */
   /* replace1701_1 -> 36 in the cache */
   /* replace1701 -> 3712 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1702_0_0_0 -> 16 in the cache */
   /* search1702_0_0 -> 1966 in the cache */
   /* search1702_0 -> 4690 in the cache */
   /* search1702_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4690, 36 },
      6,
   } },

   /* replace1702_0 -> 16 in the cache */
   /* replace1702_1 -> 36 in the cache */
   /* replace1702 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1703_0_0_0 -> 16 in the cache */
   /* search1703_0_0 -> 3900 in the cache */
   /* search1703_0 -> 4692 in the cache */
   /* search1703_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4692, 36 },
      6,
   } },

   /* replace1703_0 -> 16 in the cache */
   /* replace1703_1 -> 36 in the cache */
   /* replace1703 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1704_0_0 -> 16 in the cache */
   /* search1704_0_1 -> 120 in the cache */
   /* search1704_0 -> 393 in the cache */
   /* search1704_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1704_0 -> 16 in the cache */
   /* replace1704_1 -> 36 in the cache */
   /* replace1704 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1705_0_0_0 -> 16 in the cache */
   /* search1705_0_0 -> 1966 in the cache */
   /* search1705_0 -> 4690 in the cache */
   /* search1705_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4690, 36 },
      6,
   } },

   /* replace1705_0 -> 16 in the cache */
   /* replace1705_1 -> 36 in the cache */
   /* replace1705 -> 1972 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1706_0_0_0 -> 16 in the cache */
   /* search1706_0_0 -> 3900 in the cache */
   /* search1706_0 -> 4692 in the cache */
   /* search1706_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4692, 36 },
      6,
   } },

   /* replace1706_0 -> 16 in the cache */
   /* replace1706_1 -> 36 in the cache */
   /* replace1706 -> 1972 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1707_0_0 -> 16 in the cache */
   /* search1707_0_1 -> 120 in the cache */
   /* search1707_0 -> 393 in the cache */
   /* search1707_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1707_0 -> 16 in the cache */
   /* replace1707_1 -> 36 in the cache */
   /* replace1707 -> 1972 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1708_0_0_0 -> 16 in the cache */
   /* search1708_0_0 -> 1966 in the cache */
   /* search1708_0 -> 4690 in the cache */
   /* search1708_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4690, 36 },
      6,
   } },

   /* replace1708_0 -> 16 in the cache */
   /* replace1708_1 -> 36 in the cache */
   /* replace1708 -> 2010 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1709_0_0_0 -> 16 in the cache */
   /* search1709_0_0 -> 3900 in the cache */
   /* search1709_0 -> 4692 in the cache */
   /* search1709_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4692, 36 },
      6,
   } },

   /* replace1709_0 -> 16 in the cache */
   /* replace1709_1 -> 36 in the cache */
   /* replace1709 -> 2010 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1710_0_0 -> 16 in the cache */
   /* search1710_0_1 -> 120 in the cache */
   /* search1710_0 -> 393 in the cache */
   /* search1710_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1710_0 -> 16 in the cache */
   /* replace1710_1 -> 36 in the cache */
   /* replace1710 -> 2010 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1711_0_0_0 -> 16 in the cache */
   /* search1711_0_0 -> 1966 in the cache */
   /* search1711_0 -> 4690 in the cache */
   /* search1711_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4690, 36 },
      6,
   } },

   /* replace1711_0 -> 16 in the cache */
   /* replace1711_1 -> 36 in the cache */
   /* replace1711 -> 2034 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1712_0_0_0 -> 16 in the cache */
   /* search1712_0_0 -> 3900 in the cache */
   /* search1712_0 -> 4692 in the cache */
   /* search1712_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4692, 36 },
      6,
   } },

   /* replace1712_0 -> 16 in the cache */
   /* replace1712_1 -> 36 in the cache */
   /* replace1712 -> 2034 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1713_0_0 -> 16 in the cache */
   /* search1713_0_1 -> 120 in the cache */
   /* search1713_0 -> 393 in the cache */
   /* search1713_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 393, 36 },
      6,
   } },

   /* replace1713_0 -> 16 in the cache */
   /* replace1713_1 -> 36 in the cache */
   /* replace1713 -> 2034 in the cache */

   /* ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1714_0_0 -> 16 in the cache */
   /* search1714_0 -> 1966 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1966 },
      6,
   } },

   /* replace1714 -> 16 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1715_0 -> 16 in the cache */
   /* search1715_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 120 },
      6,
   } },

   /* replace1715 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1716_0 -> 502 in the cache */
   /* search1716_1_0_0 -> 360 in the cache */
   /* search1716_1_0 -> 4681 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4681 },
      -1,
   } },
   /* search1716_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4709, 540 },
      6,
   } },

   /* replace1716_0 -> 502 in the cache */
   /* replace1716_1 -> 360 in the cache */
   /* replace1716_2 -> 540 in the cache */
   /* replace1716 -> 4684 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1717_0 -> 502 in the cache */
   /* search1717_1_0_0 -> 360 in the cache */
   /* search1717_1_0 -> 4685 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4685 },
      -1,
   } },
   /* search1717_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4711, 540 },
      6,
   } },

   /* replace1717_0 -> 502 in the cache */
   /* replace1717_1 -> 360 in the cache */
   /* replace1717_2 -> 540 in the cache */
   /* replace1717 -> 4684 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1718_0 -> 502 in the cache */
   /* search1718_1_0 -> 360 in the cache */
   /* search1718_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 360, 120 },
      -1,
   } },
   /* search1718_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4713, 540 },
      6,
   } },

   /* replace1718_0 -> 502 in the cache */
   /* replace1718_1 -> 360 in the cache */
   /* replace1718_2 -> 540 in the cache */
   /* replace1718 -> 4684 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1719_0_0_0 -> 16 in the cache */
   /* search1719_0_0 -> 1966 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1966 },
      -1,
   } },
   /* search1719_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4715, 36 },
      6,
   } },

   /* replace1719_0 -> 16 in the cache */
   /* replace1719_1 -> 36 in the cache */
   /* replace1719 -> 3712 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1720_0_0_0 -> 16 in the cache */
   /* search1720_0_0 -> 3900 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3900 },
      -1,
   } },
   /* search1720_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4717, 36 },
      6,
   } },

   /* replace1720_0 -> 16 in the cache */
   /* replace1720_1 -> 36 in the cache */
   /* replace1720 -> 3712 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1721_0_0 -> 16 in the cache */
   /* search1721_0_1 -> 120 in the cache */
   /* search1721_0 -> 374 in the cache */
   /* search1721_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1721_0 -> 16 in the cache */
   /* replace1721_1 -> 36 in the cache */
   /* replace1721 -> 3712 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1722_0_0_0 -> 16 in the cache */
   /* search1722_0_0 -> 1966 in the cache */
   /* search1722_0 -> 4715 in the cache */
   /* search1722_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4715, 36 },
      6,
   } },

   /* replace1722_0 -> 16 in the cache */
   /* replace1722_1 -> 36 in the cache */
   /* replace1722 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1723_0_0_0 -> 16 in the cache */
   /* search1723_0_0 -> 3900 in the cache */
   /* search1723_0 -> 4717 in the cache */
   /* search1723_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4717, 36 },
      6,
   } },

   /* replace1723_0 -> 16 in the cache */
   /* replace1723_1 -> 36 in the cache */
   /* replace1723 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1724_0_0 -> 16 in the cache */
   /* search1724_0_1 -> 120 in the cache */
   /* search1724_0 -> 374 in the cache */
   /* search1724_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1724_0 -> 16 in the cache */
   /* replace1724_1 -> 36 in the cache */
   /* replace1724 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1725_0_0_0 -> 16 in the cache */
   /* search1725_0_0 -> 1966 in the cache */
   /* search1725_0 -> 4715 in the cache */
   /* search1725_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4715, 36 },
      6,
   } },

   /* replace1725_0 -> 16 in the cache */
   /* replace1725_1 -> 36 in the cache */
   /* replace1725 -> 1972 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1726_0_0_0 -> 16 in the cache */
   /* search1726_0_0 -> 3900 in the cache */
   /* search1726_0 -> 4717 in the cache */
   /* search1726_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4717, 36 },
      6,
   } },

   /* replace1726_0 -> 16 in the cache */
   /* replace1726_1 -> 36 in the cache */
   /* replace1726 -> 1972 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1727_0_0 -> 16 in the cache */
   /* search1727_0_1 -> 120 in the cache */
   /* search1727_0 -> 374 in the cache */
   /* search1727_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1727_0 -> 16 in the cache */
   /* replace1727_1 -> 36 in the cache */
   /* replace1727 -> 1972 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1728_0_0_0 -> 16 in the cache */
   /* search1728_0_0 -> 1966 in the cache */
   /* search1728_0 -> 4715 in the cache */
   /* search1728_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4715, 36 },
      6,
   } },

   /* replace1728_0 -> 16 in the cache */
   /* replace1728_1 -> 36 in the cache */
   /* replace1728 -> 2010 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1729_0_0_0 -> 16 in the cache */
   /* search1729_0_0 -> 3900 in the cache */
   /* search1729_0 -> 4717 in the cache */
   /* search1729_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4717, 36 },
      6,
   } },

   /* replace1729_0 -> 16 in the cache */
   /* replace1729_1 -> 36 in the cache */
   /* replace1729 -> 2010 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1730_0_0 -> 16 in the cache */
   /* search1730_0_1 -> 120 in the cache */
   /* search1730_0 -> 374 in the cache */
   /* search1730_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1730_0 -> 16 in the cache */
   /* replace1730_1 -> 36 in the cache */
   /* replace1730 -> 2010 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1731_0_0_0 -> 16 in the cache */
   /* search1731_0_0 -> 1966 in the cache */
   /* search1731_0 -> 4715 in the cache */
   /* search1731_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4715, 36 },
      6,
   } },

   /* replace1731_0 -> 16 in the cache */
   /* replace1731_1 -> 36 in the cache */
   /* replace1731 -> 2034 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1732_0_0_0 -> 16 in the cache */
   /* search1732_0_0 -> 3900 in the cache */
   /* search1732_0 -> 4717 in the cache */
   /* search1732_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4717, 36 },
      6,
   } },

   /* replace1732_0 -> 16 in the cache */
   /* replace1732_1 -> 36 in the cache */
   /* replace1732 -> 2034 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1733_0_0 -> 16 in the cache */
   /* search1733_0_1 -> 120 in the cache */
   /* search1733_0 -> 374 in the cache */
   /* search1733_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 374, 36 },
      6,
   } },

   /* replace1733_0 -> 16 in the cache */
   /* replace1733_1 -> 36 in the cache */
   /* replace1733 -> 2034 in the cache */

   /* ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1734_0_0 -> 16 in the cache */
   /* search1734_0 -> 3003 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3003 },
      7,
   } },

   /* replace1734 -> 16 in the cache */

   /* ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1735_0 -> 16 in the cache */
   /* search1735_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 120 },
      7,
   } },

   /* replace1735 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1736_0 -> 502 in the cache */
   /* search1736_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4734 },
      -1,
   } },
   /* search1736_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4735, 540 },
      7,
   } },

   /* replace1736_0 -> 502 in the cache */
   /* replace1736_1 -> 360 in the cache */
   /* replace1736_2 -> 540 in the cache */
   /* replace1736 -> 4684 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1737_0 -> 502 in the cache */
   /* search1737_1_0_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 360 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4737 },
      -1,
   } },
   /* search1737_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4738, 540 },
      7,
   } },

   /* replace1737_0 -> 502 in the cache */
   /* replace1737_1 -> 360 in the cache */
   /* replace1737_2 -> 540 in the cache */
   /* replace1737 -> 4684 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1738_0 -> 502 in the cache */
   /* search1738_1_0 -> 360 in the cache */
   /* search1738_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 360, 120 },
      -1,
   } },
   /* search1738_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4740, 540 },
      7,
   } },

   /* replace1738_0 -> 502 in the cache */
   /* replace1738_1 -> 360 in the cache */
   /* replace1738_2 -> 540 in the cache */
   /* replace1738 -> 4684 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1739_0_0_0 -> 16 in the cache */
   /* search1739_0_0 -> 3003 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3003 },
      -1,
   } },
   /* search1739_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4742, 36 },
      7,
   } },

   /* replace1739_0 -> 16 in the cache */
   /* replace1739_1 -> 36 in the cache */
   /* replace1739 -> 3712 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1740_0_0_0 -> 16 in the cache */
   /* search1740_0_0 -> 3902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3902 },
      -1,
   } },
   /* search1740_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4744, 36 },
      7,
   } },

   /* replace1740_0 -> 16 in the cache */
   /* replace1740_1 -> 36 in the cache */
   /* replace1740 -> 3712 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1741_0_0 -> 16 in the cache */
   /* search1741_0_1 -> 120 in the cache */
   /* search1741_0 -> 425 in the cache */
   /* search1741_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1741_0 -> 16 in the cache */
   /* replace1741_1 -> 36 in the cache */
   /* replace1741 -> 3712 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1742_0_0_0 -> 16 in the cache */
   /* search1742_0_0 -> 3003 in the cache */
   /* search1742_0 -> 4742 in the cache */
   /* search1742_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4742, 36 },
      7,
   } },

   /* replace1742_0 -> 16 in the cache */
   /* replace1742_1 -> 36 in the cache */
   /* replace1742 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1743_0_0_0 -> 16 in the cache */
   /* search1743_0_0 -> 3902 in the cache */
   /* search1743_0 -> 4744 in the cache */
   /* search1743_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4744, 36 },
      7,
   } },

   /* replace1743_0 -> 16 in the cache */
   /* replace1743_1 -> 36 in the cache */
   /* replace1743 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1744_0_0 -> 16 in the cache */
   /* search1744_0_1 -> 120 in the cache */
   /* search1744_0 -> 425 in the cache */
   /* search1744_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1744_0 -> 16 in the cache */
   /* replace1744_1 -> 36 in the cache */
   /* replace1744 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1745_0_0_0 -> 16 in the cache */
   /* search1745_0_0 -> 3003 in the cache */
   /* search1745_0 -> 4742 in the cache */
   /* search1745_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4742, 36 },
      7,
   } },

   /* replace1745_0 -> 16 in the cache */
   /* replace1745_1 -> 36 in the cache */
   /* replace1745 -> 1972 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1746_0_0_0 -> 16 in the cache */
   /* search1746_0_0 -> 3902 in the cache */
   /* search1746_0 -> 4744 in the cache */
   /* search1746_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4744, 36 },
      7,
   } },

   /* replace1746_0 -> 16 in the cache */
   /* replace1746_1 -> 36 in the cache */
   /* replace1746 -> 1972 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1747_0_0 -> 16 in the cache */
   /* search1747_0_1 -> 120 in the cache */
   /* search1747_0 -> 425 in the cache */
   /* search1747_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1747_0 -> 16 in the cache */
   /* replace1747_1 -> 36 in the cache */
   /* replace1747 -> 1972 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1748_0_0_0 -> 16 in the cache */
   /* search1748_0_0 -> 3003 in the cache */
   /* search1748_0 -> 4742 in the cache */
   /* search1748_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4742, 36 },
      7,
   } },

   /* replace1748_0 -> 16 in the cache */
   /* replace1748_1 -> 36 in the cache */
   /* replace1748 -> 2010 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1749_0_0_0 -> 16 in the cache */
   /* search1749_0_0 -> 3902 in the cache */
   /* search1749_0 -> 4744 in the cache */
   /* search1749_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4744, 36 },
      7,
   } },

   /* replace1749_0 -> 16 in the cache */
   /* replace1749_1 -> 36 in the cache */
   /* replace1749 -> 2010 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1750_0_0 -> 16 in the cache */
   /* search1750_0_1 -> 120 in the cache */
   /* search1750_0 -> 425 in the cache */
   /* search1750_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1750_0 -> 16 in the cache */
   /* replace1750_1 -> 36 in the cache */
   /* replace1750 -> 2010 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1751_0_0_0 -> 16 in the cache */
   /* search1751_0_0 -> 3003 in the cache */
   /* search1751_0 -> 4742 in the cache */
   /* search1751_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4742, 36 },
      7,
   } },

   /* replace1751_0 -> 16 in the cache */
   /* replace1751_1 -> 36 in the cache */
   /* replace1751 -> 2034 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1752_0_0_0 -> 16 in the cache */
   /* search1752_0_0 -> 3902 in the cache */
   /* search1752_0 -> 4744 in the cache */
   /* search1752_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4744, 36 },
      7,
   } },

   /* replace1752_0 -> 16 in the cache */
   /* replace1752_1 -> 36 in the cache */
   /* replace1752 -> 2034 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1753_0_0 -> 16 in the cache */
   /* search1753_0_1 -> 120 in the cache */
   /* search1753_0 -> 425 in the cache */
   /* search1753_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 425, 36 },
      7,
   } },

   /* replace1753_0 -> 16 in the cache */
   /* replace1753_1 -> 36 in the cache */
   /* replace1753 -> 2034 in the cache */

   /* ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1754_0_0 -> 16 in the cache */
   /* search1754_0 -> 3003 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3003 },
      7,
   } },

   /* replace1754 -> 16 in the cache */

   /* ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1755_0 -> 16 in the cache */
   /* search1755_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 120 },
      7,
   } },

   /* replace1755 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1756_0 -> 502 in the cache */
   /* search1756_1_0_0 -> 360 in the cache */
   /* search1756_1_0 -> 4734 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4734 },
      -1,
   } },
   /* search1756_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4761, 540 },
      7,
   } },

   /* replace1756_0 -> 502 in the cache */
   /* replace1756_1 -> 360 in the cache */
   /* replace1756_2 -> 540 in the cache */
   /* replace1756 -> 4684 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1757_0 -> 502 in the cache */
   /* search1757_1_0_0 -> 360 in the cache */
   /* search1757_1_0 -> 4737 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4737 },
      -1,
   } },
   /* search1757_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4763, 540 },
      7,
   } },

   /* replace1757_0 -> 502 in the cache */
   /* replace1757_1 -> 360 in the cache */
   /* replace1757_2 -> 540 in the cache */
   /* replace1757 -> 4684 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1758_0 -> 502 in the cache */
   /* search1758_1_0 -> 360 in the cache */
   /* search1758_1_1 -> 120 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 360, 120 },
      -1,
   } },
   /* search1758_2 -> 540 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 4765, 540 },
      7,
   } },

   /* replace1758_0 -> 502 in the cache */
   /* replace1758_1 -> 360 in the cache */
   /* replace1758_2 -> 540 in the cache */
   /* replace1758 -> 4684 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1759_0_0_0 -> 16 in the cache */
   /* search1759_0_0 -> 3003 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3003 },
      -1,
   } },
   /* search1759_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4767, 36 },
      7,
   } },

   /* replace1759_0 -> 16 in the cache */
   /* replace1759_1 -> 36 in the cache */
   /* replace1759 -> 3712 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1760_0_0_0 -> 16 in the cache */
   /* search1760_0_0 -> 3902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3902 },
      -1,
   } },
   /* search1760_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 4769, 36 },
      7,
   } },

   /* replace1760_0 -> 16 in the cache */
   /* replace1760_1 -> 36 in the cache */
   /* replace1760 -> 3712 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1761_0_0 -> 16 in the cache */
   /* search1761_0_1 -> 120 in the cache */
   /* search1761_0 -> 417 in the cache */
   /* search1761_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1761_0 -> 16 in the cache */
   /* replace1761_1 -> 36 in the cache */
   /* replace1761 -> 3712 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1762_0_0_0 -> 16 in the cache */
   /* search1762_0_0 -> 3003 in the cache */
   /* search1762_0 -> 4767 in the cache */
   /* search1762_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4767, 36 },
      7,
   } },

   /* replace1762_0 -> 16 in the cache */
   /* replace1762_1 -> 36 in the cache */
   /* replace1762 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1763_0_0_0 -> 16 in the cache */
   /* search1763_0_0 -> 3902 in the cache */
   /* search1763_0 -> 4769 in the cache */
   /* search1763_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 4769, 36 },
      7,
   } },

   /* replace1763_0 -> 16 in the cache */
   /* replace1763_1 -> 36 in the cache */
   /* replace1763 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1764_0_0 -> 16 in the cache */
   /* search1764_0_1 -> 120 in the cache */
   /* search1764_0 -> 417 in the cache */
   /* search1764_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1764_0 -> 16 in the cache */
   /* replace1764_1 -> 36 in the cache */
   /* replace1764 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1765_0_0_0 -> 16 in the cache */
   /* search1765_0_0 -> 3003 in the cache */
   /* search1765_0 -> 4767 in the cache */
   /* search1765_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4767, 36 },
      7,
   } },

   /* replace1765_0 -> 16 in the cache */
   /* replace1765_1 -> 36 in the cache */
   /* replace1765 -> 1972 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1766_0_0_0 -> 16 in the cache */
   /* search1766_0_0 -> 3902 in the cache */
   /* search1766_0 -> 4769 in the cache */
   /* search1766_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 4769, 36 },
      7,
   } },

   /* replace1766_0 -> 16 in the cache */
   /* replace1766_1 -> 36 in the cache */
   /* replace1766 -> 1972 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1767_0_0 -> 16 in the cache */
   /* search1767_0_1 -> 120 in the cache */
   /* search1767_0 -> 417 in the cache */
   /* search1767_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1767_0 -> 16 in the cache */
   /* replace1767_1 -> 36 in the cache */
   /* replace1767 -> 1972 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1768_0_0_0 -> 16 in the cache */
   /* search1768_0_0 -> 3003 in the cache */
   /* search1768_0 -> 4767 in the cache */
   /* search1768_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4767, 36 },
      7,
   } },

   /* replace1768_0 -> 16 in the cache */
   /* replace1768_1 -> 36 in the cache */
   /* replace1768 -> 2010 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1769_0_0_0 -> 16 in the cache */
   /* search1769_0_0 -> 3902 in the cache */
   /* search1769_0 -> 4769 in the cache */
   /* search1769_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4769, 36 },
      7,
   } },

   /* replace1769_0 -> 16 in the cache */
   /* replace1769_1 -> 36 in the cache */
   /* replace1769 -> 2010 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1770_0_0 -> 16 in the cache */
   /* search1770_0_1 -> 120 in the cache */
   /* search1770_0 -> 417 in the cache */
   /* search1770_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1770_0 -> 16 in the cache */
   /* replace1770_1 -> 36 in the cache */
   /* replace1770 -> 2010 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1771_0_0_0 -> 16 in the cache */
   /* search1771_0_0 -> 3003 in the cache */
   /* search1771_0 -> 4767 in the cache */
   /* search1771_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4767, 36 },
      7,
   } },

   /* replace1771_0 -> 16 in the cache */
   /* replace1771_1 -> 36 in the cache */
   /* replace1771 -> 2034 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1772_0_0_0 -> 16 in the cache */
   /* search1772_0_0 -> 3902 in the cache */
   /* search1772_0 -> 4769 in the cache */
   /* search1772_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 4769, 36 },
      7,
   } },

   /* replace1772_0 -> 16 in the cache */
   /* replace1772_1 -> 36 in the cache */
   /* replace1772 -> 2034 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1773_0_0 -> 16 in the cache */
   /* search1773_0_1 -> 120 in the cache */
   /* search1773_0 -> 417 in the cache */
   /* search1773_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 417, 36 },
      7,
   } },

   /* replace1773_0 -> 16 in the cache */
   /* replace1773_1 -> 36 in the cache */
   /* replace1773 -> 2034 in the cache */

   /* ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* exp */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 4784, 4785 },
      -1,
   } },

   /* replace1774_0_0 -> 4784 in the cache */
   /* replace1774_0_1_0_0_0_0_0_0 -> 4785 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1e /* -30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 4785, 4787 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1e /* 30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 4788, 4789 },
      -1,
   } },
   /* replace1774_0_1_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4790, 377 },
      -1,
   } },
   /* replace1774_0_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 4791, 14 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xa /* 10 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 4792, 4793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 3,
      { 4794 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 4784, 4795 },
      -1,
   } },
   /* replace1774_1_0_0_0_0_0_0 -> 4785 in the cache */
   /* replace1774_1_0_0_0_0_0_1 -> 4787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 4785, 4787 },
      -1,
   } },
   /* replace1774_1_0_0_0_0_1 -> 4789 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 4797, 4789 },
      -1,
   } },
   /* replace1774_1_0_0_0_1_0_0_0 -> 4785 in the cache */
   /* replace1774_1_0_0_0_1_0_0_1 -> 4787 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 4785, 4787 },
      -1,
   } },
   /* replace1774_1_0_0_0_1_0_1 -> 4789 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 4799, 4789 },
      -1,
   } },
   /* replace1774_1_0_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4800, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 4798, 4801 },
      -1,
   } },
   /* replace1774_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 4802, 14 },
      -1,
   } },
   /* replace1774_1_0_1 -> 4793 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4803, 4793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 5,
      { 4804 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 4796, 4805 },
      -1,
   } },

   /* ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23)) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1775_1 -> 4785 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 4807, 4785 },
      -1,
   } },

   /* replace1775_0_0 -> 4807 in the cache */
   /* replace1775_0_1_0_0_0_0_0 -> 4785 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0xfe /* -254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 4785, 4809 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfe /* 254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 4810, 4811 },
      -1,
   } },
   /* replace1775_0_1_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4812, 377 },
      -1,
   } },
   /* replace1775_0_1_0_1 -> 3986 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 4813, 3986 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x17 /* 23 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 4814, 4815 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 4807, 4816 },
      -1,
   } },
   /* replace1775_1_0_0_0_0_0 -> 4785 in the cache */
   /* replace1775_1_0_0_0_0_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 4785, 4809 },
      -1,
   } },
   /* replace1775_1_0_0_0_1 -> 4811 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 4818, 4811 },
      -1,
   } },
   /* replace1775_1_0_0_1_0_0_0 -> 4785 in the cache */
   /* replace1775_1_0_0_1_0_0_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 4785, 4809 },
      -1,
   } },
   /* replace1775_1_0_0_1_0_1 -> 4811 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 4820, 4811 },
      -1,
   } },
   /* replace1775_1_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4821, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 4819, 4822 },
      -1,
   } },
   /* replace1775_1_0_1 -> 3986 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 4823, 3986 },
      -1,
   } },
   /* replace1775_1_1 -> 4815 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4824, 4815 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 4817, 4825 },
      -1,
   } },

   /* ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1776_1 -> 4785 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 4827, 4785 },
      -1,
   } },

   /* replace1776_0_0 -> 4827 in the cache */
   /* replace1776_0_1_0 -> 120 in the cache */
   /* replace1776_0_1_1_0_0_0_0_0 -> 4785 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x7fe /* -2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 4785, 4829 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fe /* 2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 4830, 4831 },
      -1,
   } },
   /* replace1776_0_1_1_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4832, 377 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3ff /* 1023 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 4833, 4834 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x14 /* 20 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 4835, 4836 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 3,
      { 120, 4837 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 4827, 4838 },
      -1,
   } },
   /* replace1776_1_0 -> 120 in the cache */
   /* replace1776_1_1_0_0_0_0_0 -> 4785 in the cache */
   /* replace1776_1_1_0_0_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 4785, 4829 },
      -1,
   } },
   /* replace1776_1_1_0_0_0_1 -> 4831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 4840, 4831 },
      -1,
   } },
   /* replace1776_1_1_0_0_1_0_0_0 -> 4785 in the cache */
   /* replace1776_1_1_0_0_1_0_0_1 -> 4829 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 4785, 4829 },
      -1,
   } },
   /* replace1776_1_1_0_0_1_0_1 -> 4831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 4842, 4831 },
      -1,
   } },
   /* replace1776_1_1_0_0_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 4843, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 4841, 4844 },
      -1,
   } },
   /* replace1776_1_1_0_1 -> 4834 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 4845, 4834 },
      -1,
   } },
   /* replace1776_1_1_1 -> 4836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4846, 4836 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 5,
      { 120, 4847 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 4839, 4848 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x') */
   /* search1777_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1777_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 4807, 808 },
      -1,
   } },
   /* search1777_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1777_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 808 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 4807, 808 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      8, 1,
      { 4850, 4851 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff /* 16711935 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 4852, 4853 },
      -1,
   } },
   /* search1777_0_0_0_0_0_0_0_0_0_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4854, 786 },
      -1,
   } },
   /* search1777_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1777_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1777_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1777_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1777_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1777_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      10, 1,
      { 4850, 4851 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff00 /* 4278255360 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 4856, 4857 },
      -1,
   } },
   /* search1777_0_0_0_0_0_0_0_0_0_1_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4858, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 4855, 4859 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f /* 252645135 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 4860, 4861 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 4862, 4863 },
      -1,
   } },
   /* search1777_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1777_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1777_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1777_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1777_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1777_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      14, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_0_0_0_0_0_0_1_0_0_0_0_1 -> 4853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 4865, 4853 },
      -1,
   } },
   /* search1777_0_0_0_0_0_0_1_0_0_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4866, 786 },
      -1,
   } },
   /* search1777_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1777_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1777_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1777_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1777_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1777_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      16, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_0_0_0_0_0_0_1_0_0_1_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 4868, 4857 },
      -1,
   } },
   /* search1777_0_0_0_0_0_0_1_0_0_1_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4869, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 4867, 4870 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f0 /* 4042322160 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 4871, 4872 },
      -1,
   } },
   /* search1777_0_0_0_0_0_0_1_1 -> 4863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 4873, 4863 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 4864, 4874 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x33333333 /* 858993459 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 4875, 4876 },
      -1,
   } },
   /* search1777_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 4877, 382 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1777_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1777_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1777_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1777_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1777_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      22, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_0_0_0_0_0_1 -> 4853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 4879, 4853 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_0_0_0_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4880, 786 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1777_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1777_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1777_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1777_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1777_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      24, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_0_0_0_1_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 4882, 4857 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_0_0_0_1_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4883, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 4881, 4884 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_0_0_1 -> 4861 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 4885, 4861 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_0_1 -> 4863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 4886, 4863 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1777_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1777_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1777_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1777_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1777_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      28, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_1_0_0_0_0_1 -> 4853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 4888, 4853 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_1_0_0_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4889, 786 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1777_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1777_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1777_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1777_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1777_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      30, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_1_0_0_1_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 4891, 4857 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_1_0_0_1_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4892, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 4890, 4893 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_1_0_1 -> 4872 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 4894, 4872 },
      -1,
   } },
   /* search1777_0_0_0_1_0_0_1_1 -> 4863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 4895, 4863 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 4887, 4896 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xcccccccc /* 3435973836 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 4897, 4898 },
      -1,
   } },
   /* search1777_0_0_0_1_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 4899, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 4878, 4900 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x55555555 /* 1431655765 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 4901, 4902 },
      -1,
   } },
   /* search1777_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 30,
      { 4903, 377 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1777_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1777_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1777_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1777_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1777_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      38, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_0_0_0_0_0_1 -> 4853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 4905, 4853 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_0_0_0_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4906, 786 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1777_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1777_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1777_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1777_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1777_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      40, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_0_0_0_1_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 4908, 4857 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_0_0_0_1_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4909, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 4907, 4910 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_0_0_1 -> 4861 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 4911, 4861 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_0_1 -> 4863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 4912, 4863 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1777_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1777_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1777_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1777_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1777_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      44, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_1_0_0_0_0_1 -> 4853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 4914, 4853 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_1_0_0_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4915, 786 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1777_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1777_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1777_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1777_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1777_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      46, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_1_0_0_1_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 4917, 4857 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_1_0_0_1_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4918, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 4916, 4919 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_1_0_1 -> 4872 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 4920, 4872 },
      -1,
   } },
   /* search1777_1_0_0_0_0_0_1_1 -> 4863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 4921, 4863 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 4913, 4922 },
      -1,
   } },
   /* search1777_1_0_0_0_0_1 -> 4876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 4923, 4876 },
      -1,
   } },
   /* search1777_1_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 4924, 382 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1777_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1777_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1777_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1777_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1777_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      52, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_0_0_0_0_0_1 -> 4853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 4926, 4853 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_0_0_0_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4927, 786 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1777_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1777_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1777_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1777_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1777_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      54, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_0_0_0_1_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 4929, 4857 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_0_0_0_1_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4930, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 4928, 4931 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_0_0_1 -> 4861 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 4932, 4861 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_0_1 -> 4863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 4933, 4863 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1777_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1777_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1777_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1777_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1777_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      58, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_1_0_0_0_0_1 -> 4853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 4935, 4853 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_1_0_0_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 4936, 786 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1777_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1777_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1777_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1777_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1777_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 4851 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      60, 1,
      { 4850, 4851 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_1_0_0_1_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 4938, 4857 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_1_0_0_1_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 4939, 786 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 4937, 4940 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_1_0_1 -> 4872 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 4941, 4872 },
      -1,
   } },
   /* search1777_1_0_0_1_0_0_1_1 -> 4863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 4942, 4863 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 4934, 4943 },
      -1,
   } },
   /* search1777_1_0_0_1_0_1 -> 4898 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 4944, 4898 },
      -1,
   } },
   /* search1777_1_0_0_1_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 4945, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 4925, 4946 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xaaaaaaaa /* 2863311530 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 4947, 4948 },
      -1,
   } },
   /* search1777_1_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 30,
      { 4949, 377 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 4904, 4950 },
      -1,
   } },

   /* replace1777_0 -> 4807 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_reverse,
      -1, 0,
      { 4807 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x') */
   /* search1778_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 4851 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_0_0_0 -> 4852 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4852, 377 },
      -1,
   } },
   /* search1778_0_0_0_0_0_0_0_0_0_0_1 -> 4948 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 4953, 4948 },
      -1,
   } },
   /* search1778_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 4851 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_1_0_0 -> 4856 in the cache */
   /* search1778_0_0_0_0_0_0_0_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4856, 377 },
      -1,
   } },
   /* search1778_0_0_0_0_0_0_0_0_0_1_1 -> 4902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 4955, 4902 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 4954, 4956 },
      -1,
   } },
   /* search1778_0_0_0_0_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4957, 382 },
      -1,
   } },
   /* search1778_0_0_0_0_0_0_0_1 -> 4898 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 4958, 4898 },
      -1,
   } },
   /* search1778_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 4851 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_0_0_0 -> 4865 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4865, 377 },
      -1,
   } },
   /* search1778_0_0_0_0_0_0_1_0_0_0_1 -> 4948 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 4960, 4948 },
      -1,
   } },
   /* search1778_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 4851 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_1_0_0 -> 4868 in the cache */
   /* search1778_0_0_0_0_0_0_1_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4868, 377 },
      -1,
   } },
   /* search1778_0_0_0_0_0_0_1_0_0_1_1 -> 4902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 4962, 4902 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 4961, 4963 },
      -1,
   } },
   /* search1778_0_0_0_0_0_0_1_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 4964, 382 },
      -1,
   } },
   /* search1778_0_0_0_0_0_0_1_1 -> 4876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 4965, 4876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 4959, 4966 },
      -1,
   } },
   /* search1778_0_0_0_0_0_1 -> 4863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 4967, 4863 },
      -1,
   } },
   /* search1778_0_0_0_0_1 -> 4872 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 4968, 4872 },
      -1,
   } },
   /* search1778_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 4851 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_0_0_0 -> 4879 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4879, 377 },
      -1,
   } },
   /* search1778_0_0_0_1_0_0_0_0_0_0_1 -> 4948 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 4970, 4948 },
      -1,
   } },
   /* search1778_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 4851 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_1_0_0 -> 4882 in the cache */
   /* search1778_0_0_0_1_0_0_0_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4882, 377 },
      -1,
   } },
   /* search1778_0_0_0_1_0_0_0_0_0_1_1 -> 4902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 4972, 4902 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 4971, 4973 },
      -1,
   } },
   /* search1778_0_0_0_1_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4974, 382 },
      -1,
   } },
   /* search1778_0_0_0_1_0_0_0_1 -> 4898 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 4975, 4898 },
      -1,
   } },
   /* search1778_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 4851 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_0_0_0 -> 4888 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4888, 377 },
      -1,
   } },
   /* search1778_0_0_0_1_0_0_1_0_0_0_1 -> 4948 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 4977, 4948 },
      -1,
   } },
   /* search1778_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 4851 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_1_0_0 -> 4891 in the cache */
   /* search1778_0_0_0_1_0_0_1_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4891, 377 },
      -1,
   } },
   /* search1778_0_0_0_1_0_0_1_0_0_1_1 -> 4902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 4979, 4902 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 4978, 4980 },
      -1,
   } },
   /* search1778_0_0_0_1_0_0_1_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 4981, 382 },
      -1,
   } },
   /* search1778_0_0_0_1_0_0_1_1 -> 4876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 4982, 4876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 4976, 4983 },
      -1,
   } },
   /* search1778_0_0_0_1_0_1 -> 4863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 4984, 4863 },
      -1,
   } },
   /* search1778_0_0_0_1_1 -> 4861 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 4985, 4861 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 4969, 4986 },
      -1,
   } },
   /* search1778_0_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 29,
      { 4987, 786 },
      -1,
   } },
   /* search1778_0_1 -> 4857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 4988, 4857 },
      -1,
   } },
   /* search1778_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 4851 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_0_0_0 -> 4905 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4905, 377 },
      -1,
   } },
   /* search1778_1_0_0_0_0_0_0_0_0_0_1 -> 4948 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 4990, 4948 },
      -1,
   } },
   /* search1778_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 4851 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_1_0_0 -> 4908 in the cache */
   /* search1778_1_0_0_0_0_0_0_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4908, 377 },
      -1,
   } },
   /* search1778_1_0_0_0_0_0_0_0_0_1_1 -> 4902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 4992, 4902 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 4991, 4993 },
      -1,
   } },
   /* search1778_1_0_0_0_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 4994, 382 },
      -1,
   } },
   /* search1778_1_0_0_0_0_0_0_1 -> 4898 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 4995, 4898 },
      -1,
   } },
   /* search1778_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 4851 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_0_0_0 -> 4914 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4914, 377 },
      -1,
   } },
   /* search1778_1_0_0_0_0_0_1_0_0_0_1 -> 4948 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 4997, 4948 },
      -1,
   } },
   /* search1778_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 4851 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_1_0_0 -> 4917 in the cache */
   /* search1778_1_0_0_0_0_0_1_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4917, 377 },
      -1,
   } },
   /* search1778_1_0_0_0_0_0_1_0_0_1_1 -> 4902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 4999, 4902 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 4998, 5000 },
      -1,
   } },
   /* search1778_1_0_0_0_0_0_1_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5001, 382 },
      -1,
   } },
   /* search1778_1_0_0_0_0_0_1_1 -> 4876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 5002, 4876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 4996, 5003 },
      -1,
   } },
   /* search1778_1_0_0_0_0_1 -> 4863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 5004, 4863 },
      -1,
   } },
   /* search1778_1_0_0_0_1 -> 4872 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 5005, 4872 },
      -1,
   } },
   /* search1778_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 4851 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_0_0_0 -> 4926 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4926, 377 },
      -1,
   } },
   /* search1778_1_0_0_1_0_0_0_0_0_0_1 -> 4948 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 5007, 4948 },
      -1,
   } },
   /* search1778_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 4851 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_1_0_0 -> 4929 in the cache */
   /* search1778_1_0_0_1_0_0_0_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4929, 377 },
      -1,
   } },
   /* search1778_1_0_0_1_0_0_0_0_0_1_1 -> 4902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 5009, 4902 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 5008, 5010 },
      -1,
   } },
   /* search1778_1_0_0_1_0_0_0_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5011, 382 },
      -1,
   } },
   /* search1778_1_0_0_1_0_0_0_1 -> 4898 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 5012, 4898 },
      -1,
   } },
   /* search1778_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 4807 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 808 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 4850 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 4807 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 808 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 4851 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_0_0_0 -> 4935 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_0_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 4935, 377 },
      -1,
   } },
   /* search1778_1_0_0_1_0_0_1_0_0_0_1 -> 4948 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 5014, 4948 },
      -1,
   } },
   /* search1778_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 4807 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 808 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 4850 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 4807 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 808 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 4851 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_1_0_0 -> 4938 in the cache */
   /* search1778_1_0_0_1_0_0_1_0_0_1_0_1 -> 377 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 4938, 377 },
      -1,
   } },
   /* search1778_1_0_0_1_0_0_1_0_0_1_1 -> 4902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 5016, 4902 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 5015, 5017 },
      -1,
   } },
   /* search1778_1_0_0_1_0_0_1_0_1 -> 382 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5018, 382 },
      -1,
   } },
   /* search1778_1_0_0_1_0_0_1_1 -> 4876 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 5019, 4876 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 5013, 5020 },
      -1,
   } },
   /* search1778_1_0_0_1_0_1 -> 4863 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 5021, 4863 },
      -1,
   } },
   /* search1778_1_0_0_1_1 -> 4861 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 5022, 4861 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 5006, 5023 },
      -1,
   } },
   /* search1778_1_0_1 -> 786 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 29,
      { 5024, 786 },
      -1,
   } },
   /* search1778_1_1 -> 4853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 5025, 4853 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 4989, 5026 },
      -1,
   } },

   /* replace1778_0 -> 4807 in the cache */
   /* replace1778 -> 4952 in the cache */

   /* ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b') */
   /* search1779_0_0 -> 0 in the cache */
   /* search1779_0_1 -> 3 in the cache */
   /* search1779_0 -> 1035 in the cache */
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1035, 5028 },
      -1,
   } },

   /* replace1779_0 -> 0 in the cache */
   /* replace1779_1 -> 3 in the cache */
   /* replace1779 -> 2350 in the cache */

   /* ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b') */
   /* search1780_0_0 -> 0 in the cache */
   /* search1780_0_1 -> 3 in the cache */
   /* search1780_0 -> 1029 in the cache */
   /* search1780_1 -> 5028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1029, 5028 },
      -1,
   } },

   /* replace1780_0 -> 0 in the cache */
   /* replace1780_1 -> 3 in the cache */
   /* replace1780 -> 2385 in the cache */

   /* ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b') */
   /* search1781_0_0 -> 0 in the cache */
   /* search1781_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 5031, 5032 },
      -1,
   } },

   /* replace1781_0 -> 0 in the cache */
   /* replace1781_1 -> 3 in the cache */
   /* replace1781 -> 2370 in the cache */

   /* ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b') */
   /* search1782_0_0 -> 0 in the cache */
   /* search1782_0_1 -> 3 in the cache */
   /* search1782_0 -> 3744 in the cache */
   /* search1782_1 -> 5032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 3744, 5032 },
      -1,
   } },

   /* replace1782_0 -> 0 in the cache */
   /* replace1782_1 -> 3 in the cache */
   /* replace1782 -> 2400 in the cache */

   /* ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b') */
   /* search1783_0_0 -> 0 in the cache */
   /* search1783_0_1 -> 3 in the cache */
   /* search1783_0 -> 1035 in the cache */
   /* search1783_1 -> 5028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1035, 5028 },
      -1,
   } },

   /* replace1783_0 -> 0 in the cache */
   /* replace1783_1 -> 3 in the cache */
   /* replace1783 -> 2356 in the cache */

   /* ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b') */
   /* search1784_0_0 -> 0 in the cache */
   /* search1784_0_1 -> 3 in the cache */
   /* search1784_0 -> 1029 in the cache */
   /* search1784_1 -> 5028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1029, 5028 },
      -1,
   } },

   /* replace1784_0 -> 0 in the cache */
   /* replace1784_1 -> 3 in the cache */
   /* replace1784 -> 2389 in the cache */

   /* ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b') */
   /* search1785_0_0 -> 0 in the cache */
   /* search1785_0_1 -> 3 in the cache */
   /* search1785_0 -> 5031 in the cache */
   /* search1785_1 -> 5032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 5031, 5032 },
      -1,
   } },

   /* replace1785_0 -> 0 in the cache */
   /* replace1785_1 -> 3 in the cache */
   /* replace1785 -> 2374 in the cache */

   /* ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b') */
   /* search1786_0_0 -> 0 in the cache */
   /* search1786_0_1 -> 3 in the cache */
   /* search1786_0 -> 3744 in the cache */
   /* search1786_1 -> 5032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 3744, 5032 },
      -1,
   } },

   /* replace1786_0 -> 0 in the cache */
   /* replace1786_1 -> 3 in the cache */
   /* replace1786 -> 2404 in the cache */

   /* ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b') */
   /* search1787_0_0 -> 0 in the cache */
   /* search1787_0_1 -> 3 in the cache */
   /* search1787_0 -> 1035 in the cache */
   /* search1787_1 -> 5028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1035, 5028 },
      -1,
   } },

   /* replace1787_0 -> 0 in the cache */
   /* replace1787_1 -> 3 in the cache */
   /* replace1787 -> 2363 in the cache */

   /* ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b') */
   /* search1788_0_0 -> 0 in the cache */
   /* search1788_0_1 -> 3 in the cache */
   /* search1788_0 -> 1029 in the cache */
   /* search1788_1 -> 5028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1029, 5028 },
      -1,
   } },

   /* replace1788_0 -> 0 in the cache */
   /* replace1788_1 -> 3 in the cache */
   /* replace1788 -> 2395 in the cache */

   /* ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b') */
   /* search1789_0_0 -> 0 in the cache */
   /* search1789_0_1 -> 3 in the cache */
   /* search1789_0 -> 5031 in the cache */
   /* search1789_1 -> 5032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 5031, 5032 },
      -1,
   } },

   /* replace1789_0 -> 0 in the cache */
   /* replace1789_1 -> 3 in the cache */
   /* replace1789 -> 2380 in the cache */

   /* ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b') */
   /* search1790_0_0 -> 0 in the cache */
   /* search1790_0_1 -> 3 in the cache */
   /* search1790_0 -> 3744 in the cache */
   /* search1790_1 -> 5032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 3744, 5032 },
      -1,
   } },

   /* replace1790_0 -> 0 in the cache */
   /* replace1790_1 -> 3 in the cache */
   /* replace1790 -> 2410 in the cache */

   /* ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b') */
   /* search1791_0_0 -> 0 in the cache */
   /* search1791_0_1 -> 3 in the cache */
   /* search1791_0 -> 1035 in the cache */
   /* search1791_1 -> 5028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1035, 5028 },
      -1,
   } },

   /* replace1791_0 -> 0 in the cache */
   /* replace1791_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b') */
   /* search1792_0_0 -> 0 in the cache */
   /* search1792_0_1 -> 3 in the cache */
   /* search1792_0 -> 1029 in the cache */
   /* search1792_1 -> 5028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1029, 5028 },
      -1,
   } },

   /* replace1792_0 -> 0 in the cache */
   /* replace1792_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b') */
   /* search1793_0_0 -> 0 in the cache */
   /* search1793_0_1 -> 3 in the cache */
   /* search1793_0 -> 5031 in the cache */
   /* search1793_1 -> 5032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 5031, 5032 },
      -1,
   } },

   /* replace1793_0 -> 0 in the cache */
   /* replace1793_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b') */
   /* search1794_0_0 -> 0 in the cache */
   /* search1794_0_1 -> 3 in the cache */
   /* search1794_0 -> 3744 in the cache */
   /* search1794_1 -> 5032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 3744, 5032 },
      -1,
   } },

   /* replace1794_0 -> 0 in the cache */
   /* replace1794_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b') */
   /* search1795_0_0 -> 0 in the cache */
   /* search1795_0_1 -> 3 in the cache */
   /* search1795_0 -> 1035 in the cache */
   /* search1795_1 -> 5028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1035, 5028 },
      -1,
   } },

   /* replace1795_0 -> 0 in the cache */
   /* replace1795_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b') */
   /* search1796_0_0 -> 0 in the cache */
   /* search1796_0_1 -> 3 in the cache */
   /* search1796_0 -> 1029 in the cache */
   /* search1796_1 -> 5028 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1029, 5028 },
      -1,
   } },

   /* replace1796_0 -> 0 in the cache */
   /* replace1796_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b') */
   /* search1797_0_0 -> 0 in the cache */
   /* search1797_0_1 -> 3 in the cache */
   /* search1797_0 -> 5031 in the cache */
   /* search1797_1 -> 5032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 5031, 5032 },
      -1,
   } },

   /* replace1797_0 -> 0 in the cache */
   /* replace1797_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b') */
   /* search1798_0_0 -> 0 in the cache */
   /* search1798_0_1 -> 3 in the cache */
   /* search1798_0 -> 3744 in the cache */
   /* search1798_1 -> 5032 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 3744, 5032 },
      -1,
   } },

   /* replace1798_0 -> 0 in the cache */
   /* replace1798_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b') */
   /* search1799_0_0 -> 0 in the cache */
   /* search1799_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1799_1_0 -> 0 in the cache */
   /* search1799_1_1 -> 3 in the cache */
   /* search1799_1 -> 1004 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5059, 1004 },
      -1,
   } },

   /* replace1799_0 -> 0 in the cache */
   /* replace1799_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a') */
   /* search1800_0_0 -> 32 in the cache */
   /* search1800_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   /* search1800_1_0 -> 2195 in the cache */
   /* search1800_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2195, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5062, 5063 },
      -1,
   } },

   /* replace1800_0 -> 2195 in the cache */
   /* replace1800_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 2195, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b') */
   /* search1801_0_0 -> 0 in the cache */
   /* search1801_0_1 -> 0 in the cache */
   /* search1801_0 -> 5059 in the cache */
   /* search1801_1_0 -> 0 in the cache */
   /* search1801_1_1 -> 3 in the cache */
   /* search1801_1 -> 1001 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5059, 1001 },
      -1,
   } },

   /* replace1801_0 -> 0 in the cache */
   /* replace1801_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a') */
   /* search1802_0_0 -> 32 in the cache */
   /* search1802_0_1 -> 32 in the cache */
   /* search1802_0 -> 5062 in the cache */
   /* search1802_1_0 -> 2195 in the cache */
   /* search1802_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2195, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5062, 5068 },
      -1,
   } },

   /* replace1802_0 -> 2195 in the cache */
   /* replace1802_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 2195, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b') */
   /* search1803_0_0 -> 0 in the cache */
   /* search1803_0_1 -> 0 in the cache */
   /* search1803_0 -> 5059 in the cache */
   /* search1803_1_0 -> 0 in the cache */
   /* search1803_1_1 -> 3 in the cache */
   /* search1803_1 -> 1029 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5059, 1029 },
      -1,
   } },

   /* replace1803_0 -> 0 in the cache */
   /* replace1803_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a') */
   /* search1804_0_0 -> 32 in the cache */
   /* search1804_0_1 -> 32 in the cache */
   /* search1804_0 -> 5062 in the cache */
   /* search1804_1_0 -> 2195 in the cache */
   /* search1804_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 2195, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5062, 5073 },
      -1,
   } },

   /* replace1804_0 -> 2195 in the cache */
   /* replace1804_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_feq,
      0, 1,
      { 2195, 32 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd')) */
   /* search1805_0_0 -> 715 in the cache */
   /* search1805_0_1 -> 983 in the cache */
   /* search1805_0_2 -> 3191 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 983, 3191 },
      -1,
   } },
   /* search1805_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 5076, 986 },
      -1,
   } },

   /* replace1805_0 -> 715 in the cache */
   /* replace1805_1_0 -> 148 in the cache */
   /* replace1805_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1805_2_0 -> 150 in the cache */
   /* replace1805_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5078, 5079 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd')) */
   /* search1806_0_0 -> 715 in the cache */
   /* search1806_0_1 -> 983 in the cache */
   /* search1806_0_2 -> 3191 in the cache */
   /* search1806_0 -> 5076 in the cache */
   /* search1806_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 5076, 986 },
      -1,
   } },

   /* replace1806_0 -> 715 in the cache */
   /* replace1806_1_0 -> 148 in the cache */
   /* replace1806_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1806_2_0 -> 150 in the cache */
   /* replace1806_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5082, 5083 },
      -1,
   } },

   /* ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd')) */
   /* search1807_0_0 -> 715 in the cache */
   /* search1807_0_1 -> 983 in the cache */
   /* search1807_0_2 -> 3191 in the cache */
   /* search1807_0 -> 5076 in the cache */
   /* search1807_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 5076, 986 },
      -1,
   } },

   /* replace1807_0 -> 715 in the cache */
   /* replace1807_1_0 -> 148 in the cache */
   /* replace1807_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1807_2_0 -> 150 in the cache */
   /* replace1807_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5086, 5087 },
      -1,
   } },

   /* ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd')) */
   /* search1808_0_0 -> 715 in the cache */
   /* search1808_0_1 -> 983 in the cache */
   /* search1808_0_2 -> 3191 in the cache */
   /* search1808_0 -> 5076 in the cache */
   /* search1808_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 5076, 986 },
      -1,
   } },

   /* replace1808_0 -> 715 in the cache */
   /* replace1808_1_0 -> 148 in the cache */
   /* replace1808_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1808_2_0 -> 150 in the cache */
   /* replace1808_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5090, 5091 },
      -1,
   } },

   /* ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd')) */
   /* search1809_0_0 -> 715 in the cache */
   /* search1809_0_1 -> 983 in the cache */
   /* search1809_0_2 -> 3191 in the cache */
   /* search1809_0 -> 5076 in the cache */
   /* search1809_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5076, 986 },
      -1,
   } },

   /* replace1809_0 -> 715 in the cache */
   /* replace1809_1_0 -> 148 in the cache */
   /* replace1809_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1809_2_0 -> 150 in the cache */
   /* replace1809_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5094, 5095 },
      -1,
   } },

   /* ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1810_1_0 -> 1124 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1124, 5098, 5099 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5097, 5100 },
      -1,
   } },

   /* replace1810_0 -> 1124 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5102, 5103 },
      -1,
   } },
   /* replace1810_2_0 -> 5102 in the cache */
   /* replace1810_2_1 -> 1663 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5102, 1663 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1124, 5104, 5105 },
      -1,
   } },

   /* ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd')) */
   /* search1811_0_0 -> 715 in the cache */
   /* search1811_0_1 -> 983 in the cache */
   /* search1811_0_2 -> 3191 in the cache */
   /* search1811_0 -> 5076 in the cache */
   /* search1811_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5076, 986 },
      -1,
   } },

   /* replace1811_0 -> 715 in the cache */
   /* replace1811_1_0 -> 148 in the cache */
   /* replace1811_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1811_2_0 -> 150 in the cache */
   /* replace1811_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5108, 5109 },
      -1,
   } },

   /* ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c')) */
   /* search1812_0 -> 5097 in the cache */
   /* search1812_1_0 -> 1124 in the cache */
   /* search1812_1_1 -> 5098 in the cache */
   /* search1812_1_2 -> 5099 in the cache */
   /* search1812_1 -> 5100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5097, 5100 },
      -1,
   } },

   /* replace1812_0 -> 1124 in the cache */
   /* replace1812_1_0 -> 5102 in the cache */
   /* replace1812_1_1 -> 5103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5102, 5103 },
      -1,
   } },
   /* replace1812_2_0 -> 5102 in the cache */
   /* replace1812_2_1 -> 1663 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5102, 1663 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1124, 5112, 5113 },
      -1,
   } },

   /* ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd')) */
   /* search1813_0_0 -> 715 in the cache */
   /* search1813_0_1 -> 983 in the cache */
   /* search1813_0_2 -> 3191 in the cache */
   /* search1813_0 -> 5076 in the cache */
   /* search1813_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5076, 986 },
      -1,
   } },

   /* replace1813_0 -> 715 in the cache */
   /* replace1813_1_0 -> 148 in the cache */
   /* replace1813_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1813_2_0 -> 150 in the cache */
   /* replace1813_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5116, 5117 },
      -1,
   } },

   /* ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c')) */
   /* search1814_0 -> 5097 in the cache */
   /* search1814_1_0 -> 1124 in the cache */
   /* search1814_1_1 -> 5098 in the cache */
   /* search1814_1_2 -> 5099 in the cache */
   /* search1814_1 -> 5100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5097, 5100 },
      -1,
   } },

   /* replace1814_0 -> 1124 in the cache */
   /* replace1814_1_0 -> 5102 in the cache */
   /* replace1814_1_1 -> 5103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5102, 5103 },
      -1,
   } },
   /* replace1814_2_0 -> 5102 in the cache */
   /* replace1814_2_1 -> 1663 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5102, 1663 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1124, 5120, 5121 },
      -1,
   } },

   /* ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd')) */
   /* search1815_0_0 -> 715 in the cache */
   /* search1815_0_1 -> 983 in the cache */
   /* search1815_0_2 -> 3191 in the cache */
   /* search1815_0 -> 5076 in the cache */
   /* search1815_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5076, 986 },
      -1,
   } },

   /* replace1815_0 -> 715 in the cache */
   /* replace1815_1_0 -> 148 in the cache */
   /* replace1815_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1815_2_0 -> 150 in the cache */
   /* replace1815_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5124, 5125 },
      -1,
   } },

   /* ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c')) */
   /* search1816_0 -> 5097 in the cache */
   /* search1816_1_0 -> 1124 in the cache */
   /* search1816_1_1 -> 5098 in the cache */
   /* search1816_1_2 -> 5099 in the cache */
   /* search1816_1 -> 5100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5097, 5100 },
      -1,
   } },

   /* replace1816_0 -> 1124 in the cache */
   /* replace1816_1_0 -> 5102 in the cache */
   /* replace1816_1_1 -> 5103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5102, 5103 },
      -1,
   } },
   /* replace1816_2_0 -> 5102 in the cache */
   /* replace1816_2_1 -> 1663 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5102, 1663 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1124, 5128, 5129 },
      -1,
   } },

   /* ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd')) */
   /* search1817_0_0 -> 715 in the cache */
   /* search1817_0_1 -> 983 in the cache */
   /* search1817_0_2 -> 3191 in the cache */
   /* search1817_0 -> 5076 in the cache */
   /* search1817_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5076, 986 },
      -1,
   } },

   /* replace1817_0 -> 715 in the cache */
   /* replace1817_1_0 -> 148 in the cache */
   /* replace1817_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1817_2_0 -> 150 in the cache */
   /* replace1817_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5132, 5133 },
      -1,
   } },

   /* ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c')) */
   /* search1818_0 -> 5097 in the cache */
   /* search1818_1_0 -> 1124 in the cache */
   /* search1818_1_1 -> 5098 in the cache */
   /* search1818_1_2 -> 5099 in the cache */
   /* search1818_1 -> 5100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5097, 5100 },
      -1,
   } },

   /* replace1818_0 -> 1124 in the cache */
   /* replace1818_1_0 -> 5102 in the cache */
   /* replace1818_1_1 -> 5103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5102, 5103 },
      -1,
   } },
   /* replace1818_2_0 -> 5102 in the cache */
   /* replace1818_2_1 -> 1663 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5102, 1663 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1124, 5136, 5137 },
      -1,
   } },

   /* ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd')) */
   /* search1819_0_0 -> 715 in the cache */
   /* search1819_0_1 -> 983 in the cache */
   /* search1819_0_2 -> 3191 in the cache */
   /* search1819_0 -> 5076 in the cache */
   /* search1819_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5076, 986 },
      -1,
   } },

   /* replace1819_0 -> 715 in the cache */
   /* replace1819_1_0 -> 148 in the cache */
   /* replace1819_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   /* replace1819_2_0 -> 150 in the cache */
   /* replace1819_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5140, 5141 },
      -1,
   } },

   /* ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c')) */
   /* search1820_0 -> 5097 in the cache */
   /* search1820_1_0 -> 1124 in the cache */
   /* search1820_1_1 -> 5098 in the cache */
   /* search1820_1_2 -> 5099 in the cache */
   /* search1820_1 -> 5100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5097, 5100 },
      -1,
   } },

   /* replace1820_0 -> 1124 in the cache */
   /* replace1820_1_0 -> 5102 in the cache */
   /* replace1820_1_1 -> 5103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5102, 5103 },
      -1,
   } },
   /* replace1820_2_0 -> 5102 in the cache */
   /* replace1820_2_1 -> 1663 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5102, 1663 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1124, 5144, 5145 },
      -1,
   } },

   /* ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd')) */
   /* search1821_0_0 -> 715 in the cache */
   /* search1821_0_1 -> 983 in the cache */
   /* search1821_0_2 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 983, 150 },
      0,
   } },
   /* search1821_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 5147, 986 },
      -1,
   } },

   /* replace1821_0 -> 715 in the cache */
   /* replace1821_1_0 -> 148 in the cache */
   /* replace1821_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1821_2_0 -> 150 in the cache */
   /* replace1821_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5149, 5150 },
      -1,
   } },

   /* ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd')) */
   /* search1822_0_0 -> 715 in the cache */
   /* search1822_0_1 -> 983 in the cache */
   /* search1822_0_2 -> 150 in the cache */
   /* search1822_0 -> 5147 in the cache */
   /* search1822_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 5147, 986 },
      -1,
   } },

   /* replace1822_0 -> 715 in the cache */
   /* replace1822_1_0 -> 148 in the cache */
   /* replace1822_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1822_2_0 -> 150 in the cache */
   /* replace1822_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5153, 5154 },
      -1,
   } },

   /* ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd')) */
   /* search1823_0_0 -> 715 in the cache */
   /* search1823_0_1 -> 33 in the cache */
   /* search1823_0_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 33, 133 },
      0,
   } },
   /* search1823_1 -> 296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 5156, 296 },
      -1,
   } },

   /* replace1823_0 -> 715 in the cache */
   /* replace1823_1_0 -> 36 in the cache */
   /* replace1823_1_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 161 },
      -1,
   } },
   /* replace1823_2_0 -> 133 in the cache */
   /* replace1823_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5158, 5159 },
      -1,
   } },

   /* ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd')) */
   /* search1824_0_0 -> 715 in the cache */
   /* search1824_0_1 -> 983 in the cache */
   /* search1824_0_2 -> 150 in the cache */
   /* search1824_0 -> 5147 in the cache */
   /* search1824_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5147, 986 },
      -1,
   } },

   /* replace1824_0 -> 715 in the cache */
   /* replace1824_1_0 -> 148 in the cache */
   /* replace1824_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1824_2_0 -> 150 in the cache */
   /* replace1824_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5162, 5163 },
      -1,
   } },

   /* ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd')) */
   /* search1825_0_0 -> 715 in the cache */
   /* search1825_0_1 -> 983 in the cache */
   /* search1825_0_2 -> 150 in the cache */
   /* search1825_0 -> 5147 in the cache */
   /* search1825_1 -> 986 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5147, 986 },
      -1,
   } },

   /* replace1825_0 -> 715 in the cache */
   /* replace1825_1_0 -> 148 in the cache */
   /* replace1825_1_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 151 },
      -1,
   } },
   /* replace1825_2_0 -> 150 in the cache */
   /* replace1825_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5166, 5167 },
      -1,
   } },

   /* ('fddx', 'a') => 0.0 */
   /* search1826_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1826 -> 113 in the cache */

   /* ('fddx_fine', 'a') => 0.0 */
   /* search1827_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1827 -> 113 in the cache */

   /* ('fddx_coarse', 'a') => 0.0 */
   /* search1828_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1828 -> 113 in the cache */

   /* ('fddy', 'a') => 0.0 */
   /* search1829_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1829 -> 113 in the cache */

   /* ('fddy_fine', 'a') => 0.0 */
   /* search1830_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1830 -> 113 in the cache */

   /* ('fddy_coarse', 'a') => 0.0 */
   /* search1831_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1831 -> 113 in the cache */

   /* ('umul_low', '#a(is_lower_half_zero)', 'b') => 0 */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      30,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1832_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_low,
      0, 1,
      { 5175, 36 },
      -1,
   } },

   /* replace1832 -> 120 in the cache */

   /* ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c */
   /* search1833_0 -> 5175 in the cache */
   /* search1833_1 -> 36 in the cache */
   /* search1833_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 5175, 36, 133 },
      -1,
   } },

   /* replace1833 -> 133 in the cache */

   /* ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c */
   /* search1834_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      31,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1834_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 16, 5178, 133 },
      -1,
   } },

   /* replace1834 -> 133 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1835_0 -> 715 in the cache */
   /* search1835_1_0 -> 707 in the cache */
   /* search1835_1_1 -> 708 in the cache */
   /* search1835_1_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 708, 717 },
      0,
   } },
   /* search1835_2_0 -> 707 in the cache */
   /* search1835_2_1 -> 708 in the cache */
   /* search1835_2_2 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 708, 719 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5180, 5181 },
      -1,
   } },

   /* replace1835_0 -> 707 in the cache */
   /* replace1835_1 -> 708 in the cache */
   /* replace1835_2_0 -> 715 in the cache */
   /* replace1835_2_1 -> 717 in the cache */
   /* replace1835_2_2 -> 719 in the cache */
   /* replace1835_2 -> 1250 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 708, 1250 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1836_0 -> 715 in the cache */
   /* search1836_1_0 -> 707 in the cache */
   /* search1836_1_1 -> 708 in the cache */
   /* search1836_1_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 708, 717 },
      -1,
   } },
   /* search1836_2_0 -> 707 in the cache */
   /* search1836_2_1 -> 708 in the cache */
   /* search1836_2_2 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 708, 719 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5184, 5185 },
      -1,
   } },

   /* replace1836_0 -> 707 in the cache */
   /* replace1836_1 -> 708 in the cache */
   /* replace1836_2_0 -> 715 in the cache */
   /* replace1836_2_1 -> 717 in the cache */
   /* replace1836_2_2 -> 719 in the cache */
   /* replace1836_2 -> 1250 in the cache */
   /* replace1836 -> 5183 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1837_0 -> 715 in the cache */
   /* search1837_1_0 -> 707 in the cache */
   /* search1837_1_1 -> 708 in the cache */
   /* search1837_1_2 -> 717 in the cache */
   /* search1837_1 -> 5180 in the cache */
   /* search1837_2_0 -> 707 in the cache */
   /* search1837_2_1 -> 719 in the cache */
   /* search1837_2_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 719, 717 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5180, 5187 },
      -1,
   } },

   /* replace1837_0 -> 707 in the cache */
   /* replace1837_1_0 -> 715 in the cache */
   /* replace1837_1_1 -> 708 in the cache */
   /* replace1837_1_2 -> 719 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 708, 719 },
      -1,
   } },
   /* replace1837_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 5189, 717 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1838_0 -> 715 in the cache */
   /* search1838_1_0 -> 707 in the cache */
   /* search1838_1_1 -> 708 in the cache */
   /* search1838_1_2 -> 717 in the cache */
   /* search1838_1 -> 5184 in the cache */
   /* search1838_2_0 -> 707 in the cache */
   /* search1838_2_1 -> 719 in the cache */
   /* search1838_2_2 -> 717 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 707, 719, 717 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5184, 5191 },
      -1,
   } },

   /* replace1838_0 -> 707 in the cache */
   /* replace1838_1_0 -> 715 in the cache */
   /* replace1838_1_1 -> 708 in the cache */
   /* replace1838_1_2 -> 719 in the cache */
   /* replace1838_1 -> 5189 in the cache */
   /* replace1838_2 -> 717 in the cache */
   /* replace1838 -> 5190 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1839_0 -> 715 in the cache */
   /* search1839_1_0 -> 148 in the cache */
   /* search1839_1_1 -> 150 in the cache */
   /* search1839_1_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 148, 150, 151 },
      0,
   } },
   /* search1839_2_0 -> 1256 in the cache */
   /* search1839_2_1 -> 150 in the cache */
   /* search1839_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1256, 150, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5193, 5194 },
      -1,
   } },

   /* replace1839_0_0 -> 715 in the cache */
   /* replace1839_0_1 -> 148 in the cache */
   /* replace1839_0_2 -> 1256 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 148, 1256 },
      -1,
   } },
   /* replace1839_1 -> 150 in the cache */
   /* replace1839_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 5196, 150, 151 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1840_0 -> 715 in the cache */
   /* search1840_1_0 -> 148 in the cache */
   /* search1840_1_1 -> 150 in the cache */
   /* search1840_1_2 -> 151 in the cache */
   /* search1840_1 -> 663 in the cache */
   /* search1840_2_0 -> 1256 in the cache */
   /* search1840_2_1 -> 150 in the cache */
   /* search1840_2_2 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1256, 150, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 663, 5198 },
      -1,
   } },

   /* replace1840_0_0 -> 715 in the cache */
   /* replace1840_0_1 -> 148 in the cache */
   /* replace1840_0_2 -> 1256 in the cache */
   /* replace1840_0 -> 5196 in the cache */
   /* replace1840_1 -> 150 in the cache */
   /* replace1840_2 -> 151 in the cache */
   /* replace1840 -> 5197 in the cache */

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1841_0 -> 715 in the cache */
   /* search1841_1_0 -> 36 in the cache */
   /* search1841_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 133 },
      0,
   } },
   /* search1841_2_0 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 5201 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5200, 5202 },
      -1,
   } },

   /* replace1841_0 -> 36 in the cache */
   /* replace1841_1_0 -> 715 in the cache */
   /* replace1841_1_1 -> 133 in the cache */
   /* replace1841_1_2 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 5204 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1842_0 -> 715 in the cache */
   /* search1842_1_0 -> 36 in the cache */
   /* search1842_1_1 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 332 },
      0,
   } },
   /* search1842_2_0 -> 36 in the cache */
   /* search1842_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5206, 5207 },
      -1,
   } },

   /* replace1842_0 -> 36 in the cache */
   /* replace1842_1_0 -> 715 in the cache */
   /* replace1842_1_1 -> 133 in the cache */
   /* replace1842_1_2 -> 161 in the cache */
   /* replace1842_1 -> 5204 in the cache */
   /* replace1842 -> 5205 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1843_0 -> 715 in the cache */
   /* search1843_1_0 -> 36 in the cache */
   /* search1843_1_1 -> 332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 332 },
      -1,
   } },
   /* search1843_2_0 -> 36 in the cache */
   /* search1843_2_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 161 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5209, 5210 },
      -1,
   } },

   /* replace1843_0 -> 36 in the cache */
   /* replace1843_1_0 -> 715 in the cache */
   /* replace1843_1_1 -> 133 in the cache */
   /* replace1843_1_2 -> 161 in the cache */
   /* replace1843_1 -> 5204 in the cache */
   /* replace1843 -> 5205 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1844_0 -> 715 in the cache */
   /* search1844_1_0 -> 36 in the cache */
   /* search1844_1_1 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 133 },
      -1,
   } },
   /* search1844_2_0 -> 36 in the cache */
   /* search1844_2_1 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 5201 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5212, 5213 },
      -1,
   } },

   /* replace1844_0 -> 36 in the cache */
   /* replace1844_1_0 -> 715 in the cache */
   /* replace1844_1_1 -> 133 in the cache */
   /* replace1844_1_2 -> 161 in the cache */
   /* replace1844_1 -> 5204 in the cache */
   /* replace1844 -> 5205 in the cache */

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1845_0 -> 715 in the cache */
   /* search1845_1_0 -> 148 in the cache */
   /* search1845_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1845_2_0 -> 148 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 5216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5215, 5217 },
      -1,
   } },

   /* replace1845_0 -> 148 in the cache */
   /* replace1845_1_0 -> 715 in the cache */
   /* replace1845_1_1 -> 150 in the cache */
   /* replace1845_1_2 -> 151 in the cache */
   /* replace1845_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1846_0 -> 715 in the cache */
   /* search1846_1_0 -> 148 in the cache */
   /* search1846_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 3206 },
      0,
   } },
   /* search1846_2_0 -> 148 in the cache */
   /* search1846_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5220, 5221 },
      -1,
   } },

   /* replace1846_0 -> 148 in the cache */
   /* replace1846_1_0 -> 715 in the cache */
   /* replace1846_1_1 -> 150 in the cache */
   /* replace1846_1_2 -> 151 in the cache */
   /* replace1846_1 -> 1245 in the cache */
   /* replace1846 -> 5219 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1847_0 -> 715 in the cache */
   /* search1847_1_0 -> 148 in the cache */
   /* search1847_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 3206 },
      -1,
   } },
   /* search1847_2_0 -> 148 in the cache */
   /* search1847_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5223, 5224 },
      -1,
   } },

   /* replace1847_0 -> 148 in the cache */
   /* replace1847_1_0 -> 715 in the cache */
   /* replace1847_1_1 -> 150 in the cache */
   /* replace1847_1_2 -> 151 in the cache */
   /* replace1847_1 -> 1245 in the cache */
   /* replace1847 -> 5219 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1848_0 -> 715 in the cache */
   /* search1848_1_0 -> 148 in the cache */
   /* search1848_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1848_2_0 -> 148 in the cache */
   /* search1848_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 148, 5216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5226, 5227 },
      -1,
   } },

   /* replace1848_0 -> 148 in the cache */
   /* replace1848_1_0 -> 715 in the cache */
   /* replace1848_1_1 -> 150 in the cache */
   /* replace1848_1_2 -> 151 in the cache */
   /* replace1848_1 -> 1245 in the cache */
   /* replace1848 -> 5219 in the cache */

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1849_0 -> 715 in the cache */
   /* search1849_1_0 -> 148 in the cache */
   /* search1849_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1849_2_0 -> 148 in the cache */
   /* search1849_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 5216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5229, 5230 },
      -1,
   } },

   /* replace1849_0 -> 148 in the cache */
   /* replace1849_1_0 -> 715 in the cache */
   /* replace1849_1_1 -> 150 in the cache */
   /* replace1849_1_2 -> 151 in the cache */
   /* replace1849_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1850_0 -> 715 in the cache */
   /* search1850_1_0 -> 148 in the cache */
   /* search1850_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 3206 },
      0,
   } },
   /* search1850_2_0 -> 148 in the cache */
   /* search1850_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5233, 5234 },
      -1,
   } },

   /* replace1850_0 -> 148 in the cache */
   /* replace1850_1_0 -> 715 in the cache */
   /* replace1850_1_1 -> 150 in the cache */
   /* replace1850_1_2 -> 151 in the cache */
   /* replace1850_1 -> 1245 in the cache */
   /* replace1850 -> 5232 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1851_0 -> 715 in the cache */
   /* search1851_1_0 -> 148 in the cache */
   /* search1851_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 3206 },
      -1,
   } },
   /* search1851_2_0 -> 148 in the cache */
   /* search1851_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5236, 5237 },
      -1,
   } },

   /* replace1851_0 -> 148 in the cache */
   /* replace1851_1_0 -> 715 in the cache */
   /* replace1851_1_1 -> 150 in the cache */
   /* replace1851_1_2 -> 151 in the cache */
   /* replace1851_1 -> 1245 in the cache */
   /* replace1851 -> 5232 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1852_0 -> 715 in the cache */
   /* search1852_1_0 -> 148 in the cache */
   /* search1852_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1852_2_0 -> 148 in the cache */
   /* search1852_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 148, 5216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5239, 5240 },
      -1,
   } },

   /* replace1852_0 -> 148 in the cache */
   /* replace1852_1_0 -> 715 in the cache */
   /* replace1852_1_1 -> 150 in the cache */
   /* replace1852_1_2 -> 151 in the cache */
   /* replace1852_1 -> 1245 in the cache */
   /* replace1852 -> 5232 in the cache */

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1853_0 -> 715 in the cache */
   /* search1853_1_0 -> 148 in the cache */
   /* search1853_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1853_2_0 -> 148 in the cache */
   /* search1853_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 148, 5216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5242, 5243 },
      -1,
   } },

   /* replace1853_0 -> 148 in the cache */
   /* replace1853_1_0 -> 715 in the cache */
   /* replace1853_1_1 -> 150 in the cache */
   /* replace1853_1_2 -> 151 in the cache */
   /* replace1853_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1854_0 -> 715 in the cache */
   /* search1854_1_0 -> 148 in the cache */
   /* search1854_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 3206 },
      0,
   } },
   /* search1854_2_0 -> 148 in the cache */
   /* search1854_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5246, 5247 },
      -1,
   } },

   /* replace1854_0 -> 148 in the cache */
   /* replace1854_1_0 -> 715 in the cache */
   /* replace1854_1_1 -> 150 in the cache */
   /* replace1854_1_2 -> 151 in the cache */
   /* replace1854_1 -> 1245 in the cache */
   /* replace1854 -> 5245 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1855_0 -> 715 in the cache */
   /* search1855_1_0 -> 148 in the cache */
   /* search1855_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 3206 },
      -1,
   } },
   /* search1855_2_0 -> 148 in the cache */
   /* search1855_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5249, 5250 },
      -1,
   } },

   /* replace1855_0 -> 148 in the cache */
   /* replace1855_1_0 -> 715 in the cache */
   /* replace1855_1_1 -> 150 in the cache */
   /* replace1855_1_2 -> 151 in the cache */
   /* replace1855_1 -> 1245 in the cache */
   /* replace1855 -> 5245 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1856_0 -> 715 in the cache */
   /* search1856_1_0 -> 148 in the cache */
   /* search1856_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1856_2_0 -> 148 in the cache */
   /* search1856_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 148, 5216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5252, 5253 },
      -1,
   } },

   /* replace1856_0 -> 148 in the cache */
   /* replace1856_1_0 -> 715 in the cache */
   /* replace1856_1_1 -> 150 in the cache */
   /* replace1856_1_2 -> 151 in the cache */
   /* replace1856_1 -> 1245 in the cache */
   /* replace1856 -> 5245 in the cache */

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1857_0 -> 715 in the cache */
   /* search1857_1_0 -> 148 in the cache */
   /* search1857_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1857_2_0 -> 148 in the cache */
   /* search1857_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 148, 5216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5255, 5256 },
      -1,
   } },

   /* replace1857_0 -> 148 in the cache */
   /* replace1857_1_0 -> 715 in the cache */
   /* replace1857_1_1 -> 150 in the cache */
   /* replace1857_1_2 -> 151 in the cache */
   /* replace1857_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1858_0 -> 715 in the cache */
   /* search1858_1_0 -> 148 in the cache */
   /* search1858_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 3206 },
      0,
   } },
   /* search1858_2_0 -> 148 in the cache */
   /* search1858_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5259, 5260 },
      -1,
   } },

   /* replace1858_0 -> 148 in the cache */
   /* replace1858_1_0 -> 715 in the cache */
   /* replace1858_1_1 -> 150 in the cache */
   /* replace1858_1_2 -> 151 in the cache */
   /* replace1858_1 -> 1245 in the cache */
   /* replace1858 -> 5258 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1859_0 -> 715 in the cache */
   /* search1859_1_0 -> 148 in the cache */
   /* search1859_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 3206 },
      -1,
   } },
   /* search1859_2_0 -> 148 in the cache */
   /* search1859_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5262, 5263 },
      -1,
   } },

   /* replace1859_0 -> 148 in the cache */
   /* replace1859_1_0 -> 715 in the cache */
   /* replace1859_1_1 -> 150 in the cache */
   /* replace1859_1_2 -> 151 in the cache */
   /* replace1859_1 -> 1245 in the cache */
   /* replace1859 -> 5258 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1860_0 -> 715 in the cache */
   /* search1860_1_0 -> 148 in the cache */
   /* search1860_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1860_2_0 -> 148 in the cache */
   /* search1860_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 148, 5216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5265, 5266 },
      -1,
   } },

   /* replace1860_0 -> 148 in the cache */
   /* replace1860_1_0 -> 715 in the cache */
   /* replace1860_1_1 -> 150 in the cache */
   /* replace1860_1_2 -> 151 in the cache */
   /* replace1860_1 -> 1245 in the cache */
   /* replace1860 -> 5258 in the cache */

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1861_0 -> 715 in the cache */
   /* search1861_1_0 -> 148 in the cache */
   /* search1861_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1861_2_0 -> 148 in the cache */
   /* search1861_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 148, 5216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5268, 5269 },
      -1,
   } },

   /* replace1861_0 -> 148 in the cache */
   /* replace1861_1_0 -> 715 in the cache */
   /* replace1861_1_1 -> 150 in the cache */
   /* replace1861_1_2 -> 151 in the cache */
   /* replace1861_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1862_0 -> 715 in the cache */
   /* search1862_1_0 -> 148 in the cache */
   /* search1862_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 3206 },
      0,
   } },
   /* search1862_2_0 -> 148 in the cache */
   /* search1862_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5272, 5273 },
      -1,
   } },

   /* replace1862_0 -> 148 in the cache */
   /* replace1862_1_0 -> 715 in the cache */
   /* replace1862_1_1 -> 150 in the cache */
   /* replace1862_1_2 -> 151 in the cache */
   /* replace1862_1 -> 1245 in the cache */
   /* replace1862 -> 5271 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1863_0 -> 715 in the cache */
   /* search1863_1_0 -> 148 in the cache */
   /* search1863_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 3206 },
      -1,
   } },
   /* search1863_2_0 -> 148 in the cache */
   /* search1863_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5275, 5276 },
      -1,
   } },

   /* replace1863_0 -> 148 in the cache */
   /* replace1863_1_0 -> 715 in the cache */
   /* replace1863_1_1 -> 150 in the cache */
   /* replace1863_1_2 -> 151 in the cache */
   /* replace1863_1 -> 1245 in the cache */
   /* replace1863 -> 5271 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1864_0 -> 715 in the cache */
   /* search1864_1_0 -> 148 in the cache */
   /* search1864_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1864_2_0 -> 148 in the cache */
   /* search1864_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 148, 5216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5278, 5279 },
      -1,
   } },

   /* replace1864_0 -> 148 in the cache */
   /* replace1864_1_0 -> 715 in the cache */
   /* replace1864_1_1 -> 150 in the cache */
   /* replace1864_1_2 -> 151 in the cache */
   /* replace1864_1 -> 1245 in the cache */
   /* replace1864 -> 5271 in the cache */

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1865_0 -> 715 in the cache */
   /* search1865_1_0 -> 148 in the cache */
   /* search1865_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1865_2_0 -> 148 in the cache */
   /* search1865_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 148, 5216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5281, 5282 },
      -1,
   } },

   /* replace1865_0 -> 148 in the cache */
   /* replace1865_1_0 -> 715 in the cache */
   /* replace1865_1_1 -> 150 in the cache */
   /* replace1865_1_2 -> 151 in the cache */
   /* replace1865_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1866_0 -> 715 in the cache */
   /* search1866_1_0 -> 148 in the cache */
   /* search1866_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 3206 },
      0,
   } },
   /* search1866_2_0 -> 148 in the cache */
   /* search1866_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5285, 5286 },
      -1,
   } },

   /* replace1866_0 -> 148 in the cache */
   /* replace1866_1_0 -> 715 in the cache */
   /* replace1866_1_1 -> 150 in the cache */
   /* replace1866_1_2 -> 151 in the cache */
   /* replace1866_1 -> 1245 in the cache */
   /* replace1866 -> 5284 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1867_0 -> 715 in the cache */
   /* search1867_1_0 -> 148 in the cache */
   /* search1867_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 3206 },
      -1,
   } },
   /* search1867_2_0 -> 148 in the cache */
   /* search1867_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5288, 5289 },
      -1,
   } },

   /* replace1867_0 -> 148 in the cache */
   /* replace1867_1_0 -> 715 in the cache */
   /* replace1867_1_1 -> 150 in the cache */
   /* replace1867_1_2 -> 151 in the cache */
   /* replace1867_1 -> 1245 in the cache */
   /* replace1867 -> 5284 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1868_0 -> 715 in the cache */
   /* search1868_1_0 -> 148 in the cache */
   /* search1868_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1868_2_0 -> 148 in the cache */
   /* search1868_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 148, 5216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5291, 5292 },
      -1,
   } },

   /* replace1868_0 -> 148 in the cache */
   /* replace1868_1_0 -> 715 in the cache */
   /* replace1868_1_1 -> 150 in the cache */
   /* replace1868_1_2 -> 151 in the cache */
   /* replace1868_1 -> 1245 in the cache */
   /* replace1868 -> 5284 in the cache */

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1869_0 -> 715 in the cache */
   /* search1869_1_0 -> 148 in the cache */
   /* search1869_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1869_2_0 -> 148 in the cache */
   /* search1869_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 148, 5216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5294, 5295 },
      -1,
   } },

   /* replace1869_0 -> 148 in the cache */
   /* replace1869_1_0 -> 715 in the cache */
   /* replace1869_1_1 -> 150 in the cache */
   /* replace1869_1_2 -> 151 in the cache */
   /* replace1869_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1870_0 -> 715 in the cache */
   /* search1870_1_0 -> 148 in the cache */
   /* search1870_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 3206 },
      0,
   } },
   /* search1870_2_0 -> 148 in the cache */
   /* search1870_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5298, 5299 },
      -1,
   } },

   /* replace1870_0 -> 148 in the cache */
   /* replace1870_1_0 -> 715 in the cache */
   /* replace1870_1_1 -> 150 in the cache */
   /* replace1870_1_2 -> 151 in the cache */
   /* replace1870_1 -> 1245 in the cache */
   /* replace1870 -> 5297 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1871_0 -> 715 in the cache */
   /* search1871_1_0 -> 148 in the cache */
   /* search1871_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 3206 },
      -1,
   } },
   /* search1871_2_0 -> 148 in the cache */
   /* search1871_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5301, 5302 },
      -1,
   } },

   /* replace1871_0 -> 148 in the cache */
   /* replace1871_1_0 -> 715 in the cache */
   /* replace1871_1_1 -> 150 in the cache */
   /* replace1871_1_2 -> 151 in the cache */
   /* replace1871_1 -> 1245 in the cache */
   /* replace1871 -> 5297 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1872_0 -> 715 in the cache */
   /* search1872_1_0 -> 148 in the cache */
   /* search1872_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1872_2_0 -> 148 in the cache */
   /* search1872_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 148, 5216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5304, 5305 },
      -1,
   } },

   /* replace1872_0 -> 148 in the cache */
   /* replace1872_1_0 -> 715 in the cache */
   /* replace1872_1_1 -> 150 in the cache */
   /* replace1872_1_2 -> 151 in the cache */
   /* replace1872_1 -> 1245 in the cache */
   /* replace1872 -> 5297 in the cache */

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1873_0 -> 715 in the cache */
   /* search1873_1_0 -> 148 in the cache */
   /* search1873_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1873_2_0 -> 148 in the cache */
   /* search1873_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 5216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5307, 5308 },
      -1,
   } },

   /* replace1873_0 -> 148 in the cache */
   /* replace1873_1_0 -> 715 in the cache */
   /* replace1873_1_1 -> 150 in the cache */
   /* replace1873_1_2 -> 151 in the cache */
   /* replace1873_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1874_0 -> 715 in the cache */
   /* search1874_1_0 -> 148 in the cache */
   /* search1874_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 3206 },
      0,
   } },
   /* search1874_2_0 -> 148 in the cache */
   /* search1874_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5311, 5312 },
      -1,
   } },

   /* replace1874_0 -> 148 in the cache */
   /* replace1874_1_0 -> 715 in the cache */
   /* replace1874_1_1 -> 150 in the cache */
   /* replace1874_1_2 -> 151 in the cache */
   /* replace1874_1 -> 1245 in the cache */
   /* replace1874 -> 5310 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1875_0 -> 715 in the cache */
   /* search1875_1_0 -> 148 in the cache */
   /* search1875_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 3206 },
      -1,
   } },
   /* search1875_2_0 -> 148 in the cache */
   /* search1875_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5314, 5315 },
      -1,
   } },

   /* replace1875_0 -> 148 in the cache */
   /* replace1875_1_0 -> 715 in the cache */
   /* replace1875_1_1 -> 150 in the cache */
   /* replace1875_1_2 -> 151 in the cache */
   /* replace1875_1 -> 1245 in the cache */
   /* replace1875 -> 5310 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1876_0 -> 715 in the cache */
   /* search1876_1_0 -> 148 in the cache */
   /* search1876_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1876_2_0 -> 148 in the cache */
   /* search1876_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 148, 5216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5317, 5318 },
      -1,
   } },

   /* replace1876_0 -> 148 in the cache */
   /* replace1876_1_0 -> 715 in the cache */
   /* replace1876_1_1 -> 150 in the cache */
   /* replace1876_1_2 -> 151 in the cache */
   /* replace1876_1 -> 1245 in the cache */
   /* replace1876 -> 5310 in the cache */

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1877_0 -> 715 in the cache */
   /* search1877_1_0 -> 148 in the cache */
   /* search1877_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1877_2_0 -> 148 in the cache */
   /* search1877_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 148, 5216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5320, 5321 },
      -1,
   } },

   /* replace1877_0 -> 148 in the cache */
   /* replace1877_1_0 -> 715 in the cache */
   /* replace1877_1_1 -> 150 in the cache */
   /* replace1877_1_2 -> 151 in the cache */
   /* replace1877_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1878_0 -> 715 in the cache */
   /* search1878_1_0 -> 148 in the cache */
   /* search1878_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 3206 },
      0,
   } },
   /* search1878_2_0 -> 148 in the cache */
   /* search1878_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5324, 5325 },
      -1,
   } },

   /* replace1878_0 -> 148 in the cache */
   /* replace1878_1_0 -> 715 in the cache */
   /* replace1878_1_1 -> 150 in the cache */
   /* replace1878_1_2 -> 151 in the cache */
   /* replace1878_1 -> 1245 in the cache */
   /* replace1878 -> 5323 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1879_0 -> 715 in the cache */
   /* search1879_1_0 -> 148 in the cache */
   /* search1879_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 3206 },
      -1,
   } },
   /* search1879_2_0 -> 148 in the cache */
   /* search1879_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5327, 5328 },
      -1,
   } },

   /* replace1879_0 -> 148 in the cache */
   /* replace1879_1_0 -> 715 in the cache */
   /* replace1879_1_1 -> 150 in the cache */
   /* replace1879_1_2 -> 151 in the cache */
   /* replace1879_1 -> 1245 in the cache */
   /* replace1879 -> 5323 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1880_0 -> 715 in the cache */
   /* search1880_1_0 -> 148 in the cache */
   /* search1880_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1880_2_0 -> 148 in the cache */
   /* search1880_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 148, 5216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5330, 5331 },
      -1,
   } },

   /* replace1880_0 -> 148 in the cache */
   /* replace1880_1_0 -> 715 in the cache */
   /* replace1880_1_1 -> 150 in the cache */
   /* replace1880_1_2 -> 151 in the cache */
   /* replace1880_1 -> 1245 in the cache */
   /* replace1880 -> 5323 in the cache */

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1881_0 -> 715 in the cache */
   /* search1881_1_0 -> 148 in the cache */
   /* search1881_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1881_2_0 -> 148 in the cache */
   /* search1881_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 148, 5216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5333, 5334 },
      -1,
   } },

   /* replace1881_0 -> 148 in the cache */
   /* replace1881_1_0 -> 715 in the cache */
   /* replace1881_1_1 -> 150 in the cache */
   /* replace1881_1_2 -> 151 in the cache */
   /* replace1881_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1882_0 -> 715 in the cache */
   /* search1882_1_0 -> 148 in the cache */
   /* search1882_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 3206 },
      0,
   } },
   /* search1882_2_0 -> 148 in the cache */
   /* search1882_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5337, 5338 },
      -1,
   } },

   /* replace1882_0 -> 148 in the cache */
   /* replace1882_1_0 -> 715 in the cache */
   /* replace1882_1_1 -> 150 in the cache */
   /* replace1882_1_2 -> 151 in the cache */
   /* replace1882_1 -> 1245 in the cache */
   /* replace1882 -> 5336 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1883_0 -> 715 in the cache */
   /* search1883_1_0 -> 148 in the cache */
   /* search1883_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 3206 },
      -1,
   } },
   /* search1883_2_0 -> 148 in the cache */
   /* search1883_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5340, 5341 },
      -1,
   } },

   /* replace1883_0 -> 148 in the cache */
   /* replace1883_1_0 -> 715 in the cache */
   /* replace1883_1_1 -> 150 in the cache */
   /* replace1883_1_2 -> 151 in the cache */
   /* replace1883_1 -> 1245 in the cache */
   /* replace1883 -> 5336 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1884_0 -> 715 in the cache */
   /* search1884_1_0 -> 148 in the cache */
   /* search1884_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1884_2_0 -> 148 in the cache */
   /* search1884_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 148, 5216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5343, 5344 },
      -1,
   } },

   /* replace1884_0 -> 148 in the cache */
   /* replace1884_1_0 -> 715 in the cache */
   /* replace1884_1_1 -> 150 in the cache */
   /* replace1884_1_2 -> 151 in the cache */
   /* replace1884_1 -> 1245 in the cache */
   /* replace1884 -> 5336 in the cache */

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1885_0 -> 715 in the cache */
   /* search1885_1_0 -> 148 in the cache */
   /* search1885_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1885_2_0 -> 148 in the cache */
   /* search1885_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 148, 5216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5346, 5347 },
      -1,
   } },

   /* replace1885_0 -> 148 in the cache */
   /* replace1885_1_0 -> 715 in the cache */
   /* replace1885_1_1 -> 150 in the cache */
   /* replace1885_1_2 -> 151 in the cache */
   /* replace1885_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1886_0 -> 715 in the cache */
   /* search1886_1_0 -> 148 in the cache */
   /* search1886_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 3206 },
      0,
   } },
   /* search1886_2_0 -> 148 in the cache */
   /* search1886_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5350, 5351 },
      -1,
   } },

   /* replace1886_0 -> 148 in the cache */
   /* replace1886_1_0 -> 715 in the cache */
   /* replace1886_1_1 -> 150 in the cache */
   /* replace1886_1_2 -> 151 in the cache */
   /* replace1886_1 -> 1245 in the cache */
   /* replace1886 -> 5349 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1887_0 -> 715 in the cache */
   /* search1887_1_0 -> 148 in the cache */
   /* search1887_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 3206 },
      -1,
   } },
   /* search1887_2_0 -> 148 in the cache */
   /* search1887_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5353, 5354 },
      -1,
   } },

   /* replace1887_0 -> 148 in the cache */
   /* replace1887_1_0 -> 715 in the cache */
   /* replace1887_1_1 -> 150 in the cache */
   /* replace1887_1_2 -> 151 in the cache */
   /* replace1887_1 -> 1245 in the cache */
   /* replace1887 -> 5349 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1888_0 -> 715 in the cache */
   /* search1888_1_0 -> 148 in the cache */
   /* search1888_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1888_2_0 -> 148 in the cache */
   /* search1888_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 148, 5216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5356, 5357 },
      -1,
   } },

   /* replace1888_0 -> 148 in the cache */
   /* replace1888_1_0 -> 715 in the cache */
   /* replace1888_1_1 -> 150 in the cache */
   /* replace1888_1_2 -> 151 in the cache */
   /* replace1888_1 -> 1245 in the cache */
   /* replace1888 -> 5349 in the cache */

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1889_0 -> 715 in the cache */
   /* search1889_1_0 -> 148 in the cache */
   /* search1889_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 150 },
      0,
   } },
   /* search1889_2_0 -> 148 in the cache */
   /* search1889_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 148, 5216 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5359, 5360 },
      -1,
   } },

   /* replace1889_0 -> 148 in the cache */
   /* replace1889_1_0 -> 715 in the cache */
   /* replace1889_1_1 -> 150 in the cache */
   /* replace1889_1_2 -> 151 in the cache */
   /* replace1889_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1890_0 -> 715 in the cache */
   /* search1890_1_0 -> 148 in the cache */
   /* search1890_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 3206 },
      0,
   } },
   /* search1890_2_0 -> 148 in the cache */
   /* search1890_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5363, 5364 },
      -1,
   } },

   /* replace1890_0 -> 148 in the cache */
   /* replace1890_1_0 -> 715 in the cache */
   /* replace1890_1_1 -> 150 in the cache */
   /* replace1890_1_2 -> 151 in the cache */
   /* replace1890_1 -> 1245 in the cache */
   /* replace1890 -> 5362 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1891_0 -> 715 in the cache */
   /* search1891_1_0 -> 148 in the cache */
   /* search1891_1_1 -> 3206 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 3206 },
      -1,
   } },
   /* search1891_2_0 -> 148 in the cache */
   /* search1891_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5366, 5367 },
      -1,
   } },

   /* replace1891_0 -> 148 in the cache */
   /* replace1891_1_0 -> 715 in the cache */
   /* replace1891_1_1 -> 150 in the cache */
   /* replace1891_1_2 -> 151 in the cache */
   /* replace1891_1 -> 1245 in the cache */
   /* replace1891 -> 5362 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1892_0 -> 715 in the cache */
   /* search1892_1_0 -> 148 in the cache */
   /* search1892_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 148, 150 },
      -1,
   } },
   /* search1892_2_0 -> 148 in the cache */
   /* search1892_2_1 -> 5216 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 148, 5216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 715, 5369, 5370 },
      -1,
   } },

   /* replace1892_0 -> 148 in the cache */
   /* replace1892_1_0 -> 715 in the cache */
   /* replace1892_1_1 -> 150 in the cache */
   /* replace1892_1_2 -> 151 in the cache */
   /* replace1892_1 -> 1245 in the cache */
   /* replace1892 -> 5362 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1893_0 -> 715 in the cache */
   /* search1893_1_0 -> 148 in the cache */
   /* search1893_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 150 },
      0,
   } },
   /* search1893_2_0 -> 148 in the cache */
   /* search1893_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 151 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5372, 5373 },
      -1,
   } },

   /* replace1893_0 -> 148 in the cache */
   /* replace1893_1_0 -> 715 in the cache */
   /* replace1893_1_1 -> 150 in the cache */
   /* replace1893_1_2 -> 151 in the cache */
   /* replace1893_1 -> 1245 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 1245 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1894_0 -> 715 in the cache */
   /* search1894_1_0 -> 148 in the cache */
   /* search1894_1_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 150 },
      -1,
   } },
   /* search1894_2_0 -> 148 in the cache */
   /* search1894_2_1 -> 151 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 148, 151 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5376, 5377 },
      -1,
   } },

   /* replace1894_0 -> 148 in the cache */
   /* replace1894_1_0 -> 715 in the cache */
   /* replace1894_1_1 -> 150 in the cache */
   /* replace1894_1_2 -> 151 in the cache */
   /* replace1894_1 -> 1245 in the cache */
   /* replace1894 -> 5375 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search1895_0 -> 715 in the cache */
   /* search1895_1_0 -> 125 in the cache */
   /* search1895_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 125, 127 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1895_2_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5380, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5379, 5381 },
      -1,
   } },

   /* replace1895_0_0 -> 715 in the cache */
   /* replace1895_0_1 -> 125 in the cache */
   /* replace1895_0_2 -> 5380 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 125, 5380 },
      -1,
   } },
   /* replace1895_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5383, 127 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search1896_0 -> 715 in the cache */
   /* search1896_1_0 -> 125 in the cache */
   /* search1896_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 125, 127 },
      -1,
   } },
   /* search1896_2_0 -> 5380 in the cache */
   /* search1896_2_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5380, 127 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 715, 5385, 5386 },
      -1,
   } },

   /* replace1896_0_0 -> 715 in the cache */
   /* replace1896_0_1 -> 125 in the cache */
   /* replace1896_0_2 -> 5380 in the cache */
   /* replace1896_0 -> 5383 in the cache */
   /* replace1896_1 -> 127 in the cache */
   /* replace1896 -> 5384 in the cache */

   /* ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b')) */
   /* search1897_0 -> 502 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5388 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5390 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5389, 5391 },
      -1,
   } },

   /* replace1897_0_0 -> 502 in the cache */
   /* replace1897_0_1 -> 5388 in the cache */
   /* replace1897_0_2 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5388, 5390 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5393 },
      -1,
   } },

   /* ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b')) */
   /* search1898_0 -> 502 in the cache */
   /* search1898_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5388 },
      0,
   } },
   /* search1898_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5390 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5395, 5396 },
      -1,
   } },

   /* replace1898_0_0 -> 502 in the cache */
   /* replace1898_0_1 -> 5388 in the cache */
   /* replace1898_0_2 -> 5390 in the cache */
   /* replace1898_0 -> 5393 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5393 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b')) */
   /* search1899_0 -> 502 in the cache */
   /* search1899_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5388 },
      0,
   } },
   /* search1899_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5390 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5399, 5400 },
      -1,
   } },

   /* replace1899_0_0 -> 502 in the cache */
   /* replace1899_0_1 -> 5388 in the cache */
   /* replace1899_0_2 -> 5390 in the cache */
   /* replace1899_0 -> 5393 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5393 },
      -1,
   } },

   /* ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b')) */
   /* search1900_0 -> 502 in the cache */
   /* search1900_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5388 },
      0,
   } },
   /* search1900_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5390 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5403, 5404 },
      -1,
   } },

   /* replace1900_0_0 -> 502 in the cache */
   /* replace1900_0_1 -> 5388 in the cache */
   /* replace1900_0_2 -> 5390 in the cache */
   /* replace1900_0 -> 5393 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5393 },
      -1,
   } },

   /* ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b')) */
   /* search1901_0 -> 502 in the cache */
   /* search1901_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5388 },
      0,
   } },
   /* search1901_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5390 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5407, 5408 },
      -1,
   } },

   /* replace1901_0_0 -> 502 in the cache */
   /* replace1901_0_1 -> 5388 in the cache */
   /* replace1901_0_2 -> 5390 in the cache */
   /* replace1901_0 -> 5393 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5393 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search1902_0 -> 502 in the cache */
   /* search1902_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5388 },
      0,
   } },
   /* search1902_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5390 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5411, 5412 },
      -1,
   } },

   /* replace1902_0_0 -> 502 in the cache */
   /* replace1902_0_1 -> 5388 in the cache */
   /* replace1902_0_2 -> 5390 in the cache */
   /* replace1902_0 -> 5393 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5393 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b')) */
   /* search1903_0 -> 502 in the cache */
   /* search1903_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5388 },
      0,
   } },
   /* search1903_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5390 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5415, 5416 },
      -1,
   } },

   /* replace1903_0_0 -> 502 in the cache */
   /* replace1903_0_1 -> 5388 in the cache */
   /* replace1903_0_2 -> 5390 in the cache */
   /* replace1903_0 -> 5393 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5393 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b')) */
   /* search1904_0 -> 502 in the cache */
   /* search1904_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5388 },
      0,
   } },
   /* search1904_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5390 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5419, 5420 },
      -1,
   } },

   /* replace1904_0_0 -> 502 in the cache */
   /* replace1904_0_1 -> 5388 in the cache */
   /* replace1904_0_2 -> 5390 in the cache */
   /* replace1904_0 -> 5393 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5393 },
      -1,
   } },

   /* ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b')) */
   /* search1905_0 -> 502 in the cache */
   /* search1905_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5388 },
      0,
   } },
   /* search1905_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5390 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5423, 5424 },
      -1,
   } },

   /* replace1905_0_0 -> 502 in the cache */
   /* replace1905_0_1 -> 5388 in the cache */
   /* replace1905_0_2 -> 5390 in the cache */
   /* replace1905_0 -> 5393 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5393 },
      -1,
   } },

   /* ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b')) */
   /* search1906_0 -> 502 in the cache */
   /* search1906_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5388 },
      0,
   } },
   /* search1906_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5390 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5427, 5428 },
      -1,
   } },

   /* replace1906_0_0 -> 502 in the cache */
   /* replace1906_0_1 -> 5388 in the cache */
   /* replace1906_0_2 -> 5390 in the cache */
   /* replace1906_0 -> 5393 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5393 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search1907_0 -> 502 in the cache */
   /* search1907_1_0 -> 5388 in the cache */
   /* search1907_1 -> 5411 in the cache */
   /* search1907_2_0 -> 5390 in the cache */
   /* search1907_2 -> 5412 in the cache */
   /* search1907 -> 5413 in the cache */

   /* replace1907_0_0 -> 502 in the cache */
   /* replace1907_0_1 -> 5388 in the cache */
   /* replace1907_0_2 -> 5390 in the cache */
   /* replace1907_0 -> 5393 in the cache */
   /* replace1907 -> 5414 in the cache */

   /* ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b')) */
   /* search1908_0_0 -> 502 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5431, 5432 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5433 },
      -1,
   } },

   /* replace1908_0 -> 502 in the cache */
   /* replace1908_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5388 },
      -1,
   } },
   /* replace1908_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5390 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5435, 5436 },
      -1,
   } },

   /* ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b')) */
   /* search1909_0_0 -> 502 in the cache */
   /* search1909_0_1 -> 5431 in the cache */
   /* search1909_0_2 -> 5432 in the cache */
   /* search1909_0 -> 5433 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5433 },
      -1,
   } },

   /* replace1909_0 -> 502 in the cache */
   /* replace1909_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5388 },
      -1,
   } },
   /* replace1909_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5390 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5439, 5440 },
      -1,
   } },

   /* ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b')) */
   /* search1910_0_0 -> 502 in the cache */
   /* search1910_0_1 -> 5431 in the cache */
   /* search1910_0_2 -> 5432 in the cache */
   /* search1910_0 -> 5433 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5433 },
      -1,
   } },

   /* replace1910_0 -> 502 in the cache */
   /* replace1910_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5388 },
      -1,
   } },
   /* replace1910_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5390 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5443, 5444 },
      -1,
   } },

   /* ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b')) */
   /* search1911_0_0 -> 502 in the cache */
   /* search1911_0_1 -> 5431 in the cache */
   /* search1911_0_2 -> 5432 in the cache */
   /* search1911_0 -> 5433 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5433 },
      -1,
   } },

   /* replace1911_0 -> 502 in the cache */
   /* replace1911_1_0 -> 5388 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5388 },
      -1,
   } },
   /* replace1911_2_0 -> 5390 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5390 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 5447, 5448 },
      -1,
   } },

   /* ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216)) */
   /* search1912_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 16 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1ffffff /* 33554431 */ },
   } },
   /* replace1912_1_0_0 -> 16 in the cache */
   /* replace1912_1_0_1 -> 377 in the cache */
   /* replace1912_1_0 -> 946 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1000000 /* 16777216 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 946, 5452 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 5451, 5453 },
      -1,
   } },

   /* ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b')) */
   /* search1913_0_0 -> 16 in the cache */
   /* search1913_0_1 -> 36 in the cache */
   /* search1913_0 -> 2905 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 2905 },
      -1,
   } },

   /* replace1913_0_0 -> 16 in the cache */
   /* replace1913_0 -> 3593 in the cache */
   /* replace1913_1_0 -> 36 in the cache */
   /* replace1913_1 -> 3590 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3593, 3590 },
      -1,
   } },

   /* ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b')) */
   /* search1914_0_0 -> 16 in the cache */
   /* search1914_0_1 -> 36 in the cache */
   /* search1914_0 -> 2905 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 2905 },
      -1,
   } },

   /* replace1914_0_0 -> 16 in the cache */
   /* replace1914_0 -> 1934 in the cache */
   /* replace1914_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 1934, 5458 },
      -1,
   } },

   /* ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b')) */
   /* search1915_0_0 -> 16 in the cache */
   /* search1915_0_1 -> 36 in the cache */
   /* search1915_0 -> 2905 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2905 },
      -1,
   } },

   /* replace1915_0_0 -> 16 in the cache */
   /* replace1915_0 -> 3003 in the cache */
   /* replace1915_1_0 -> 36 in the cache */
   /* replace1915_1 -> 4416 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3003, 4416 },
      -1,
   } },

   /* ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b')) */
   /* search1916_0_0 -> 16 in the cache */
   /* search1916_0_1 -> 36 in the cache */
   /* search1916_0 -> 2905 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2905 },
      -1,
   } },

   /* replace1916_0_0 -> 16 in the cache */
   /* replace1916_0 -> 3902 in the cache */
   /* replace1916_1_0 -> 36 in the cache */
   /* replace1916_1 -> 4087 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3902, 4087 },
      -1,
   } },

   /* ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b')) */
   /* search1917_0_0 -> 16 in the cache */
   /* search1917_0_1 -> 36 in the cache */
   /* search1917_0 -> 2905 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 2905 },
      -1,
   } },

   /* replace1917_0_0 -> 16 in the cache */
   /* replace1917_0 -> 1945 in the cache */
   /* replace1917_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 1945, 5465 },
      -1,
   } },

   /* ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c')) */
   /* search1918_0_0 -> 16 in the cache */
   /* search1918_0_1 -> 36 in the cache */
   /* search1918_0_2 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 16, 36, 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 5467 },
      -1,
   } },

   /* replace1918_0_0 -> 16 in the cache */
   /* replace1918_0 -> 3593 in the cache */
   /* replace1918_1_0 -> 36 in the cache */
   /* replace1918_1 -> 3590 in the cache */
   /* replace1918_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3593, 3590, 5469 },
      -1,
   } },

   /* ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c')) */
   /* search1919_0_0 -> 16 in the cache */
   /* search1919_0_1 -> 36 in the cache */
   /* search1919_0_2 -> 133 in the cache */
   /* search1919_0 -> 5467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 5467 },
      -1,
   } },

   /* replace1919_0_0 -> 16 in the cache */
   /* replace1919_0 -> 1934 in the cache */
   /* replace1919_1_0 -> 36 in the cache */
   /* replace1919_1 -> 5458 in the cache */
   /* replace1919_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 1934, 5458, 5472 },
      -1,
   } },

   /* ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c')) */
   /* search1920_0_0 -> 16 in the cache */
   /* search1920_0_1 -> 36 in the cache */
   /* search1920_0_2 -> 133 in the cache */
   /* search1920_0 -> 5467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5467 },
      -1,
   } },

   /* replace1920_0_0 -> 16 in the cache */
   /* replace1920_0 -> 3003 in the cache */
   /* replace1920_1_0 -> 36 in the cache */
   /* replace1920_1 -> 4416 in the cache */
   /* replace1920_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3003, 4416, 5475 },
      -1,
   } },

   /* ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c')) */
   /* search1921_0_0 -> 16 in the cache */
   /* search1921_0_1 -> 36 in the cache */
   /* search1921_0_2 -> 133 in the cache */
   /* search1921_0 -> 5467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5467 },
      -1,
   } },

   /* replace1921_0_0 -> 16 in the cache */
   /* replace1921_0 -> 3902 in the cache */
   /* replace1921_1_0 -> 36 in the cache */
   /* replace1921_1 -> 4087 in the cache */
   /* replace1921_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3902, 4087, 5478 },
      -1,
   } },

   /* ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c')) */
   /* search1922_0_0 -> 16 in the cache */
   /* search1922_0_1 -> 36 in the cache */
   /* search1922_0_2 -> 133 in the cache */
   /* search1922_0 -> 5467 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 5467 },
      -1,
   } },

   /* replace1922_0_0 -> 16 in the cache */
   /* replace1922_0 -> 1945 in the cache */
   /* replace1922_1_0 -> 36 in the cache */
   /* replace1922_1 -> 5465 in the cache */
   /* replace1922_2_0 -> 133 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 133 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 1945, 5465, 5481 },
      -1,
   } },

   /* ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd')) */
   /* search1923_0_0 -> 16 in the cache */
   /* search1923_0_1 -> 36 in the cache */
   /* search1923_0_2 -> 133 in the cache */
   /* search1923_0_3 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 16, 36, 133, 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 5483 },
      -1,
   } },

   /* replace1923_0_0 -> 16 in the cache */
   /* replace1923_0 -> 3593 in the cache */
   /* replace1923_1_0 -> 36 in the cache */
   /* replace1923_1 -> 3590 in the cache */
   /* replace1923_2_0 -> 133 in the cache */
   /* replace1923_2 -> 5469 in the cache */
   /* replace1923_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3593, 3590, 5469, 5485 },
      -1,
   } },

   /* ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd')) */
   /* search1924_0_0 -> 16 in the cache */
   /* search1924_0_1 -> 36 in the cache */
   /* search1924_0_2 -> 133 in the cache */
   /* search1924_0_3 -> 161 in the cache */
   /* search1924_0 -> 5483 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 5483 },
      -1,
   } },

   /* replace1924_0_0 -> 16 in the cache */
   /* replace1924_0 -> 1934 in the cache */
   /* replace1924_1_0 -> 36 in the cache */
   /* replace1924_1 -> 5458 in the cache */
   /* replace1924_2_0 -> 133 in the cache */
   /* replace1924_2 -> 5472 in the cache */
   /* replace1924_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 1934, 5458, 5472, 5488 },
      -1,
   } },

   /* ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd')) */
   /* search1925_0_0 -> 16 in the cache */
   /* search1925_0_1 -> 36 in the cache */
   /* search1925_0_2 -> 133 in the cache */
   /* search1925_0_3 -> 161 in the cache */
   /* search1925_0 -> 5483 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5483 },
      -1,
   } },

   /* replace1925_0_0 -> 16 in the cache */
   /* replace1925_0 -> 3003 in the cache */
   /* replace1925_1_0 -> 36 in the cache */
   /* replace1925_1 -> 4416 in the cache */
   /* replace1925_2_0 -> 133 in the cache */
   /* replace1925_2 -> 5475 in the cache */
   /* replace1925_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3003, 4416, 5475, 5491 },
      -1,
   } },

   /* ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd')) */
   /* search1926_0_0 -> 16 in the cache */
   /* search1926_0_1 -> 36 in the cache */
   /* search1926_0_2 -> 133 in the cache */
   /* search1926_0_3 -> 161 in the cache */
   /* search1926_0 -> 5483 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5483 },
      -1,
   } },

   /* replace1926_0_0 -> 16 in the cache */
   /* replace1926_0 -> 3902 in the cache */
   /* replace1926_1_0 -> 36 in the cache */
   /* replace1926_1 -> 4087 in the cache */
   /* replace1926_2_0 -> 133 in the cache */
   /* replace1926_2 -> 5478 in the cache */
   /* replace1926_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3902, 4087, 5478, 5494 },
      -1,
   } },

   /* ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd')) */
   /* search1927_0_0 -> 16 in the cache */
   /* search1927_0_1 -> 36 in the cache */
   /* search1927_0_2 -> 133 in the cache */
   /* search1927_0_3 -> 161 in the cache */
   /* search1927_0 -> 5483 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 5483 },
      -1,
   } },

   /* replace1927_0_0 -> 16 in the cache */
   /* replace1927_0 -> 1945 in the cache */
   /* replace1927_1_0 -> 36 in the cache */
   /* replace1927_1 -> 5465 in the cache */
   /* replace1927_2_0 -> 133 in the cache */
   /* replace1927_2 -> 5481 in the cache */
   /* replace1927_3_0 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 1945, 5465, 5481, 5497 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_expression_cond[] = {
   (is_used_once),
   (is_only_used_as_float),
   (is_used_by_if),
   (is_not_used_by_if),
   (is_used_by_non_fsat),
   (no_signed_wrap),
   (only_lower_8_bits_used),
   (only_lower_16_bits_used),
};

static const nir_search_variable_cond nir_opt_algebraic_variable_cond[] = {
   (is_pos_power_of_two),
   (is_neg_power_of_two),
   (is_bitcount2),
   (is_finite_not_zero),
   (is_finite),
   (is_not_const),
   (is_not_const_zero),
   (is_ult_0xfffc07fc),
   (is_not_fmul),
   (is_first_5_bits_uge_2),
   (is_unsigned_multiple_of_4),
   (is_unsigned_multiple_of_2),
   (is_unsigned_multiple_of_8),
   (is_unsigned_multiple_of_16),
   (is_unsigned_multiple_of_32),
   (is_unsigned_multiple_of_64),
   (is_a_number),
   (is_gt_0_and_lt_1),
   (is_zero_to_one),
   (is_not_negative),
   (is_integral),
   (is_not_positive),
   (is_not_zero),
   (is_a_number_not_negative),
   (is_a_number_not_positive),
   (is_gt_zero),
   (is_lt_zero),
   (is_a_number_gt_zero),
   (is_a_number_lt_zero),
   (is_fmul),
   (is_lower_half_zero),
   (is_upper_half_zero),
};

static const struct transform nir_opt_algebraic_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2479, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2479, 1177, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2910, 3000, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 54, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 57, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 32, 0 },
   { 67, 68, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 61, 0 },
   { 78, 81, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 62, 61, 0 },
   { 64, 61, 0 },
   { 82, 81, 1 },
   { 83, 88, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 61, 0 },
   { 66, 61, 0 },
   { 89, 95, 1 },
   { 96, 97, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2852, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2853, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2743, 1181, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 121, 16, 0 },
   { 123, 122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 269, 270, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 269, 270, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 253, 254, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 253, 254, 6 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 272, 273, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 253, 254, 6 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 272, 273, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1454, 37 },
   { 2855, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 120, 0 },
   { 225, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 3606, 94 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 277, 249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 277, 249, 0 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 36, 0 },
   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 36, 0 },
   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 36, 0 },
   { 333, 335, 0 },
   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 282, 36, 0 },
   { 333, 335, 0 },
   { 316, 392, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 36, 0 },
   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 36, 0 },
   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 36, 0 },
   { 336, 338, 0 },
   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 283, 36, 0 },
   { 336, 338, 0 },
   { 319, 408, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 437, 438, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 36, 0 },
   { 437, 438, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 284, 36, 0 },
   { 348, 349, 7 },
   { 437, 438, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 434, 319, 0 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 36, 0 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 36, 0 },
   { 434, 319, 0 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 36, 0 },
   { 350, 351, 8 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 285, 36, 0 },
   { 350, 351, 8 },
   { 434, 319, 0 },
   { 435, 436, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 286, 36, 0 },
   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 286, 36, 0 },
   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 286, 36, 0 },
   { 342, 344, 0 },
   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 286, 36, 0 },
   { 342, 344, 0 },
   { 328, 424, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 36, 0 },
   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 36, 0 },
   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 36, 0 },
   { 345, 347, 0 },
   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 36, 0 },
   { 345, 347, 0 },
   { 331, 432, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 443, 444, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 288, 36, 0 },
   { 443, 444, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 288, 36, 0 },
   { 354, 355, 7 },
   { 443, 444, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 441, 442, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 36, 0 },
   { 441, 442, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 36, 0 },
   { 356, 357, 8 },
   { 441, 442, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 290, 36, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 290, 36, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 36, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 36, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 290, 36, 0 },
   { 291, 36, 0 },
   { 339, 341, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 290, 36, 0 },
   { 291, 36, 0 },
   { 339, 341, 0 },
   { 322, 416, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 439, 440, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 36, 0 },
   { 439, 440, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 293, 36, 0 },
   { 439, 440, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 36, 0 },
   { 293, 36, 0 },
   { 352, 353, 7 },
   { 439, 440, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2456, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 669, 673, 20 },
   { 2849, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 674, 683, 21 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 684, 685, 22 },
   { 2847, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 675, 688, 24 },
   { 2850, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 689, 691, 25 },
   { 2848, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 723, 728, 32 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 759, 760, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 757, 758, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 755, 756, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 751, 754, 0 },
   { 755, 756, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 761, 754, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2483, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2483, 1177, 0 },
   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2482, 32, 0 },
   { 2933, 2934, 55 },
   { 2935, 387, 55 },
   { 2936, 2937, 55 },
   { 2967, 420, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2481, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2481, 1177, 0 },
   { 2482, 32, 0 },
   { 2933, 2934, 55 },
   { 2935, 387, 55 },
   { 2936, 2937, 55 },
   { 2967, 420, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2457, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { 1426, 3414, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { 1426, 3414, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2451, 1032, 0 },
   { 2900, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2451, 1032, 0 },
   { 2899, 1185, 0 },
   { 3421, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2451, 1032, 0 },
   { 2899, 1185, 0 },
   { 2900, 1032, 0 },
   { 3421, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 1423, 3415, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 1423, 3415, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2450, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2450, 1032, 0 },
   { 2745, 1080, 0 },
   { 2746, 715, 0 },
   { 2890, 1185, 0 },
   { 3416, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1273, 61, 0 },
   { 1274, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1275, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1275, 32, 0 },
   { 1276, 32, 0 },
   { 1277, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3517, 3520, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3517, 3520, 81 },
   { 4627, 11, 0 },
   { 4680, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3789, 11, 0 },
   { 3790, 16, 0 },
   { 3791, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3779, 715, 0 },
   { 3780, 6, 0 },
   { 3781, 11, 0 },
   { 3782, 16, 0 },
   { 3783, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3512, 3516, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3512, 3516, 81 },
   { 4655, 11, 0 },
   { 4708, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3521, 3525, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3521, 3525, 82 },
   { 4760, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3526, 3529, 82 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3526, 3529, 82 },
   { 4733, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 2465, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2294, 2302, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2294, 2302, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2294, 2302, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2294, 2302, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2296, 2303, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2296, 2303, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2296, 2303, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2296, 2303, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2298, 2304, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2300, 2305, 44 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2324, 2331, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2332, 2334, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2335, 2337, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2338, 2341, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2342, 2346, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2347, 2349, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2350, 2355, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2356, 2362, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2363, 2369, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2370, 2373, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2374, 2379, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2380, 2384, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2385, 2388, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2389, 2394, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2395, 2399, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2400, 2403, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2404, 2409, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2410, 2414, 45 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 3155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2489, 2492, 47 },
   { 2496, 2499, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2502, 2504, 47 },
   { 2507, 2509, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2514, 2517, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2514, 2517, 48 },
   { 2538, 32, 0 },
   { 2539, 236, 0 },
   { 2540, 2537, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2514, 2517, 48 },
   { 2541, 2512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2514, 2517, 48 },
   { 2538, 32, 0 },
   { 2539, 236, 0 },
   { 2540, 2537, 0 },
   { 2541, 2512, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2530, 2584, 51 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2579, 2581, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2578, 2559, 0 },
   { 2579, 2581, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2586, 2668, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2669, 2738, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2782, 36, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2901, 2995, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2911, 3002, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2919, 3003, 61 },
   { 2919, 3003, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2921, 3004, 61 },
   { 2921, 3004, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3458, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2955, 393, 55 },
   { 2956, 396, 55 },
   { 2957, 400, 55 },
   { 2958, 403, 55 },
   { 2971, 425, 56 },
   { 2972, 428, 56 },
   { 3458, 120, 0 },
   { 3460, 3462, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3459, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2959, 374, 55 },
   { 2960, 378, 55 },
   { 2961, 383, 55 },
   { 2962, 387, 55 },
   { 2973, 417, 56 },
   { 2974, 420, 56 },
   { 3459, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2996, 2999, 59 },
   { 2996, 3598, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3006, 3596, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3013, 3597, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3041, 3595, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3041, 3595, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3041, 3595, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3041, 3595, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3150, 16, 0 },
   { 3151, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3152, 3153, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3156, 3158, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3159, 3160, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3508, 3511, 80 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3493, 3497, 78 },
   { 3493, 3501, 79 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3503, 3507, 79 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3311, 3314, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3315, 3318, 62 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3319, 3322, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3323, 3324, 64 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3329, 3333, 65 },
   { 3329, 3430, 74 },
   { 3329, 3432, 75 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3334, 3337, 66 },
   { 3348, 3352, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3338, 3340, 66 },
   { 3353, 3355, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3341, 3344, 66 },
   { 3356, 3360, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3345, 3347, 66 },
   { 3361, 3363, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3364, 3368, 68 },
   { 3369, 3371, 69 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3372, 3373, 69 },
   { 3374, 3377, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3378, 3391, 71 },
   { 3670, 3681, 102 },
   { 3690, 3701, 102 },
   { 3710, 3720, 102 },
   { 3378, 3735, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3392, 3400, 71 },
   { 3682, 3689, 102 },
   { 3702, 3709, 102 },
   { 3721, 3728, 102 },
   { 3392, 3740, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3436, 3439, 76 },
   { 3436, 3486, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3440, 3442, 76 },
   { 3440, 3492, 77 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3443, 2472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3531, 3537, 83 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3538, 3543, 84 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3544, 3551, 85 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3552, 3557, 86 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3558, 3563, 87 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3564, 3571, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3572, 3579, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3580, 3589, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3599, 3601, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3607, 906, 95 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3608, 3612, 96 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3613, 3617, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3618, 3619, 98 },
   { 3618, 49, 95 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3620, 3613, 99 },
   { 3620, 3622, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3623, 3608, 100 },
   { 3623, 49, 96 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3624, 3619, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3625, 536, 0 },
   { 3626, 3627, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3624, 3619, 0 },
   { 3625, 536, 0 },
   { 3626, 3627, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3625, 536, 0 },
   { 3626, 3627, 0 },
   { 3628, 3630, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3624, 3619, 0 },
   { 3625, 536, 0 },
   { 3626, 3627, 0 },
   { 3628, 3630, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3632, 3634, 1 },
   { 3636, 3640, 1 },
   { 3641, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3792, 715, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3793, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3794, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3795, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4786, 4806, 105 },
   { 4808, 4826, 105 },
   { 4828, 4849, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5169, 113, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5170, 113, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5171, 113, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5172, 113, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5173, 113, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5174, 113, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5176, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5179, 133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5177, 133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5177, 133, 0 },
   { 5179, 133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5450, 5454, 108 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 3170, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4644, 4642, 0 },
   { 4697, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4669, 4642, 0 },
   { 4722, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4774, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4749, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 3186, 3187, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 3186, 3187, 0 },
   { 3230, 3187, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 3169, 3170, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 979, 982, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 5165, 5168, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4644, 4642, 0 },
   { 4697, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4669, 4642, 0 },
   { 4722, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4774, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4749, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 3170, 0 },
   { 4644, 4642, 0 },
   { 4697, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 3170, 0 },
   { 4669, 4642, 0 },
   { 4722, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 3170, 0 },
   { 4774, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 3170, 0 },
   { 4749, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2433, 2434, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4644, 4642, 0 },
   { 4669, 4642, 0 },
   { 4697, 49, 0 },
   { 4722, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4644, 4642, 0 },
   { 4697, 49, 0 },
   { 4774, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4644, 4642, 0 },
   { 4697, 49, 0 },
   { 4749, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4669, 4642, 0 },
   { 4722, 49, 0 },
   { 4774, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4669, 4642, 0 },
   { 4722, 49, 0 },
   { 4749, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4749, 49, 0 },
   { 4774, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3276, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { 3276, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 191, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3216, 3217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3216, 3217, 0 },
   { 3258, 3217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 297, 299, 0 },
   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 301, 302, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 308, 309, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 311, 312, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 304, 306, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 5161, 5164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 177, 179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 194, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 194, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4640, 3692, 0 },
   { 4666, 3692, 0 },
   { 4694, 3712, 0 },
   { 4719, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4746, 3712, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3040, 3041, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2571, 2573, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3304, 103, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3304, 103, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3304, 103, 0 },
   { 3665, 3647, 101 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3304, 103, 0 },
   { 3308, 3310, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3665, 3647, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3665, 3647, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3665, 3647, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3665, 3647, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { 3664, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3664, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3664, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2571, 2573, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3304, 103, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3304, 103, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3304, 103, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3304, 103, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { 3667, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3667, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3667, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3669, 3653, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3669, 3653, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3669, 3653, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3669, 3653, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3657, 3658, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3657, 3658, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3657, 3658, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3657, 3658, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { 3655, 3656, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3655, 3656, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3655, 3656, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3662, 3663, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3662, 3663, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3662, 3663, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3662, 3663, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2748, 715, 0 },
   { 2749, 1080, 0 },
   { 2752, 2753, 0 },
   { 2754, 2755, 0 },
   { 2758, 2759, 0 },
   { 2760, 2761, 0 },
   { 2762, 2763, 0 },
   { 2764, 2765, 0 },
   { 2767, 2768, 0 },
   { 2769, 2770, 0 },
   { 2771, 2772, 54 },
   { 2773, 2774, 54 },
   { 2777, 2778, 54 },
   { 2779, 2780, 54 },
   { 2781, 3, 0 },
   { 2784, 2172, 0 },
   { 2785, 2787, 0 },
   { 2789, 1176, 0 },
   { 2790, 2786, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5244, 5245, 0 },
   { 5248, 5245, 0 },
   { 5251, 5245, 0 },
   { 5254, 5245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5425, 5426, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5429, 5430, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5231, 5232, 0 },
   { 5235, 5232, 0 },
   { 5238, 5232, 0 },
   { 5241, 5232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5218, 5219, 0 },
   { 5222, 5219, 0 },
   { 5225, 5219, 0 },
   { 5228, 5219, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5203, 5205, 0 },
   { 5208, 5205, 0 },
   { 5211, 5205, 0 },
   { 5214, 5205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5257, 5258, 0 },
   { 5261, 5258, 0 },
   { 5264, 5258, 0 },
   { 5267, 5258, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5270, 5271, 0 },
   { 5274, 5271, 0 },
   { 5277, 5271, 0 },
   { 5280, 5271, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5413, 5414, 0 },
   { 5413, 5414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5182, 5183, 0 },
   { 5186, 5183, 0 },
   { 5188, 5190, 0 },
   { 5192, 5190, 0 },
   { 5195, 5197, 0 },
   { 5199, 5197, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1244, 0 },
   { 1246, 1244, 0 },
   { 1249, 1251, 0 },
   { 1254, 1251, 0 },
   { 1258, 1260, 0 },
   { 1263, 1260, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3305, 3306, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1714, 1716, 0 },
   { 1821, 1823, 0 },
   { 1904, 1906, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5296, 5297, 0 },
   { 5300, 5297, 0 },
   { 5303, 5297, 0 },
   { 5306, 5297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5309, 5310, 0 },
   { 5313, 5310, 0 },
   { 5316, 5310, 0 },
   { 5319, 5310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5322, 5323, 0 },
   { 5326, 5323, 0 },
   { 5329, 5323, 0 },
   { 5332, 5323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5335, 5336, 0 },
   { 5339, 5336, 0 },
   { 5342, 5336, 0 },
   { 5345, 5336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5348, 5349, 0 },
   { 5352, 5349, 0 },
   { 5355, 5349, 0 },
   { 5358, 5349, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5361, 5362, 0 },
   { 5365, 5362, 0 },
   { 5368, 5362, 0 },
   { 5371, 5362, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4636, 4631, 0 },
   { 4689, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4661, 4631, 0 },
   { 4714, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4766, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4741, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5283, 5284, 0 },
   { 5287, 5284, 0 },
   { 5290, 5284, 0 },
   { 5293, 5284, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5405, 5406, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5409, 5410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5374, 5375, 0 },
   { 5378, 5375, 0 },
   { 5382, 5384, 0 },
   { 5387, 5384, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5401, 5402, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5392, 5394, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5397, 5398, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5417, 5418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 5421, 5422, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3286, 3277, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3288, 3280, 0 },
   { 3291, 3280, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3289, 3283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2073, 2074, 0 },
   { 2099, 2100, 0 },
   { 2125, 901, 0 },
   { 2150, 2151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2073, 2074, 0 },
   { 2099, 2100, 0 },
   { 2125, 901, 0 },
   { 2150, 2151, 0 },
   { 2479, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2479, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 778, 780, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 782, 791, 0 },
   { 804, 812, 0 },
   { 825, 832, 0 },
   { 845, 853, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 975, 977, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 945, 946, 0 },
   { 952, 953, 0 },
   { 959, 960, 0 },
   { 968, 969, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 865, 868, 0 },
   { 873, 876, 0 },
   { 881, 884, 0 },
   { 889, 892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 865, 868, 0 },
   { 873, 876, 0 },
   { 881, 884, 0 },
   { 889, 892, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 865, 868, 0 },
   { 873, 876, 0 },
   { 881, 884, 0 },
   { 889, 892, 0 },
   { 2073, 2074, 0 },
   { 2099, 2100, 0 },
   { 2125, 901, 0 },
   { 2150, 2151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 865, 868, 0 },
   { 873, 876, 0 },
   { 881, 884, 0 },
   { 889, 892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 869, 868, 0 },
   { 877, 876, 0 },
   { 885, 884, 0 },
   { 893, 892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 869, 868, 0 },
   { 877, 876, 0 },
   { 885, 884, 0 },
   { 893, 892, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 869, 868, 0 },
   { 877, 876, 0 },
   { 885, 884, 0 },
   { 893, 892, 0 },
   { 2073, 2074, 0 },
   { 2099, 2100, 0 },
   { 2125, 901, 0 },
   { 2150, 2151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 869, 868, 0 },
   { 877, 876, 0 },
   { 885, 884, 0 },
   { 893, 892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2480, 32, 0 },
   { 3035, 3036, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2471, 2472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4647, 1964, 0 },
   { 4700, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4672, 1964, 0 },
   { 4725, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4752, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 905, 906, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 900, 901, 0 },
   { 947, 946, 0 },
   { 954, 953, 0 },
   { 962, 960, 0 },
   { 971, 969, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 910, 912, 0 },
   { 916, 918, 0 },
   { 922, 924, 0 },
   { 928, 930, 0 },
   { 934, 936, 0 },
   { 940, 942, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2471, 2472, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2471, 2472, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { 3260, 3262, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2470, 3, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 949, 948, 0 },
   { 956, 955, 0 },
   { 964, 963, 0 },
   { 973, 972, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { 4647, 1964, 0 },
   { 4700, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { 4672, 1964, 0 },
   { 4725, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { 4752, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2002, 2003, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 2471, 2472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2471, 2472, 0 },
   { 4647, 1964, 0 },
   { 4700, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2471, 2472, 0 },
   { 4672, 1964, 0 },
   { 4725, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2471, 2472, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2471, 2472, 0 },
   { 4752, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 184, 0 },
   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4647, 1964, 0 },
   { 4700, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4672, 1964, 0 },
   { 4725, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4752, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 5071, 5072, 0 },
   { 5074, 5075, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 5060, 5061, 0 },
   { 5064, 5065, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 5066, 5067, 0 },
   { 5069, 5070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1031, 1032, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2435, 2434, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1993, 1995, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1998, 1999, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2475, 2476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1034, 1032, 0 },
   { 1565, 1567, 0 },
   { 1568, 1570, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1034, 1032, 0 },
   { 1565, 1567, 0 },
   { 1568, 1570, 0 },
   { 1581, 1567, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1034, 1032, 0 },
   { 1565, 1567, 0 },
   { 1568, 1570, 0 },
   { 1691, 1692, 0 },
   { 1693, 1692, 0 },
   { 1798, 1799, 0 },
   { 1800, 1799, 0 },
   { 1881, 1882, 0 },
   { 1883, 1882, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1034, 1032, 0 },
   { 1565, 1567, 0 },
   { 1568, 1570, 0 },
   { 1581, 1567, 0 },
   { 1691, 1692, 0 },
   { 1693, 1692, 0 },
   { 1798, 1799, 0 },
   { 1800, 1799, 0 },
   { 1881, 1882, 0 },
   { 1883, 1882, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1034, 1032, 0 },
   { 1565, 1567, 0 },
   { 1568, 1570, 0 },
   { 1586, 1570, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1034, 1032, 0 },
   { 1565, 1567, 0 },
   { 1568, 1570, 0 },
   { 1586, 1570, 0 },
   { 1691, 1692, 0 },
   { 1693, 1692, 0 },
   { 1798, 1799, 0 },
   { 1800, 1799, 0 },
   { 1881, 1882, 0 },
   { 1883, 1882, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1034, 1032, 0 },
   { 1565, 1567, 0 },
   { 1568, 1570, 0 },
   { 1581, 1567, 0 },
   { 1586, 1570, 0 },
   { 1691, 1692, 0 },
   { 1693, 1692, 0 },
   { 1798, 1799, 0 },
   { 1800, 1799, 0 },
   { 1881, 1882, 0 },
   { 1883, 1882, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1571, 1573, 0 },
   { 1574, 1576, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1571, 1573, 0 },
   { 1574, 1576, 0 },
   { 1589, 1573, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 35 },
   { 1571, 1573, 0 },
   { 1574, 1576, 0 },
   { 1694, 1695, 0 },
   { 1696, 1695, 0 },
   { 1801, 1802, 0 },
   { 1803, 1802, 0 },
   { 1884, 1885, 0 },
   { 1886, 1885, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 35 },
   { 1571, 1573, 0 },
   { 1574, 1576, 0 },
   { 1589, 1573, 0 },
   { 1694, 1695, 0 },
   { 1696, 1695, 0 },
   { 1801, 1802, 0 },
   { 1803, 1802, 0 },
   { 1884, 1885, 0 },
   { 1886, 1885, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1571, 1573, 0 },
   { 1574, 1576, 0 },
   { 1592, 1576, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 35 },
   { 1571, 1573, 0 },
   { 1574, 1576, 0 },
   { 1592, 1576, 0 },
   { 1694, 1695, 0 },
   { 1696, 1695, 0 },
   { 1801, 1802, 0 },
   { 1803, 1802, 0 },
   { 1884, 1885, 0 },
   { 1886, 1885, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1209, 1210, 35 },
   { 1571, 1573, 0 },
   { 1574, 1576, 0 },
   { 1589, 1573, 0 },
   { 1592, 1576, 0 },
   { 1694, 1695, 0 },
   { 1696, 1695, 0 },
   { 1801, 1802, 0 },
   { 1803, 1802, 0 },
   { 1884, 1885, 0 },
   { 1886, 1885, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1039, 1032, 0 },
   { 1633, 1634, 0 },
   { 1635, 1636, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1041, 1032, 0 },
   { 1641, 1642, 0 },
   { 1643, 1644, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1637, 1638, 0 },
   { 1639, 1640, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1645, 1646, 0 },
   { 1647, 1648, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1037, 1032, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2055, 2057, 40 },
   { 2055, 2063, 42 },
   { 2081, 2083, 40 },
   { 2081, 2089, 42 },
   { 2107, 2109, 40 },
   { 2107, 2115, 42 },
   { 2132, 2134, 40 },
   { 2132, 2140, 42 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2067, 2068, 43 },
   { 2093, 2094, 43 },
   { 2119, 2120, 43 },
   { 2144, 2145, 43 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1981, 1982, 0 },
   { 2458, 32, 0 },
   { 4647, 1964, 0 },
   { 4700, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4647, 1964, 0 },
   { 4672, 1964, 0 },
   { 4700, 1972, 0 },
   { 4725, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4647, 1964, 0 },
   { 4700, 1972, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4647, 1964, 0 },
   { 4700, 1972, 0 },
   { 4752, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1976, 1978, 0 },
   { 2458, 32, 0 },
   { 4672, 1964, 0 },
   { 4725, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4672, 1964, 0 },
   { 4725, 1972, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4672, 1964, 0 },
   { 4725, 1972, 0 },
   { 4752, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1985, 1986, 0 },
   { 2458, 32, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4752, 1972, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1989, 1990, 0 },
   { 2458, 32, 0 },
   { 4752, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4650, 2006, 0 },
   { 4703, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4675, 2006, 0 },
   { 4728, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4755, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { 2468, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { 2469, 2236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { 2469, 2236, 0 },
   { 3264, 3266, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { 4650, 2006, 0 },
   { 4703, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { 4675, 2006, 0 },
   { 4728, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { 4755, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2026, 2027, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { 2469, 2236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { 4650, 2006, 0 },
   { 4703, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { 4675, 2006, 0 },
   { 4728, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { 4755, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { 4650, 2006, 0 },
   { 4703, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { 4675, 2006, 0 },
   { 4728, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { 4755, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2436, 2437, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2021, 2023, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2024, 2025, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { 2477, 2478, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { 4650, 2006, 0 },
   { 4703, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { 4675, 2006, 0 },
   { 4728, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { 4755, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1532, 1534, 0 },
   { 1538, 1540, 0 },
   { 1674, 1007, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4650, 2006, 0 },
   { 4703, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4675, 2006, 0 },
   { 4728, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4755, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1532, 1534, 0 },
   { 1538, 1540, 0 },
   { 1553, 1534, 0 },
   { 1674, 1007, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1532, 1534, 0 },
   { 1538, 1540, 0 },
   { 1674, 1007, 0 },
   { 1677, 1679, 0 },
   { 1682, 1679, 0 },
   { 1784, 1786, 0 },
   { 1789, 1786, 0 },
   { 1867, 1869, 0 },
   { 1872, 1869, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1532, 1534, 0 },
   { 1538, 1540, 0 },
   { 1553, 1534, 0 },
   { 1674, 1007, 0 },
   { 1677, 1679, 0 },
   { 1682, 1679, 0 },
   { 1784, 1786, 0 },
   { 1789, 1786, 0 },
   { 1867, 1869, 0 },
   { 1872, 1869, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1532, 1534, 0 },
   { 1538, 1540, 0 },
   { 1558, 1540, 0 },
   { 1674, 1007, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1532, 1534, 0 },
   { 1538, 1540, 0 },
   { 1558, 1540, 0 },
   { 1674, 1007, 0 },
   { 1677, 1679, 0 },
   { 1682, 1679, 0 },
   { 1784, 1786, 0 },
   { 1789, 1786, 0 },
   { 1867, 1869, 0 },
   { 1872, 1869, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1532, 1534, 0 },
   { 1538, 1540, 0 },
   { 1553, 1534, 0 },
   { 1558, 1540, 0 },
   { 1674, 1007, 0 },
   { 1677, 1679, 0 },
   { 1682, 1679, 0 },
   { 1784, 1786, 0 },
   { 1789, 1786, 0 },
   { 1867, 1869, 0 },
   { 1872, 1869, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1543, 1545, 0 },
   { 1548, 1550, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1543, 1545, 0 },
   { 1548, 1550, 0 },
   { 1561, 1545, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1543, 1545, 0 },
   { 1548, 1550, 0 },
   { 1685, 1687, 0 },
   { 1690, 1687, 0 },
   { 1792, 1794, 0 },
   { 1797, 1794, 0 },
   { 1875, 1877, 0 },
   { 1880, 1877, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1543, 1545, 0 },
   { 1548, 1550, 0 },
   { 1561, 1545, 0 },
   { 1685, 1687, 0 },
   { 1690, 1687, 0 },
   { 1792, 1794, 0 },
   { 1797, 1794, 0 },
   { 1875, 1877, 0 },
   { 1880, 1877, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1543, 1545, 0 },
   { 1548, 1550, 0 },
   { 1564, 1550, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1543, 1545, 0 },
   { 1548, 1550, 0 },
   { 1564, 1550, 0 },
   { 1685, 1687, 0 },
   { 1690, 1687, 0 },
   { 1792, 1794, 0 },
   { 1797, 1794, 0 },
   { 1875, 1877, 0 },
   { 1880, 1877, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1543, 1545, 0 },
   { 1548, 1550, 0 },
   { 1561, 1545, 0 },
   { 1564, 1550, 0 },
   { 1685, 1687, 0 },
   { 1690, 1687, 0 },
   { 1792, 1794, 0 },
   { 1797, 1794, 0 },
   { 1875, 1877, 0 },
   { 1880, 1877, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1595, 1597, 0 },
   { 1600, 1602, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1615, 1617, 0 },
   { 1620, 1622, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1605, 1607, 0 },
   { 1610, 1612, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1625, 1627, 0 },
   { 1630, 1632, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2162, 2163, 0 },
   { 2166, 2167, 0 },
   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2064, 2066, 43 },
   { 2090, 2092, 43 },
   { 2116, 2118, 43 },
   { 2141, 2143, 43 },
   { 2158, 2159, 0 },
   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { 4650, 2006, 0 },
   { 4703, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { 4675, 2006, 0 },
   { 4728, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { 4755, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2060, 2061, 41 },
   { 2060, 2069, 42 },
   { 2086, 2087, 41 },
   { 2086, 2095, 42 },
   { 2112, 2113, 41 },
   { 2112, 2121, 42 },
   { 2137, 2138, 41 },
   { 2137, 2146, 42 },
   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2015, 2016, 0 },
   { 2461, 32, 0 },
   { 4650, 2006, 0 },
   { 4703, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4650, 2006, 0 },
   { 4675, 2006, 0 },
   { 4703, 2010, 0 },
   { 4728, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4650, 2006, 0 },
   { 4703, 2010, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4650, 2006, 0 },
   { 4703, 2010, 0 },
   { 4755, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2012, 2014, 0 },
   { 2461, 32, 0 },
   { 4675, 2006, 0 },
   { 4728, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4675, 2006, 0 },
   { 4728, 2010, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4675, 2006, 0 },
   { 4728, 2010, 0 },
   { 4755, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2017, 2018, 0 },
   { 2461, 32, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4755, 2010, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2019, 2020, 0 },
   { 2461, 32, 0 },
   { 4755, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 3042, 3041, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4653, 2030, 0 },
   { 4706, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4678, 2030, 0 },
   { 4731, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4783, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4758, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 2465, 32, 0 },
   { 4653, 2030, 0 },
   { 4706, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 2465, 32, 0 },
   { 4678, 2030, 0 },
   { 4731, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 2465, 32, 0 },
   { 4783, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 2465, 32, 0 },
   { 4758, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 2465, 32, 0 },
   { 3268, 3270, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2050, 2051, 0 },
   { 2464, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2045, 2047, 0 },
   { 2464, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2048, 2049, 0 },
   { 2464, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2039, 2040, 0 },
   { 2464, 61, 0 },
   { 4653, 2030, 0 },
   { 4706, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4653, 2030, 0 },
   { 4678, 2030, 0 },
   { 4706, 2034, 0 },
   { 4731, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4653, 2030, 0 },
   { 4706, 2034, 0 },
   { 4783, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4653, 2030, 0 },
   { 4706, 2034, 0 },
   { 4758, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2036, 2038, 0 },
   { 2464, 61, 0 },
   { 4678, 2030, 0 },
   { 4731, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4678, 2030, 0 },
   { 4731, 2034, 0 },
   { 4783, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4678, 2030, 0 },
   { 4731, 2034, 0 },
   { 4758, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2041, 2042, 0 },
   { 2464, 61, 0 },
   { 4783, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4758, 2034, 0 },
   { 4783, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2043, 2044, 0 },
   { 2464, 61, 0 },
   { 4758, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2077, 2078, 0 },
   { 2103, 2104, 0 },
   { 2128, 2129, 0 },
   { 2154, 2155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2077, 2078, 0 },
   { 2103, 2104, 0 },
   { 2128, 2129, 0 },
   { 2154, 2155, 0 },
   { 2483, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2483, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 870, 872, 0 },
   { 878, 880, 0 },
   { 886, 888, 0 },
   { 894, 896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 870, 872, 0 },
   { 878, 880, 0 },
   { 886, 888, 0 },
   { 894, 896, 0 },
   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 2965, 425, 56 },
   { 963, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 870, 872, 0 },
   { 878, 880, 0 },
   { 886, 888, 0 },
   { 894, 896, 0 },
   { 2077, 2078, 0 },
   { 2103, 2104, 0 },
   { 2128, 2129, 0 },
   { 2154, 2155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 870, 872, 0 },
   { 878, 880, 0 },
   { 886, 888, 0 },
   { 894, 896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 793, 795, 0 },
   { 814, 816, 0 },
   { 834, 836, 0 },
   { 855, 857, 0 },
   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { 3037, 3034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2075, 2076, 0 },
   { 2101, 2102, 0 },
   { 2126, 2127, 0 },
   { 2152, 2153, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2075, 2076, 0 },
   { 2101, 2102, 0 },
   { 2126, 2127, 0 },
   { 2152, 2153, 0 },
   { 2481, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2482, 32, 0 },
   { 2933, 2934, 55 },
   { 2935, 387, 55 },
   { 2936, 2937, 55 },
   { 2966, 417, 56 },
   { 2967, 420, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2482, 32, 0 },
   { 2933, 2934, 55 },
   { 2935, 387, 55 },
   { 2936, 2937, 55 },
   { 2967, 420, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2075, 2076, 0 },
   { 2101, 2102, 0 },
   { 2126, 2127, 0 },
   { 2152, 2153, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 797, 802, 0 },
   { 818, 823, 0 },
   { 838, 843, 0 },
   { 859, 864, 0 },
   { 2482, 32, 0 },
   { 2933, 2934, 55 },
   { 2935, 387, 55 },
   { 2936, 2937, 55 },
   { 2967, 420, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3110, 3111, 0 },
   { 3113, 400, 0 },
   { 3114, 396, 0 },
   { 3115, 393, 0 },
   { 3117, 3088, 0 },
   { 3119, 3083, 0 },
   { 3121, 3078, 0 },
   { 3123, 3075, 0 },
   { 3125, 3071, 0 },
   { 3127, 3067, 0 },
   { 3129, 3130, 0 },
   { 3517, 3520, 81 },
   { 4627, 11, 0 },
   { 4680, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3060, 2928, 0 },
   { 3062, 396, 0 },
   { 3063, 400, 0 },
   { 3064, 403, 0 },
   { 3066, 3067, 0 },
   { 3069, 3071, 0 },
   { 3073, 3075, 0 },
   { 3076, 3078, 0 },
   { 3081, 3083, 0 },
   { 3086, 3088, 0 },
   { 3089, 2932, 0 },
   { 3517, 3520, 81 },
   { 4627, 11, 0 },
   { 4680, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3090, 2928, 0 },
   { 3092, 396, 0 },
   { 3093, 400, 0 },
   { 3094, 403, 0 },
   { 3096, 3067, 0 },
   { 3098, 3071, 0 },
   { 3100, 3075, 0 },
   { 3102, 3078, 0 },
   { 3104, 3083, 0 },
   { 3106, 3088, 0 },
   { 3107, 2932, 0 },
   { 3517, 3520, 81 },
   { 4627, 11, 0 },
   { 4680, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2964, 2948, 0 },
   { 3517, 3520, 81 },
   { 4627, 11, 0 },
   { 4680, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2963, 2948, 0 },
   { 3517, 3520, 81 },
   { 4627, 11, 0 },
   { 4680, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3108, 2942, 0 },
   { 3517, 3520, 81 },
   { 4627, 11, 0 },
   { 4680, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3052, 3053, 0 },
   { 3054, 3055, 0 },
   { 3056, 3057, 0 },
   { 3058, 3059, 0 },
   { 3517, 3520, 81 },
   { 4627, 11, 0 },
   { 4680, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3131, 3132, 0 },
   { 3133, 383, 0 },
   { 3134, 378, 0 },
   { 3135, 374, 0 },
   { 3136, 3137, 0 },
   { 3138, 3139, 0 },
   { 3140, 3141, 0 },
   { 3142, 3143, 0 },
   { 3144, 3145, 0 },
   { 3146, 3147, 0 },
   { 3148, 3149, 0 },
   { 3512, 3516, 81 },
   { 4655, 11, 0 },
   { 4708, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3044, 3045, 0 },
   { 3046, 3047, 0 },
   { 3048, 3049, 0 },
   { 3050, 3051, 0 },
   { 3512, 3516, 81 },
   { 4655, 11, 0 },
   { 4708, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2912, 21, 0 },
   { 2901, 2995, 58 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 48, 49, 0 },
   { 2910, 3000, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 51, 49, 0 },
   { 2910, 3000, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2910, 3000, 60 },
   { 3010, 2910, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2902, 16, 0 },
   { 2910, 3000, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 99, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 0 },
   { 2852, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 104, 0 },
   { 2852, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2852, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2295, 2294, 0 },
   { 2852, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2297, 2296, 0 },
   { 2852, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2299, 2298, 0 },
   { 2852, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2301, 2300, 0 },
   { 2852, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2852, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 109, 110, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3762, 715, 0 },
   { 3765, 6, 0 },
   { 3769, 11, 0 },
   { 3771, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3201, 3203, 0 },
   { 3205, 3203, 0 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3201, 3203, 0 },
   { 3205, 3203, 0 },
   { 3232, 3203, 0 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3208, 3210, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3208, 3210, 0 },
   { 3239, 3241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3212, 3214, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 3212, 3214, 0 },
   { 3249, 3251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 5148, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 199, 3, 0 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 135, 137, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 169, 164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3174, 3176, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3174, 3176, 0 },
   { 3219, 3176, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3182, 3184, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3182, 3184, 0 },
   { 3223, 3184, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 5152, 5155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { 5152, 5155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3162, 0 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2438, 1216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2569, 2570, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2574, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 3163, 3164, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 3299, 3300, 0 },
   { 3302, 3303, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 3163, 3164, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 3178, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 3178, 3180, 0 },
   { 3221, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 5157, 5160, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 117, 0 },
   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 229, 16, 0 },
   { 3299, 3300, 0 },
   { 3302, 3303, 0 },
   { 5157, 5160, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 3163, 3164, 6 },
   { 3299, 3300, 0 },
   { 3302, 3303, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 212, 6 },
   { 215, 212, 0 },
   { 216, 217, 0 },
   { 2576, 2577, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 269, 270, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 269, 270, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3192, 3194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3192, 3194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3192, 3194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3192, 3194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3192, 3194, 0 },
   { 3226, 3194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3192, 3194, 0 },
   { 3226, 3194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3192, 3194, 0 },
   { 3226, 3194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3192, 3194, 0 },
   { 3226, 3194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3197, 3198, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3197, 3198, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3197, 3198, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3197, 3198, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3166, 3167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3166, 3167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3166, 3167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { 3166, 3167, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 172, 174, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 272, 273, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 272, 273, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3195, 3196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 253, 254, 6 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3195, 3196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 172, 174, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3195, 3196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3195, 3196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3195, 3196, 0 },
   { 3227, 3196, 0 },
   { 3228, 3198, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 253, 254, 6 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3195, 3196, 0 },
   { 3227, 3196, 0 },
   { 3228, 3198, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 172, 174, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3195, 3196, 0 },
   { 3227, 3196, 0 },
   { 3228, 3198, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 246, 247, 0 },
   { 258, 259, 6 },
   { 264, 266, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3195, 3196, 0 },
   { 3227, 3196, 0 },
   { 3228, 3198, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3168, 373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 253, 254, 6 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3168, 373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 166, 137, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3168, 373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { 218, 219, 6 },
   { 220, 219, 0 },
   { 221, 222, 0 },
   { 373, 273, 27 },
   { 703, 273, 30 },
   { 3168, 373, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1454, 37 },
   { 2855, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1454, 37 },
   { 1467, 202, 0 },
   { 2855, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1462, 1464, 0 },
   { 202, 1454, 37 },
   { 2855, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1466, 1465, 0 },
   { 202, 1454, 37 },
   { 2855, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2432, 1207, 0 },
   { 2456, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1139, 1140, 0 },
   { 2456, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1060, 1061, 0 },
   { 2432, 1207, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1182, 1183, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1139, 1140, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1139, 1140, 0 },
   { 1158, 1160, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1071, 1010, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { 5077, 5080, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1174, 1080, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1193, 1183, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 1004, 0 },
   { 2425, 1001, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2418, 1001, 0 },
   { 2426, 1004, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2415, 1010, 0 },
   { 2423, 1007, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2416, 1007, 0 },
   { 2424, 1010, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1046, 1047, 0 },
   { 2432, 1207, 0 },
   { 2456, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1139, 1140, 0 },
   { 2432, 1207, 0 },
   { 2456, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1112, 1111, 0 },
   { 1343, 1111, 0 },
   { 1347, 1111, 0 },
   { 1351, 1111, 0 },
   { 2456, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2456, 1185, 0 },
   { 4563, 4565, 104 },
   { 4580, 4565, 104 },
   { 4588, 4589, 0 },
   { 4602, 4604, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1120, 670, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2203, 1032, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2197, 2198, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1052, 1053, 0 },
   { 1120, 670, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1202, 1203, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1189, 1190, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1065, 1067, 0 },
   { 1075, 1076, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { 5101, 5106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2203, 1032, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1200, 1201, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2197, 2198, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1050, 1051, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1043, 1033, 0 },
   { 1120, 670, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1188, 1032, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1135, 1136, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1135, 1136, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1120, 670, 0 },
   { 1135, 1136, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1135, 1136, 0 },
   { 2203, 1032, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1135, 1136, 0 },
   { 2197, 2198, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1135, 1136, 0 },
   { 1144, 1147, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { 5093, 5096, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2199, 1033, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2199, 1033, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1120, 670, 0 },
   { 2199, 1033, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2199, 1033, 0 },
   { 2203, 1032, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2197, 2198, 0 },
   { 2199, 1033, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1198, 1199, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2204, 1032, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2204, 1032, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1120, 670, 0 },
   { 2204, 1032, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2203, 1032, 0 },
   { 2204, 1032, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2197, 2198, 0 },
   { 2204, 1032, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { 4570, 4571, 104 },
   { 4577, 4578, 104 },
   { 4583, 4571, 104 },
   { 4587, 4578, 104 },
   { 4594, 4595, 0 },
   { 4599, 4600, 0 },
   { 4609, 4610, 0 },
   { 4615, 4616, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1121, 1122, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2201, 1185, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2205, 2206, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1056, 1057, 0 },
   { 1121, 1122, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1206, 1207, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1186, 1187, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { 5111, 5114, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1079, 1080, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2201, 1185, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1196, 1197, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2205, 2206, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1054, 1055, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1044, 1045, 0 },
   { 1121, 1122, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1184, 1185, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1137, 1138, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1137, 1138, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1121, 1122, 0 },
   { 1137, 1138, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1137, 1138, 0 },
   { 2201, 1185, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1137, 1138, 0 },
   { 2205, 2206, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1137, 1138, 0 },
   { 1153, 1154, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1070, 1001, 0 },
   { 1074, 1057, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { 5107, 5110, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2207, 1045, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2207, 1045, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1121, 1122, 0 },
   { 2207, 1045, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2201, 1185, 0 },
   { 2207, 1045, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2205, 2206, 0 },
   { 2207, 1045, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1194, 1195, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2202, 1185, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2202, 1185, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1121, 1122, 0 },
   { 2202, 1185, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2201, 1185, 0 },
   { 2202, 1185, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2202, 1185, 0 },
   { 2205, 2206, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { 4568, 4569, 104 },
   { 4574, 4576, 104 },
   { 4582, 4569, 104 },
   { 4586, 4576, 104 },
   { 4592, 4593, 0 },
   { 4597, 4598, 0 },
   { 4607, 4608, 0 },
   { 4612, 4614, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2431, 1203, 0 },
   { 2457, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1141, 1142, 0 },
   { 2457, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1058, 1059, 0 },
   { 2431, 1203, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1180, 1181, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1141, 1142, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1141, 1142, 0 },
   { 1166, 1167, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1072, 1007, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { 5081, 5084, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1175, 715, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1192, 1181, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2421, 1004, 0 },
   { 2429, 1001, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2422, 1001, 0 },
   { 2430, 1004, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2419, 1010, 0 },
   { 2427, 1007, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2420, 1007, 0 },
   { 2428, 1010, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1048, 1049, 0 },
   { 2431, 1203, 0 },
   { 2457, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1141, 1142, 0 },
   { 2431, 1203, 0 },
   { 2457, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1101, 1100, 0 },
   { 1344, 1328, 0 },
   { 1348, 1328, 0 },
   { 1352, 1328, 0 },
   { 2457, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2457, 1032, 0 },
   { 4566, 4567, 104 },
   { 4581, 4567, 104 },
   { 4590, 4591, 0 },
   { 4605, 4606, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1444, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1444, 32, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1508, 1509, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1222, 1225, 0 },
   { 1268, 32, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1454, 202, 35 },
   { 1458, 1459, 35 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1444, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1439, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1444, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1444, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1218, 1216, 0 },
   { 1268, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1448, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1448, 103, 0 },
   { 1452, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1506, 1507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1456, 202, 35 },
   { 1461, 1459, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1448, 103, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { 1448, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1212, 1213, 0 },
   { 1269, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 101, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5434, 5437, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2071, 6, 0 },
   { 2097, 11, 0 },
   { 2123, 16, 0 },
   { 2148, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 106, 0 },
   { 2853, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 107, 106, 0 },
   { 2853, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2853, 32, 0 },
   { 5438, 5441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 112, 0 },
   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2743, 1181, 0 },
   { 111, 112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2743, 1181, 0 },
   { 2818, 112, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2743, 1181, 0 },
   { 2811, 11, 0 },
   { 2813, 16, 0 },
   { 3763, 715, 0 },
   { 3767, 6, 0 },
   { 2811, 11, 0 },
   { 2813, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2743, 1181, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2739, 2740, 0 },
   { 2741, 2742, 0 },
   { 2743, 1181, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1440, 1441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1440, 1441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 3601, 3599, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1440, 1441, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { 1440, 1441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1440, 1441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1451, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1449, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1284, 1285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1451, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1449, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 3603, 3599, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1284, 1285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1449, 106, 0 },
   { 1451, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1284, 1285, 0 },
   { 1451, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1284, 1285, 0 },
   { 1449, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1723, 11, 0 },
   { 1830, 16, 0 },
   { 1913, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3774, 2802, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2814, 2815, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1721, 11, 0 },
   { 1828, 16, 0 },
   { 1911, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1749, 1750, 0 },
   { 1772, 1773, 0 },
   { 1856, 1857, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1937, 1938, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1725, 11, 0 },
   { 1832, 16, 0 },
   { 1915, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3773, 2802, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2816, 2817, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1724, 11, 0 },
   { 1831, 16, 0 },
   { 1914, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1747, 1748, 0 },
   { 1770, 1771, 0 },
   { 1854, 1855, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1935, 1936, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1752, 1753, 0 },
   { 1775, 1753, 0 },
   { 1858, 1751, 0 },
   { 3789, 11, 0 },
   { 3790, 16, 0 },
   { 3791, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1744, 1341, 0 },
   { 1767, 1341, 0 },
   { 1851, 1345, 0 },
   { 3772, 1465, 0 },
   { 3789, 11, 0 },
   { 3790, 16, 0 },
   { 3791, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3789, 11, 0 },
   { 3790, 16, 0 },
   { 3791, 21, 0 },
   { 5484, 5486, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3789, 11, 0 },
   { 3790, 16, 0 },
   { 3791, 21, 0 },
   { 5468, 5470, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3789, 11, 0 },
   { 3790, 16, 0 },
   { 3791, 21, 0 },
   { 5455, 5456, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1755, 1756, 0 },
   { 1777, 1756, 0 },
   { 1859, 1754, 0 },
   { 3789, 11, 0 },
   { 3790, 16, 0 },
   { 3791, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1739, 11, 0 },
   { 1762, 11, 0 },
   { 1846, 16, 0 },
   { 2845, 16, 0 },
   { 3789, 11, 0 },
   { 3790, 16, 0 },
   { 3791, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2838, 16, 0 },
   { 3789, 11, 0 },
   { 3790, 16, 0 },
   { 3791, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2843, 1931, 0 },
   { 3789, 11, 0 },
   { 3790, 16, 0 },
   { 3791, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2844, 1928, 0 },
   { 3789, 11, 0 },
   { 3790, 16, 0 },
   { 3791, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1929, 1930, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2832, 1341, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5487, 5489, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5471, 5473, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5457, 5459, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1932, 1933, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2821, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2820, 1207, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5442, 5445, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1006, 1007, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2466, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1000, 1001, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1003, 1004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1009, 1010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1012, 1013, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1015, 1016, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1018, 1019, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1021, 1022, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1024, 1025, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1027, 1028, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 447, 448, 14 },
   { 522, 523, 16 },
   { 588, 589, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 447, 448, 14 },
   { 522, 523, 16 },
   { 588, 589, 18 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 524, 526, 16 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 524, 526, 16 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 279, 281, 0 },
   { 447, 448, 14 },
   { 451, 453, 14 },
   { 522, 523, 16 },
   { 524, 526, 16 },
   { 588, 589, 18 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 447, 448, 14 },
   { 461, 464, 14 },
   { 522, 523, 16 },
   { 533, 535, 16 },
   { 588, 589, 18 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 447, 448, 14 },
   { 522, 523, 16 },
   { 588, 589, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 447, 448, 14 },
   { 522, 523, 16 },
   { 588, 589, 18 },
   { 666, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 524, 526, 16 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 277, 249, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 524, 526, 16 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 279, 281, 0 },
   { 447, 448, 14 },
   { 451, 453, 14 },
   { 522, 523, 16 },
   { 524, 526, 16 },
   { 588, 589, 18 },
   { 592, 594, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 277, 249, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 277, 249, 0 },
   { 447, 448, 14 },
   { 461, 464, 14 },
   { 522, 523, 16 },
   { 533, 535, 16 },
   { 588, 589, 18 },
   { 602, 605, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 457, 459, 14 },
   { 524, 526, 16 },
   { 529, 531, 16 },
   { 592, 594, 18 },
   { 598, 600, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 279, 281, 0 },
   { 451, 453, 14 },
   { 457, 459, 14 },
   { 524, 526, 16 },
   { 529, 531, 16 },
   { 592, 594, 18 },
   { 598, 600, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 279, 281, 0 },
   { 447, 448, 14 },
   { 451, 453, 14 },
   { 457, 459, 14 },
   { 522, 523, 16 },
   { 524, 526, 16 },
   { 529, 531, 16 },
   { 588, 589, 18 },
   { 592, 594, 18 },
   { 598, 600, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { 662, 664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 274, 0, 0 },
   { 275, 3, 0 },
   { 276, 0, 0 },
   { 461, 464, 14 },
   { 533, 535, 16 },
   { 602, 605, 18 },
   { 662, 664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 276, 0, 0 },
   { 447, 448, 14 },
   { 461, 464, 14 },
   { 522, 523, 16 },
   { 533, 535, 16 },
   { 588, 589, 18 },
   { 602, 605, 18 },
   { 662, 664, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1170, 1171, 0 },
   { 2449, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1170, 1171, 0 },
   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1358, 1359, 0 },
   { 1363, 1362, 0 },
   { 1380, 1381, 0 },
   { 1385, 1384, 0 },
   { 1402, 1403, 0 },
   { 1407, 1406, 0 },
   { 1422, 1423, 0 },
   { 1427, 1426, 0 },
   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { 5085, 5088, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1178, 1080, 0 },
   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1366, 1359, 0 },
   { 1368, 1362, 0 },
   { 1388, 1381, 0 },
   { 1390, 1384, 0 },
   { 1410, 1403, 0 },
   { 1411, 1406, 0 },
   { 1430, 1423, 0 },
   { 1432, 1426, 0 },
   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1371, 1359, 0 },
   { 1373, 1362, 0 },
   { 1393, 1381, 0 },
   { 1395, 1384, 0 },
   { 1414, 1403, 0 },
   { 1415, 1406, 0 },
   { 1435, 1423, 0 },
   { 1437, 1426, 0 },
   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { 3926, 3931, 103 },
   { 3973, 3978, 103 },
   { 4019, 4024, 103 },
   { 4086, 4091, 104 },
   { 4137, 4142, 104 },
   { 4215, 4220, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { 4269, 4272, 103 },
   { 4309, 4313, 103 },
   { 4351, 4356, 103 },
   { 4415, 4420, 104 },
   { 4460, 4465, 104 },
   { 4532, 4537, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { 3480, 3477, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { 3476, 3477, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1326, 1111, 0 },
   { 1331, 1111, 0 },
   { 1335, 1111, 0 },
   { 1339, 1111, 0 },
   { 2449, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { 3908, 3910, 103 },
   { 3965, 3910, 103 },
   { 4010, 3910, 103 },
   { 4057, 4058, 104 },
   { 4071, 4073, 104 },
   { 4122, 4058, 104 },
   { 4130, 4073, 104 },
   { 4174, 4175, 0 },
   { 4187, 4188, 0 },
   { 4200, 4202, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { 4253, 4255, 103 },
   { 4301, 4255, 103 },
   { 4343, 4255, 103 },
   { 4387, 4388, 104 },
   { 4400, 4402, 104 },
   { 4445, 4388, 104 },
   { 4453, 4402, 104 },
   { 4492, 4493, 0 },
   { 4505, 4506, 0 },
   { 4517, 4519, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1172, 1173, 0 },
   { 2450, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1172, 1173, 0 },
   { 2450, 1032, 0 },
   { 2745, 1080, 0 },
   { 2746, 715, 0 },
   { 2890, 1185, 0 },
   { 3416, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1360, 1359, 0 },
   { 1361, 1362, 0 },
   { 1382, 1381, 0 },
   { 1383, 1384, 0 },
   { 1404, 1403, 0 },
   { 1405, 1406, 0 },
   { 1424, 1423, 0 },
   { 1425, 1426, 0 },
   { 2450, 1032, 0 },
   { 2745, 1080, 0 },
   { 2746, 715, 0 },
   { 2890, 1185, 0 },
   { 3416, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2450, 1032, 0 },
   { 2745, 1080, 0 },
   { 2746, 715, 0 },
   { 2890, 1185, 0 },
   { 3416, 3418, 73 },
   { 5089, 5092, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1179, 715, 0 },
   { 2450, 1032, 0 },
   { 2745, 1080, 0 },
   { 2746, 715, 0 },
   { 2890, 1185, 0 },
   { 3416, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1365, 1362, 0 },
   { 1369, 1359, 0 },
   { 1387, 1384, 0 },
   { 1391, 1381, 0 },
   { 1409, 1406, 0 },
   { 1412, 1403, 0 },
   { 1429, 1426, 0 },
   { 1433, 1423, 0 },
   { 2450, 1032, 0 },
   { 2745, 1080, 0 },
   { 2746, 715, 0 },
   { 2890, 1185, 0 },
   { 3416, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1370, 1362, 0 },
   { 1374, 1359, 0 },
   { 1392, 1384, 0 },
   { 1396, 1381, 0 },
   { 1413, 1406, 0 },
   { 1416, 1403, 0 },
   { 1434, 1426, 0 },
   { 1438, 1423, 0 },
   { 2450, 1032, 0 },
   { 2745, 1080, 0 },
   { 2746, 715, 0 },
   { 2890, 1185, 0 },
   { 3416, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2450, 1032, 0 },
   { 2745, 1080, 0 },
   { 2746, 715, 0 },
   { 2890, 1185, 0 },
   { 3416, 3418, 73 },
   { 3932, 3935, 103 },
   { 3979, 3982, 103 },
   { 4025, 4028, 103 },
   { 4092, 4095, 104 },
   { 4143, 4146, 104 },
   { 4221, 4224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2450, 1032, 0 },
   { 2745, 1080, 0 },
   { 2746, 715, 0 },
   { 2890, 1185, 0 },
   { 3416, 3418, 73 },
   { 4273, 4276, 103 },
   { 4314, 4317, 103 },
   { 4357, 4360, 103 },
   { 4421, 4424, 104 },
   { 4466, 4469, 104 },
   { 4538, 4541, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2450, 1032, 0 },
   { 2745, 1080, 0 },
   { 2746, 715, 0 },
   { 2890, 1185, 0 },
   { 3416, 3418, 73 },
   { 3479, 3475, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2450, 1032, 0 },
   { 2745, 1080, 0 },
   { 2746, 715, 0 },
   { 2890, 1185, 0 },
   { 3416, 3418, 73 },
   { 3470, 3475, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1327, 1328, 0 },
   { 1332, 1328, 0 },
   { 1336, 1328, 0 },
   { 1340, 1328, 0 },
   { 2450, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2450, 1032, 0 },
   { 3911, 3912, 103 },
   { 3966, 3912, 103 },
   { 4011, 3912, 103 },
   { 4059, 4060, 104 },
   { 4074, 4075, 104 },
   { 4123, 4060, 104 },
   { 4131, 4075, 104 },
   { 4176, 4177, 0 },
   { 4189, 4190, 0 },
   { 4203, 4204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2450, 1032, 0 },
   { 4256, 4257, 103 },
   { 4302, 4257, 103 },
   { 4344, 4257, 103 },
   { 4389, 4390, 104 },
   { 4403, 4404, 104 },
   { 4446, 4390, 104 },
   { 4454, 4404, 104 },
   { 4494, 4495, 0 },
   { 4507, 4508, 0 },
   { 4520, 4521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2235, 1032, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1032, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2216, 2217, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2235, 1032, 0 },
   { 2451, 1032, 0 },
   { 2899, 1185, 0 },
   { 3421, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2451, 1032, 0 },
   { 2899, 1185, 0 },
   { 3421, 3418, 73 },
   { 5135, 5138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1032, 0 },
   { 2451, 1032, 0 },
   { 2899, 1185, 0 },
   { 3421, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1032, 0 },
   { 2280, 2281, 0 },
   { 2451, 1032, 0 },
   { 2899, 1185, 0 },
   { 3421, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2216, 2217, 0 },
   { 2451, 1032, 0 },
   { 2899, 1185, 0 },
   { 3421, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2216, 2217, 0 },
   { 2257, 2259, 0 },
   { 2451, 1032, 0 },
   { 2899, 1185, 0 },
   { 3421, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2451, 1032, 0 },
   { 2899, 1185, 0 },
   { 3421, 3418, 73 },
   { 4283, 4288, 103 },
   { 4324, 4329, 103 },
   { 4368, 4374, 103 },
   { 4430, 4434, 104 },
   { 4476, 4481, 104 },
   { 4547, 4551, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2237, 1032, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2237, 1032, 0 },
   { 2451, 1032, 0 },
   { 2900, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2235, 1032, 0 },
   { 2237, 1032, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1032, 0 },
   { 2237, 1032, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2216, 2217, 0 },
   { 2237, 1032, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2451, 1032, 0 },
   { 2900, 1032, 0 },
   { 5131, 5134, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2218, 1040, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2218, 1040, 0 },
   { 2451, 1032, 0 },
   { 2900, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2218, 1040, 0 },
   { 2235, 1032, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2218, 1040, 0 },
   { 2228, 1032, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2216, 2217, 0 },
   { 2218, 1040, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2218, 1040, 0 },
   { 2261, 2263, 0 },
   { 2451, 1032, 0 },
   { 2900, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 1032, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 1032, 0 },
   { 2451, 1032, 0 },
   { 2900, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 1032, 0 },
   { 2235, 1032, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2228, 1032, 0 },
   { 2229, 1032, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2216, 2217, 0 },
   { 2229, 1032, 0 },
   { 2451, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2229, 1032, 0 },
   { 2282, 2283, 0 },
   { 2451, 1032, 0 },
   { 2900, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2451, 1032, 0 },
   { 2900, 1032, 0 },
   { 4277, 4282, 103 },
   { 4318, 4323, 103 },
   { 4361, 4367, 103 },
   { 4425, 4429, 104 },
   { 4470, 4475, 104 },
   { 4542, 4546, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2451, 1032, 0 },
   { 4260, 4261, 103 },
   { 4267, 4268, 103 },
   { 4304, 4261, 103 },
   { 4308, 4268, 103 },
   { 4346, 4261, 103 },
   { 4350, 4268, 103 },
   { 4393, 4394, 104 },
   { 4398, 4399, 104 },
   { 4407, 4408, 104 },
   { 4413, 4414, 104 },
   { 4448, 4394, 104 },
   { 4451, 4399, 104 },
   { 4456, 4408, 104 },
   { 4459, 4414, 104 },
   { 4498, 4499, 0 },
   { 4503, 4504, 0 },
   { 4511, 4512, 0 },
   { 4515, 4516, 0 },
   { 4524, 4525, 0 },
   { 4530, 4531, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2238, 1185, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2220, 1185, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 2231, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2238, 1185, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2452, 1185, 0 },
   { 5143, 5146, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2220, 1185, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2220, 1185, 0 },
   { 2265, 2267, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 2231, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 2231, 0 },
   { 2284, 2285, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2452, 1185, 0 },
   { 4295, 4300, 103 },
   { 4336, 4341, 103 },
   { 4381, 4386, 103 },
   { 4440, 4444, 104 },
   { 4487, 4491, 104 },
   { 4557, 4561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2239, 1185, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2238, 1185, 0 },
   { 2239, 1185, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2220, 1185, 0 },
   { 2239, 1185, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 2231, 0 },
   { 2239, 1185, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2452, 1185, 0 },
   { 5139, 5142, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2232, 2233, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2232, 2233, 0 },
   { 2238, 1185, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2220, 1185, 0 },
   { 2232, 2233, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2230, 2231, 0 },
   { 2232, 2233, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2232, 2233, 0 },
   { 2286, 2287, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1185, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1185, 0 },
   { 2238, 1185, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2220, 1185, 0 },
   { 2221, 1185, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1185, 0 },
   { 2230, 2231, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2221, 1185, 0 },
   { 2269, 2271, 0 },
   { 2452, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2452, 1185, 0 },
   { 4289, 4294, 103 },
   { 4330, 4335, 103 },
   { 4375, 4380, 103 },
   { 4435, 4439, 104 },
   { 4482, 4486, 104 },
   { 4552, 4556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2452, 1185, 0 },
   { 4258, 4259, 103 },
   { 4264, 4266, 103 },
   { 4303, 4259, 103 },
   { 4307, 4266, 103 },
   { 4345, 4259, 103 },
   { 4349, 4266, 103 },
   { 4391, 4392, 104 },
   { 4396, 4397, 104 },
   { 4405, 4406, 104 },
   { 4410, 4412, 104 },
   { 4447, 4392, 104 },
   { 4450, 4397, 104 },
   { 4455, 4406, 104 },
   { 4458, 4412, 104 },
   { 4496, 4497, 0 },
   { 4501, 4502, 0 },
   { 4509, 4510, 0 },
   { 4513, 4514, 0 },
   { 4522, 4523, 0 },
   { 4527, 4529, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3445, 3446, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3443, 2472, 0 },
   { 3445, 3446, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3779, 715, 0 },
   { 3780, 6, 0 },
   { 3781, 11, 0 },
   { 3782, 16, 0 },
   { 3783, 21, 0 },
   { 4617, 3000, 0 },
   { 4618, 3003, 0 },
   { 4620, 4478, 0 },
   { 4622, 1950, 0 },
   { 4623, 1966, 0 },
   { 4625, 4371, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1745, 1329, 0 },
   { 1768, 1329, 0 },
   { 1852, 1333, 0 },
   { 3778, 2802, 0 },
   { 3779, 715, 0 },
   { 3780, 6, 0 },
   { 3781, 11, 0 },
   { 3782, 16, 0 },
   { 3783, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3779, 715, 0 },
   { 3780, 6, 0 },
   { 3781, 11, 0 },
   { 3782, 16, 0 },
   { 3783, 21, 0 },
   { 5493, 5495, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3779, 715, 0 },
   { 3780, 6, 0 },
   { 3781, 11, 0 },
   { 3782, 16, 0 },
   { 3783, 21, 0 },
   { 5477, 5479, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3779, 715, 0 },
   { 3780, 6, 0 },
   { 3781, 11, 0 },
   { 3782, 16, 0 },
   { 3783, 21, 0 },
   { 5462, 5463, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1741, 11, 0 },
   { 1764, 11, 0 },
   { 1848, 16, 0 },
   { 3779, 715, 0 },
   { 3780, 6, 0 },
   { 3781, 11, 0 },
   { 3782, 16, 0 },
   { 3783, 21, 0 },
   { 3797, 3798, 0 },
   { 3805, 3798, 0 },
   { 3811, 3798, 0 },
   { 3817, 3798, 0 },
   { 3822, 3823, 0 },
   { 3826, 3796, 0 },
   { 3830, 3796, 0 },
   { 3834, 3796, 0 },
   { 3838, 3839, 0 },
   { 3842, 3839, 0 },
   { 3844, 3845, 0 },
   { 3848, 3804, 0 },
   { 3852, 3804, 0 },
   { 3856, 3857, 0 },
   { 3860, 3857, 0 },
   { 3862, 3863, 0 },
   { 3865, 3857, 0 },
   { 3867, 3863, 0 },
   { 3869, 1740, 0 },
   { 3871, 3810, 0 },
   { 3875, 3876, 0 },
   { 3879, 3876, 0 },
   { 3881, 3882, 0 },
   { 3885, 3876, 0 },
   { 3887, 3882, 0 },
   { 3889, 1763, 0 },
   { 3891, 3876, 0 },
   { 3893, 3882, 0 },
   { 3895, 1763, 0 },
   { 3897, 1847, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3779, 715, 0 },
   { 3780, 6, 0 },
   { 3781, 11, 0 },
   { 3782, 16, 0 },
   { 3783, 21, 0 },
   { 3800, 3801, 0 },
   { 3807, 3801, 0 },
   { 3813, 3801, 0 },
   { 3819, 3801, 0 },
   { 3827, 3799, 0 },
   { 3831, 3799, 0 },
   { 3835, 3799, 0 },
   { 3849, 3806, 0 },
   { 3853, 3806, 0 },
   { 3872, 3812, 0 },
   { 4654, 11, 0 },
   { 4707, 16, 0 },
   { 4759, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2839, 16, 0 },
   { 3779, 715, 0 },
   { 3780, 6, 0 },
   { 3781, 11, 0 },
   { 3782, 16, 0 },
   { 3783, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2841, 1942, 0 },
   { 3779, 715, 0 },
   { 3780, 6, 0 },
   { 3781, 11, 0 },
   { 3782, 16, 0 },
   { 3783, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3779, 715, 0 },
   { 3780, 6, 0 },
   { 3781, 11, 0 },
   { 3782, 16, 0 },
   { 3783, 21, 0 },
   { 3899, 3900, 0 },
   { 3899, 3900, 0 },
   { 3901, 3902, 0 },
   { 3901, 3902, 0 },
   { 3903, 3782, 0 },
   { 3903, 3782, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1746, 1329, 0 },
   { 1769, 1329, 0 },
   { 1853, 1333, 0 },
   { 3776, 2802, 0 },
   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { 5490, 5492, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { 5474, 5476, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { 5460, 5461, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2945, 2947, 55 },
   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { 3802, 3798, 0 },
   { 3808, 3798, 0 },
   { 3814, 3798, 0 },
   { 3820, 3798, 0 },
   { 3828, 3796, 0 },
   { 3832, 3796, 0 },
   { 3836, 3796, 0 },
   { 3850, 3804, 0 },
   { 3854, 3804, 0 },
   { 3873, 3810, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1743, 11, 0 },
   { 1766, 11, 0 },
   { 1850, 16, 0 },
   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { 3803, 3801, 0 },
   { 3809, 3801, 0 },
   { 3815, 3801, 0 },
   { 3821, 3801, 0 },
   { 3824, 3825, 0 },
   { 3829, 3799, 0 },
   { 3833, 3799, 0 },
   { 3837, 3799, 0 },
   { 3840, 3841, 0 },
   { 3843, 3841, 0 },
   { 3846, 3847, 0 },
   { 3851, 3806, 0 },
   { 3855, 3806, 0 },
   { 3858, 3859, 0 },
   { 3861, 3859, 0 },
   { 3864, 2975, 0 },
   { 3866, 3859, 0 },
   { 3868, 2975, 0 },
   { 3870, 1742, 0 },
   { 3874, 3812, 0 },
   { 3877, 3878, 0 },
   { 3880, 3878, 0 },
   { 3883, 3884, 0 },
   { 3886, 3878, 0 },
   { 3888, 3884, 0 },
   { 3890, 1765, 0 },
   { 3892, 3878, 0 },
   { 3894, 3884, 0 },
   { 3896, 1765, 0 },
   { 3898, 1849, 0 },
   { 4626, 11, 0 },
   { 4679, 16, 0 },
   { 4732, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2840, 16, 0 },
   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2941, 2943, 55 },
   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2842, 1939, 0 },
   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { 3904, 1966, 0 },
   { 3904, 1966, 0 },
   { 3905, 3003, 0 },
   { 3905, 3003, 0 },
   { 3906, 3787, 0 },
   { 3906, 3787, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2911, 3002, 60 },
   { 3017, 2911, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2903, 36, 0 },
   { 2911, 3002, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2919, 3003, 61 },
   { 3007, 2919, 0 },
   { 2919, 3003, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2919, 3003, 61 },
   { 3021, 2919, 0 },
   { 3022, 2921, 0 },
   { 2919, 3003, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2921, 3004, 61 },
   { 3014, 2921, 0 },
   { 2921, 3004, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3448, 3441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3450, 3441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3450, 3441, 0 },
   { 3458, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3448, 3441, 0 },
   { 3450, 3441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3451, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3452, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3452, 3438, 0 },
   { 3459, 120, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3451, 3438, 0 },
   { 3452, 3438, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3005, 3006, 0 },
   { 3006, 3596, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3020, 3013, 0 },
   { 3006, 3596, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3018, 3006, 0 },
   { 3019, 3013, 0 },
   { 3006, 3596, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3012, 3013, 0 },
   { 3013, 3597, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3454, 3455, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3457, 3455, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3454, 3455, 0 },
   { 3457, 3455, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 1032, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2209, 2210, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { 5119, 5122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 1032, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 1032, 0 },
   { 2272, 2273, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2209, 2210, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2209, 2210, 0 },
   { 2241, 2243, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { 3945, 3951, 103 },
   { 3991, 3996, 103 },
   { 4038, 4044, 103 },
   { 4104, 4109, 104 },
   { 4155, 4161, 104 },
   { 4233, 4239, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { 1426, 3414, 73 },
   { 5115, 5118, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2211, 1038, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2211, 1038, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { 3407, 3409, 72 },
   { 1426, 3414, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2211, 1038, 0 },
   { 2222, 1032, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2209, 2210, 0 },
   { 2211, 1038, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2211, 1038, 0 },
   { 2245, 2247, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { 3407, 3409, 72 },
   { 1426, 3414, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2223, 1032, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2223, 1032, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { 3402, 3405, 72 },
   { 1426, 3414, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2222, 1032, 0 },
   { 2223, 1032, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2209, 2210, 0 },
   { 2223, 1032, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2223, 1032, 0 },
   { 2274, 2275, 0 },
   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { 3402, 3405, 72 },
   { 1426, 3414, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { 1426, 3414, 73 },
   { 3936, 3943, 103 },
   { 3983, 3990, 103 },
   { 4029, 4036, 103 },
   { 4096, 4103, 104 },
   { 4147, 4154, 104 },
   { 4225, 4232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 1032, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { 3915, 3916, 103 },
   { 3924, 3925, 103 },
   { 3968, 3916, 103 },
   { 3972, 3925, 103 },
   { 4013, 3916, 103 },
   { 4017, 3925, 103 },
   { 4063, 4064, 104 },
   { 4068, 4069, 104 },
   { 4078, 4079, 104 },
   { 4084, 4085, 104 },
   { 4125, 4064, 104 },
   { 4128, 4069, 104 },
   { 4133, 4079, 104 },
   { 4136, 4085, 104 },
   { 4180, 4181, 0 },
   { 4185, 4186, 0 },
   { 4193, 4194, 0 },
   { 4197, 4198, 0 },
   { 4207, 4208, 0 },
   { 4213, 4214, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2213, 1185, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2224, 2225, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 5127, 5130, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2213, 1185, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2213, 1185, 0 },
   { 2249, 2251, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2224, 2225, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2224, 2225, 0 },
   { 2276, 2277, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 3958, 3963, 103 },
   { 4003, 4008, 103 },
   { 4051, 4056, 103 },
   { 4116, 4121, 104 },
   { 4168, 4173, 104 },
   { 4246, 4251, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 1423, 3415, 73 },
   { 5123, 5126, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2226, 2227, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2226, 2227, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 3412, 3413, 72 },
   { 1423, 3415, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2213, 1185, 0 },
   { 2226, 2227, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2224, 2225, 0 },
   { 2226, 2227, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2226, 2227, 0 },
   { 2278, 2279, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 3412, 3413, 72 },
   { 1423, 3415, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1185, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1185, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 3410, 3411, 72 },
   { 1423, 3415, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2213, 1185, 0 },
   { 2214, 1185, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1185, 0 },
   { 2224, 2225, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2214, 1185, 0 },
   { 2253, 2255, 0 },
   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 3410, 3411, 72 },
   { 1423, 3415, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 1423, 3415, 73 },
   { 3952, 3957, 103 },
   { 3997, 4002, 103 },
   { 4045, 4050, 103 },
   { 4110, 4115, 104 },
   { 4162, 4167, 104 },
   { 4240, 4245, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 3913, 3914, 103 },
   { 3921, 3923, 103 },
   { 3967, 3914, 103 },
   { 3971, 3923, 103 },
   { 4012, 3914, 103 },
   { 4016, 3923, 103 },
   { 4061, 4062, 104 },
   { 4066, 4067, 104 },
   { 4076, 4077, 104 },
   { 4081, 4083, 104 },
   { 4124, 4062, 104 },
   { 4127, 4067, 104 },
   { 4132, 4077, 104 },
   { 4135, 4083, 104 },
   { 4178, 4179, 0 },
   { 4183, 4184, 0 },
   { 4191, 4192, 0 },
   { 4195, 4196, 0 },
   { 4205, 4206, 0 },
   { 4210, 4212, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 1423, 3415, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 1423, 3415, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 1423, 3415, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3599, 3601, 92 },
   { 5446, 5449, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2350, 2355, 45 },
   { 5030, 2385, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2350, 2355, 45 },
   { 5029, 2350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2356, 2362, 45 },
   { 5036, 2389, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2356, 2362, 45 },
   { 5035, 2356, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2363, 2369, 45 },
   { 5040, 2395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2363, 2369, 45 },
   { 5039, 2363, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5045, 5046, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5043, 5044, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5053, 5054, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5051, 5052, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2834, 1329, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2824, 2825, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2835, 1329, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2826, 2827, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3775, 1465, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1757, 1758, 0 },
   { 1778, 1779, 0 },
   { 1860, 1861, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1946, 1947, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3777, 1465, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1718, 1719, 0 },
   { 1825, 1826, 0 },
   { 1908, 1909, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1759, 1760, 0 },
   { 1780, 1781, 0 },
   { 1862, 1863, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1948, 1949, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2833, 1329, 0 },
   { 2833, 1329, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5496, 5498, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5480, 5482, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5464, 5466, 109 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1943, 1944, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1940, 1941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2822, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2823, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2836, 1341, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2828, 2829, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2837, 1341, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2830, 2831, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 731, 733, 33 },
   { 743, 744, 0 },
   { 759, 760, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 731, 733, 33 },
   { 738, 740, 0 },
   { 743, 744, 0 },
   { 759, 760, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 731, 733, 33 },
   { 735, 249, 0 },
   { 738, 740, 0 },
   { 743, 744, 0 },
   { 759, 760, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 748, 740, 0 },
   { 757, 758, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 746, 249, 0 },
   { 748, 740, 0 },
   { 757, 758, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 750, 249, 0 },
   { 755, 756, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 750, 249, 0 },
   { 751, 754, 0 },
   { 755, 756, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2176, 2177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2370, 2373, 45 },
   { 5034, 2400, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2370, 2373, 45 },
   { 5033, 2370, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2374, 2379, 45 },
   { 5038, 2404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2374, 2379, 45 },
   { 5037, 2374, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2380, 2384, 45 },
   { 5042, 2410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2380, 2384, 45 },
   { 5041, 2380, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5049, 5050, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5047, 5048, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5057, 5058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5055, 5056, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1289, 1290, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1273, 61, 0 },
   { 1274, 32, 0 },
   { 1289, 1290, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1273, 61, 0 },
   { 1274, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1289, 1290, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1275, 32, 0 },
   { 1281, 1282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1275, 32, 0 },
   { 1276, 32, 0 },
   { 1277, 63, 0 },
   { 1281, 1282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2990, 2991, 0 },
   { 3526, 3529, 82 },
   { 4733, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2992, 2991, 0 },
   { 3526, 3529, 82 },
   { 4733, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3038, 3034, 0 },
   { 3526, 3529, 82 },
   { 4733, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2298, 2304, 44 },
   { 2310, 2294, 0 },
   { 2318, 2296, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2298, 2304, 44 },
   { 2311, 2296, 0 },
   { 2319, 2294, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2298, 2304, 44 },
   { 2307, 2298, 0 },
   { 2316, 2300, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2298, 2304, 44 },
   { 2309, 2300, 0 },
   { 2317, 2298, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2300, 2305, 44 },
   { 2314, 2294, 0 },
   { 2322, 2296, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2300, 2305, 44 },
   { 2315, 2296, 0 },
   { 2323, 2294, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2300, 2305, 44 },
   { 2312, 2298, 0 },
   { 2320, 2300, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2300, 2305, 44 },
   { 2313, 2300, 0 },
   { 2321, 2298, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2782, 36, 0 },
   { 3646, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2782, 36, 0 },
   { 3643, 3644, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2782, 36, 0 },
   { 3643, 3644, 101 },
   { 3646, 3647, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2782, 36, 0 },
   { 3649, 3650, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2782, 36, 0 },
   { 3652, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2782, 36, 0 },
   { 3649, 3650, 101 },
   { 3652, 3653, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2513, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2565, 2566, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2557, 2558, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2560, 2561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2563, 2564, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2548, 2550, 0 },
   { 2530, 2584, 51 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2551, 2552, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2583, 2562, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2582, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2585, 2530, 52 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2553, 2556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2511, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2514, 2517, 48 },
   { 2538, 32, 0 },
   { 2539, 236, 0 },
   { 2540, 2537, 0 },
   { 2545, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2904, 2905, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2907, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2916, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2918, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2909, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 196, 3, 0 },
   { 3216, 3217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 196, 3, 0 },
   { 3216, 3217, 0 },
   { 3258, 3217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 194, 3, 0 },
   { 196, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 194, 3, 0 },
   { 196, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 315, 316, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 316, 0 },
   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 318, 319, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 318, 319, 0 },
   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 327, 328, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 327, 328, 0 },
   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 321, 322, 0 },
   { 325, 322, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 321, 322, 0 },
   { 325, 322, 0 },
   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4640, 3692, 0 },
   { 4694, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4640, 3692, 0 },
   { 4665, 3692, 0 },
   { 4694, 3712, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4640, 3692, 0 },
   { 4663, 3692, 0 },
   { 4694, 3712, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4639, 3692, 0 },
   { 4640, 3692, 0 },
   { 4693, 3712, 0 },
   { 4694, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4637, 3692, 0 },
   { 4640, 3692, 0 },
   { 4691, 3712, 0 },
   { 4694, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4666, 3692, 0 },
   { 4719, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4665, 3692, 0 },
   { 4666, 3692, 0 },
   { 4718, 3712, 0 },
   { 4719, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4663, 3692, 0 },
   { 4666, 3692, 0 },
   { 4716, 3712, 0 },
   { 4719, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4639, 3692, 0 },
   { 4666, 3692, 0 },
   { 4693, 3712, 0 },
   { 4719, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4637, 3692, 0 },
   { 4666, 3692, 0 },
   { 4691, 3712, 0 },
   { 4719, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { 4771, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4746, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4746, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { 4746, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4665, 3692, 0 },
   { 4718, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4663, 3692, 0 },
   { 4716, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4639, 3692, 0 },
   { 4693, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 3, 0 },
   { 4637, 3692, 0 },
   { 4691, 3712, 0 },
   { 4743, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4663, 3692, 0 },
   { 4665, 3692, 0 },
   { 4716, 3712, 0 },
   { 4718, 3712, 0 },
   { 4768, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4639, 3692, 0 },
   { 4665, 3692, 0 },
   { 4693, 3712, 0 },
   { 4718, 3712, 0 },
   { 4745, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4637, 3692, 0 },
   { 4665, 3692, 0 },
   { 4691, 3712, 0 },
   { 4718, 3712, 0 },
   { 4743, 3712, 0 },
   { 4770, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4639, 3692, 0 },
   { 4663, 3692, 0 },
   { 4693, 3712, 0 },
   { 4716, 3712, 0 },
   { 4745, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4637, 3692, 0 },
   { 4663, 3692, 0 },
   { 4691, 3712, 0 },
   { 4716, 3712, 0 },
   { 4743, 3712, 0 },
   { 4768, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4637, 3692, 0 },
   { 4639, 3692, 0 },
   { 4691, 3712, 0 },
   { 4693, 3712, 0 },
   { 4743, 3712, 0 },
   { 4745, 3712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3031, 3032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4668, 4642, 0 },
   { 4721, 49, 0 },
   { 4773, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4667, 4642, 0 },
   { 4720, 49, 0 },
   { 4772, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4643, 4642, 0 },
   { 4696, 49, 0 },
   { 4748, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 4642, 0 },
   { 4695, 49, 0 },
   { 4747, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 987, 991, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 979, 982, 0 },
   { 987, 991, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4668, 4642, 0 },
   { 4721, 49, 0 },
   { 4773, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4667, 4642, 0 },
   { 4720, 49, 0 },
   { 4772, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4643, 4642, 0 },
   { 4696, 49, 0 },
   { 4748, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 223, 61, 0 },
   { 231, 32, 0 },
   { 234, 100, 0 },
   { 4641, 4642, 0 },
   { 4695, 49, 0 },
   { 4747, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 3170, 0 },
   { 4668, 4642, 0 },
   { 4721, 49, 0 },
   { 4773, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 3170, 0 },
   { 4667, 4642, 0 },
   { 4720, 49, 0 },
   { 4772, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 3170, 0 },
   { 4643, 4642, 0 },
   { 4696, 49, 0 },
   { 4748, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 3170, 0 },
   { 4641, 4642, 0 },
   { 4695, 49, 0 },
   { 4747, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4644, 4642, 0 },
   { 4668, 4642, 0 },
   { 4697, 49, 0 },
   { 4721, 49, 0 },
   { 4773, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4644, 4642, 0 },
   { 4667, 4642, 0 },
   { 4697, 49, 0 },
   { 4720, 49, 0 },
   { 4772, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4643, 4642, 0 },
   { 4644, 4642, 0 },
   { 4696, 49, 0 },
   { 4697, 49, 0 },
   { 4748, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 4642, 0 },
   { 4644, 4642, 0 },
   { 4695, 49, 0 },
   { 4697, 49, 0 },
   { 4747, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4668, 4642, 0 },
   { 4669, 4642, 0 },
   { 4721, 49, 0 },
   { 4722, 49, 0 },
   { 4773, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4667, 4642, 0 },
   { 4669, 4642, 0 },
   { 4720, 49, 0 },
   { 4722, 49, 0 },
   { 4772, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4643, 4642, 0 },
   { 4669, 4642, 0 },
   { 4696, 49, 0 },
   { 4722, 49, 0 },
   { 4748, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 4642, 0 },
   { 4669, 4642, 0 },
   { 4695, 49, 0 },
   { 4722, 49, 0 },
   { 4747, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4668, 4642, 0 },
   { 4721, 49, 0 },
   { 4773, 49, 0 },
   { 4774, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4667, 4642, 0 },
   { 4720, 49, 0 },
   { 4772, 49, 0 },
   { 4774, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4643, 4642, 0 },
   { 4696, 49, 0 },
   { 4748, 49, 0 },
   { 4774, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 4642, 0 },
   { 4695, 49, 0 },
   { 4747, 49, 0 },
   { 4774, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4668, 4642, 0 },
   { 4721, 49, 0 },
   { 4749, 49, 0 },
   { 4773, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4667, 4642, 0 },
   { 4720, 49, 0 },
   { 4749, 49, 0 },
   { 4772, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4643, 4642, 0 },
   { 4696, 49, 0 },
   { 4748, 49, 0 },
   { 4749, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 4642, 0 },
   { 4695, 49, 0 },
   { 4747, 49, 0 },
   { 4749, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4667, 4642, 0 },
   { 4668, 4642, 0 },
   { 4720, 49, 0 },
   { 4721, 49, 0 },
   { 4772, 49, 0 },
   { 4773, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4643, 4642, 0 },
   { 4668, 4642, 0 },
   { 4696, 49, 0 },
   { 4721, 49, 0 },
   { 4748, 49, 0 },
   { 4773, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 4642, 0 },
   { 4668, 4642, 0 },
   { 4695, 49, 0 },
   { 4721, 49, 0 },
   { 4747, 49, 0 },
   { 4773, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4643, 4642, 0 },
   { 4667, 4642, 0 },
   { 4696, 49, 0 },
   { 4720, 49, 0 },
   { 4748, 49, 0 },
   { 4772, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 4642, 0 },
   { 4667, 4642, 0 },
   { 4695, 49, 0 },
   { 4720, 49, 0 },
   { 4747, 49, 0 },
   { 4772, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4641, 4642, 0 },
   { 4643, 4642, 0 },
   { 4695, 49, 0 },
   { 4696, 49, 0 },
   { 4747, 49, 0 },
   { 4748, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2479, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 865, 868, 0 },
   { 873, 876, 0 },
   { 881, 884, 0 },
   { 889, 892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 869, 868, 0 },
   { 877, 876, 0 },
   { 885, 884, 0 },
   { 893, 892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 993, 996, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 771, 775, 0 },
   { 975, 977, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 975, 977, 0 },
   { 993, 996, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2480, 32, 0 },
   { 3025, 3027, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2483, 1177, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 870, 872, 0 },
   { 878, 880, 0 },
   { 886, 888, 0 },
   { 894, 896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { 3028, 3024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1105, 1104, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1109, 1108, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1060, 1061, 0 },
   { 1162, 1165, 0 },
   { 2432, 1207, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1103, 1104, 0 },
   { 1139, 1140, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1107, 1108, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1106, 1104, 0 },
   { 2432, 1207, 0 },
   { 2456, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1046, 1047, 0 },
   { 1113, 1111, 0 },
   { 2432, 1207, 0 },
   { 2456, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1090, 1087, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1097, 1095, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1058, 1059, 0 },
   { 1168, 1169, 0 },
   { 2431, 1203, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1086, 1087, 0 },
   { 1141, 1142, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1094, 1095, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1092, 1087, 0 },
   { 2431, 1203, 0 },
   { 2457, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1048, 1049, 0 },
   { 1102, 1100, 0 },
   { 2431, 1203, 0 },
   { 2457, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 369, 254, 9 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { 5152, 5155, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 240, 238, 0 },
   { 3174, 3176, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 240, 238, 0 },
   { 3174, 3176, 0 },
   { 3219, 3176, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3161, 3162, 0 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 238, 0 },
   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 364, 365, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 364, 365, 9 },
   { 369, 254, 9 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { 369, 254, 9 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 500, 501, 0 },
   { 568, 569, 0 },
   { 640, 641, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 500, 501, 0 },
   { 568, 569, 0 },
   { 640, 641, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 500, 501, 0 },
   { 568, 569, 0 },
   { 640, 641, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 372, 373, 9 },
   { 500, 501, 0 },
   { 568, 569, 0 },
   { 640, 641, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 505, 506, 0 },
   { 572, 573, 0 },
   { 644, 645, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 505, 506, 0 },
   { 572, 573, 0 },
   { 644, 645, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 505, 506, 0 },
   { 572, 573, 0 },
   { 644, 645, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 505, 506, 0 },
   { 572, 573, 0 },
   { 644, 645, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 500, 501, 0 },
   { 505, 506, 0 },
   { 568, 569, 0 },
   { 572, 573, 0 },
   { 640, 641, 0 },
   { 644, 645, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 511, 513, 0 },
   { 577, 579, 0 },
   { 650, 652, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 370, 371, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 370, 371, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 370, 371, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 370, 371, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 370, 371, 9 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 0 },
   { 250, 251, 5 },
   { 252, 212, 6 },
   { 370, 371, 9 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 370, 371, 9 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 141, 143, 0 },
   { 370, 371, 9 },
   { 372, 373, 9 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4674, 2006, 0 },
   { 4727, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4673, 2006, 0 },
   { 4726, 2010, 0 },
   { 4778, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4649, 2006, 0 },
   { 4702, 2010, 0 },
   { 4754, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4701, 2010, 0 },
   { 4753, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { 4674, 2006, 0 },
   { 4727, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { 4673, 2006, 0 },
   { 4726, 2010, 0 },
   { 4778, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { 4649, 2006, 0 },
   { 4702, 2010, 0 },
   { 4754, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2462, 32, 0 },
   { 2463, 1185, 0 },
   { 4648, 2006, 0 },
   { 4701, 2010, 0 },
   { 4753, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2492, 2489, 46 },
   { 2499, 2496, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { 4674, 2006, 0 },
   { 4727, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { 4673, 2006, 0 },
   { 4726, 2010, 0 },
   { 4778, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { 4649, 2006, 0 },
   { 4702, 2010, 0 },
   { 4754, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { 4648, 2006, 0 },
   { 4701, 2010, 0 },
   { 4753, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { 4674, 2006, 0 },
   { 4727, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { 4673, 2006, 0 },
   { 4726, 2010, 0 },
   { 4778, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { 4649, 2006, 0 },
   { 4702, 2010, 0 },
   { 4754, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { 4648, 2006, 0 },
   { 4701, 2010, 0 },
   { 4753, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2504, 2502, 46 },
   { 2509, 2507, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { 4674, 2006, 0 },
   { 4727, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { 4673, 2006, 0 },
   { 4726, 2010, 0 },
   { 4778, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { 4649, 2006, 0 },
   { 4702, 2010, 0 },
   { 4754, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2171, 63, 0 },
   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4701, 2010, 0 },
   { 4753, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1653, 1656, 0 },
   { 1660, 1656, 0 },
   { 1665, 1668, 0 },
   { 1672, 1668, 0 },
   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4674, 2006, 0 },
   { 4727, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4673, 2006, 0 },
   { 4726, 2010, 0 },
   { 4778, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4649, 2006, 0 },
   { 4702, 2010, 0 },
   { 4754, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4701, 2010, 0 },
   { 4753, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { 4674, 2006, 0 },
   { 4727, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { 4673, 2006, 0 },
   { 4726, 2010, 0 },
   { 4778, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { 4649, 2006, 0 },
   { 4702, 2010, 0 },
   { 4754, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2169, 1185, 0 },
   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4701, 2010, 0 },
   { 4753, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4650, 2006, 0 },
   { 4674, 2006, 0 },
   { 4703, 2010, 0 },
   { 4727, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4650, 2006, 0 },
   { 4673, 2006, 0 },
   { 4703, 2010, 0 },
   { 4726, 2010, 0 },
   { 4778, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4649, 2006, 0 },
   { 4650, 2006, 0 },
   { 4702, 2010, 0 },
   { 4703, 2010, 0 },
   { 4754, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4650, 2006, 0 },
   { 4701, 2010, 0 },
   { 4703, 2010, 0 },
   { 4753, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4674, 2006, 0 },
   { 4675, 2006, 0 },
   { 4727, 2010, 0 },
   { 4728, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4673, 2006, 0 },
   { 4675, 2006, 0 },
   { 4726, 2010, 0 },
   { 4728, 2010, 0 },
   { 4778, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4649, 2006, 0 },
   { 4675, 2006, 0 },
   { 4702, 2010, 0 },
   { 4728, 2010, 0 },
   { 4754, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4675, 2006, 0 },
   { 4701, 2010, 0 },
   { 4728, 2010, 0 },
   { 4753, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4674, 2006, 0 },
   { 4727, 2010, 0 },
   { 4779, 2010, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4673, 2006, 0 },
   { 4726, 2010, 0 },
   { 4778, 2010, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4649, 2006, 0 },
   { 4702, 2010, 0 },
   { 4754, 2010, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4701, 2010, 0 },
   { 4753, 2010, 0 },
   { 4780, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4674, 2006, 0 },
   { 4727, 2010, 0 },
   { 4755, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4673, 2006, 0 },
   { 4726, 2010, 0 },
   { 4755, 2010, 0 },
   { 4778, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4649, 2006, 0 },
   { 4702, 2010, 0 },
   { 4754, 2010, 0 },
   { 4755, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4701, 2010, 0 },
   { 4753, 2010, 0 },
   { 4755, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2492, 2489, 46 },
   { 2499, 2496, 46 },
   { 2504, 2502, 46 },
   { 2509, 2507, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4649, 2006, 0 },
   { 4702, 2010, 0 },
   { 4754, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4701, 2010, 0 },
   { 4753, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2793, 2794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4673, 2006, 0 },
   { 4674, 2006, 0 },
   { 4726, 2010, 0 },
   { 4727, 2010, 0 },
   { 4778, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4649, 2006, 0 },
   { 4674, 2006, 0 },
   { 4702, 2010, 0 },
   { 4727, 2010, 0 },
   { 4754, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4674, 2006, 0 },
   { 4701, 2010, 0 },
   { 4727, 2010, 0 },
   { 4753, 2010, 0 },
   { 4779, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4649, 2006, 0 },
   { 4673, 2006, 0 },
   { 4702, 2010, 0 },
   { 4726, 2010, 0 },
   { 4754, 2010, 0 },
   { 4778, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4673, 2006, 0 },
   { 4701, 2010, 0 },
   { 4726, 2010, 0 },
   { 4753, 2010, 0 },
   { 4778, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4649, 2006, 0 },
   { 4701, 2010, 0 },
   { 4702, 2010, 0 },
   { 4753, 2010, 0 },
   { 4754, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4648, 2006, 0 },
   { 4701, 2010, 0 },
   { 4753, 2010, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 3033, 3032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3748, 3749, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3754, 3755, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3760, 3761, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3743, 3746, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3751, 3752, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3757, 3758, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4671, 1964, 0 },
   { 4724, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4670, 1964, 0 },
   { 4723, 1972, 0 },
   { 4775, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4646, 1964, 0 },
   { 4699, 1972, 0 },
   { 4751, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4645, 1964, 0 },
   { 4698, 1972, 0 },
   { 4750, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2470, 3, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2470, 3, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2804, 1465, 0 },
   { 2805, 2802, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { 4671, 1964, 0 },
   { 4724, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { 4670, 1964, 0 },
   { 4723, 1972, 0 },
   { 4775, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { 4646, 1964, 0 },
   { 4699, 1972, 0 },
   { 4751, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1953, 1956, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { 4645, 1964, 0 },
   { 4698, 1972, 0 },
   { 4750, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 2471, 2472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { 2471, 2472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2471, 2472, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2471, 2472, 0 },
   { 4671, 1964, 0 },
   { 4724, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2471, 2472, 0 },
   { 4670, 1964, 0 },
   { 4723, 1972, 0 },
   { 4775, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2471, 2472, 0 },
   { 4646, 1964, 0 },
   { 4699, 1972, 0 },
   { 4751, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2471, 2472, 0 },
   { 4645, 1964, 0 },
   { 4698, 1972, 0 },
   { 4750, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 184, 0 },
   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4671, 1964, 0 },
   { 4724, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4670, 1964, 0 },
   { 4723, 1972, 0 },
   { 4775, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4646, 1964, 0 },
   { 4699, 1972, 0 },
   { 4751, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4645, 1964, 0 },
   { 4698, 1972, 0 },
   { 4750, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { 2475, 2476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2055, 2057, 40 },
   { 2055, 2063, 42 },
   { 2081, 2083, 40 },
   { 2081, 2089, 42 },
   { 2107, 2109, 40 },
   { 2107, 2115, 42 },
   { 2132, 2134, 40 },
   { 2132, 2140, 42 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1037, 1032, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4647, 1964, 0 },
   { 4700, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { 4647, 1964, 0 },
   { 4700, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4647, 1964, 0 },
   { 4700, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4647, 1964, 0 },
   { 4671, 1964, 0 },
   { 4700, 1972, 0 },
   { 4724, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4647, 1964, 0 },
   { 4670, 1964, 0 },
   { 4700, 1972, 0 },
   { 4723, 1972, 0 },
   { 4775, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4646, 1964, 0 },
   { 4647, 1964, 0 },
   { 4699, 1972, 0 },
   { 4700, 1972, 0 },
   { 4751, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4645, 1964, 0 },
   { 4647, 1964, 0 },
   { 4698, 1972, 0 },
   { 4700, 1972, 0 },
   { 4750, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4672, 1964, 0 },
   { 4725, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { 4672, 1964, 0 },
   { 4725, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4672, 1964, 0 },
   { 4725, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4671, 1964, 0 },
   { 4672, 1964, 0 },
   { 4724, 1972, 0 },
   { 4725, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4670, 1964, 0 },
   { 4672, 1964, 0 },
   { 4723, 1972, 0 },
   { 4725, 1972, 0 },
   { 4775, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4646, 1964, 0 },
   { 4672, 1964, 0 },
   { 4699, 1972, 0 },
   { 4725, 1972, 0 },
   { 4751, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4645, 1964, 0 },
   { 4672, 1964, 0 },
   { 4698, 1972, 0 },
   { 4725, 1972, 0 },
   { 4750, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4671, 1964, 0 },
   { 4724, 1972, 0 },
   { 4776, 1972, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4670, 1964, 0 },
   { 4723, 1972, 0 },
   { 4775, 1972, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4646, 1964, 0 },
   { 4699, 1972, 0 },
   { 4751, 1972, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4645, 1964, 0 },
   { 4698, 1972, 0 },
   { 4750, 1972, 0 },
   { 4777, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4752, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { 4752, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4752, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4671, 1964, 0 },
   { 4724, 1972, 0 },
   { 4752, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4670, 1964, 0 },
   { 4723, 1972, 0 },
   { 4752, 1972, 0 },
   { 4775, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4646, 1964, 0 },
   { 4699, 1972, 0 },
   { 4751, 1972, 0 },
   { 4752, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4645, 1964, 0 },
   { 4698, 1972, 0 },
   { 4750, 1972, 0 },
   { 4752, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4671, 1964, 0 },
   { 4724, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4670, 1964, 0 },
   { 4723, 1972, 0 },
   { 4775, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4646, 1964, 0 },
   { 4699, 1972, 0 },
   { 4751, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2470, 3, 0 },
   { 4645, 1964, 0 },
   { 4698, 1972, 0 },
   { 4750, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 2791, 2792, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { 4671, 1964, 0 },
   { 4724, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { 4670, 1964, 0 },
   { 4723, 1972, 0 },
   { 4775, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { 4646, 1964, 0 },
   { 4699, 1972, 0 },
   { 4751, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1355, 1356, 0 },
   { 1377, 1378, 0 },
   { 1399, 1400, 0 },
   { 1419, 1420, 0 },
   { 2458, 32, 0 },
   { 4645, 1964, 0 },
   { 4698, 1972, 0 },
   { 4750, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4671, 1964, 0 },
   { 4724, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4670, 1964, 0 },
   { 4723, 1972, 0 },
   { 4775, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4646, 1964, 0 },
   { 4699, 1972, 0 },
   { 4751, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4645, 1964, 0 },
   { 4698, 1972, 0 },
   { 4750, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2055, 2057, 40 },
   { 2055, 2063, 42 },
   { 2081, 2083, 40 },
   { 2081, 2089, 42 },
   { 2107, 2109, 40 },
   { 2107, 2115, 42 },
   { 2132, 2134, 40 },
   { 2132, 2140, 42 },
   { 2458, 32, 0 },
   { 2924, 2926, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4670, 1964, 0 },
   { 4671, 1964, 0 },
   { 4723, 1972, 0 },
   { 4724, 1972, 0 },
   { 4775, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4646, 1964, 0 },
   { 4671, 1964, 0 },
   { 4699, 1972, 0 },
   { 4724, 1972, 0 },
   { 4751, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4645, 1964, 0 },
   { 4671, 1964, 0 },
   { 4698, 1972, 0 },
   { 4724, 1972, 0 },
   { 4750, 1972, 0 },
   { 4776, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4646, 1964, 0 },
   { 4670, 1964, 0 },
   { 4699, 1972, 0 },
   { 4723, 1972, 0 },
   { 4751, 1972, 0 },
   { 4775, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4645, 1964, 0 },
   { 4670, 1964, 0 },
   { 4698, 1972, 0 },
   { 4723, 1972, 0 },
   { 4750, 1972, 0 },
   { 4775, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4645, 1964, 0 },
   { 4646, 1964, 0 },
   { 4698, 1972, 0 },
   { 4699, 1972, 0 },
   { 4750, 1972, 0 },
   { 4751, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2458, 32, 0 },
   { 4645, 1964, 0 },
   { 4698, 1972, 0 },
   { 4750, 1972, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2293, 2292, 0 },
   { 2853, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2914, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1117, 1087, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1050, 1051, 0 },
   { 1205, 1203, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1050, 1051, 0 },
   { 1149, 1152, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1050, 1051, 0 },
   { 2446, 715, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1135, 1136, 0 },
   { 1227, 1004, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1135, 1136, 0 },
   { 1144, 1147, 0 },
   { 1227, 1004, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1119, 1104, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1054, 1055, 0 },
   { 1208, 1207, 0 },
   { 1208, 1207, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1054, 1055, 0 },
   { 1155, 1156, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1054, 1055, 0 },
   { 1082, 1080, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1442, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1518, 1520, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1311, 1313, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1442, 1204, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1518, 1520, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1311, 1313, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1311, 1313, 0 },
   { 1439, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1442, 1204, 0 },
   { 1444, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1444, 32, 0 },
   { 1518, 1520, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1311, 1313, 0 },
   { 1444, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1439, 1204, 0 },
   { 1442, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1439, 1204, 0 },
   { 1518, 1520, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1442, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1518, 1520, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1311, 1313, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1442, 1204, 0 },
   { 1518, 1520, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1311, 1313, 0 },
   { 1439, 1204, 0 },
   { 1442, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1219, 1220, 0 },
   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1311, 1313, 0 },
   { 1439, 1204, 0 },
   { 1518, 1520, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1446, 32, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1450, 103, 0 },
   { 1512, 1515, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { 1296, 1298, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1446, 32, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1450, 103, 0 },
   { 1512, 1515, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1524, 1525, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1456, 202, 35 },
   { 1461, 1459, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { 1296, 1298, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { 1296, 1298, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1446, 32, 0 },
   { 1448, 103, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1448, 103, 0 },
   { 1450, 103, 0 },
   { 1512, 1515, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1448, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { 1296, 1298, 0 },
   { 1448, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { 1446, 32, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { 1450, 103, 0 },
   { 1512, 1515, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1446, 32, 0 },
   { 1450, 103, 0 },
   { 1512, 1515, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1446, 32, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { 1296, 1298, 0 },
   { 1446, 32, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1215, 1217, 0 },
   { 1269, 32, 0 },
   { 1450, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1450, 103, 0 },
   { 1512, 1515, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { 1296, 1298, 0 },
   { 1450, 103, 0 },
   { 1512, 1515, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1279, 1231, 0 },
   { 1296, 1298, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1454, 37 },
   { 1470, 1472, 35 },
   { 2855, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1454, 37 },
   { 1475, 1477, 35 },
   { 2855, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1454, 37 },
   { 1480, 1482, 38 },
   { 2855, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1454, 37 },
   { 1484, 1488, 35 },
   { 2855, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1454, 37 },
   { 2855, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 202, 1454, 37 },
   { 2439, 1213, 0 },
   { 2855, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 687, 684, 23 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 201, 3, 0 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 3234, 3237, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 3243, 3247, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 3253, 3256, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 765, 767, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 687, 684, 23 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 201, 3, 0 },
   { 3201, 3203, 0 },
   { 3205, 3203, 0 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 201, 3, 0 },
   { 3201, 3203, 0 },
   { 3205, 3203, 0 },
   { 3232, 3203, 0 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 199, 3, 0 },
   { 201, 3, 0 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 199, 3, 0 },
   { 687, 684, 23 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 204, 205, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 199, 3, 0 },
   { 201, 3, 0 },
   { 687, 684, 23 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2514, 2517, 48 },
   { 2538, 32, 0 },
   { 2539, 236, 0 },
   { 2540, 2537, 0 },
   { 2547, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2518, 2514, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2518, 2514, 49 },
   { 2529, 2530, 0 },
   { 2533, 236, 0 },
   { 2536, 2537, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1440, 1441, 0 },
   { 1443, 1441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { 1321, 1323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1440, 1441, 0 },
   { 1443, 1441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { 1321, 1323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { 1321, 1323, 0 },
   { 1440, 1441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1440, 1441, 0 },
   { 1443, 1441, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { 1321, 1323, 0 },
   { 1445, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { 1440, 1441, 0 },
   { 1443, 1441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1440, 1441, 0 },
   { 1443, 1441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { 1321, 1323, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { 1321, 1323, 0 },
   { 1440, 1441, 0 },
   { 1443, 1441, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1440, 1441, 0 },
   { 2807, 2794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1447, 32, 0 },
   { 1451, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1284, 1285, 0 },
   { 1306, 1308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1447, 32, 0 },
   { 1451, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 3603, 3599, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1284, 1285, 0 },
   { 1306, 1308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1451, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1284, 1285, 0 },
   { 1306, 1308, 0 },
   { 1451, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1447, 32, 0 },
   { 1449, 106, 0 },
   { 1451, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1449, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1284, 1285, 0 },
   { 1306, 1308, 0 },
   { 1449, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1284, 1285, 0 },
   { 1447, 32, 0 },
   { 1451, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1284, 1285, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1447, 32, 0 },
   { 1451, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1284, 1285, 0 },
   { 1306, 1308, 0 },
   { 1447, 32, 0 },
   { 1451, 106, 36 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1451, 106, 36 },
   { 2806, 2792, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1271, 32, 0 },
   { 1284, 1285, 0 },
   { 1306, 1308, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2447, 1032, 0 },
   { 2800, 715, 0 },
   { 2895, 1032, 0 },
   { 2896, 1185, 0 },
   { 2897, 1185, 0 },
   { 1426, 3414, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2451, 1032, 0 },
   { 2801, 715, 0 },
   { 2899, 1185, 0 },
   { 3421, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2448, 1185, 0 },
   { 2799, 1080, 0 },
   { 2892, 1185, 0 },
   { 2893, 1032, 0 },
   { 2894, 1032, 0 },
   { 1423, 3415, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2449, 1185, 0 },
   { 2744, 715, 0 },
   { 2747, 1080, 0 },
   { 2795, 1080, 0 },
   { 2796, 715, 0 },
   { 2891, 1032, 0 },
   { 3419, 3420, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2450, 1032, 0 },
   { 2745, 1080, 0 },
   { 2746, 715, 0 },
   { 2797, 715, 0 },
   { 2798, 1080, 0 },
   { 2890, 1185, 0 },
   { 3416, 3418, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2175, 1328, 0 },
   { 2450, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1289, 1290, 0 },
   { 1316, 1318, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1273, 61, 0 },
   { 1274, 32, 0 },
   { 1289, 1290, 0 },
   { 1316, 1318, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1289, 1290, 0 },
   { 1316, 1318, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 2809, 2792, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1275, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1275, 32, 0 },
   { 1281, 1282, 0 },
   { 1301, 1303, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1275, 32, 0 },
   { 1276, 32, 0 },
   { 1277, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1275, 32, 0 },
   { 1276, 32, 0 },
   { 1277, 63, 0 },
   { 1281, 1282, 0 },
   { 1301, 1303, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1275, 32, 0 },
   { 1281, 1282, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1275, 32, 0 },
   { 2808, 2794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1275, 32, 0 },
   { 1281, 1282, 0 },
   { 1301, 1303, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2750, 1066, 0 },
   { 2751, 665, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1239, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1240, 1241, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3665, 3647, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3665, 3647, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3665, 3647, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3665, 3647, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3665, 3647, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1228, 1229, 0 },
   { 1230, 1231, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3664, 3644, 101 },
   { 3665, 3647, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3669, 3653, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3669, 3653, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3669, 3653, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3669, 3653, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3669, 3653, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1233, 0 },
   { 1235, 1236, 0 },
   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3667, 3650, 101 },
   { 3669, 3653, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2290, 2291, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3657, 3658, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3657, 3658, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3657, 3658, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3657, 3658, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3657, 3658, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2290, 2291, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3655, 3656, 101 },
   { 3657, 3658, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3662, 3663, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3662, 3663, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3662, 3663, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3662, 3663, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3662, 3663, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4659, 4631, 0 },
   { 4712, 4684, 0 },
   { 4764, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4657, 4631, 0 },
   { 4710, 4684, 0 },
   { 4762, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4634, 4631, 0 },
   { 4687, 4684, 0 },
   { 4739, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1244, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3308, 3310, 0 },
   { 3659, 3660, 101 },
   { 3662, 3663, 101 },
   { 4630, 4631, 0 },
   { 4683, 4684, 0 },
   { 4736, 4684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3279, 3277, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3282, 3280, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1087, 0 },
   { 1266, 1095, 0 },
   { 1267, 1095, 0 },
   { 2781, 3, 0 },
   { 3285, 3283, 0 },
   { 3659, 3660, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3465, 3463, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3468, 3463, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1529, 1528, 0 },
   { 3517, 3520, 81 },
   { 4627, 11, 0 },
   { 4680, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4677, 2030, 0 },
   { 4730, 2034, 0 },
   { 4782, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4676, 2030, 0 },
   { 4729, 2034, 0 },
   { 4781, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4652, 2030, 0 },
   { 4705, 2034, 0 },
   { 4757, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4651, 2030, 0 },
   { 4704, 2034, 0 },
   { 4756, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 2465, 32, 0 },
   { 4677, 2030, 0 },
   { 4730, 2034, 0 },
   { 4782, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 2465, 32, 0 },
   { 4676, 2030, 0 },
   { 4729, 2034, 0 },
   { 4781, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 2465, 32, 0 },
   { 4652, 2030, 0 },
   { 4705, 2034, 0 },
   { 4757, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 2465, 32, 0 },
   { 4651, 2030, 0 },
   { 4704, 2034, 0 },
   { 4756, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4653, 2030, 0 },
   { 4677, 2030, 0 },
   { 4706, 2034, 0 },
   { 4730, 2034, 0 },
   { 4782, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4653, 2030, 0 },
   { 4676, 2030, 0 },
   { 4706, 2034, 0 },
   { 4729, 2034, 0 },
   { 4781, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4652, 2030, 0 },
   { 4653, 2030, 0 },
   { 4705, 2034, 0 },
   { 4706, 2034, 0 },
   { 4757, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4651, 2030, 0 },
   { 4653, 2030, 0 },
   { 4704, 2034, 0 },
   { 4706, 2034, 0 },
   { 4756, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4677, 2030, 0 },
   { 4678, 2030, 0 },
   { 4730, 2034, 0 },
   { 4731, 2034, 0 },
   { 4782, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4676, 2030, 0 },
   { 4678, 2030, 0 },
   { 4729, 2034, 0 },
   { 4731, 2034, 0 },
   { 4781, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4652, 2030, 0 },
   { 4678, 2030, 0 },
   { 4705, 2034, 0 },
   { 4731, 2034, 0 },
   { 4757, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4651, 2030, 0 },
   { 4678, 2030, 0 },
   { 4704, 2034, 0 },
   { 4731, 2034, 0 },
   { 4756, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4677, 2030, 0 },
   { 4730, 2034, 0 },
   { 4782, 2034, 0 },
   { 4783, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4676, 2030, 0 },
   { 4729, 2034, 0 },
   { 4781, 2034, 0 },
   { 4783, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4652, 2030, 0 },
   { 4705, 2034, 0 },
   { 4757, 2034, 0 },
   { 4783, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4651, 2030, 0 },
   { 4704, 2034, 0 },
   { 4756, 2034, 0 },
   { 4783, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4677, 2030, 0 },
   { 4730, 2034, 0 },
   { 4758, 2034, 0 },
   { 4782, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4676, 2030, 0 },
   { 4729, 2034, 0 },
   { 4758, 2034, 0 },
   { 4781, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4652, 2030, 0 },
   { 4705, 2034, 0 },
   { 4757, 2034, 0 },
   { 4758, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4651, 2030, 0 },
   { 4704, 2034, 0 },
   { 4756, 2034, 0 },
   { 4758, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4676, 2030, 0 },
   { 4677, 2030, 0 },
   { 4729, 2034, 0 },
   { 4730, 2034, 0 },
   { 4781, 2034, 0 },
   { 4782, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4652, 2030, 0 },
   { 4677, 2030, 0 },
   { 4705, 2034, 0 },
   { 4730, 2034, 0 },
   { 4757, 2034, 0 },
   { 4782, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4651, 2030, 0 },
   { 4677, 2030, 0 },
   { 4704, 2034, 0 },
   { 4730, 2034, 0 },
   { 4756, 2034, 0 },
   { 4782, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4652, 2030, 0 },
   { 4676, 2030, 0 },
   { 4705, 2034, 0 },
   { 4729, 2034, 0 },
   { 4757, 2034, 0 },
   { 4781, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4651, 2030, 0 },
   { 4676, 2030, 0 },
   { 4704, 2034, 0 },
   { 4729, 2034, 0 },
   { 4756, 2034, 0 },
   { 4781, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4651, 2030, 0 },
   { 4652, 2030, 0 },
   { 4704, 2034, 0 },
   { 4705, 2034, 0 },
   { 4756, 2034, 0 },
   { 4757, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2464, 61, 0 },
   { 4651, 2030, 0 },
   { 4704, 2034, 0 },
   { 4756, 2034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1743, 11, 0 },
   { 1766, 11, 0 },
   { 1850, 16, 0 },
   { 1959, 1956, 0 },
   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { 3803, 3801, 0 },
   { 3809, 3801, 0 },
   { 3815, 3801, 0 },
   { 3821, 3801, 0 },
   { 3824, 3825, 0 },
   { 3829, 3799, 0 },
   { 3833, 3799, 0 },
   { 3837, 3799, 0 },
   { 3840, 3841, 0 },
   { 3843, 3841, 0 },
   { 3846, 3847, 0 },
   { 3851, 3806, 0 },
   { 3855, 3806, 0 },
   { 3858, 3859, 0 },
   { 3861, 3859, 0 },
   { 3864, 2975, 0 },
   { 3866, 3859, 0 },
   { 3868, 2975, 0 },
   { 3870, 1742, 0 },
   { 3874, 3812, 0 },
   { 3877, 3878, 0 },
   { 3880, 3878, 0 },
   { 3883, 3884, 0 },
   { 3886, 3878, 0 },
   { 3888, 3884, 0 },
   { 3890, 1765, 0 },
   { 3892, 3878, 0 },
   { 3894, 3884, 0 },
   { 3896, 1765, 0 },
   { 3898, 1849, 0 },
   { 4626, 11, 0 },
   { 4679, 16, 0 },
   { 4732, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1743, 11, 0 },
   { 1766, 11, 0 },
   { 1850, 16, 0 },
   { 2953, 2954, 0 },
   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { 3803, 3801, 0 },
   { 3809, 3801, 0 },
   { 3815, 3801, 0 },
   { 3821, 3801, 0 },
   { 3824, 3825, 0 },
   { 3829, 3799, 0 },
   { 3833, 3799, 0 },
   { 3837, 3799, 0 },
   { 3840, 3841, 0 },
   { 3843, 3841, 0 },
   { 3846, 3847, 0 },
   { 3851, 3806, 0 },
   { 3855, 3806, 0 },
   { 3858, 3859, 0 },
   { 3861, 3859, 0 },
   { 3864, 2975, 0 },
   { 3866, 3859, 0 },
   { 3868, 2975, 0 },
   { 3870, 1742, 0 },
   { 3874, 3812, 0 },
   { 3877, 3878, 0 },
   { 3880, 3878, 0 },
   { 3883, 3884, 0 },
   { 3886, 3878, 0 },
   { 3888, 3884, 0 },
   { 3890, 1765, 0 },
   { 3892, 3878, 0 },
   { 3894, 3884, 0 },
   { 3896, 1765, 0 },
   { 3898, 1849, 0 },
   { 4626, 11, 0 },
   { 4679, 16, 0 },
   { 4732, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2950, 2952, 0 },
   { 3779, 715, 0 },
   { 3780, 6, 0 },
   { 3781, 11, 0 },
   { 3782, 16, 0 },
   { 3783, 21, 0 },
   { 3800, 3801, 0 },
   { 3807, 3801, 0 },
   { 3813, 3801, 0 },
   { 3819, 3801, 0 },
   { 3827, 3799, 0 },
   { 3831, 3799, 0 },
   { 3835, 3799, 0 },
   { 3849, 3806, 0 },
   { 3853, 3806, 0 },
   { 3872, 3812, 0 },
   { 4654, 11, 0 },
   { 4707, 16, 0 },
   { 4759, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2071, 6, 0 },
   { 2097, 11, 0 },
   { 2123, 16, 0 },
   { 2148, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2488, 2489, 46 },
   { 2495, 2496, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2501, 2502, 46 },
   { 2506, 2507, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2488, 2489, 46 },
   { 2495, 2496, 46 },
   { 2504, 2502, 46 },
   { 2509, 2507, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2492, 2489, 46 },
   { 2499, 2496, 46 },
   { 2501, 2502, 46 },
   { 2506, 2507, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2488, 2489, 46 },
   { 2495, 2496, 46 },
   { 2501, 2502, 46 },
   { 2506, 2507, 46 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 900, 901, 0 },
   { 947, 946, 0 },
   { 954, 953, 0 },
   { 962, 960, 0 },
   { 971, 969, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 949, 948, 0 },
   { 956, 955, 0 },
   { 964, 963, 0 },
   { 973, 972, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { 687, 684, 23 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { 687, 684, 23 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 201, 3, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 201, 3, 0 },
   { 482, 472, 15 },
   { 492, 490, 14 },
   { 552, 543, 17 },
   { 561, 559, 16 },
   { 623, 613, 19 },
   { 632, 630, 18 },
   { 3274, 3203, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 482, 472, 15 },
   { 552, 543, 17 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 113, 0 },
   { 1729, 1730, 39 },
   { 1836, 1837, 39 },
   { 1919, 1920, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2005, 2007, 0 },
   { 2009, 2011, 0 },
   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1963, 1965, 0 },
   { 1971, 1973, 0 },
   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2029, 2031, 0 },
   { 2033, 2035, 0 },
   { 3784, 715, 0 },
   { 3785, 6, 0 },
   { 3786, 11, 0 },
   { 3787, 16, 0 },
   { 3788, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 945, 946, 0 },
   { 952, 953, 0 },
   { 959, 960, 0 },
   { 968, 969, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1492, 1493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1492, 1493, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1454, 202, 35 },
   { 1458, 1459, 35 },
   { 1492, 1493, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 2856, 202, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1492, 1493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1444, 32, 0 },
   { 1492, 1493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1444, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1492, 1493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1439, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1442, 1204, 0 },
   { 1492, 1493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1442, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1492, 1493, 0 },
   { 1518, 1520, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1518, 1520, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1311, 1313, 0 },
   { 1492, 1493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1287, 1233, 0 },
   { 1311, 1313, 0 },
   { 1439, 1204, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 32, 0 },
   { 1439, 1204, 0 },
   { 1492, 1493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 369, 254, 9 },
   { 3293, 3294, 0 },
   { 3296, 3297, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3161, 3162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 240, 238, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 242, 3, 0 },
   { 244, 243, 5 },
   { 245, 36, 6 },
   { 256, 257, 0 },
   { 261, 262, 0 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 158, 160, 0 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 495, 490, 0 },
   { 505, 506, 0 },
   { 564, 559, 0 },
   { 572, 573, 0 },
   { 635, 630, 0 },
   { 644, 645, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 145, 146, 0 },
   { 372, 373, 9 },
   { 495, 490, 0 },
   { 564, 559, 0 },
   { 635, 630, 0 },
   { 692, 694, 26 },
   { 219, 696, 27 },
   { 697, 699, 28 },
   { 700, 694, 29 },
   { 701, 696, 30 },
   { 702, 699, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1110, 1111, 0 },
   { 1139, 1140, 0 },
   { 2456, 1185, 0 },
   { 2872, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1099, 1100, 0 },
   { 1141, 1142, 0 },
   { 2457, 1032, 0 },
   { 2871, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2524, 2527, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1050, 1051, 0 },
   { 1116, 1087, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1054, 1055, 0 },
   { 1118, 1104, 0 },
   { 2455, 1185, 0 },
   { 2875, 1185, 0 },
   { 2878, 1032, 0 },
   { 2881, 1032, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1497, 1498, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1497, 1498, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1497, 1498, 0 },
   { 3601, 3599, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1440, 1441, 0 },
   { 1497, 1498, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1445, 32, 0 },
   { 1497, 1498, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { 1497, 1498, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1440, 1441, 0 },
   { 1443, 1441, 0 },
   { 1497, 1498, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1270, 32, 0 },
   { 1292, 1293, 0 },
   { 1321, 1323, 0 },
   { 1497, 1498, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1502, 1503, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1273, 61, 0 },
   { 1274, 32, 0 },
   { 1502, 1503, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1289, 1290, 0 },
   { 1502, 1503, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 32, 0 },
   { 1289, 1290, 0 },
   { 1316, 1318, 0 },
   { 1502, 1503, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 61, 0 },
   { 1736, 1737, 39 },
   { 1843, 1844, 39 },
   { 1926, 1927, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 2469, 2236, 0 },
   { 2986, 2988, 57 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1135, 1136, 0 },
   { 1144, 1147, 0 },
   { 2453, 1032, 0 },
   { 2860, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1135, 1136, 0 },
   { 1144, 1147, 0 },
   { 1227, 1004, 0 },
   { 2453, 1032, 0 },
   { 2864, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1131, 1134, 0 },
   { 2199, 1033, 0 },
   { 2453, 1032, 0 },
   { 2883, 1032, 0 },
   { 2886, 1185, 0 },
   { 2889, 1185, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 2867, 2859, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 32, 0 },
   { 1524, 1525, 35 },
   { 2869, 2863, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 113, 0 },
   { 207, 115, 5 },
   { 208, 117, 6 },
   { 227, 32, 0 },
   { 230, 32, 0 },
   { 233, 98, 0 },
   { 714, 722, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 114, 32, 0 },
   { 116, 11, 5 },
   { 118, 16, 6 },
   { 190, 113, 0 },
   { 519, 520, 15 },
   { 585, 586, 17 },
   { 658, 659, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 477, 478, 15 },
   { 548, 549, 17 },
   { 618, 619, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 477, 478, 15 },
   { 482, 472, 15 },
   { 548, 549, 17 },
   { 552, 543, 17 },
   { 618, 619, 19 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 477, 478, 15 },
   { 482, 472, 15 },
   { 542, 543, 17 },
   { 548, 549, 17 },
   { 552, 543, 17 },
   { 612, 613, 19 },
   { 618, 619, 19 },
   { 623, 613, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 489, 490, 14 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 558, 559, 16 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { 629, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 489, 490, 14 },
   { 492, 490, 14 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 558, 559, 16 },
   { 561, 559, 16 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { 629, 630, 18 },
   { 632, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 477, 478, 15 },
   { 482, 472, 15 },
   { 489, 490, 14 },
   { 542, 543, 17 },
   { 548, 549, 17 },
   { 552, 543, 17 },
   { 558, 559, 16 },
   { 612, 613, 19 },
   { 618, 619, 19 },
   { 623, 613, 19 },
   { 629, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 477, 478, 15 },
   { 548, 549, 17 },
   { 618, 619, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 131, 0 },
   { 471, 472, 15 },
   { 482, 472, 15 },
   { 489, 490, 14 },
   { 542, 543, 17 },
   { 552, 543, 17 },
   { 558, 559, 16 },
   { 612, 613, 19 },
   { 623, 613, 19 },
   { 629, 630, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2182, 2185, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2190, 2194, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2182, 2185, 0 },
   { 2190, 2194, 0 },
   { 2458, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2470, 3, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1264, 1087, 0 },
   { 1265, 1087, 0 },
   { 1267, 1095, 0 },
   { 1704, 1711, 0 },
   { 1811, 1818, 0 },
   { 1894, 1901, 0 },
   { 2781, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 900, 901, 0 },
   { 947, 946, 0 },
   { 954, 953, 0 },
   { 962, 960, 0 },
   { 971, 969, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 949, 948, 0 },
   { 956, 955, 0 },
   { 964, 963, 0 },
   { 973, 972, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 945, 946, 0 },
   { 952, 953, 0 },
   { 959, 960, 0 },
   { 968, 969, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2470, 3, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 900, 901, 0 },
   { 947, 946, 0 },
   { 954, 953, 0 },
   { 962, 960, 0 },
   { 971, 969, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 949, 948, 0 },
   { 956, 955, 0 },
   { 964, 963, 0 },
   { 973, 972, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 945, 946, 0 },
   { 952, 953, 0 },
   { 959, 960, 0 },
   { 968, 969, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2470, 3, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 900, 901, 0 },
   { 947, 946, 0 },
   { 954, 953, 0 },
   { 962, 960, 0 },
   { 971, 969, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 949, 948, 0 },
   { 956, 955, 0 },
   { 964, 963, 0 },
   { 973, 972, 0 },
   { 2441, 2442, 0 },
   { 2444, 2445, 0 },
   { 2458, 32, 0 },
   { 2459, 32, 0 },
   { 2460, 61, 0 },
   { 2938, 2939, 55 },
   { 2969, 2970, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 945, 946, 0 },
   { 952, 953, 0 },
   { 959, 960, 0 },
   { 968, 969, 0 },
   { 2480, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2484, 32, 0 },
   { 2927, 2928, 55 },
   { 972, 403, 55 },
   { 2930, 2932, 55 },
   { 963, 428, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 187, 189, 0 },
   { 2461, 32, 0 },
   { 2468, 3, 0 },
   { 5027, 4952, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2461, 32, 0 },
   { 4951, 4952, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_pass_op_table[nir_num_search_ops] = {
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         5,
         13,
         5,
         5,
         5,
         5,
         0,
         12,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         15,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         2,
         3,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2323,
         2324,
         2325,
         2326,
         3,
         3,
         346,
         347,
         348,
         349,
         350,
         3,
         351,
         352,
         353,
         354,
         2327,
         2328,
         2329,
         2330,
         2331,
         2332,
         2,
         346,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2323,
         2324,
         2325,
         2326,
         2,
         347,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2323,
         2324,
         2325,
         2326,
         341,
         348,
         341,
         341,
         341,
         341,
         341,
         341,
         355,
         356,
         357,
         358,
         341,
         341,
         2333,
         2334,
         2335,
         2336,
         2,
         349,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2323,
         2324,
         2325,
         2326,
         2,
         350,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2323,
         2324,
         2325,
         2326,
         2,
         3,
         2,
         2,
         341,
         2,
         2,
         359,
         342,
         343,
         344,
         345,
         2,
         2,
         2323,
         2324,
         2325,
         2326,
         342,
         351,
         342,
         342,
         355,
         342,
         342,
         342,
         342,
         360,
         361,
         362,
         342,
         342,
         2337,
         2338,
         2339,
         2340,
         343,
         352,
         343,
         343,
         356,
         343,
         343,
         343,
         360,
         343,
         363,
         364,
         343,
         343,
         2341,
         2342,
         2343,
         2344,
         344,
         353,
         344,
         344,
         357,
         344,
         344,
         344,
         361,
         363,
         344,
         365,
         344,
         344,
         2345,
         2346,
         2347,
         2348,
         345,
         354,
         345,
         345,
         358,
         345,
         345,
         345,
         362,
         364,
         365,
         345,
         345,
         345,
         2349,
         2350,
         2351,
         2352,
         2,
         2327,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2323,
         2324,
         2325,
         2326,
         2,
         2328,
         2,
         2,
         341,
         2,
         2,
         2,
         342,
         343,
         344,
         345,
         2,
         2,
         2323,
         2324,
         2325,
         2326,
         2323,
         2329,
         2323,
         2323,
         2333,
         2323,
         2323,
         2323,
         2337,
         2341,
         2345,
         2349,
         2323,
         2323,
         2323,
         2353,
         2354,
         2355,
         2324,
         2330,
         2324,
         2324,
         2334,
         2324,
         2324,
         2324,
         2338,
         2342,
         2346,
         2350,
         2324,
         2324,
         2353,
         2324,
         2356,
         2357,
         2325,
         2331,
         2325,
         2325,
         2335,
         2325,
         2325,
         2325,
         2339,
         2343,
         2347,
         2351,
         2325,
         2325,
         2354,
         2356,
         2325,
         2358,
         2326,
         2332,
         2326,
         2326,
         2336,
         2326,
         2326,
         2326,
         2340,
         2344,
         2348,
         2352,
         2326,
         2326,
         2355,
         2357,
         2358,
         2326,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         4,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         4,
         14,
         4,
         4,
         4,
         4,
         0,
         11,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         19,
         0,
         5,
         5,
         3,
         6,
         20,
         15,
         3,
         6,
         21,
         5,
         5,
         3,
         6,
         22,
         15,
         3,
         6,
         23,
         5,
         5,
         3,
         6,
         0,
         15,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         4,
         5,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         6,
         7,
         6,
         6,
         6,
         1342,
         6,
         6,
         6,
         1343,
         6,
         6,
         6,
         2360,
         6,
         6,
         6,
         1342,
         6,
         1342,
         6,
         1342,
         6,
         1342,
         4,
         1344,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1345,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1346,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1347,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         1348,
         1349,
         1348,
         1348,
         1348,
         1350,
         1348,
         1348,
         1348,
         1351,
         1348,
         1348,
         1348,
         2361,
         1348,
         1348,
         1348,
         1350,
         1348,
         1350,
         1348,
         1350,
         1348,
         1350,
         1352,
         1353,
         1352,
         1352,
         1352,
         1354,
         1352,
         1352,
         1352,
         1355,
         1352,
         1352,
         1352,
         2362,
         1352,
         1352,
         1352,
         1354,
         1352,
         1354,
         1352,
         1354,
         1352,
         1354,
         4,
         1356,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         5,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1357,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         2363,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         2364,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1346,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         2365,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         2366,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         2367,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3041,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3132,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3138,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3142,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3147,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3151,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         3156,
         4,
         4,
         4,
         1340,
         4,
         4,
         4,
         1341,
         4,
         4,
         4,
         2359,
         4,
         4,
         4,
         1340,
         4,
         1340,
         4,
         1340,
         4,
         1340,
      },
   },
   [nir_op_unpack_64_2x32_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         8,
         1567,
         1568,
         1569,
         1570,
      },
   },
   [nir_op_imul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_umul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_udiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         11,
         0,
         11,
      },
   },
   [nir_op_idiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         12,
         0,
         0,
         12,
         0,
         366,
         367,
         366,
      },
   },
   [nir_op_umod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         13,
         0,
         13,
      },
   },
   [nir_op_imod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         14,
         0,
         14,
      },
   },
   [nir_op_irem] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         15,
         0,
         15,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         14,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         10,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         9,
         9,
         9,
         9,
         9,
         9,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         5,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         16,
         1571,
         1572,
         1573,
         1574,
         1575,
         1576,
         1577,
         1578,
         1579,
         1580,
         1581,
         1582,
         1583,
         2691,
         2692,
         2693,
         3034,
      },
   },
   [nir_op_ineg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         4,
         6,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         17,
         1848,
         1849,
         1850,
         1851,
         1852,
         3001,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         18,
         1584,
         1585,
         1586,
         1587,
         1588,
         1589,
         1590,
         1591,
      },
   },
   [nir_search_op_u2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         19,
         2144,
         2145,
         2146,
      },
   },
   [nir_op_iabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         20,
         1853,
         1854,
         1855,
         2611,
      },
   },
   [nir_search_op_f2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         21,
         1592,
         1593,
      },
   },
   [nir_search_op_i2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         22,
         1856,
         1857,
         1858,
         1859,
         1860,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         7,
         8,
         7,
         8,
         7,
         8,
         9,
         10,
         9,
         10,
         9,
         10,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         14,
         2,
         2,
         15,
         16,
         17,
         18,
         19,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         3,
         21,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         20,
         3,
         3,
         3,
         3,
         3,
         5,
         22,
         5,
         5,
         23,
         24,
         5,
         5,
         5,
         5,
         5,
         22,
         5,
         5,
         5,
         23,
         24,
         22,
         5,
         5,
         23,
         24,
         5,
         22,
         22,
         22,
         25,
         26,
         5,
         23,
         24,
         23,
         24,
         23,
         27,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         9,
         9,
         9,
         10,
         9,
         9,
         9,
         10,
         9,
         9,
         28,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         30,
         31,
         5,
         5,
         30,
         31,
         5,
         5,
         5,
         30,
         31,
         5,
         22,
         32,
         33,
         34,
         22,
         5,
         30,
         31,
         5,
         30,
         31,
         5,
         23,
         35,
         36,
         23,
         24,
         37,
         38,
         24,
         5,
         5,
         30,
         31,
         5,
         30,
         31,
         31,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         11,
         11,
         11,
         20,
         3,
         21,
         21,
         21,
         21,
         21,
         21,
         4,
         4,
         20,
         20,
         3,
         20,
         20,
         3,
         0,
         2,
         40,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         21,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         3,
         3,
         3,
         3,
         20,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         43,
         44,
         43,
         44,
         43,
         44,
         43,
         45,
         43,
         44,
         43,
         44,
         46,
         47,
         48,
         49,
         43,
         44,
         50,
         51,
         52,
         44,
         43,
         44,
         53,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         21,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 54,
      .table = (const uint16_t []) {
      
         23,
         24,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3010,
         3010,
         23,
         3010,
         3010,
         3011,
         3011,
         3010,
         3010,
         23,
         1594,
         1594,
         1594,
         23,
         3010,
         3010,
         23,
         3011,
         23,
         3010,
         23,
         3010,
         3010,
         3010,
         24,
         24,
         1596,
         1597,
         1598,
         24,
         24,
         1599,
         1600,
         1601,
         1602,
         24,
         1603,
         24,
         2676,
         2677,
         2678,
         2679,
         2680,
         2681,
         2682,
         2683,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         3012,
         3012,
         3013,
         3012,
         3012,
         3014,
         3014,
         3012,
         3012,
         3015,
         3016,
         2680,
         3119,
         24,
         3012,
         3012,
         24,
         3014,
         24,
         3012,
         3013,
         3012,
         3012,
         3012,
         1594,
         1596,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2684,
         2684,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3017,
         3017,
         3018,
         3018,
         3017,
         3017,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3018,
         1594,
         3017,
         1594,
         3017,
         3017,
         3017,
         1595,
         1597,
         1604,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1604,
         1604,
         1604,
         1604,
         1604,
         2685,
         2675,
         2675,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         3019,
         3019,
         1595,
         3019,
         3019,
         3020,
         3020,
         3019,
         3019,
         1595,
         1604,
         1604,
         1604,
         1595,
         3019,
         3019,
         1595,
         3020,
         1595,
         3019,
         1595,
         3019,
         3019,
         3019,
         1595,
         1598,
         1604,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1604,
         1604,
         1604,
         1604,
         1604,
         2685,
         2675,
         2675,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         3019,
         3019,
         1595,
         3019,
         3019,
         3020,
         3020,
         3019,
         3019,
         1595,
         1604,
         1604,
         1604,
         1595,
         3019,
         3019,
         1595,
         3020,
         1595,
         3019,
         1595,
         3019,
         3019,
         3019,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         1605,
         1605,
         1605,
         1605,
         1605,
         1605,
         23,
         23,
         3021,
         3022,
         1605,
         3021,
         3022,
         3023,
         3024,
         3021,
         3022,
         23,
         1594,
         1594,
         1594,
         1605,
         3022,
         3022,
         1605,
         3024,
         1605,
         3022,
         1605,
         3021,
         3022,
         3022,
         23,
         24,
         1594,
         1595,
         1595,
         23,
         1607,
         23,
         23,
         1608,
         1608,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3010,
         3010,
         23,
         3010,
         3010,
         3011,
         3011,
         3010,
         3010,
         23,
         1594,
         1594,
         1594,
         23,
         3010,
         3010,
         23,
         3011,
         23,
         3010,
         23,
         3010,
         3010,
         3010,
         23,
         1599,
         1594,
         1595,
         1595,
         1606,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         1606,
         1606,
         1606,
         1606,
         1606,
         1606,
         23,
         23,
         3025,
         3025,
         1606,
         3025,
         3025,
         3026,
         3026,
         3025,
         3025,
         23,
         1594,
         1594,
         1594,
         1606,
         3025,
         3025,
         1606,
         3026,
         1606,
         3025,
         1606,
         3025,
         3025,
         3025,
         23,
         1600,
         1594,
         1595,
         1595,
         1606,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         1606,
         1606,
         1606,
         1606,
         1606,
         1606,
         23,
         23,
         3025,
         3025,
         1606,
         3025,
         3025,
         3026,
         3026,
         3025,
         3025,
         23,
         1594,
         1594,
         1594,
         1606,
         3025,
         3025,
         1606,
         3026,
         1606,
         3025,
         1606,
         3025,
         3025,
         3025,
         23,
         1601,
         1594,
         1595,
         1595,
         23,
         1608,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3010,
         3010,
         23,
         3010,
         3010,
         3011,
         3011,
         3010,
         3010,
         23,
         1594,
         1594,
         1594,
         23,
         3010,
         3010,
         23,
         3011,
         23,
         3010,
         23,
         3010,
         3010,
         3010,
         23,
         1602,
         1594,
         1595,
         1595,
         23,
         1608,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3010,
         3010,
         23,
         3010,
         3010,
         3011,
         3011,
         3010,
         3010,
         23,
         1594,
         1594,
         1594,
         23,
         3010,
         3010,
         23,
         3011,
         23,
         3010,
         23,
         3010,
         3010,
         3010,
         23,
         24,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         23,
         23,
         23,
         23,
         23,
         23,
         2686,
         23,
         3010,
         3010,
         23,
         3010,
         3010,
         3011,
         3011,
         3010,
         3010,
         23,
         1594,
         1594,
         1594,
         23,
         3010,
         3010,
         23,
         3011,
         23,
         3010,
         23,
         3010,
         3010,
         3010,
         23,
         1603,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3010,
         3010,
         23,
         3010,
         3010,
         3011,
         3011,
         3010,
         3010,
         23,
         1594,
         1594,
         1594,
         23,
         3010,
         3010,
         23,
         3011,
         23,
         3010,
         23,
         3010,
         3010,
         3010,
         23,
         24,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1609,
         1594,
         1594,
         1594,
         1594,
         2687,
         2674,
         2675,
         2675,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1609,
         3010,
         3010,
         23,
         3010,
         3010,
         3011,
         3011,
         3010,
         3010,
         23,
         1594,
         2687,
         1594,
         23,
         3010,
         3010,
         23,
         3011,
         23,
         3010,
         23,
         3010,
         3010,
         3010,
         1594,
         2676,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2684,
         2684,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3017,
         3017,
         3018,
         3018,
         3017,
         3017,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3018,
         1594,
         3017,
         1594,
         3017,
         3017,
         3017,
         1594,
         2677,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2684,
         2684,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3017,
         3017,
         3018,
         3018,
         3017,
         3017,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3018,
         1594,
         3017,
         1594,
         3017,
         3017,
         3017,
         1594,
         2678,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2684,
         2684,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3017,
         3017,
         3018,
         3018,
         3017,
         3017,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3018,
         1594,
         3017,
         1594,
         3017,
         3017,
         3017,
         1594,
         2679,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2684,
         2684,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3017,
         3017,
         3018,
         3018,
         3017,
         3017,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3018,
         1594,
         3017,
         1594,
         3017,
         3017,
         3017,
         1594,
         2680,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2687,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2684,
         2684,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2687,
         3017,
         3017,
         1594,
         3017,
         3017,
         3018,
         3018,
         3017,
         3017,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3018,
         1594,
         3017,
         1594,
         3017,
         3017,
         3017,
         2674,
         2681,
         2674,
         2685,
         2685,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         2688,
         2688,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         2674,
         3027,
         3027,
         2674,
         3027,
         3027,
         3028,
         3028,
         3027,
         3027,
         2674,
         2674,
         2674,
         2674,
         2674,
         3027,
         3027,
         2674,
         3028,
         2674,
         3027,
         2674,
         3027,
         3027,
         3027,
         2675,
         2682,
         2684,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         3029,
         3029,
         2675,
         3029,
         3029,
         3030,
         3030,
         3029,
         3029,
         2675,
         2684,
         2684,
         2684,
         2675,
         3029,
         3029,
         2675,
         3030,
         2675,
         3029,
         2675,
         3029,
         3029,
         3029,
         2675,
         2683,
         2684,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2684,
         2684,
         2684,
         2684,
         2684,
         2688,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         2675,
         3029,
         3029,
         2675,
         3029,
         3029,
         3030,
         3030,
         3029,
         3029,
         2675,
         2684,
         2684,
         2684,
         2675,
         3029,
         3029,
         2675,
         3030,
         2675,
         3029,
         2675,
         3029,
         3029,
         3029,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         1605,
         1605,
         1605,
         1605,
         1605,
         1605,
         23,
         23,
         3021,
         3022,
         1605,
         3021,
         3022,
         3023,
         3024,
         3021,
         3022,
         23,
         1594,
         1594,
         1594,
         3120,
         3022,
         3022,
         3120,
         3024,
         3120,
         3022,
         3120,
         3121,
         3122,
         3122,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         1605,
         1605,
         1605,
         1605,
         1605,
         1605,
         23,
         23,
         3021,
         3022,
         1605,
         3021,
         3022,
         3023,
         3024,
         3021,
         3022,
         23,
         1594,
         1594,
         1594,
         1605,
         3123,
         3123,
         1605,
         3124,
         1605,
         3123,
         1605,
         3021,
         3022,
         3123,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         1605,
         1605,
         2689,
         1605,
         2689,
         2689,
         23,
         23,
         3021,
         3022,
         1605,
         3021,
         3022,
         3023,
         3024,
         3031,
         3032,
         23,
         1594,
         1594,
         1594,
         1605,
         3022,
         3022,
         1605,
         3024,
         2689,
         3032,
         1605,
         3021,
         3022,
         3022,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         1605,
         1605,
         1605,
         1605,
         1605,
         1605,
         23,
         23,
         3021,
         3022,
         1605,
         3021,
         3022,
         3023,
         3024,
         3021,
         3022,
         23,
         1594,
         1594,
         1594,
         3120,
         3123,
         3123,
         3120,
         3124,
         3120,
         3123,
         3120,
         3121,
         3122,
         3125,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         1605,
         1605,
         2689,
         1605,
         2689,
         2689,
         23,
         23,
         3021,
         3022,
         1605,
         3021,
         3022,
         3023,
         3024,
         3031,
         3032,
         23,
         1594,
         1594,
         1594,
         3120,
         3022,
         3022,
         3120,
         3024,
         3126,
         3032,
         3120,
         3121,
         3122,
         3122,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         1605,
         1605,
         2689,
         1605,
         2689,
         2689,
         23,
         23,
         3021,
         3022,
         1605,
         3021,
         3022,
         3023,
         3024,
         3031,
         3032,
         23,
         1594,
         1594,
         1594,
         1605,
         3123,
         3123,
         1605,
         3124,
         2689,
         3127,
         1605,
         3021,
         3022,
         3123,
         23,
         24,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         2686,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         23,
         23,
         23,
         23,
         23,
         23,
         2686,
         23,
         3010,
         3010,
         23,
         3010,
         3010,
         3011,
         3011,
         3010,
         3010,
         23,
         1594,
         1594,
         1594,
         23,
         3010,
         3010,
         23,
         3011,
         23,
         3010,
         23,
         3010,
         3010,
         3010,
         23,
         24,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1609,
         1594,
         1594,
         1594,
         1594,
         2687,
         2674,
         2675,
         2675,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1609,
         3010,
         3010,
         23,
         3010,
         3010,
         3011,
         3011,
         3010,
         3010,
         23,
         1594,
         3033,
         1594,
         23,
         3010,
         3010,
         23,
         3011,
         23,
         3010,
         23,
         3010,
         3010,
         3010,
         3010,
         3012,
         3017,
         3019,
         3019,
         3021,
         3010,
         3025,
         3025,
         3010,
         3010,
         3010,
         3010,
         3010,
         3017,
         3017,
         3017,
         3017,
         3017,
         3027,
         3029,
         3029,
         3021,
         3021,
         3021,
         3021,
         3021,
         3021,
         3010,
         3010,
         3021,
         3022,
         3021,
         3021,
         3022,
         3023,
         3024,
         3021,
         3022,
         3010,
         3017,
         3017,
         3017,
         3021,
         3022,
         3022,
         3021,
         3024,
         3021,
         3022,
         3021,
         3021,
         3022,
         3022,
         3010,
         3012,
         3017,
         3019,
         3019,
         3022,
         3010,
         3025,
         3025,
         3010,
         3010,
         3010,
         3010,
         3010,
         3017,
         3017,
         3017,
         3017,
         3017,
         3027,
         3029,
         3029,
         3022,
         3022,
         3022,
         3022,
         3022,
         3022,
         3010,
         3010,
         3022,
         3022,
         3022,
         3022,
         3022,
         3024,
         3024,
         3022,
         3022,
         3010,
         3017,
         3017,
         3017,
         3022,
         3022,
         3022,
         3022,
         3024,
         3022,
         3022,
         3022,
         3022,
         3022,
         3022,
         23,
         3013,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         1605,
         1605,
         1605,
         1605,
         1605,
         1605,
         23,
         23,
         3021,
         3022,
         1605,
         3021,
         3022,
         3023,
         3024,
         3021,
         3022,
         23,
         1594,
         1594,
         1594,
         3120,
         3022,
         3022,
         3120,
         3024,
         3120,
         3022,
         3120,
         3121,
         3122,
         3122,
         3010,
         3012,
         3017,
         3019,
         3019,
         3021,
         3010,
         3025,
         3025,
         3010,
         3010,
         3010,
         3010,
         3010,
         3017,
         3017,
         3017,
         3017,
         3017,
         3027,
         3029,
         3029,
         3021,
         3021,
         3021,
         3021,
         3021,
         3021,
         3010,
         3010,
         3021,
         3022,
         3021,
         3021,
         3022,
         3023,
         3024,
         3021,
         3022,
         3010,
         3017,
         3017,
         3017,
         3121,
         3022,
         3022,
         3121,
         3024,
         3121,
         3022,
         3121,
         3121,
         3122,
         3122,
         3010,
         3012,
         3017,
         3019,
         3019,
         3022,
         3010,
         3025,
         3025,
         3010,
         3010,
         3010,
         3010,
         3010,
         3017,
         3017,
         3017,
         3017,
         3017,
         3027,
         3029,
         3029,
         3022,
         3022,
         3022,
         3022,
         3022,
         3022,
         3010,
         3010,
         3022,
         3022,
         3022,
         3022,
         3022,
         3024,
         3024,
         3022,
         3022,
         3010,
         3017,
         3017,
         3017,
         3122,
         3022,
         3022,
         3122,
         3024,
         3122,
         3022,
         3122,
         3122,
         3122,
         3122,
         3011,
         3014,
         3018,
         3020,
         3020,
         3023,
         3011,
         3026,
         3026,
         3011,
         3011,
         3011,
         3011,
         3011,
         3018,
         3018,
         3018,
         3018,
         3018,
         3028,
         3030,
         3030,
         3023,
         3023,
         3023,
         3023,
         3023,
         3023,
         3011,
         3011,
         3023,
         3024,
         3023,
         3023,
         3024,
         3023,
         3024,
         3023,
         3024,
         3011,
         3018,
         3018,
         3018,
         3023,
         3124,
         3124,
         3023,
         3124,
         3023,
         3124,
         3023,
         3023,
         3024,
         3124,
         3011,
         3014,
         3018,
         3020,
         3020,
         3024,
         3011,
         3026,
         3026,
         3011,
         3011,
         3011,
         3011,
         3011,
         3018,
         3018,
         3018,
         3018,
         3018,
         3028,
         3030,
         3030,
         3024,
         3024,
         3024,
         3024,
         3024,
         3024,
         3011,
         3011,
         3024,
         3024,
         3024,
         3024,
         3024,
         3024,
         3024,
         3024,
         3024,
         3011,
         3018,
         3018,
         3018,
         3024,
         3124,
         3124,
         3024,
         3124,
         3024,
         3124,
         3024,
         3024,
         3024,
         3124,
         3010,
         3012,
         3017,
         3019,
         3019,
         3021,
         3010,
         3025,
         3025,
         3010,
         3010,
         3010,
         3010,
         3010,
         3017,
         3017,
         3017,
         3017,
         3017,
         3027,
         3029,
         3029,
         3021,
         3021,
         3031,
         3021,
         3031,
         3031,
         3010,
         3010,
         3021,
         3022,
         3021,
         3021,
         3022,
         3023,
         3024,
         3031,
         3032,
         3010,
         3017,
         3017,
         3017,
         3021,
         3022,
         3022,
         3021,
         3024,
         3031,
         3032,
         3021,
         3021,
         3022,
         3022,
         3010,
         3012,
         3017,
         3019,
         3019,
         3022,
         3010,
         3025,
         3025,
         3010,
         3010,
         3010,
         3010,
         3010,
         3017,
         3017,
         3017,
         3017,
         3017,
         3027,
         3029,
         3029,
         3022,
         3022,
         3032,
         3022,
         3032,
         3032,
         3010,
         3010,
         3022,
         3022,
         3022,
         3022,
         3022,
         3024,
         3024,
         3032,
         3032,
         3010,
         3017,
         3017,
         3017,
         3022,
         3022,
         3022,
         3022,
         3024,
         3032,
         3032,
         3022,
         3022,
         3022,
         3022,
         23,
         3015,
         1594,
         1595,
         1595,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         3010,
         3010,
         23,
         3010,
         3010,
         3011,
         3011,
         3010,
         3010,
         23,
         1594,
         1594,
         1594,
         23,
         3010,
         3010,
         23,
         3011,
         23,
         3010,
         23,
         3010,
         3010,
         3010,
         1594,
         3016,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2684,
         2684,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3017,
         3017,
         3018,
         3018,
         3017,
         3017,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3018,
         1594,
         3017,
         1594,
         3017,
         3017,
         3017,
         1594,
         2680,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2687,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2684,
         2684,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3033,
         3017,
         3017,
         1594,
         3017,
         3017,
         3018,
         3018,
         3017,
         3017,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3018,
         1594,
         3017,
         1594,
         3017,
         3017,
         3017,
         1594,
         3119,
         1594,
         1604,
         1604,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2684,
         2684,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3017,
         3017,
         3018,
         3018,
         3017,
         3017,
         1594,
         1594,
         1594,
         1594,
         1594,
         3017,
         3017,
         1594,
         3018,
         1594,
         3017,
         1594,
         3017,
         3017,
         3017,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         3120,
         1605,
         1605,
         3120,
         3120,
         1605,
         23,
         23,
         3021,
         3022,
         3120,
         3121,
         3122,
         3023,
         3024,
         3021,
         3022,
         23,
         1594,
         1594,
         1594,
         3120,
         3022,
         3122,
         3120,
         3024,
         3120,
         3022,
         3120,
         3121,
         3122,
         3122,
         3010,
         3012,
         3017,
         3019,
         3019,
         3022,
         3010,
         3025,
         3025,
         3010,
         3010,
         3010,
         3010,
         3010,
         3017,
         3017,
         3017,
         3017,
         3017,
         3027,
         3029,
         3029,
         3022,
         3123,
         3022,
         3123,
         3022,
         3123,
         3010,
         3010,
         3022,
         3022,
         3022,
         3022,
         3022,
         3124,
         3124,
         3022,
         3022,
         3010,
         3017,
         3017,
         3017,
         3022,
         3022,
         3022,
         3123,
         3124,
         3022,
         3022,
         3022,
         3022,
         3022,
         3022,
         3010,
         3012,
         3017,
         3019,
         3019,
         3022,
         3010,
         3025,
         3025,
         3010,
         3010,
         3010,
         3010,
         3010,
         3017,
         3017,
         3017,
         3017,
         3017,
         3027,
         3029,
         3029,
         3022,
         3123,
         3022,
         3123,
         3022,
         3123,
         3010,
         3010,
         3022,
         3022,
         3022,
         3022,
         3022,
         3124,
         3124,
         3022,
         3022,
         3010,
         3017,
         3017,
         3017,
         3122,
         3022,
         3022,
         3125,
         3124,
         3122,
         3022,
         3122,
         3122,
         3122,
         3122,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         3120,
         1605,
         1605,
         3120,
         3120,
         1605,
         23,
         23,
         3021,
         3022,
         3120,
         3121,
         3122,
         3023,
         3024,
         3021,
         3022,
         23,
         1594,
         1594,
         1594,
         3120,
         3123,
         3125,
         3120,
         3124,
         3120,
         3123,
         3120,
         3121,
         3122,
         3125,
         3011,
         3014,
         3018,
         3020,
         3020,
         3024,
         3011,
         3026,
         3026,
         3011,
         3011,
         3011,
         3011,
         3011,
         3018,
         3018,
         3018,
         3018,
         3018,
         3028,
         3030,
         3030,
         3024,
         3124,
         3024,
         3124,
         3024,
         3124,
         3011,
         3011,
         3024,
         3024,
         3024,
         3024,
         3024,
         3124,
         3124,
         3024,
         3024,
         3011,
         3018,
         3018,
         3018,
         3024,
         3124,
         3124,
         3124,
         3124,
         3024,
         3124,
         3024,
         3024,
         3024,
         3124,
         23,
         24,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         3120,
         1605,
         2689,
         3120,
         3126,
         2689,
         23,
         23,
         3021,
         3022,
         3120,
         3121,
         3122,
         3023,
         3024,
         3031,
         3032,
         23,
         1594,
         1594,
         1594,
         3120,
         3022,
         3122,
         3120,
         3024,
         3126,
         3032,
         3120,
         3121,
         3122,
         3122,
         3010,
         3012,
         3017,
         3019,
         3019,
         3022,
         3010,
         3025,
         3025,
         3010,
         3010,
         3010,
         3010,
         3010,
         3017,
         3017,
         3017,
         3017,
         3017,
         3027,
         3029,
         3029,
         3022,
         3123,
         3032,
         3123,
         3032,
         3127,
         3010,
         3010,
         3022,
         3022,
         3022,
         3022,
         3022,
         3124,
         3124,
         3032,
         3032,
         3010,
         3017,
         3017,
         3017,
         3022,
         3022,
         3022,
         3123,
         3124,
         3032,
         3032,
         3022,
         3022,
         3022,
         3022,
         23,
         3013,
         1594,
         1595,
         1595,
         1605,
         23,
         1606,
         1606,
         23,
         23,
         23,
         23,
         23,
         1594,
         1594,
         1594,
         1594,
         1594,
         2674,
         2675,
         2675,
         3120,
         1605,
         1605,
         3120,
         3120,
         1605,
         23,
         23,
         3021,
         3022,
         3120,
         3121,
         3122,
         3023,
         3024,
         3021,
         3022,
         23,
         1594,
         1594,
         1594,
         3120,
         3022,
         3122,
         3120,
         3024,
         3120,
         3022,
         3120,
         3121,
         3122,
         3122,
         3010,
         3012,
         3017,
         3019,
         3019,
         3021,
         3010,
         3025,
         3025,
         3010,
         3010,
         3010,
         3010,
         3010,
         3017,
         3017,
         3017,
         3017,
         3017,
         3027,
         3029,
         3029,
         3121,
         3021,
         3021,
         3121,
         3121,
         3021,
         3010,
         3010,
         3021,
         3022,
         3121,
         3121,
         3122,
         3023,
         3024,
         3021,
         3022,
         3010,
         3017,
         3017,
         3017,
         3121,
         3022,
         3122,
         3121,
         3024,
         3121,
         3022,
         3121,
         3121,
         3122,
         3122,
         3010,
         3012,
         3017,
         3019,
         3019,
         3022,
         3010,
         3025,
         3025,
         3010,
         3010,
         3010,
         3010,
         3010,
         3017,
         3017,
         3017,
         3017,
         3017,
         3027,
         3029,
         3029,
         3122,
         3022,
         3022,
         3122,
         3122,
         3022,
         3010,
         3010,
         3022,
         3022,
         3122,
         3122,
         3122,
         3024,
         3024,
         3022,
         3022,
         3010,
         3017,
         3017,
         3017,
         3122,
         3022,
         3122,
         3122,
         3024,
         3122,
         3022,
         3122,
         3122,
         3122,
         3122,
         3010,
         3012,
         3017,
         3019,
         3019,
         3022,
         3010,
         3025,
         3025,
         3010,
         3010,
         3010,
         3010,
         3010,
         3017,
         3017,
         3017,
         3017,
         3017,
         3027,
         3029,
         3029,
         3122,
         3123,
         3022,
         3125,
         3122,
         3123,
         3010,
         3010,
         3022,
         3022,
         3122,
         3122,
         3122,
         3124,
         3124,
         3022,
         3022,
         3010,
         3017,
         3017,
         3017,
         3122,
         3022,
         3122,
         3125,
         3124,
         3122,
         3022,
         3122,
         3122,
         3122,
         3122,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         11,
         0,
         11,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         15,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         21,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         22,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         27,
         28,
         0,
         0,
         0,
         0,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         20,
         20,
         20,
         20,
         20,
         20,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         25,
         25,
         23,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 31,
      .table = (const uint16_t []) {
      
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2232,
         2233,
         2234,
         2235,
         2236,
         2237,
         25,
         25,
         25,
         25,
         368,
         26,
         26,
         26,
         379,
         380,
         381,
         382,
         383,
         384,
         385,
         386,
         387,
         388,
         389,
         390,
         391,
         392,
         26,
         26,
         26,
         2238,
         2239,
         2240,
         2241,
         2242,
         2243,
         26,
         26,
         26,
         26,
         380,
         25,
         26,
         393,
         393,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2232,
         2233,
         2234,
         2235,
         2236,
         2237,
         25,
         25,
         25,
         25,
         368,
         25,
         379,
         393,
         393,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2232,
         2233,
         2234,
         2235,
         2236,
         2237,
         25,
         25,
         25,
         25,
         368,
         368,
         380,
         368,
         368,
         368,
         394,
         395,
         396,
         397,
         398,
         399,
         400,
         368,
         401,
         402,
         403,
         404,
         368,
         368,
         368,
         2244,
         2245,
         2246,
         2247,
         2248,
         2249,
         368,
         368,
         368,
         368,
         368,
         25,
         381,
         25,
         25,
         394,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2232,
         2233,
         2234,
         2235,
         2236,
         2237,
         25,
         25,
         25,
         25,
         394,
         369,
         382,
         369,
         369,
         395,
         369,
         369,
         405,
         406,
         407,
         408,
         409,
         369,
         410,
         411,
         412,
         413,
         369,
         369,
         369,
         2233,
         2233,
         2250,
         2251,
         2252,
         2253,
         369,
         369,
         369,
         369,
         395,
         370,
         383,
         370,
         370,
         396,
         370,
         405,
         370,
         414,
         415,
         416,
         417,
         370,
         418,
         419,
         420,
         421,
         370,
         370,
         370,
         2254,
         2255,
         2256,
         2257,
         2258,
         2259,
         370,
         370,
         370,
         370,
         396,
         371,
         384,
         371,
         371,
         397,
         371,
         406,
         414,
         371,
         422,
         423,
         424,
         371,
         425,
         426,
         427,
         428,
         371,
         371,
         371,
         2260,
         2261,
         2262,
         2263,
         2264,
         2265,
         371,
         371,
         371,
         371,
         397,
         372,
         385,
         372,
         372,
         398,
         372,
         407,
         415,
         422,
         372,
         429,
         430,
         372,
         431,
         432,
         433,
         434,
         372,
         372,
         372,
         2266,
         2267,
         2268,
         2269,
         2270,
         2271,
         372,
         372,
         372,
         372,
         398,
         373,
         386,
         373,
         373,
         399,
         373,
         408,
         416,
         423,
         429,
         373,
         435,
         373,
         436,
         437,
         438,
         439,
         373,
         373,
         373,
         2272,
         2273,
         2274,
         2275,
         2276,
         2277,
         373,
         373,
         373,
         373,
         399,
         374,
         387,
         374,
         374,
         400,
         374,
         409,
         417,
         424,
         430,
         435,
         374,
         374,
         440,
         441,
         442,
         443,
         374,
         374,
         374,
         2278,
         2279,
         2280,
         2281,
         2282,
         2283,
         374,
         374,
         374,
         374,
         400,
         25,
         388,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2232,
         2233,
         2234,
         2235,
         2236,
         2237,
         25,
         25,
         25,
         25,
         368,
         375,
         389,
         375,
         375,
         401,
         375,
         410,
         418,
         425,
         431,
         436,
         440,
         375,
         375,
         444,
         445,
         446,
         375,
         375,
         375,
         2284,
         2285,
         2286,
         2287,
         2288,
         2289,
         375,
         375,
         375,
         375,
         401,
         376,
         390,
         376,
         376,
         402,
         376,
         411,
         419,
         426,
         432,
         437,
         441,
         376,
         444,
         376,
         447,
         448,
         376,
         376,
         376,
         2290,
         2291,
         2292,
         2293,
         2294,
         2295,
         376,
         376,
         376,
         376,
         402,
         377,
         391,
         377,
         377,
         403,
         377,
         412,
         420,
         427,
         433,
         438,
         442,
         377,
         445,
         447,
         377,
         449,
         377,
         377,
         377,
         2296,
         2297,
         2298,
         2299,
         2300,
         2301,
         377,
         377,
         377,
         377,
         403,
         378,
         392,
         378,
         378,
         404,
         378,
         413,
         421,
         428,
         434,
         439,
         443,
         378,
         446,
         448,
         449,
         378,
         378,
         378,
         378,
         2302,
         2303,
         2304,
         2305,
         2306,
         2307,
         378,
         378,
         378,
         378,
         404,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         450,
         450,
         2232,
         2233,
         2234,
         2235,
         2236,
         2237,
         25,
         25,
         25,
         25,
         368,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         450,
         25,
         450,
         2232,
         2233,
         2234,
         2235,
         2236,
         2237,
         25,
         25,
         25,
         25,
         368,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         450,
         450,
         450,
         2232,
         2233,
         2234,
         2235,
         2236,
         2237,
         25,
         25,
         25,
         25,
         368,
         2232,
         2238,
         2232,
         2232,
         2244,
         2232,
         2233,
         2254,
         2260,
         2266,
         2272,
         2278,
         2232,
         2284,
         2290,
         2296,
         2302,
         2232,
         2232,
         2232,
         2232,
         2233,
         2308,
         2309,
         2310,
         2311,
         2232,
         2232,
         2232,
         2232,
         2244,
         2233,
         2239,
         2233,
         2233,
         2245,
         2233,
         2233,
         2255,
         2261,
         2267,
         2273,
         2279,
         2233,
         2285,
         2291,
         2297,
         2303,
         2233,
         2233,
         2233,
         2233,
         2233,
         2312,
         2313,
         2314,
         2315,
         2233,
         2233,
         2233,
         2233,
         2245,
         2234,
         2240,
         2234,
         2234,
         2246,
         2234,
         2250,
         2256,
         2262,
         2268,
         2274,
         2280,
         2234,
         2286,
         2292,
         2298,
         2304,
         2234,
         2234,
         2234,
         2308,
         2312,
         2234,
         2316,
         2317,
         2318,
         2234,
         2234,
         2234,
         2234,
         2246,
         2235,
         2241,
         2235,
         2235,
         2247,
         2235,
         2251,
         2257,
         2263,
         2269,
         2275,
         2281,
         2235,
         2287,
         2293,
         2299,
         2305,
         2235,
         2235,
         2235,
         2309,
         2313,
         2316,
         2235,
         2319,
         2320,
         2235,
         2235,
         2235,
         2235,
         2247,
         2236,
         2242,
         2236,
         2236,
         2248,
         2236,
         2252,
         2258,
         2264,
         2270,
         2276,
         2282,
         2236,
         2288,
         2294,
         2300,
         2306,
         2236,
         2236,
         2236,
         2310,
         2314,
         2317,
         2319,
         2236,
         2321,
         2236,
         2236,
         2236,
         2236,
         2248,
         2237,
         2243,
         2237,
         2237,
         2249,
         2237,
         2253,
         2259,
         2265,
         2271,
         2277,
         2283,
         2237,
         2289,
         2295,
         2301,
         2307,
         2237,
         2237,
         2237,
         2311,
         2315,
         2318,
         2320,
         2321,
         2237,
         2237,
         2237,
         2237,
         2237,
         2249,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2232,
         2233,
         2234,
         2235,
         2236,
         2237,
         25,
         2322,
         2322,
         25,
         368,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2232,
         2233,
         2234,
         2235,
         2236,
         2237,
         2322,
         25,
         2322,
         25,
         368,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2232,
         2233,
         2234,
         2235,
         2236,
         2237,
         2322,
         2322,
         2322,
         25,
         368,
         25,
         26,
         25,
         25,
         368,
         25,
         369,
         370,
         371,
         372,
         373,
         374,
         25,
         375,
         376,
         377,
         378,
         25,
         25,
         25,
         2232,
         2233,
         2234,
         2235,
         2236,
         2237,
         25,
         25,
         25,
         25,
         3109,
         368,
         380,
         368,
         368,
         368,
         394,
         395,
         396,
         397,
         398,
         399,
         400,
         368,
         401,
         402,
         403,
         404,
         368,
         368,
         368,
         2244,
         2245,
         2246,
         2247,
         2248,
         2249,
         368,
         368,
         368,
         3109,
         368,
      },
   },
   [nir_op_usadd_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         27,
         27,
         27,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         9,
         10,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         16,
         15,
         15,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         20,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         4,
         4,
         4,
         4,
         3,
         20,
         3,
         3,
         3,
         20,
         3,
         20,
         3,
         3,
         3,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         22,
         7,
         18,
         0,
         19,
         19,
         19,
         19,
         23,
         19,
         0,
         0,
         18,
         18,
         0,
         18,
         18,
         0,
         0,
         2,
         2,
         2,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         19,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         0,
         0,
         0,
         0,
         18,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 25,
      .table = (const uint16_t []) {
      
         28,
         29,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2387,
         1610,
         2388,
         2389,
         2390,
         2390,
         3061,
         3062,
         28,
         29,
         29,
         1616,
         1617,
         1618,
         1619,
         1620,
         1621,
         1622,
         1623,
         1624,
         1625,
         29,
         1626,
         29,
         1623,
         2391,
         1616,
         2392,
         2393,
         2394,
         2395,
         3063,
         3064,
         3118,
         1610,
         1616,
         1610,
         1610,
         1610,
         1610,
         1610,
         1627,
         1628,
         1610,
         1629,
         1630,
         1610,
         1631,
         1610,
         1610,
         2396,
         1610,
         2397,
         2398,
         2399,
         2399,
         3065,
         3066,
         1610,
         28,
         1617,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1632,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2387,
         1610,
         2388,
         2389,
         2390,
         2390,
         3061,
         3062,
         28,
         28,
         1618,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1632,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2387,
         1610,
         2388,
         2389,
         2390,
         2390,
         3061,
         3062,
         28,
         28,
         1619,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2387,
         1610,
         2388,
         2389,
         2390,
         2390,
         3061,
         3062,
         28,
         28,
         1620,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2387,
         1610,
         2388,
         2389,
         2390,
         2390,
         3061,
         3062,
         28,
         1611,
         1621,
         1627,
         1611,
         1611,
         1611,
         1611,
         1633,
         1634,
         1611,
         1635,
         1636,
         1611,
         1637,
         1611,
         1611,
         2400,
         2401,
         2402,
         2403,
         2404,
         2404,
         3067,
         3068,
         1611,
         1612,
         1622,
         1628,
         1632,
         1632,
         1612,
         1612,
         1634,
         1612,
         1612,
         1638,
         1639,
         1612,
         1640,
         1612,
         1612,
         2405,
         1628,
         2406,
         2407,
         2408,
         2408,
         3069,
         3070,
         1612,
         28,
         1623,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2387,
         1610,
         2388,
         2389,
         2390,
         2390,
         3061,
         3062,
         28,
         1613,
         1624,
         1629,
         1613,
         1613,
         1613,
         1613,
         1635,
         1638,
         1613,
         1613,
         1641,
         1613,
         1642,
         1613,
         1613,
         2387,
         1629,
         2409,
         2410,
         2411,
         2411,
         3071,
         3072,
         1613,
         1614,
         1625,
         1630,
         1614,
         1614,
         1614,
         1614,
         1636,
         1639,
         1614,
         1641,
         1643,
         1614,
         1644,
         1614,
         1614,
         2412,
         1630,
         2413,
         2414,
         2415,
         2415,
         3073,
         3074,
         1614,
         28,
         29,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         1645,
         1615,
         28,
         28,
         2387,
         1610,
         2388,
         2389,
         2390,
         2390,
         3061,
         3062,
         28,
         1615,
         1626,
         1631,
         1615,
         1615,
         1615,
         1615,
         1637,
         1640,
         1615,
         1642,
         1644,
         1615,
         1615,
         1615,
         1615,
         2416,
         1631,
         2417,
         2418,
         2419,
         2419,
         3075,
         3076,
         1615,
         28,
         29,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         1646,
         28,
         2387,
         1610,
         2388,
         2389,
         2390,
         2390,
         3061,
         3062,
         28,
         28,
         1623,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         2420,
         2421,
         1610,
         2388,
         2389,
         2390,
         2390,
         3061,
         3062,
         28,
         2387,
         2391,
         2396,
         2387,
         2387,
         2387,
         2387,
         2400,
         2405,
         2387,
         2387,
         2412,
         2387,
         2416,
         2387,
         2421,
         2421,
         2396,
         2422,
         2423,
         2424,
         2424,
         3077,
         3078,
         2387,
         1610,
         1616,
         1610,
         1610,
         1610,
         1610,
         1610,
         2401,
         1628,
         1610,
         1629,
         1630,
         1610,
         1631,
         1610,
         1610,
         2396,
         1610,
         2397,
         2398,
         2399,
         2399,
         3079,
         3066,
         1610,
         2388,
         2392,
         2397,
         2388,
         2388,
         2388,
         2388,
         2402,
         2406,
         2388,
         2409,
         2413,
         2388,
         2417,
         2388,
         2388,
         2422,
         2397,
         2388,
         2389,
         2425,
         2425,
         3080,
         3062,
         2388,
         2389,
         2393,
         2398,
         2389,
         2389,
         2389,
         2389,
         2403,
         2407,
         2389,
         2410,
         2414,
         2389,
         2418,
         2389,
         2389,
         2423,
         2398,
         2389,
         2426,
         2427,
         2427,
         3081,
         3082,
         2389,
         2390,
         2394,
         2399,
         2390,
         2390,
         2390,
         2390,
         2404,
         2408,
         2390,
         2411,
         2415,
         2390,
         2419,
         2390,
         2390,
         2424,
         2399,
         2425,
         2427,
         2390,
         2390,
         3083,
         3084,
         2390,
         2390,
         2395,
         2399,
         2390,
         2390,
         2390,
         2390,
         2404,
         2408,
         2390,
         2411,
         2415,
         2390,
         2419,
         2390,
         2390,
         2424,
         2399,
         2425,
         2427,
         2390,
         2390,
         3083,
         3084,
         2390,
         3061,
         3063,
         3065,
         3061,
         3061,
         3061,
         3061,
         3067,
         3069,
         3061,
         3071,
         3073,
         3061,
         3075,
         3061,
         3061,
         3077,
         3079,
         3080,
         3081,
         3083,
         3083,
         3067,
         3085,
         3061,
         3062,
         3064,
         3066,
         3062,
         3062,
         3062,
         3062,
         3068,
         3070,
         3062,
         3072,
         3074,
         3062,
         3076,
         3062,
         3062,
         3078,
         3066,
         3062,
         3082,
         3084,
         3084,
         3085,
         3082,
         3062,
         28,
         3118,
         1610,
         28,
         28,
         28,
         28,
         1611,
         1612,
         28,
         1613,
         1614,
         28,
         1615,
         28,
         28,
         2387,
         1610,
         2388,
         2389,
         2390,
         2390,
         3061,
         3062,
         28,
      },
   },
   [nir_op_fmulz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         30,
         31,
         1647,
         30,
         30,
         30,
         1648,
         30,
         31,
         31,
         1649,
         1650,
         1651,
         1652,
         1653,
         31,
         1647,
         1649,
         1647,
         1647,
         1647,
         1647,
         1654,
         1647,
         30,
         1650,
         1647,
         30,
         30,
         30,
         1648,
         30,
         30,
         1651,
         1647,
         30,
         30,
         30,
         1648,
         30,
         30,
         1652,
         1647,
         30,
         30,
         30,
         1648,
         30,
         1648,
         1653,
         1654,
         1648,
         1648,
         1648,
         1648,
         1648,
         30,
         31,
         1647,
         30,
         30,
         30,
         1648,
         1655,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         11,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         12,
         4,
         3,
         3,
         3,
         11,
         3,
         3,
         3,
         3,
         3,
         11,
         3,
         3,
         11,
         3,
         11,
         3,
         11,
         11,
         3,
         3,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         11,
         11,
         11,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         14,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         10,
         10,
         10,
         15,
         10,
         0,
         0,
         10,
         10,
         0,
         10,
         10,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         10,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         11,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         13,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2432,
         2429,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         36,
         37,
         36,
         1665,
         1665,
         36,
         1666,
         36,
         36,
         36,
         36,
         1665,
         1665,
         1666,
         1666,
         36,
         1667,
         1668,
         1667,
         1669,
         1669,
         1667,
         1670,
         1667,
         1667,
         1667,
         1667,
         1669,
         1669,
         1670,
         1670,
         1667,
         1671,
         1672,
         1671,
         1673,
         1673,
         1671,
         1674,
         1671,
         1671,
         1671,
         1671,
         1673,
         1673,
         1674,
         1674,
         1671,
         1675,
         1676,
         1675,
         1677,
         1677,
         1675,
         1678,
         1675,
         1675,
         1675,
         1675,
         1677,
         1677,
         1678,
         1678,
         1675,
         1679,
         1680,
         1679,
         1681,
         1681,
         1679,
         1682,
         1679,
         1679,
         1679,
         1679,
         1681,
         1681,
         1682,
         1682,
         1679,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         2433,
         34,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         2434,
         2435,
         2434,
         2436,
         2436,
         2434,
         2437,
         2434,
         2434,
         2434,
         2434,
         2436,
         2436,
         2437,
         2437,
         2434,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1671,
         1672,
         1671,
         1673,
         1673,
         1671,
         1674,
         1671,
         1671,
         1671,
         1671,
         1673,
         1673,
         1674,
         1674,
         1671,
         1675,
         1676,
         1675,
         1677,
         1677,
         1675,
         1678,
         1675,
         1675,
         1675,
         1675,
         1677,
         1677,
         1678,
         1678,
         1675,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         3087,
         3087,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         1667,
         1668,
         1667,
         1669,
         1669,
         1667,
         1670,
         1667,
         1667,
         1667,
         1667,
         1669,
         1669,
         1670,
         1670,
         1667,
         1683,
         1684,
         1683,
         1685,
         1685,
         1683,
         1686,
         1683,
         1683,
         1683,
         1683,
         1685,
         1685,
         1686,
         1686,
         1683,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         1688,
         1689,
         1688,
         1690,
         1690,
         1688,
         1691,
         1688,
         1688,
         1688,
         1688,
         1690,
         1690,
         1691,
         2438,
         1688,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         2439,
         2440,
         2439,
         2441,
         2441,
         2439,
         2442,
         2439,
         2439,
         2439,
         2439,
         2441,
         2441,
         2442,
         2442,
         2439,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         3088,
         3088,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         1671,
         1672,
         1671,
         1673,
         1673,
         1671,
         1674,
         1671,
         1671,
         1671,
         1671,
         1673,
         1673,
         1674,
         1674,
         1671,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         2429,
         2430,
         2429,
         2443,
         2443,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2443,
         2443,
         2432,
         2432,
         2429,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3089,
         3089,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         1675,
         1676,
         1675,
         1677,
         1677,
         1675,
         1678,
         1675,
         1675,
         1675,
         1675,
         1677,
         1677,
         1678,
         1678,
         1675,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         2429,
         2430,
         2429,
         2443,
         2443,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2443,
         2443,
         2432,
         2432,
         2429,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3089,
         3089,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         1679,
         1680,
         1679,
         1681,
         1681,
         1679,
         1682,
         1679,
         1679,
         1679,
         1679,
         1681,
         1681,
         1682,
         1682,
         1679,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2432,
         2429,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2432,
         2429,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2428,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         2433,
         34,
         1688,
         1689,
         1688,
         1690,
         1690,
         1688,
         1691,
         1688,
         1688,
         1688,
         1688,
         1690,
         1690,
         1691,
         2438,
         1688,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2428,
         32,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2444,
         2429,
         2445,
         2446,
         2445,
         2447,
         2447,
         2445,
         2448,
         2445,
         2445,
         2445,
         2445,
         2447,
         2447,
         2448,
         2449,
         2445,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2428,
         32,
         32,
         33,
         32,
         2450,
         2450,
         32,
         1657,
         32,
         32,
         32,
         32,
         2450,
         2450,
         1657,
         2428,
         32,
         32,
         33,
         32,
         2450,
         2450,
         32,
         1657,
         32,
         32,
         32,
         32,
         2450,
         2450,
         1657,
         2428,
         32,
         2445,
         2446,
         2445,
         2447,
         2447,
         2445,
         2448,
         2445,
         2445,
         2445,
         2445,
         3090,
         3090,
         2448,
         2449,
         2445,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         2428,
         32,
         2451,
         2452,
         2451,
         2453,
         2453,
         2451,
         2454,
         2451,
         2451,
         2451,
         2451,
         2453,
         2453,
         2454,
         2454,
         2451,
         2455,
         2456,
         2455,
         2457,
         2457,
         2455,
         2458,
         2455,
         2455,
         2455,
         2455,
         2457,
         2457,
         2458,
         2458,
         2455,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2432,
         2429,
         2434,
         2435,
         2434,
         2436,
         2436,
         2434,
         2437,
         2434,
         2434,
         2434,
         2434,
         2436,
         2436,
         2437,
         2437,
         2434,
         2439,
         2440,
         2439,
         2441,
         2441,
         2439,
         2442,
         2439,
         2439,
         2439,
         2439,
         2441,
         2441,
         2442,
         2442,
         2439,
         2429,
         2430,
         2429,
         2443,
         2443,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2443,
         2443,
         2432,
         2432,
         2429,
         2429,
         2430,
         2429,
         2443,
         2443,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2443,
         2443,
         2432,
         2432,
         2429,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2432,
         2429,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2432,
         2429,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2444,
         2429,
         2455,
         2456,
         2455,
         2457,
         2457,
         2455,
         2458,
         2455,
         2455,
         2455,
         2455,
         2457,
         2457,
         2458,
         2458,
         2455,
         2455,
         2456,
         2455,
         2457,
         2457,
         2455,
         2458,
         2455,
         2455,
         2455,
         2455,
         2457,
         2457,
         2458,
         2458,
         2455,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2432,
         2429,
         2429,
         2430,
         2429,
         2443,
         2443,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2443,
         2443,
         2432,
         2432,
         2429,
         2429,
         2430,
         2429,
         2443,
         2443,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2443,
         2443,
         2432,
         2432,
         2429,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2432,
         2429,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2432,
         2429,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         3091,
         3091,
         2432,
         2432,
         2429,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2445,
         2446,
         2445,
         2447,
         2447,
         2445,
         2448,
         2445,
         2445,
         2445,
         2445,
         2447,
         2447,
         2448,
         2449,
         2445,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2432,
         2429,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         1671,
         1672,
         1671,
         1673,
         1673,
         1671,
         1674,
         1671,
         1671,
         1671,
         1671,
         1673,
         1673,
         1674,
         1674,
         1671,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         2429,
         2430,
         2429,
         2443,
         2443,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2443,
         2443,
         2432,
         2432,
         2429,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3089,
         3089,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         1675,
         1676,
         1675,
         1677,
         1677,
         1675,
         1678,
         1675,
         1675,
         1675,
         1675,
         1677,
         1677,
         1678,
         1678,
         1675,
         1660,
         1661,
         1660,
         1687,
         1687,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1687,
         1687,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         2429,
         2430,
         2429,
         2443,
         2443,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2443,
         2443,
         2432,
         2432,
         2429,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3089,
         3089,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         2450,
         2450,
         32,
         1657,
         32,
         32,
         32,
         32,
         2450,
         2450,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2432,
         2429,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         1658,
         1658,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         1662,
         1662,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         2450,
         2450,
         32,
         1657,
         32,
         32,
         32,
         32,
         2450,
         2450,
         1657,
         2428,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         2431,
         2431,
         2432,
         2432,
         2429,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         1664,
         1664,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         1656,
         1656,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         34,
         35,
         34,
         1658,
         1658,
         34,
         1659,
         34,
         34,
         34,
         34,
         3087,
         3087,
         1659,
         1659,
         34,
         1660,
         1661,
         1660,
         1662,
         1662,
         1660,
         1663,
         1660,
         1660,
         1660,
         1660,
         3088,
         3088,
         1663,
         1663,
         1660,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3089,
         3089,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3089,
         3089,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         2445,
         2446,
         2445,
         2447,
         2447,
         2445,
         2448,
         2445,
         2445,
         2445,
         2445,
         3090,
         3090,
         2448,
         2449,
         2445,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         2429,
         2430,
         2429,
         2431,
         2431,
         2429,
         2432,
         2429,
         2429,
         2429,
         2429,
         3091,
         3091,
         2432,
         2432,
         2429,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3089,
         3089,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1664,
         1664,
         32,
         1657,
         32,
         32,
         32,
         32,
         3089,
         3089,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
         32,
         33,
         32,
         1656,
         1656,
         32,
         1657,
         32,
         32,
         32,
         32,
         3086,
         3086,
         1657,
         1657,
         32,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         38,
         39,
         38,
         1692,
         1692,
         1693,
         40,
         41,
         40,
         1694,
         1694,
         1695,
         38,
         39,
         38,
         1692,
         1692,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1692,
         1692,
         1693,
         40,
         41,
         40,
         1694,
         1694,
         1695,
         42,
         43,
         42,
         1697,
         1697,
         1698,
         40,
         41,
         40,
         1694,
         1694,
         1695,
         1699,
         1700,
         1699,
         1701,
         1701,
         1702,
         1703,
         1704,
         1703,
         1705,
         1705,
         1706,
         40,
         41,
         40,
         1694,
         1694,
         1695,
         38,
         39,
         38,
         1692,
         1692,
         1693,
         40,
         41,
         40,
         1694,
         1694,
         1695,
         1707,
         1708,
         1707,
         1709,
         1709,
         1710,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1692,
         1692,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         1699,
         1700,
         1699,
         1701,
         1701,
         1702,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         1703,
         1704,
         1703,
         1705,
         1705,
         1706,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1692,
         1692,
         1693,
         40,
         41,
         40,
         1694,
         1694,
         1695,
         38,
         39,
         38,
         1692,
         1692,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1696,
         1696,
         1693,
         38,
         39,
         38,
         1692,
         1692,
         1693,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         4,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         12,
         13,
         14,
         15,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         25,
         26,
         27,
         26,
         27,
         28,
         28,
         28,
         28,
         29,
         29,
         29,
         29,
         30,
         30,
         31,
         32,
         33,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         35,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         37,
         38,
         39,
         40,
         41,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         3,
         4,
         3,
         3,
         3,
         4,
         3,
         3,
         4,
         4,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         44,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         13,
         12,
         12,
         13,
         13,
         14,
         14,
         15,
         14,
         15,
         14,
         15,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         17,
         17,
         17,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         18,
         17,
         18,
         17,
         18,
         17,
         17,
         17,
         18,
         18,
         17,
         18,
         17,
         17,
         17,
         18,
         17,
         18,
         17,
         17,
         17,
         17,
         21,
         21,
         21,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         22,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         22,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         21,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         46,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         31,
         32,
         32,
         32,
         32,
         32,
         32,
         47,
         32,
         32,
         48,
         49,
         32,
         32,
         31,
         31,
         31,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         33,
         33,
         33,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         27,
         26,
         27,
         26,
         26,
         27,
         26,
         27,
         26,
         26,
         27,
         27,
         26,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         42,
         42,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         54,
         4,
         12,
         12,
         12,
         55,
         13,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         16,
         16,
         16,
         16,
         16,
         16,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         19,
         18,
         18,
         18,
         18,
         18,
         23,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         27,
         28,
         29,
         32,
         34,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         53,
         53,
         51,
         45,
         9,
         9,
         9,
         9,
         9,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         57,
         58,
         4,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         25,
         0,
         18,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         59,
         18,
         18,
         18,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         60,
         61,
         8,
         0,
         8,
         8,
         4,
         13,
         9,
         62,
         63,
         64,
         8,
         8,
         8,
         4,
         13,
         9,
         65,
         66,
         67,
         8,
         8,
         8,
         4,
         13,
         9,
         65,
      },
      
      .num_filtered_states = 68,
      .table = (const uint16_t []) {
      
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         45,
         45,
         1364,
         45,
         1365,
         1366,
         45,
         1367,
         1368,
         1369,
         45,
         45,
         45,
         1370,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         1371,
         45,
         1372,
         45,
         1373,
         45,
         1374,
         2532,
         2533,
         2534,
         2535,
         2536,
         45,
         45,
         2537,
         2538,
         2539,
         2540,
         3008,
         3009,
         45,
         45,
         45,
         3134,
         3136,
         3137,
         3144,
         3145,
         3146,
         3153,
         3154,
         3155,
         44,
         1364,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         1375,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         1375,
         44,
         44,
         44,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         44,
         1365,
         44,
         1375,
         1375,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         1375,
         44,
         44,
         44,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         44,
         1366,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         2541,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1358,
         1367,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1376,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1377,
         1358,
         1378,
         1358,
         1379,
         1358,
         1380,
         2542,
         1376,
         1358,
         2543,
         2544,
         1358,
         1358,
         2545,
         2546,
         2547,
         2548,
         1358,
         1358,
         1358,
         1358,
         1358,
         1376,
         1358,
         1358,
         1376,
         1358,
         1358,
         1376,
         1358,
         1358,
         1358,
         1368,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1376,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1358,
         1377,
         1358,
         1378,
         1358,
         1379,
         1358,
         1380,
         2542,
         1376,
         1358,
         2543,
         2544,
         1358,
         1358,
         2545,
         2546,
         2547,
         2548,
         1358,
         1358,
         1358,
         1358,
         1358,
         1376,
         1358,
         1358,
         1376,
         1358,
         1358,
         1376,
         1358,
         1358,
         1359,
         1369,
         1359,
         1359,
         1359,
         1359,
         1359,
         1376,
         1376,
         1381,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1382,
         1359,
         1383,
         1359,
         1384,
         1359,
         1385,
         2549,
         1381,
         1359,
         2550,
         2551,
         1359,
         1359,
         2552,
         2553,
         2554,
         2555,
         1359,
         1359,
         1359,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1386,
         44,
         44,
         44,
         44,
         44,
         44,
         1387,
         1387,
         1387,
         1387,
         1388,
         1388,
         1388,
         1388,
         1389,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         1390,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         1391,
         44,
         44,
         44,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         44,
         1370,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         1391,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         1391,
         44,
         44,
         44,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         1392,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         1392,
         1392,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         1393,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2556,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         1393,
         1393,
         1393,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1387,
         44,
         44,
         44,
         44,
         44,
         44,
         1394,
         1394,
         1394,
         1394,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1387,
         44,
         44,
         44,
         44,
         44,
         44,
         1394,
         1395,
         1396,
         1397,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1387,
         44,
         44,
         44,
         44,
         44,
         44,
         1394,
         1396,
         1398,
         1399,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1387,
         44,
         44,
         44,
         44,
         44,
         44,
         1394,
         1397,
         1399,
         1400,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1388,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1401,
         1401,
         1401,
         1401,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1388,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1401,
         1402,
         1403,
         1404,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1388,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1401,
         1403,
         1405,
         1406,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1388,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1401,
         1404,
         1406,
         1407,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         1389,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1408,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1409,
         1409,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1409,
         1409,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         3128,
         3129,
         3130,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1410,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1411,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1412,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1413,
         1413,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1414,
         1413,
         1413,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2557,
         1414,
         1414,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1413,
         1413,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2558,
         1413,
         1413,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1413,
         1413,
         44,
         1415,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2558,
         1413,
         1413,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1416,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1360,
         1371,
         1360,
         1360,
         1360,
         1360,
         1360,
         1377,
         1377,
         1382,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1360,
         1416,
         1416,
         1360,
         1417,
         1360,
         1418,
         1360,
         1419,
         2559,
         1382,
         1360,
         2560,
         2561,
         1360,
         1360,
         2562,
         2563,
         2564,
         2565,
         1360,
         1360,
         1360,
         1360,
         1360,
         1382,
         1360,
         1360,
         1382,
         1360,
         1360,
         1382,
         1360,
         1360,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1420,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1361,
         1372,
         1361,
         1361,
         1361,
         1361,
         1361,
         1378,
         1378,
         1383,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1361,
         1417,
         1420,
         1420,
         1361,
         1421,
         1361,
         1422,
         2566,
         1383,
         1361,
         2567,
         2568,
         1361,
         1361,
         2569,
         2570,
         2571,
         2572,
         1361,
         1361,
         1361,
         1361,
         1361,
         1383,
         1361,
         1361,
         1383,
         1361,
         1361,
         1383,
         1361,
         1361,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1423,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1362,
         1373,
         1362,
         1362,
         1362,
         1362,
         1362,
         1379,
         1379,
         1384,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1362,
         1418,
         1362,
         1421,
         1423,
         1423,
         1362,
         1424,
         2573,
         1384,
         1362,
         2574,
         2575,
         1362,
         1362,
         2576,
         2577,
         2578,
         2579,
         1362,
         1362,
         1362,
         1362,
         1362,
         1384,
         1362,
         1362,
         1384,
         1362,
         1362,
         1384,
         1362,
         1362,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1425,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1363,
         1374,
         1363,
         1363,
         1363,
         1363,
         1363,
         1380,
         1380,
         1385,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1363,
         1419,
         1363,
         1422,
         1363,
         1424,
         1425,
         1425,
         2580,
         1385,
         1363,
         2581,
         2582,
         1363,
         1363,
         2583,
         2584,
         2585,
         2586,
         1363,
         1363,
         1363,
         1363,
         1363,
         1385,
         1363,
         1363,
         1385,
         1363,
         1363,
         1385,
         1363,
         1363,
         2525,
         2532,
         2525,
         2525,
         2525,
         2525,
         2525,
         2542,
         2542,
         2549,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2525,
         2559,
         2525,
         2566,
         2525,
         2573,
         2525,
         2580,
         2549,
         2549,
         2525,
         2587,
         2588,
         2525,
         2525,
         2589,
         2590,
         2591,
         2592,
         2525,
         2525,
         2525,
         2525,
         2525,
         2549,
         2525,
         2525,
         2549,
         2525,
         2525,
         2549,
         2525,
         2525,
         1359,
         2533,
         1359,
         1359,
         1359,
         1359,
         1359,
         1376,
         1376,
         1381,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1382,
         1359,
         1383,
         1359,
         1384,
         1359,
         1385,
         2549,
         1381,
         1359,
         2550,
         2551,
         1359,
         1359,
         2552,
         2553,
         2554,
         2555,
         1359,
         1359,
         1359,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         44,
         2534,
         44,
         44,
         44,
         44,
         2541,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         2593,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         2526,
         2535,
         2526,
         2526,
         2526,
         2526,
         2526,
         2543,
         2543,
         2550,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2556,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2526,
         2560,
         2526,
         2567,
         2526,
         2574,
         2526,
         2581,
         2587,
         2550,
         2526,
         2556,
         2594,
         2526,
         2526,
         2595,
         2596,
         2597,
         2598,
         2526,
         2526,
         2556,
         2556,
         2556,
         2550,
         2526,
         2526,
         2550,
         2526,
         2526,
         2550,
         2526,
         2526,
         2527,
         2536,
         2527,
         2527,
         2527,
         2527,
         2527,
         2544,
         2544,
         2551,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2527,
         2557,
         2558,
         2558,
         2527,
         2561,
         2527,
         2568,
         2527,
         2575,
         2527,
         2582,
         2588,
         2551,
         2527,
         2594,
         2557,
         2557,
         2557,
         2599,
         2600,
         2601,
         2602,
         2527,
         2527,
         2527,
         2527,
         2527,
         2551,
         2527,
         2527,
         2551,
         2527,
         2527,
         2551,
         2527,
         2527,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1414,
         1413,
         1413,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2557,
         1414,
         2603,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1414,
         1413,
         1413,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2557,
         2603,
         1414,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         44,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         2528,
         2537,
         2528,
         2528,
         2528,
         2528,
         2528,
         2545,
         2545,
         2552,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2528,
         2562,
         2528,
         2569,
         2528,
         2576,
         2528,
         2583,
         2589,
         2552,
         2528,
         2595,
         2599,
         2528,
         2528,
         2528,
         2604,
         2605,
         2606,
         2528,
         2528,
         2528,
         2528,
         2528,
         2552,
         2528,
         2528,
         2552,
         2528,
         2528,
         2552,
         2528,
         2528,
         2529,
         2538,
         2529,
         2529,
         2529,
         2529,
         2529,
         2546,
         2546,
         2553,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2529,
         2563,
         2529,
         2570,
         2529,
         2577,
         2529,
         2584,
         2590,
         2553,
         2529,
         2596,
         2600,
         2529,
         2529,
         2604,
         2529,
         2607,
         2608,
         2529,
         2529,
         2529,
         2529,
         2529,
         2553,
         2529,
         2529,
         2553,
         2529,
         2529,
         2553,
         2529,
         2529,
         2530,
         2539,
         2530,
         2530,
         2530,
         2530,
         2530,
         2547,
         2547,
         2554,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2530,
         2564,
         2530,
         2571,
         2530,
         2578,
         2530,
         2585,
         2591,
         2554,
         2530,
         2597,
         2601,
         2530,
         2530,
         2605,
         2607,
         2530,
         2609,
         2530,
         2530,
         2530,
         2530,
         2530,
         2554,
         2530,
         2530,
         2554,
         2530,
         2530,
         2554,
         2530,
         2530,
         2531,
         2540,
         2531,
         2531,
         2531,
         2531,
         2531,
         2548,
         2548,
         2555,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2531,
         2565,
         2531,
         2572,
         2531,
         2579,
         2531,
         2586,
         2592,
         2555,
         2531,
         2598,
         2602,
         2531,
         2531,
         2606,
         2608,
         2609,
         2610,
         2531,
         2531,
         2531,
         2531,
         2531,
         2555,
         2531,
         2531,
         2555,
         2531,
         2531,
         2555,
         2531,
         2531,
         44,
         3008,
         44,
         1375,
         1375,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         1375,
         44,
         44,
         44,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         44,
         3009,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         1391,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         1391,
         44,
         44,
         44,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         1393,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         3128,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2556,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         1393,
         1393,
         1393,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         1393,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         3129,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2556,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         1393,
         1393,
         1393,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         44,
         45,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         1393,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         3130,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2556,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         44,
         1393,
         1393,
         1393,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         44,
         44,
         1359,
         3134,
         1359,
         1359,
         1359,
         1359,
         1359,
         1376,
         1376,
         1381,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1382,
         1359,
         1383,
         1359,
         1384,
         1359,
         1385,
         2549,
         1381,
         1359,
         2550,
         2551,
         1359,
         1359,
         2552,
         2553,
         2554,
         2555,
         1359,
         1359,
         1359,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         44,
         3136,
         44,
         1375,
         1375,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         1375,
         44,
         44,
         44,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         44,
         3137,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         1391,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         1391,
         44,
         44,
         44,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         3144,
         1359,
         1359,
         1359,
         1359,
         1359,
         1376,
         1376,
         1381,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1382,
         1359,
         1383,
         1359,
         1384,
         1359,
         1385,
         2549,
         1381,
         1359,
         2550,
         2551,
         1359,
         1359,
         2552,
         2553,
         2554,
         2555,
         1359,
         1359,
         1359,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         44,
         3145,
         44,
         1375,
         1375,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         1375,
         44,
         44,
         44,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         44,
         3146,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         1391,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         1391,
         44,
         44,
         44,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         3153,
         1359,
         1359,
         1359,
         1359,
         1359,
         1376,
         1376,
         1381,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1359,
         1382,
         1359,
         1383,
         1359,
         1384,
         1359,
         1385,
         2549,
         1381,
         1359,
         2550,
         2551,
         1359,
         1359,
         2552,
         2553,
         2554,
         2555,
         1359,
         1359,
         1359,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         1381,
         1359,
         1359,
         44,
         3154,
         44,
         1375,
         1375,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         1375,
         44,
         44,
         44,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         1359,
         1375,
         44,
         44,
         3155,
         44,
         44,
         44,
         44,
         44,
         1358,
         1358,
         1359,
         44,
         44,
         1391,
         1391,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         1360,
         44,
         1361,
         44,
         1362,
         44,
         1363,
         2525,
         1359,
         44,
         2526,
         2527,
         44,
         44,
         2528,
         2529,
         2530,
         2531,
         44,
         1391,
         44,
         44,
         44,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
         1359,
         44,
         1391,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         10,
         11,
         12,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         22,
         23,
         23,
         23,
         23,
         24,
         24,
         24,
         24,
         25,
         25,
         25,
         25,
         26,
         27,
         0,
         28,
         0,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         31,
         0,
         0,
         0,
         0,
         32,
         0,
         0,
         33,
         34,
         35,
         36,
         37,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         40,
         41,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         42,
         2,
         42,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         42,
         2,
         3,
         2,
         42,
         43,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         45,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         5,
         5,
         5,
         5,
         5,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         46,
         9,
         46,
         9,
         10,
         9,
         46,
         10,
         10,
         11,
         11,
         12,
         11,
         12,
         11,
         12,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         14,
         14,
         14,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         15,
         14,
         15,
         14,
         15,
         14,
         14,
         14,
         15,
         15,
         14,
         15,
         14,
         14,
         14,
         15,
         14,
         15,
         14,
         14,
         14,
         14,
         18,
         18,
         18,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         19,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         19,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         18,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         47,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         0,
         0,
         0,
         0,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         26,
         26,
         26,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         48,
         49,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         50,
         51,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         54,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         38,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         55,
         55,
         55,
         55,
         3,
         3,
         3,
         3,
         3,
         56,
         56,
         56,
         10,
         10,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         44,
         44,
         44,
         44,
         44,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         57,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         57,
         57,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         13,
         13,
         13,
         13,
         13,
         13,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         16,
         15,
         15,
         15,
         15,
         15,
         20,
         19,
         19,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         24,
         25,
         28,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         51,
         51,
         49,
         47,
         5,
         5,
         5,
         58,
         5,
         5,
         59,
         60,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         13,
         13,
         13,
         61,
         62,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         22,
         0,
         15,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         3,
         10,
         4,
         0,
         63,
         64,
         65,
         66,
         5,
         5,
         3,
         10,
         4,
         67,
         68,
         69,
         70,
         5,
         5,
         3,
         10,
         4,
         71,
         72,
         73,
         74,
         5,
         5,
      },
      
      .num_filtered_states = 75,
      .table = (const uint16_t []) {
      
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         47,
         47,
         47,
         47,
         1435,
         1436,
         1437,
         47,
         47,
         47,
         47,
         47,
         47,
         1438,
         1439,
         1439,
         1439,
         1439,
         47,
         47,
         47,
         47,
         47,
         47,
         47,
         47,
         47,
         47,
         1440,
         47,
         47,
         1441,
         47,
         47,
         1442,
         47,
         1443,
         47,
         1444,
         47,
         47,
         47,
         47,
         47,
         1436,
         1437,
         47,
         47,
         2463,
         2464,
         2465,
         2466,
         47,
         47,
         47,
         47,
         47,
         1436,
         1436,
         1435,
         1435,
         47,
         47,
         1435,
         1435,
         47,
         47,
         1435,
         1435,
         47,
         47,
         1435,
         1435,
         47,
         47,
         46,
         47,
         46,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         1445,
         1427,
         1427,
         2467,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         3002,
         1427,
         1427,
         1426,
         1426,
         1445,
         46,
         1426,
         1426,
         1445,
         46,
         1426,
         1426,
         1445,
         46,
         1426,
         1426,
         1445,
         46,
         46,
         47,
         1445,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1446,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         1445,
         1445,
         1427,
         1427,
         2467,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         1445,
         3002,
         1427,
         1427,
         1426,
         1426,
         1445,
         1446,
         1426,
         1426,
         1445,
         1446,
         1426,
         1426,
         1445,
         1446,
         1426,
         1426,
         1445,
         1446,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2468,
         2469,
         2470,
         2471,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1427,
         1436,
         1427,
         1427,
         1448,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1456,
         1457,
         1457,
         1457,
         1457,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1458,
         1427,
         1427,
         1459,
         1427,
         1427,
         1460,
         1427,
         1461,
         1427,
         1462,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         2472,
         2473,
         2474,
         2475,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1427,
         1437,
         1427,
         1427,
         1448,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1456,
         1457,
         1457,
         1457,
         1457,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1458,
         1427,
         1427,
         1459,
         1427,
         1427,
         1460,
         1427,
         1461,
         1427,
         1462,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         2472,
         2473,
         2474,
         2475,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         1463,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         1464,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         1465,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2476,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         3003,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         1466,
         1426,
         1426,
         46,
         1466,
         1426,
         1426,
         46,
         1466,
         1426,
         1426,
         46,
         1466,
         46,
         47,
         46,
         1446,
         1426,
         1427,
         1427,
         46,
         46,
         1466,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2476,
         1446,
         1427,
         1427,
         1466,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         3003,
         1466,
         1427,
         1427,
         1426,
         1426,
         1446,
         1466,
         1426,
         1426,
         1446,
         1466,
         1426,
         1426,
         1446,
         1466,
         1426,
         1426,
         1446,
         1466,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         1467,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         1467,
         1467,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1428,
         1438,
         1428,
         1428,
         1449,
         1456,
         1456,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1468,
         1469,
         1469,
         1469,
         1469,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1428,
         1470,
         1428,
         1428,
         1471,
         1428,
         1428,
         1472,
         1428,
         1473,
         1428,
         1474,
         1428,
         1428,
         1428,
         1428,
         1428,
         1456,
         1456,
         1428,
         1428,
         2477,
         2478,
         2479,
         2480,
         1428,
         1428,
         1428,
         1428,
         1428,
         1456,
         1456,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1449,
         1449,
         1428,
         1428,
         1429,
         1439,
         1429,
         1429,
         1450,
         1457,
         1457,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1469,
         1475,
         1475,
         1475,
         1475,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1476,
         1429,
         1429,
         1477,
         1429,
         1429,
         1478,
         1429,
         1479,
         1429,
         1480,
         1429,
         1429,
         1429,
         1429,
         1429,
         2481,
         2481,
         1429,
         1429,
         2482,
         2483,
         2484,
         2485,
         1429,
         1429,
         1429,
         1429,
         1429,
         1457,
         1457,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1429,
         1439,
         1429,
         1429,
         1450,
         1457,
         1457,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1469,
         1475,
         1481,
         1482,
         1483,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1476,
         1429,
         1429,
         1477,
         1429,
         1429,
         1478,
         1429,
         1479,
         1429,
         1480,
         1429,
         1429,
         1429,
         1429,
         1429,
         2481,
         2481,
         1429,
         1429,
         2482,
         2483,
         2484,
         2485,
         1429,
         1429,
         1429,
         1429,
         1429,
         1457,
         1457,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1429,
         1439,
         1429,
         1429,
         1450,
         1457,
         1457,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1469,
         1475,
         1482,
         1484,
         1485,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1476,
         1429,
         1429,
         1477,
         1429,
         1429,
         1478,
         1429,
         1479,
         1429,
         1480,
         1429,
         1429,
         1429,
         1429,
         1429,
         2481,
         2481,
         1429,
         1429,
         2482,
         2483,
         2484,
         2485,
         1429,
         1429,
         1429,
         1429,
         1429,
         1457,
         1457,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1429,
         1439,
         1429,
         1429,
         1450,
         1457,
         1457,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1469,
         1475,
         1483,
         1485,
         1486,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1429,
         1476,
         1429,
         1429,
         1477,
         1429,
         1429,
         1478,
         1429,
         1479,
         1429,
         1480,
         1429,
         1429,
         1429,
         1429,
         1429,
         2481,
         2481,
         1429,
         1429,
         2482,
         2483,
         2484,
         2485,
         1429,
         1429,
         1429,
         1429,
         1429,
         1457,
         1457,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         1450,
         1450,
         1429,
         1429,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         1487,
         1487,
         1487,
         1487,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         1487,
         1488,
         1489,
         1490,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         1487,
         1489,
         1491,
         1492,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         1487,
         1490,
         1492,
         1493,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         1464,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         1494,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         1495,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         1496,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1497,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1498,
         1498,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1498,
         1498,
         1499,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1430,
         1440,
         1430,
         1430,
         1451,
         1458,
         1458,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1470,
         1476,
         1476,
         1476,
         1476,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1430,
         1499,
         1500,
         1430,
         1430,
         1501,
         1430,
         1430,
         1502,
         1430,
         1503,
         1430,
         1504,
         1430,
         1430,
         1430,
         1430,
         1430,
         1458,
         1458,
         1430,
         1430,
         2486,
         2487,
         2488,
         2489,
         1430,
         1430,
         1430,
         1430,
         1430,
         1458,
         1458,
         1451,
         1451,
         1430,
         1430,
         1451,
         1451,
         1430,
         1430,
         1451,
         1451,
         1430,
         1430,
         1451,
         1451,
         1430,
         1430,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         1505,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1506,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1431,
         1441,
         1431,
         1431,
         1452,
         1459,
         1459,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1471,
         1477,
         1477,
         1477,
         1477,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1431,
         1501,
         1431,
         1506,
         1506,
         1431,
         1431,
         1507,
         1431,
         1508,
         1431,
         1509,
         1431,
         1431,
         1431,
         1431,
         1431,
         1459,
         1459,
         1431,
         1431,
         2490,
         2491,
         2492,
         2493,
         1431,
         1431,
         1431,
         1431,
         1431,
         1459,
         1459,
         1452,
         1452,
         1431,
         1431,
         1452,
         1452,
         1431,
         1431,
         1452,
         1452,
         1431,
         1431,
         1452,
         1452,
         1431,
         1431,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         2494,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1510,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1432,
         1442,
         1432,
         1432,
         1453,
         1460,
         1460,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1472,
         1478,
         1478,
         1478,
         1478,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1432,
         1502,
         1432,
         1432,
         1507,
         1432,
         1510,
         1510,
         1432,
         1511,
         1432,
         1512,
         1432,
         1432,
         1432,
         1432,
         1432,
         1460,
         1460,
         1432,
         1432,
         2495,
         2496,
         2497,
         2498,
         1432,
         1432,
         1432,
         1432,
         1432,
         1460,
         1460,
         1453,
         1453,
         1432,
         1432,
         1453,
         1453,
         1432,
         1432,
         1453,
         1453,
         1432,
         1432,
         1453,
         1453,
         1432,
         1432,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1513,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1433,
         1443,
         1433,
         1433,
         1454,
         1461,
         1461,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1473,
         1479,
         1479,
         1479,
         1479,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1433,
         1503,
         1433,
         1433,
         1508,
         1433,
         1433,
         1511,
         1513,
         1513,
         1433,
         1514,
         1433,
         1433,
         1433,
         1433,
         1433,
         1461,
         1461,
         1433,
         1433,
         2499,
         2500,
         2501,
         2502,
         1433,
         1433,
         1433,
         1433,
         1433,
         1461,
         1461,
         1454,
         1454,
         1433,
         1433,
         1454,
         1454,
         1433,
         1433,
         1454,
         1454,
         1433,
         1433,
         1454,
         1454,
         1433,
         1433,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1515,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1434,
         1444,
         1434,
         1434,
         1455,
         1462,
         1462,
         1434,
         1434,
         1434,
         1434,
         1434,
         1434,
         1474,
         1480,
         1480,
         1480,
         1480,
         1434,
         1434,
         1434,
         1434,
         1434,
         1434,
         1434,
         1434,
         1434,
         1434,
         1504,
         1434,
         1434,
         1509,
         1434,
         1434,
         1512,
         1434,
         1514,
         1515,
         1515,
         1434,
         1434,
         1434,
         1434,
         1434,
         1462,
         1462,
         1434,
         1434,
         2503,
         2504,
         2505,
         2506,
         1434,
         1434,
         1434,
         1434,
         1434,
         1462,
         1462,
         1455,
         1455,
         1434,
         1434,
         1455,
         1455,
         1434,
         1434,
         1455,
         1455,
         1434,
         1434,
         1455,
         1455,
         1434,
         1434,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         1516,
         1516,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         1516,
         46,
         1516,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         1516,
         1516,
         1516,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         2476,
         2476,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         1445,
         1427,
         1427,
         2507,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         3004,
         1427,
         1427,
         1426,
         1426,
         1445,
         2476,
         1426,
         1426,
         1445,
         2476,
         1426,
         1426,
         1445,
         2476,
         1426,
         1426,
         1445,
         2476,
         46,
         47,
         1445,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1446,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         2494,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         1445,
         1445,
         1427,
         1427,
         2467,
         46,
         2459,
         2460,
         2508,
         2509,
         46,
         46,
         46,
         1445,
         3002,
         3005,
         3110,
         1426,
         1426,
         1445,
         1446,
         1426,
         1426,
         1445,
         1446,
         1426,
         1426,
         1445,
         1446,
         1426,
         1426,
         1445,
         1446,
         1427,
         1436,
         1427,
         1427,
         1448,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1456,
         2481,
         2481,
         2481,
         2481,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1458,
         1427,
         1427,
         1459,
         1427,
         1427,
         1460,
         1427,
         1461,
         1427,
         1462,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         2472,
         2473,
         2474,
         2475,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1427,
         1437,
         1427,
         1427,
         1448,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1456,
         2481,
         2481,
         2481,
         2481,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1458,
         1427,
         1427,
         1459,
         1427,
         1427,
         1460,
         1427,
         1461,
         1427,
         1462,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         2472,
         2473,
         2474,
         2475,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         46,
         47,
         2467,
         2467,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2507,
         2467,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         3006,
         46,
         1427,
         1427,
         1426,
         1426,
         2467,
         1466,
         1426,
         1426,
         2467,
         1466,
         1426,
         1426,
         2467,
         1466,
         1426,
         1426,
         2467,
         1466,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         2510,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         2459,
         2463,
         2459,
         2459,
         2468,
         2472,
         2472,
         2459,
         2459,
         2459,
         2459,
         2459,
         2459,
         2477,
         2482,
         2482,
         2482,
         2482,
         2459,
         2459,
         2459,
         2459,
         2459,
         2459,
         2459,
         2459,
         2459,
         2459,
         2486,
         2459,
         2459,
         2490,
         2459,
         2459,
         2495,
         2459,
         2499,
         2459,
         2503,
         2459,
         2459,
         2459,
         2459,
         2459,
         2472,
         2472,
         2459,
         2459,
         2459,
         2511,
         2512,
         2513,
         2459,
         2459,
         2459,
         2459,
         2459,
         2472,
         2472,
         2468,
         2468,
         2459,
         2459,
         2468,
         2468,
         2459,
         2459,
         2468,
         2468,
         2459,
         2459,
         2468,
         2468,
         2459,
         2459,
         2460,
         2464,
         2460,
         2460,
         2469,
         2473,
         2473,
         2460,
         2460,
         2460,
         2460,
         2460,
         2460,
         2478,
         2483,
         2483,
         2483,
         2483,
         2460,
         2460,
         2460,
         2460,
         2460,
         2460,
         2460,
         2460,
         2460,
         2460,
         2487,
         2460,
         2460,
         2491,
         2460,
         2460,
         2496,
         2460,
         2500,
         2460,
         2504,
         2460,
         2460,
         2460,
         2460,
         2460,
         2473,
         2473,
         2460,
         2460,
         2511,
         2460,
         2514,
         2515,
         2460,
         2460,
         2460,
         2460,
         2460,
         2473,
         2473,
         2469,
         2469,
         2460,
         2460,
         2469,
         2469,
         2460,
         2460,
         2469,
         2469,
         2460,
         2460,
         2469,
         2469,
         2460,
         2460,
         2461,
         2465,
         2461,
         2461,
         2470,
         2474,
         2474,
         2461,
         2461,
         2461,
         2461,
         2461,
         2461,
         2479,
         2484,
         2484,
         2484,
         2484,
         2461,
         2461,
         2461,
         2461,
         2461,
         2461,
         2461,
         2461,
         2461,
         2461,
         2488,
         2461,
         2461,
         2492,
         2461,
         2461,
         2497,
         2461,
         2501,
         2461,
         2505,
         2461,
         2461,
         2461,
         2461,
         2508,
         2474,
         2474,
         2461,
         2461,
         2512,
         2514,
         2461,
         2516,
         2461,
         2461,
         2461,
         2461,
         2461,
         2474,
         2474,
         2470,
         2470,
         2461,
         2461,
         2470,
         2470,
         2461,
         2461,
         2470,
         2470,
         2461,
         2461,
         2470,
         2470,
         2461,
         2461,
         2462,
         2466,
         2462,
         2462,
         2471,
         2475,
         2475,
         2462,
         2462,
         2462,
         2462,
         2462,
         2462,
         2480,
         2485,
         2485,
         2485,
         2485,
         2462,
         2462,
         2462,
         2462,
         2462,
         2462,
         2462,
         2462,
         2462,
         2462,
         2489,
         2462,
         2462,
         2493,
         2462,
         2462,
         2498,
         2462,
         2502,
         2462,
         2506,
         2462,
         2462,
         2462,
         2462,
         2509,
         2475,
         2475,
         2462,
         2462,
         2513,
         2515,
         2516,
         2517,
         2462,
         2462,
         2462,
         2462,
         2462,
         2475,
         2475,
         2471,
         2471,
         2462,
         2462,
         2471,
         2471,
         2462,
         2462,
         2471,
         2471,
         2462,
         2462,
         2471,
         2471,
         2462,
         2462,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         2518,
         2518,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         2518,
         46,
         2518,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         46,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         46,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         46,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         2518,
         2518,
         2518,
         46,
         46,
         1427,
         1427,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         1426,
         1426,
         46,
         46,
         46,
         47,
         46,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         3003,
         3003,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         46,
         1445,
         1427,
         1427,
         3006,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         46,
         3007,
         1427,
         1427,
         1426,
         1426,
         1445,
         3003,
         1426,
         1426,
         1445,
         3003,
         1426,
         1426,
         1445,
         3003,
         1426,
         1426,
         1445,
         3003,
         46,
         47,
         3002,
         3002,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         3004,
         3002,
         1427,
         1427,
         46,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         3007,
         46,
         1427,
         1427,
         1426,
         1426,
         3002,
         1466,
         1426,
         1426,
         3002,
         1466,
         1426,
         1426,
         3002,
         1466,
         1426,
         1426,
         3002,
         1466,
         1427,
         1436,
         1427,
         1427,
         1448,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1456,
         1457,
         1457,
         1457,
         1457,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1458,
         1427,
         1427,
         1459,
         1427,
         1427,
         1460,
         1427,
         1461,
         1427,
         1462,
         1427,
         1427,
         1427,
         1427,
         3005,
         1427,
         1427,
         1427,
         1427,
         2472,
         2473,
         2474,
         2475,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1427,
         1436,
         1427,
         1427,
         1448,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1456,
         1457,
         1457,
         1457,
         1457,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1458,
         1427,
         1427,
         1459,
         1427,
         1427,
         1460,
         1427,
         1461,
         1427,
         1462,
         1427,
         1427,
         1427,
         1427,
         3110,
         1427,
         1427,
         1427,
         1427,
         2472,
         2473,
         2474,
         2475,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1448,
         1448,
         1427,
         1427,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2468,
         2469,
         2470,
         2471,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         3111,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2468,
         2469,
         2470,
         2471,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         3111,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         46,
         47,
         1445,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1446,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         1445,
         1445,
         1427,
         1427,
         2467,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         1445,
         3002,
         1427,
         1427,
         1426,
         1426,
         1445,
         3112,
         1426,
         1426,
         1445,
         3112,
         1426,
         1426,
         1445,
         3112,
         1426,
         1426,
         1445,
         3112,
         46,
         47,
         46,
         1446,
         1426,
         1427,
         1427,
         46,
         46,
         1466,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2476,
         1446,
         1427,
         1427,
         1466,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         3003,
         1466,
         1427,
         1427,
         1426,
         1426,
         3112,
         1466,
         1426,
         1426,
         3112,
         1466,
         1426,
         1426,
         3112,
         1466,
         1426,
         1426,
         3112,
         1466,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2468,
         2469,
         2470,
         2471,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         1447,
         3140,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2468,
         2469,
         2470,
         2471,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         3140,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         46,
         47,
         1445,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1446,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         1445,
         1445,
         1427,
         1427,
         2467,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         1445,
         3002,
         1427,
         1427,
         1426,
         1426,
         1445,
         3112,
         1426,
         1426,
         1445,
         3141,
         1426,
         1426,
         1445,
         3141,
         1426,
         1426,
         1445,
         3141,
         46,
         47,
         46,
         1446,
         1426,
         1427,
         1427,
         46,
         46,
         1466,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2476,
         1446,
         1427,
         1427,
         1466,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         3003,
         1466,
         1427,
         1427,
         1426,
         1426,
         3112,
         1466,
         1426,
         1426,
         3141,
         1466,
         1426,
         1426,
         3141,
         1466,
         1426,
         1426,
         3141,
         1466,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2468,
         2469,
         2470,
         2471,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         3149,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2468,
         2469,
         2470,
         2471,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         3149,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         46,
         47,
         1445,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1446,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         1445,
         1445,
         1427,
         1427,
         2467,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         1445,
         3002,
         1427,
         1427,
         1426,
         1426,
         1445,
         3112,
         1426,
         1426,
         1445,
         3141,
         1426,
         1426,
         1445,
         3150,
         1426,
         1426,
         1445,
         3150,
         46,
         47,
         46,
         1446,
         1426,
         1427,
         1427,
         46,
         46,
         1466,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2476,
         1446,
         1427,
         1427,
         1466,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         3003,
         1466,
         1427,
         1427,
         1426,
         1426,
         3112,
         1466,
         1426,
         1426,
         3141,
         1466,
         1426,
         1426,
         3150,
         1466,
         1426,
         1426,
         3150,
         1466,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2468,
         2469,
         2470,
         2471,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         3158,
         1426,
         1426,
         1426,
         1435,
         1426,
         1426,
         1447,
         1448,
         1448,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1449,
         1450,
         1450,
         1450,
         1450,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1426,
         1451,
         1426,
         1426,
         1452,
         1426,
         1426,
         1453,
         1426,
         1454,
         1426,
         1455,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1426,
         1426,
         2468,
         2469,
         2470,
         2471,
         1426,
         1426,
         1426,
         1426,
         1426,
         1448,
         1448,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         1447,
         1447,
         1426,
         1426,
         3158,
         1447,
         1426,
         1426,
         46,
         47,
         1445,
         1445,
         1426,
         1427,
         1427,
         46,
         46,
         46,
         1446,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         1445,
         1445,
         1427,
         1427,
         2467,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         1445,
         3002,
         1427,
         1427,
         1426,
         1426,
         1445,
         3112,
         1426,
         1426,
         1445,
         3141,
         1426,
         1426,
         1445,
         3150,
         1426,
         1426,
         1445,
         3159,
         46,
         47,
         46,
         1446,
         1426,
         1427,
         1427,
         46,
         46,
         1466,
         1466,
         46,
         46,
         1428,
         1429,
         1429,
         1429,
         1429,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         46,
         1430,
         46,
         46,
         1431,
         46,
         46,
         1432,
         46,
         1433,
         46,
         1434,
         46,
         46,
         46,
         2476,
         1446,
         1427,
         1427,
         1466,
         46,
         2459,
         2460,
         2461,
         2462,
         46,
         46,
         46,
         3003,
         1466,
         1427,
         1427,
         1426,
         1426,
         3112,
         1466,
         1426,
         1426,
         3141,
         1466,
         1426,
         1426,
         3150,
         1466,
         1426,
         1426,
         3159,
         1466,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         5,
         5,
         6,
         7,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         48,
         1711,
         1712,
         1713,
         1714,
         2668,
         2669,
         2670,
         2671,
         2672,
         2673,
      },
   },
   [nir_op_umul_unorm_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         49,
         49,
         49,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         50,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         51,
         52,
         51,
         51,
         1929,
         53,
         54,
         53,
         53,
         1930,
         1931,
         1932,
         1931,
         1931,
         1933,
         1934,
         1935,
         1934,
         1934,
         1936,
         51,
         52,
         51,
         51,
         1929,
         55,
         56,
         55,
         55,
         1937,
         57,
         58,
         57,
         57,
         1938,
         1939,
         1940,
         1939,
         1939,
         1941,
         1942,
         1943,
         1942,
         1942,
         1944,
         55,
         56,
         55,
         55,
         1937,
         51,
         52,
         51,
         51,
         1929,
         53,
         54,
         53,
         53,
         1930,
         1945,
         1946,
         1945,
         1945,
         1947,
         1934,
         1935,
         1934,
         1934,
         1936,
         51,
         52,
         51,
         51,
         1929,
         51,
         52,
         51,
         51,
         1929,
         53,
         54,
         53,
         53,
         1930,
         1931,
         1932,
         1931,
         1931,
         1933,
         1948,
         1949,
         1948,
         1948,
         1950,
         51,
         52,
         51,
         51,
         1929,
         51,
         52,
         51,
         51,
         1929,
         53,
         54,
         53,
         53,
         1930,
         1931,
         1932,
         1931,
         1931,
         1933,
         1934,
         1935,
         1934,
         1934,
         1936,
         51,
         52,
         51,
         51,
         1929,
      },
   },
   [nir_op_sdot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         59,
         60,
         61,
         62,
         61,
         62,
         63,
         64,
      },
   },
   [nir_op_udot_4x8_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         65,
         66,
         67,
         68,
         67,
         68,
         69,
         70,
      },
   },
   [nir_op_sdot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         71,
         71,
         72,
         72,
         72,
         72,
         73,
         73,
      },
   },
   [nir_op_udot_4x8_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         74,
         75,
         76,
         77,
         76,
         77,
         78,
         79,
      },
   },
   [nir_op_sdot_2x16_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         80,
         81,
         82,
         83,
         82,
         83,
         84,
         85,
      },
   },
   [nir_op_udot_2x16_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         86,
         87,
         88,
         89,
         88,
         89,
         90,
         91,
      },
   },
   [nir_op_sdot_2x16_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         92,
         92,
         93,
         93,
         93,
         93,
         94,
         94,
      },
   },
   [nir_op_udot_2x16_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         95,
         95,
         96,
         96,
         96,
         96,
         97,
         97,
      },
   },
   [nir_op_sudot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         98,
         99,
         100,
         101,
         102,
         103,
         104,
         105,
      },
   },
   [nir_op_sudot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         106,
         106,
         107,
         107,
         108,
         108,
         109,
         109,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         4,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         6,
         0,
         7,
         7,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         0,
         11,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         0,
         0,
         0,
         26,
         27,
         28,
         0,
         0,
         0,
         0,
         0,
         29,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         32,
         33,
         33,
         0,
         34,
         34,
         35,
         35,
         36,
         36,
         37,
         37,
         38,
         38,
         0,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         40,
         0,
         41,
         0,
         42,
         43,
         43,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         44,
         45,
         46,
         46,
         46,
         46,
         47,
         48,
         49,
         0,
         0,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         54,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         39,
         39,
         39,
         39,
         39,
         39,
         39,
         40,
         40,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         19,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         19,
         18,
         19,
         18,
         18,
         18,
         19,
         18,
         19,
         18,
         18,
         18,
         18,
         22,
         22,
         22,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         24,
         23,
         22,
         23,
         22,
         23,
         22,
         22,
         22,
         23,
         23,
         23,
         22,
         23,
         22,
         22,
         22,
         23,
         22,
         23,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         0,
         0,
         0,
         0,
         55,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         17,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         57,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         58,
         59,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         27,
         27,
         27,
         27,
         27,
         27,
         26,
         0,
         26,
         0,
         0,
         26,
         0,
         26,
         0,
         0,
         26,
         26,
         0,
         0,
         0,
         30,
         30,
         30,
         30,
         30,
         30,
         29,
         0,
         29,
         0,
         0,
         29,
         0,
         29,
         0,
         0,
         29,
         29,
         0,
         60,
         61,
         62,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         37,
         37,
         37,
         37,
         37,
         38,
         38,
         42,
         42,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         45,
         45,
         45,
         45,
         47,
         48,
         48,
         48,
         48,
         49,
         44,
         46,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         17,
         17,
         17,
         17,
         17,
         17,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         20,
         19,
         19,
         19,
         19,
         19,
         24,
         23,
         23,
         23,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         46,
         3,
         3,
         3,
         44,
         44,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         26,
         0,
         29,
         0,
         32,
         0,
         37,
         37,
         37,
         37,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         39,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         59,
         59,
         57,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         17,
         17,
         17,
         0,
         0,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         44,
         19,
         23,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         37,
         37,
         37,
         37,
         6,
         10,
         10,
         10,
         19,
         19,
         19,
         34,
         34,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         63,
         0,
         0,
         9,
         13,
         9,
         9,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         10,
         10,
      },
      
      .num_filtered_states = 64,
      .table = (const uint16_t []) {
      
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         116,
         117,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         497,
         116,
         498,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         116,
         114,
         115,
         499,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         500,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         501,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         502,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         503,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         504,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         505,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         506,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         507,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         508,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         509,
         510,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         511,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         509,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         512,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         513,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         514,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         515,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         516,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         517,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         518,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         519,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         520,
         521,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         522,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         520,
         523,
         524,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         525,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         523,
         526,
         527,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         528,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         526,
         529,
         530,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         531,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         529,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         532,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         533,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         534,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         535,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         536,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         537,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         538,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         539,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         540,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         2755,
         2756,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2757,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2755,
         2758,
         2759,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2760,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2758,
         2761,
         2762,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2763,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2761,
         2764,
         2765,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2766,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         2764,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         115,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         496,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         114,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         544,
         545,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         546,
         544,
         547,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         544,
         541,
         542,
         548,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         549,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         550,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         551,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         552,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         553,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         554,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         555,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         556,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         557,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         558,
         559,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         560,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         558,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         561,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         562,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         563,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         564,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         565,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         566,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         567,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         568,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         569,
         570,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         571,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         569,
         572,
         573,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         574,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         572,
         575,
         576,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         577,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         575,
         578,
         579,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         580,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         578,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         581,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         582,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         583,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         584,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         585,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         586,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         587,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         588,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         589,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         2767,
         2768,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2769,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2767,
         2770,
         2771,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2772,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2770,
         2773,
         2774,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2775,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2773,
         2776,
         2777,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2778,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         542,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         543,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         541,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         590,
         591,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         592,
         590,
         593,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         590,
         3135,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         597,
         598,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         599,
         597,
         600,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         597,
         594,
         595,
         601,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         602,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         603,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         604,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         605,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         606,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         607,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         608,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         609,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         610,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         611,
         612,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         613,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         611,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         614,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         615,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         616,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         617,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         618,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         619,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         620,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         621,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         622,
         623,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         624,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         622,
         625,
         626,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         627,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         625,
         628,
         629,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         630,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         628,
         631,
         632,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         633,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         631,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         634,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         635,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         636,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         637,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         638,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         639,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         640,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         641,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         642,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         2779,
         2780,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2781,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2779,
         2782,
         2783,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2784,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2782,
         2785,
         2786,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2787,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2785,
         2788,
         2789,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2790,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         2788,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         595,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         596,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         594,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         646,
         647,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         648,
         646,
         649,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         646,
         643,
         644,
         650,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         651,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         652,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         653,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         654,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         655,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         656,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         657,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         658,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         659,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         660,
         661,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         662,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         660,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         663,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         664,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         665,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         666,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         667,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         668,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         669,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         670,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         671,
         672,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         673,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         671,
         674,
         675,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         677,
         678,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         679,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         677,
         680,
         681,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         682,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         680,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         683,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         684,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         685,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         686,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         687,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         688,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         689,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         690,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         691,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         2791,
         2792,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2793,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2794,
         2795,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2796,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2794,
         2797,
         2798,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2799,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2797,
         2800,
         2801,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2802,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         2800,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         644,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         645,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         643,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         695,
         696,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         697,
         695,
         698,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         699,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         692,
         693,
         700,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         701,
         702,
         701,
         703,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         704,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         701,
         692,
         693,
         692,
         692,
         705,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         706,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         707,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         708,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         709,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         710,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         711,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         712,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         713,
         714,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         715,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         713,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         716,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         717,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         718,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         719,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         720,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         721,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         722,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         723,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         724,
         725,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         726,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         724,
         727,
         728,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         729,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         727,
         730,
         731,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         732,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         730,
         733,
         734,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         735,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         733,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         736,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         737,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         738,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         739,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         740,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         741,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         742,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         743,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         744,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         2803,
         2804,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2805,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2803,
         2806,
         2807,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2808,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2806,
         2809,
         2810,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2811,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2809,
         2812,
         2813,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2814,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         2812,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         693,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         694,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         692,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         748,
         749,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         750,
         748,
         751,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         748,
         745,
         746,
         752,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         753,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         754,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         755,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         756,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         757,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         758,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         759,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         760,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         761,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         762,
         763,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         764,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         762,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         765,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         766,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         767,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         768,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         769,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         770,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         771,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         772,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         773,
         774,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         775,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         773,
         776,
         777,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         778,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         776,
         779,
         780,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         783,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         784,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         782,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         785,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         786,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         787,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         788,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         789,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         790,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         791,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         792,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         793,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         2815,
         2816,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2817,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2815,
         2818,
         2819,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2820,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2818,
         2821,
         2822,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2823,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2821,
         2824,
         2825,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2826,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         2824,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         746,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         747,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         745,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         797,
         798,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         799,
         797,
         800,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         801,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         797,
         794,
         795,
         802,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         803,
         804,
         803,
         805,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         806,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         803,
         794,
         795,
         794,
         794,
         807,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         808,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         809,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         810,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         811,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         812,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         813,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         814,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         815,
         816,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         817,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         815,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         818,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         819,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         820,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         821,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         822,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         823,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         824,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         825,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         826,
         827,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         829,
         830,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         831,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         829,
         832,
         833,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         834,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         832,
         835,
         836,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         837,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         835,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         838,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         839,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         840,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         841,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         842,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         843,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         844,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         845,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         846,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         2827,
         2828,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2829,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2827,
         2830,
         2831,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2832,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2830,
         2833,
         2834,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2835,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2833,
         2836,
         2837,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2838,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         2836,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         795,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         796,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         794,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         850,
         851,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         852,
         850,
         853,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         847,
         848,
         854,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         855,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         856,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         857,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         858,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         859,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         860,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         861,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         862,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         863,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         864,
         865,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         866,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         864,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         867,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         868,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         869,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         870,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         871,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         872,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         873,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         874,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         875,
         876,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         877,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         878,
         879,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         880,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         878,
         881,
         882,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         883,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         881,
         884,
         885,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         886,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         884,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         887,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         888,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         889,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         890,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         891,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         892,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         893,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         894,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         895,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         2839,
         2840,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2841,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2839,
         2842,
         2843,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2844,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2842,
         2845,
         2846,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2847,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2845,
         2848,
         2849,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2850,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         2848,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         848,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         849,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         847,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         899,
         900,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         901,
         899,
         902,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         899,
         896,
         897,
         903,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         904,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         905,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         906,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         907,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         908,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         909,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         910,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         911,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         912,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         913,
         914,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         915,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         913,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         916,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         917,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         918,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         919,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         920,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         921,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         922,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         923,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         924,
         925,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         926,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         924,
         927,
         928,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         929,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         927,
         930,
         931,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         932,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         930,
         933,
         934,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         935,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         933,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         936,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         937,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         938,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         939,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         940,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         941,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         942,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         943,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         944,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         2851,
         2852,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2853,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2851,
         2854,
         2855,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2856,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2854,
         2857,
         2858,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2859,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2857,
         2860,
         2861,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2862,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         2860,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         897,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         898,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         896,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         948,
         949,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         950,
         948,
         951,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         945,
         946,
         952,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         953,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         954,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         955,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         956,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         957,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         958,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         959,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         960,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         961,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         962,
         963,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         965,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         966,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         967,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         968,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         969,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         970,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         971,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         972,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         973,
         974,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         975,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         973,
         976,
         977,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         978,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         976,
         979,
         980,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         981,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         979,
         982,
         983,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         984,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         982,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         985,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         986,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         987,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         988,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         989,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         990,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         991,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         992,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         993,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         2863,
         2864,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2865,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2863,
         2866,
         2867,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2868,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2866,
         2869,
         2870,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2871,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2869,
         2872,
         2873,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2874,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         2872,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         946,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         947,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         945,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         997,
         998,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         999,
         997,
         1000,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         994,
         995,
         1001,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         1002,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         1003,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         1004,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         1005,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         1006,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1007,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1008,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1009,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1010,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1011,
         1012,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1013,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         1011,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1014,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         1015,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1016,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1017,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1018,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1019,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1020,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1021,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1022,
         1023,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1024,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1022,
         1025,
         1026,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1027,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1025,
         1028,
         1029,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1030,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1028,
         1031,
         1032,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1033,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         1031,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1034,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1035,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1036,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1037,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1038,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1039,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1040,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1041,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1042,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         2875,
         2876,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2877,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2875,
         2878,
         2879,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2880,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2878,
         2881,
         2882,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2883,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2881,
         2884,
         2885,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2886,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         2884,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         995,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         996,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         994,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1046,
         1047,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1048,
         1046,
         1049,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1043,
         1044,
         1050,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1051,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1052,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1053,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1054,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1055,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1056,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1057,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1058,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1059,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1060,
         1061,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1062,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1060,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1063,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1064,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1065,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1066,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1067,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1068,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1069,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1070,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1071,
         1072,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1073,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1071,
         1074,
         1075,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1076,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1074,
         1077,
         1078,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1079,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1077,
         1080,
         1081,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1082,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1080,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1083,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1084,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1085,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1086,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1087,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1088,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1089,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1090,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1091,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         2887,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         2888,
         2889,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2890,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2888,
         2891,
         2892,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2893,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2891,
         2894,
         2895,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2896,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2894,
         2897,
         2898,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2899,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         2897,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1044,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1045,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1043,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1095,
         1096,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1097,
         1095,
         1098,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1095,
         1092,
         1093,
         1099,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1100,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1101,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1102,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1103,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1104,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1105,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1106,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1107,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1108,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1109,
         1110,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1111,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1109,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1112,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1113,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1114,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1115,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1116,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1117,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1118,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1119,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1120,
         1121,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1122,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1120,
         1123,
         1124,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1125,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1126,
         1127,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1128,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1129,
         1130,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1131,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1132,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1133,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1134,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1135,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1136,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1137,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1138,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1139,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1140,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         2900,
         2901,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2902,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2900,
         2903,
         2904,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2905,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2903,
         2906,
         2907,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2908,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2906,
         2909,
         2910,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2911,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         2909,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1093,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1094,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1092,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1144,
         1145,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1146,
         1144,
         1147,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1144,
         1141,
         1142,
         1148,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1149,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1150,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1151,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1152,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1153,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1154,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1155,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1156,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1157,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1158,
         1159,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1160,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1158,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1161,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1162,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1163,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1164,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1165,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1166,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1167,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1168,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1169,
         1170,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1171,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1169,
         1172,
         1173,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1174,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1172,
         1175,
         1176,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1177,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1175,
         1178,
         1179,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1180,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1178,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1181,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1182,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1183,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1184,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1185,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1186,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1187,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1188,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1189,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         2912,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         2913,
         2914,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2915,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2913,
         2916,
         2917,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2918,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2916,
         2919,
         2920,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2921,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2919,
         2922,
         2923,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2924,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         2922,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1142,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1143,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1141,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1193,
         1194,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1195,
         1193,
         1196,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1190,
         1191,
         1197,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1198,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1199,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1200,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1201,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1202,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1203,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1204,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1205,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1206,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1207,
         1208,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1209,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1210,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1211,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1212,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1213,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1214,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1215,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1216,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1217,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1218,
         1219,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1220,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1221,
         1222,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1223,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1224,
         1225,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1226,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1227,
         1228,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1229,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1230,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1231,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1232,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1233,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1234,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1235,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1236,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1237,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1238,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2925,
         2926,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2927,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2928,
         2929,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2930,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2931,
         2932,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2933,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2934,
         2935,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2936,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1242,
         1243,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1244,
         1242,
         1245,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1242,
         1239,
         1240,
         1246,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1247,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1248,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1249,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1250,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1251,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1252,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1253,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1254,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1255,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1256,
         1257,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1258,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1256,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1259,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1260,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1261,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1262,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1263,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1264,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1265,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1266,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1267,
         1268,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1269,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1267,
         1270,
         1271,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1272,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1270,
         1273,
         1274,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1275,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1273,
         1276,
         1277,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1278,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1276,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1279,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1280,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1281,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1282,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1283,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1284,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1285,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1286,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1287,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         2937,
         2938,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2939,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2937,
         2940,
         2941,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2942,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2940,
         2943,
         2944,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2945,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2943,
         2946,
         2947,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2948,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         2946,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1240,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1241,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1239,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1291,
         1292,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1293,
         1291,
         1294,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1291,
         1288,
         1289,
         1295,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1296,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1297,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1298,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1299,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1300,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1301,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1302,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1303,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1304,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1305,
         1306,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1307,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1305,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1308,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1309,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1310,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1311,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1312,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1313,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1314,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1315,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1316,
         1317,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1318,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1316,
         1319,
         1320,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1321,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1319,
         1322,
         1323,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1324,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1322,
         1325,
         1326,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1327,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1325,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1328,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1329,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1330,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1331,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1332,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1333,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1334,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1335,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1336,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         2949,
         2950,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2951,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2949,
         2952,
         2953,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2954,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2952,
         2955,
         2956,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2957,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2955,
         2958,
         2959,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2960,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         2958,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1289,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1290,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         1288,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         1337,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         1338,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         1339,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1193,
         1194,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1195,
         1193,
         1196,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1190,
         1191,
         1197,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1198,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1199,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1200,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1201,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1202,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1203,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1204,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1205,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1206,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1207,
         1208,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1209,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1210,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1211,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1212,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1213,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1214,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1215,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1216,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1217,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1218,
         1219,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1220,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1221,
         1222,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1223,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1224,
         1225,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1226,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1227,
         1228,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1229,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1230,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1231,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1232,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1233,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1234,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1235,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1236,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1237,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1238,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2961,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2925,
         2926,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2927,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2928,
         2929,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2930,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2931,
         2932,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2933,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2934,
         2935,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2936,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1193,
         1194,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1195,
         1193,
         1196,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1190,
         1191,
         1197,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1198,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1199,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1200,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1201,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1202,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1203,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1204,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1205,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1206,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1207,
         1208,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1209,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1210,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1211,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1212,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1213,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1214,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1215,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1216,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1217,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1218,
         1219,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1220,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1221,
         1222,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1223,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1224,
         1225,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1226,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1227,
         1228,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1229,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1230,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1231,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1232,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1233,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1234,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1235,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1236,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1237,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1238,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2962,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2925,
         2926,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2927,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2928,
         2929,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2930,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2931,
         2932,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2933,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2934,
         2935,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2936,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1193,
         1194,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1195,
         1193,
         1196,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1193,
         1190,
         1191,
         1197,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1198,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1199,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1200,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1201,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1202,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1203,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1204,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1205,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1206,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1207,
         1208,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1209,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1207,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1210,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1211,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1212,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1213,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1214,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1215,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1216,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1217,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1218,
         1219,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1220,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1221,
         1222,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1223,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1221,
         1224,
         1225,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1226,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1224,
         1227,
         1228,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1229,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1227,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1230,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1231,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1232,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1233,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1234,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1235,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1236,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1237,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1238,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2963,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         2925,
         2926,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2927,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2925,
         2928,
         2929,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2930,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2928,
         2931,
         2932,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2933,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2931,
         2934,
         2935,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2936,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         2934,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1191,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1192,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         1190,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         112,
         113,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         452,
         112,
         453,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         112,
         110,
         111,
         454,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         455,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         456,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         457,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         458,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         459,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         460,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         461,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         462,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         463,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         464,
         465,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         466,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         464,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         467,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         468,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         469,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         470,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         471,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         472,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         473,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         474,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         475,
         476,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         477,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         475,
         478,
         479,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         480,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         478,
         481,
         482,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         483,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         481,
         484,
         485,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         486,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         484,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         487,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         488,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         489,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         490,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         491,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         492,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         493,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         494,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         495,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         2743,
         2744,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2745,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2743,
         2746,
         2747,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2748,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2746,
         2749,
         2750,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2751,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2749,
         2752,
         2753,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2754,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         2752,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         111,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         451,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
         110,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         12,
         12,
         12,
         12,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         2,
         18,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         21,
         4,
         4,
         0,
         2,
         2,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         118,
         119,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         119,
         119,
         1717,
         1718,
         1719,
         1720,
         1721,
         1722,
         1723,
         1724,
         119,
         1725,
         1726,
         1727,
         1728,
         2373,
         2374,
         2375,
         1717,
         2376,
         2377,
         3092,
         1715,
         1717,
         1729,
         1715,
         1730,
         1730,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1729,
         1729,
         1730,
         1715,
         1730,
         118,
         1718,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         1716,
         1719,
         1730,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1730,
         1730,
         1716,
         1716,
         1716,
         1716,
         1720,
         1730,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1730,
         1730,
         1716,
         1716,
         1716,
         118,
         1721,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         1722,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         1723,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         1731,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         2378,
         1716,
         118,
         1716,
         118,
         1724,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         119,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         1732,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         1725,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         1726,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         1727,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         1728,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         2373,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         118,
         2374,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         1715,
         2375,
         1729,
         1715,
         1730,
         1730,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1729,
         1729,
         1730,
         1715,
         1730,
         1715,
         1717,
         1729,
         1715,
         1730,
         1730,
         1715,
         1715,
         2378,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1715,
         1729,
         2379,
         1730,
         1715,
         1730,
         1716,
         2376,
         1730,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1730,
         1730,
         1716,
         1716,
         1716,
         118,
         2377,
         1715,
         118,
         1716,
         1716,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         118,
         1715,
         1715,
         1716,
         118,
         1716,
         1716,
         3092,
         1730,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1716,
         1730,
         1730,
         1716,
         1716,
         1716,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         120,
         2173,
         2174,
         2175,
      },
   },
   [nir_op_ftrunc] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         121,
      },
   },
   [nir_op_fround_even] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         122,
      },
   },
   [nir_op_ffloor] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         123,
      },
   },
   [nir_op_ffract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         124,
      },
   },
   [nir_op_fceil] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         125,
      },
   },
   [nir_search_op_b2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         126,
         2176,
         2177,
         2178,
         2179,
         2964,
         2965,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         127,
      },
   },
   [nir_op_fdot4] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         128,
         2163,
         2164,
         2165,
         2163,
         2163,
         2164,
         2165,
         2164,
         2164,
         2164,
         2165,
         2165,
         2165,
         2165,
         2165,
      },
   },
   [nir_op_vec4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         129,
         130,
         129,
         131,
         129,
         130,
         129,
         132,
         129,
         130,
         129,
         131,
         129,
         130,
         129,
         132,
      },
   },
   [nir_op_fdot3] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         133,
         2166,
         2167,
         2166,
         2166,
         2167,
         2167,
         2167,
         2167,
      },
   },
   [nir_op_vec3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         134,
         135,
         134,
         136,
         134,
         135,
         134,
         136,
      },
   },
   [nir_op_fdot2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         137,
         138,
         2168,
         138,
         138,
         2169,
         2168,
         2169,
         2168,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         139,
         140,
         139,
         139,
         141,
         142,
         141,
         141,
         139,
         140,
         139,
         1565,
         139,
         140,
         139,
         139,
      },
   },
   [nir_op_fsum2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         143,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         10,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         12,
         0,
         3,
         3,
         2,
         4,
         13,
         8,
         2,
         4,
         14,
         3,
         3,
         2,
         4,
         15,
         8,
         2,
         4,
         16,
         3,
         3,
         2,
         4,
         0,
         8,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         144,
         145,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         146,
         147,
         146,
         1541,
         146,
         1542,
         146,
         2369,
         146,
         146,
         1541,
         146,
         1541,
         146,
         1541,
         146,
         1541,
         1543,
         1544,
         1543,
         1545,
         1543,
         1546,
         1543,
         2370,
         1543,
         1543,
         1545,
         1543,
         1545,
         1543,
         1545,
         1543,
         1545,
         144,
         145,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1547,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         145,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1548,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         145,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         2371,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         2372,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3042,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3133,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3139,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3143,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3148,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3152,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         3157,
         144,
         1539,
         144,
         1540,
         144,
         2368,
         144,
         144,
         1539,
         144,
         1539,
         144,
         1539,
         144,
         1539,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         4,
         0,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         148,
         149,
         148,
         148,
         1549,
         148,
         150,
         151,
         150,
         150,
         1550,
         150,
         148,
         1551,
         148,
         148,
         1549,
         148,
         1552,
         1553,
         1552,
         1552,
         1554,
         1552,
         148,
         149,
         148,
         148,
         1549,
         148,
         148,
         1555,
         148,
         148,
         1549,
         148,
      },
   },
   [nir_op_inot] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         5,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         8,
         8,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         11,
         11,
         11,
         11,
         12,
         12,
         13,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         0,
         0,
         22,
         0,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         0,
         22,
         22,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         21,
         23,
         21,
         21,
         21,
         21,
         0,
         22,
         0,
         0,
         0,
         0,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         11,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         8,
         0,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         152,
         1915,
         1916,
         1917,
         1918,
         1919,
         1920,
         1921,
         1922,
         1923,
         1924,
         1925,
         1926,
         1927,
         1928,
         2519,
         2520,
         2521,
         2522,
         2523,
         2524,
         3038,
         3039,
         3040,
      },
   },
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         13,
         2,
         14,
         2,
         2,
         2,
         2,
         2,
         15,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         16,
         5,
         17,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         16,
         5,
         5,
         5,
         5,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         16,
         5,
         17,
         17,
         17,
         17,
         17,
         17,
         6,
         6,
         16,
         16,
         5,
         16,
         16,
         5,
         0,
         19,
         2,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         20,
         6,
         6,
         21,
         16,
         16,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         16,
         16,
         5,
         5,
         5,
         5,
         16,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         22,
         9,
         9,
         22,
         9,
         9,
         22,
         9,
         22,
         22,
         9,
         22,
         9,
         22,
         9,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 23,
      .table = (const uint16_t []) {
      
         153,
         154,
         1733,
         153,
         153,
         153,
         153,
         153,
         153,
         1734,
         153,
         1735,
         153,
         1733,
         1733,
         1733,
         153,
         153,
         153,
         1733,
         153,
         153,
         1734,
         155,
         156,
         1736,
         1737,
         1738,
         155,
         155,
         1739,
         1740,
         1741,
         1742,
         1743,
         155,
         1736,
         1736,
         1736,
         155,
         155,
         2613,
         1736,
         155,
         155,
         1741,
         153,
         1744,
         1745,
         153,
         153,
         153,
         153,
         153,
         153,
         1734,
         153,
         1735,
         153,
         1745,
         1745,
         1745,
         153,
         153,
         153,
         1745,
         153,
         153,
         1734,
         153,
         154,
         1733,
         153,
         153,
         153,
         153,
         153,
         153,
         1734,
         153,
         1735,
         153,
         1733,
         1733,
         1733,
         153,
         153,
         153,
         1733,
         153,
         153,
         1734,
         153,
         1746,
         1733,
         153,
         153,
         153,
         153,
         153,
         153,
         1734,
         153,
         1735,
         153,
         1733,
         1733,
         1733,
         153,
         153,
         153,
         1733,
         153,
         153,
         1734,
         1747,
         1748,
         1749,
         1747,
         1747,
         1747,
         1747,
         1747,
         1747,
         1750,
         1747,
         1751,
         1747,
         1749,
         1749,
         1749,
         1747,
         1747,
         1747,
         1749,
         1747,
         1747,
         1750,
         1747,
         1752,
         1749,
         1747,
         1747,
         1747,
         1747,
         1747,
         1747,
         1750,
         1747,
         1751,
         1747,
         1749,
         1749,
         1749,
         1747,
         1747,
         1747,
         1749,
         1747,
         1747,
         1750,
         153,
         154,
         1733,
         153,
         153,
         153,
         153,
         153,
         153,
         1734,
         153,
         1735,
         153,
         1733,
         1733,
         1733,
         153,
         153,
         153,
         1733,
         153,
         153,
         1734,
         153,
         1753,
         1733,
         153,
         153,
         153,
         153,
         153,
         153,
         1734,
         153,
         1735,
         153,
         1733,
         1733,
         1733,
         153,
         153,
         153,
         1733,
         153,
         153,
         1734,
         1754,
         1755,
         1756,
         1754,
         1754,
         1754,
         1754,
         1754,
         1754,
         1757,
         1754,
         1758,
         1754,
         1756,
         1756,
         1756,
         1754,
         1754,
         1754,
         1756,
         1754,
         1754,
         1757,
         153,
         1759,
         1733,
         153,
         153,
         153,
         153,
         153,
         153,
         1734,
         153,
         1735,
         153,
         1733,
         1733,
         1733,
         153,
         153,
         153,
         1733,
         153,
         153,
         1734,
         1760,
         1761,
         1762,
         1760,
         1760,
         1760,
         1760,
         1760,
         1760,
         1763,
         1760,
         1764,
         1760,
         1762,
         1762,
         1762,
         1760,
         1760,
         1760,
         1762,
         1760,
         1760,
         1763,
         153,
         154,
         1733,
         153,
         153,
         153,
         153,
         153,
         153,
         1734,
         153,
         1735,
         1765,
         1733,
         1733,
         1733,
         153,
         153,
         153,
         1733,
         153,
         153,
         1734,
         153,
         2614,
         1745,
         153,
         153,
         153,
         153,
         153,
         153,
         1734,
         153,
         1735,
         153,
         1745,
         1745,
         1745,
         153,
         153,
         153,
         1745,
         153,
         153,
         1734,
         153,
         2615,
         1745,
         153,
         153,
         153,
         153,
         153,
         153,
         1734,
         153,
         1735,
         153,
         1745,
         1745,
         1745,
         153,
         153,
         153,
         1745,
         153,
         153,
         1734,
         153,
         2616,
         1745,
         153,
         153,
         153,
         153,
         153,
         153,
         1734,
         153,
         1735,
         153,
         1745,
         1745,
         1745,
         153,
         153,
         153,
         1745,
         153,
         153,
         1734,
         1747,
         2617,
         1749,
         1747,
         1747,
         1747,
         1747,
         1747,
         1747,
         1750,
         1747,
         1751,
         1747,
         1749,
         1749,
         1749,
         1747,
         1747,
         1747,
         1749,
         1747,
         1747,
         1750,
         1747,
         2618,
         1749,
         1747,
         1747,
         1747,
         1747,
         1747,
         1747,
         1750,
         1747,
         1751,
         1747,
         1749,
         1749,
         1749,
         1747,
         1747,
         1747,
         1749,
         1747,
         1747,
         1750,
         1747,
         1748,
         1749,
         1747,
         1747,
         1747,
         1747,
         1747,
         1747,
         1750,
         1747,
         1751,
         1747,
         1749,
         1749,
         1749,
         1747,
         1747,
         1747,
         1749,
         1747,
         1747,
         1750,
         153,
         3095,
         1745,
         153,
         153,
         153,
         153,
         153,
         153,
         1734,
         153,
         1735,
         153,
         1745,
         1745,
         1745,
         153,
         153,
         153,
         1745,
         153,
         153,
         1734,
         1747,
         3113,
         1749,
         1747,
         1747,
         1747,
         1747,
         1747,
         1747,
         1750,
         1747,
         1751,
         1747,
         1749,
         1749,
         1749,
         1747,
         1747,
         1747,
         1749,
         1747,
         1747,
         1750,
         1747,
         3114,
         1749,
         1747,
         1747,
         1747,
         1747,
         1747,
         1747,
         1750,
         1747,
         1751,
         1747,
         1749,
         1749,
         1749,
         1747,
         1747,
         1747,
         1749,
         1747,
         1747,
         1750,
         1754,
         3115,
         1756,
         1754,
         1754,
         1754,
         1754,
         1754,
         1754,
         1757,
         1754,
         1758,
         1754,
         1756,
         1756,
         1756,
         1754,
         1754,
         1754,
         1756,
         1754,
         1754,
         1757,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         14,
         2,
         15,
         2,
         2,
         2,
         2,
         2,
         16,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         7,
         7,
         7,
         7,
         7,
         7,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         18,
         2,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         157,
         158,
         1766,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         157,
         1766,
         1766,
         1766,
         157,
         1766,
         159,
         160,
         1769,
         1770,
         1771,
         159,
         159,
         159,
         1772,
         1773,
         1774,
         1775,
         1776,
         159,
         1769,
         1769,
         1769,
         2619,
         1769,
         157,
         1777,
         1778,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         157,
         1778,
         1778,
         1778,
         157,
         1778,
         157,
         158,
         1766,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         157,
         1766,
         1766,
         1766,
         157,
         1766,
         157,
         1779,
         1766,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         157,
         1766,
         1766,
         1766,
         157,
         1766,
         1780,
         1781,
         1782,
         1780,
         1780,
         1780,
         1780,
         1780,
         1780,
         1780,
         1783,
         1780,
         1784,
         1780,
         1782,
         1782,
         1782,
         1780,
         1782,
         1780,
         1785,
         1782,
         1780,
         1780,
         1780,
         1780,
         1780,
         1780,
         1780,
         1783,
         1780,
         1784,
         1780,
         1782,
         1782,
         1782,
         1780,
         1782,
         157,
         1786,
         1766,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         157,
         1766,
         1766,
         1766,
         157,
         1766,
         157,
         1787,
         1766,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         157,
         1766,
         1766,
         1766,
         157,
         1766,
         157,
         158,
         1766,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         157,
         1766,
         1766,
         1766,
         157,
         1766,
         1788,
         1789,
         1790,
         1788,
         1788,
         1788,
         1788,
         1788,
         1788,
         1788,
         1791,
         1788,
         1792,
         1788,
         1790,
         1790,
         1790,
         1788,
         1790,
         157,
         1793,
         1766,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         157,
         1766,
         1766,
         1766,
         157,
         1766,
         1794,
         1795,
         1796,
         1794,
         1794,
         1794,
         1794,
         1794,
         1794,
         1794,
         1797,
         1794,
         1798,
         1794,
         1796,
         1796,
         1796,
         1794,
         1796,
         157,
         158,
         1766,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         1799,
         1766,
         1766,
         1766,
         157,
         1766,
         157,
         2620,
         1778,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         157,
         1778,
         1778,
         1778,
         157,
         1778,
         157,
         2621,
         1778,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         157,
         1778,
         1778,
         1778,
         157,
         1778,
         157,
         2622,
         1778,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         157,
         1778,
         1778,
         1778,
         157,
         1778,
         1780,
         1781,
         1782,
         1780,
         1780,
         1780,
         1780,
         1780,
         1780,
         1780,
         1783,
         1780,
         1784,
         1780,
         1782,
         1782,
         1782,
         1780,
         1782,
         157,
         3096,
         1778,
         157,
         157,
         157,
         157,
         157,
         157,
         157,
         1767,
         157,
         1768,
         157,
         1778,
         1778,
         1778,
         157,
         1778,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         12,
         12,
         12,
         12,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         2,
         18,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         21,
         4,
         4,
         0,
         2,
         2,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         161,
         162,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         162,
         162,
         1802,
         1803,
         1804,
         1805,
         1806,
         1807,
         1808,
         1809,
         162,
         1810,
         1811,
         1812,
         1813,
         2380,
         2381,
         2382,
         1802,
         2383,
         2384,
         3093,
         1800,
         1802,
         1814,
         1800,
         1815,
         1815,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1814,
         1814,
         1815,
         1800,
         1815,
         161,
         1803,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         1801,
         1804,
         1815,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1815,
         1815,
         1801,
         1801,
         1801,
         1801,
         1805,
         1815,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1815,
         1815,
         1801,
         1801,
         1801,
         161,
         1806,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         161,
         1807,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         161,
         1808,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         1816,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         2385,
         1801,
         161,
         1801,
         161,
         1809,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         161,
         162,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         1817,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         161,
         1810,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         161,
         1811,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         161,
         1812,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         161,
         1813,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         161,
         2380,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         161,
         2381,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         1800,
         2382,
         1814,
         1800,
         1815,
         1815,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1814,
         1814,
         1815,
         1800,
         1815,
         1800,
         1802,
         1814,
         1800,
         1815,
         1815,
         1800,
         1800,
         2385,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1800,
         1814,
         2386,
         1815,
         1800,
         1815,
         1801,
         2383,
         1815,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1815,
         1815,
         1801,
         1801,
         1801,
         161,
         2384,
         1800,
         161,
         1801,
         1801,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         161,
         1800,
         1800,
         1801,
         161,
         1801,
         1801,
         3093,
         1815,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1801,
         1815,
         1815,
         1801,
         1801,
         1801,
      },
   },
   [nir_op_ilt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         163,
         164,
         163,
         2084,
         2084,
         2085,
         2085,
         163,
         163,
         165,
         166,
         2086,
         2087,
         2088,
         2089,
         2090,
         2091,
         165,
         163,
         2092,
         163,
         2084,
         2084,
         2085,
         2085,
         163,
         163,
         2093,
         2094,
         2093,
         2095,
         2095,
         2096,
         2096,
         2093,
         2093,
         2093,
         2097,
         2093,
         2095,
         2095,
         2096,
         2096,
         2093,
         2093,
         2098,
         2099,
         2098,
         2100,
         2100,
         2101,
         2101,
         2098,
         2098,
         2098,
         2102,
         2098,
         2100,
         2100,
         2101,
         2101,
         2098,
         2098,
         163,
         2103,
         163,
         2084,
         2084,
         2085,
         2085,
         2104,
         163,
         163,
         2726,
         163,
         2084,
         2084,
         2085,
         2085,
         163,
         163,
      },
   },
   [nir_op_ult] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         5,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         7,
         7,
         8,
         8,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         10,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         167,
         168,
         1982,
         167,
         167,
         1983,
         1983,
         1984,
         1984,
         167,
         167,
         169,
         170,
         1985,
         169,
         1986,
         1987,
         1988,
         1989,
         1990,
         1991,
         2727,
         167,
         168,
         1982,
         167,
         167,
         1983,
         1983,
         1984,
         1984,
         167,
         167,
         1992,
         1993,
         1994,
         1992,
         1992,
         1995,
         1995,
         1996,
         1996,
         1992,
         1992,
         167,
         1997,
         1982,
         167,
         167,
         1983,
         1983,
         1984,
         1984,
         167,
         167,
         1998,
         1999,
         2000,
         1998,
         1998,
         2001,
         2001,
         2002,
         2002,
         1998,
         1998,
         1998,
         2003,
         2000,
         1998,
         1998,
         2001,
         2001,
         2002,
         2002,
         1998,
         1998,
         2004,
         2005,
         2006,
         2004,
         2004,
         2007,
         2007,
         2008,
         2008,
         2004,
         2004,
         2004,
         2009,
         2006,
         2004,
         2004,
         2007,
         2007,
         2008,
         2008,
         2004,
         2004,
         167,
         2010,
         1982,
         167,
         167,
         1983,
         1983,
         1984,
         1984,
         2011,
         167,
         167,
         168,
         1982,
         167,
         167,
         1983,
         1983,
         1984,
         1984,
         167,
         167,
      },
   },
   [nir_op_ige] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         171,
         172,
         171,
         2105,
         2105,
         2106,
         2106,
         171,
         171,
         171,
         171,
         171,
         173,
         174,
         2107,
         2108,
         2109,
         2110,
         2111,
         2112,
         173,
         173,
         173,
         173,
         171,
         2113,
         171,
         2105,
         2105,
         2106,
         2106,
         171,
         171,
         171,
         171,
         171,
         2114,
         2115,
         2114,
         2116,
         2116,
         2117,
         2117,
         2114,
         2114,
         2114,
         2114,
         2114,
         2114,
         2118,
         2114,
         2116,
         2116,
         2117,
         2117,
         2114,
         2114,
         2114,
         2114,
         2114,
         2119,
         2120,
         2119,
         2121,
         2121,
         2122,
         2122,
         2119,
         2119,
         2119,
         2119,
         2119,
         2119,
         2123,
         2119,
         2121,
         2121,
         2122,
         2122,
         2119,
         2119,
         2119,
         2119,
         2119,
         171,
         2124,
         171,
         2105,
         2105,
         2106,
         2106,
         2125,
         171,
         171,
         171,
         171,
         171,
         2126,
         171,
         2105,
         2105,
         2106,
         2106,
         171,
         171,
         171,
         171,
         171,
         171,
         2127,
         171,
         2105,
         2105,
         2106,
         2106,
         171,
         171,
         171,
         171,
         171,
         171,
         2128,
         171,
         2105,
         2105,
         2106,
         2106,
         171,
         171,
         171,
         171,
         171,
         171,
         2728,
         171,
         2105,
         2105,
         2106,
         2106,
         171,
         171,
         171,
         171,
         171,
      },
   },
   [nir_op_uge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         5,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         7,
         7,
         8,
         8,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         175,
         175,
         2012,
         175,
         175,
         2013,
         2013,
         2014,
         2014,
         175,
         176,
         176,
         2015,
         176,
         2016,
         2017,
         2018,
         2019,
         2020,
         2021,
         175,
         175,
         2012,
         175,
         175,
         2013,
         2013,
         2014,
         2014,
         175,
         2022,
         2022,
         2023,
         2022,
         2022,
         2024,
         2024,
         2025,
         2025,
         2022,
         175,
         2026,
         2012,
         175,
         175,
         2013,
         2013,
         2014,
         2014,
         175,
         2027,
         2027,
         2028,
         2027,
         2027,
         2029,
         2029,
         2030,
         2030,
         2027,
         2027,
         2031,
         2028,
         2027,
         2027,
         2029,
         2029,
         2030,
         2030,
         2027,
         2032,
         2032,
         2033,
         2032,
         2032,
         2034,
         2034,
         2035,
         2035,
         2032,
         2032,
         2036,
         2033,
         2032,
         2032,
         2034,
         2034,
         2035,
         2035,
         2032,
         175,
         2037,
         2012,
         175,
         175,
         2013,
         2013,
         2014,
         2014,
         2038,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         0,
         13,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         11,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         9,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         0,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         177,
         178,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         178,
         178,
         1952,
         1953,
         1954,
         1955,
         1956,
         1957,
         1958,
         1959,
         1960,
         1961,
         1962,
         1963,
         1964,
         2729,
         1951,
         1952,
         1951,
         1951,
         1951,
         1951,
         1951,
         1951,
         1951,
         1951,
         1951,
         1951,
         1951,
         1951,
         1951,
         1951,
         177,
         1953,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1954,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1955,
         1951,
         177,
         177,
         1965,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1956,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1957,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1958,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1959,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         1966,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1960,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1967,
         177,
         177,
         177,
         177,
         177,
         177,
         1961,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1962,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1963,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         1964,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         2729,
         1951,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
         177,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         8,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         0,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         179,
         180,
         1968,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         180,
         180,
         1969,
         1970,
         1971,
         1972,
         1973,
         1974,
         1975,
         1976,
         1977,
         1978,
         2730,
         1968,
         1969,
         1968,
         1968,
         1968,
         1968,
         1968,
         1968,
         1968,
         1968,
         1968,
         1968,
         1968,
         179,
         1970,
         1968,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         1971,
         1968,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         1972,
         1968,
         179,
         179,
         1979,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         1973,
         1968,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         1974,
         1968,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         1975,
         1968,
         179,
         179,
         179,
         179,
         179,
         1980,
         179,
         179,
         179,
         179,
         179,
         1976,
         1968,
         179,
         179,
         179,
         179,
         179,
         179,
         1981,
         179,
         179,
         179,
         179,
         1977,
         1968,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         1978,
         1968,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         2730,
         1968,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         179,
         2731,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         9,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         10,
         2,
         2,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         6,
         6,
         6,
         12,
         6,
         12,
         6,
         6,
         12,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         12,
         12,
         6,
         6,
         12,
         12,
         12,
         6,
         6,
         12,
         6,
         12,
         6,
         12,
         7,
         7,
         13,
         7,
         8,
         8,
         8,
         14,
         14,
         8,
         13,
         7,
         7,
         7,
         13,
         7,
         7,
         7,
         13,
         7,
         13,
         7,
         7,
         13,
         7,
         13,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         2,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         181,
         182,
         1818,
         1819,
         181,
         181,
         1820,
         1821,
         1821,
         2623,
         1818,
         2624,
         2625,
         3043,
         3043,
         3044,
         182,
         182,
         1822,
         1823,
         1824,
         1825,
         1826,
         1827,
         1828,
         2626,
         1822,
         2627,
         2628,
         3045,
         3046,
         3047,
         1818,
         1822,
         1818,
         1829,
         1818,
         1818,
         1830,
         1831,
         1831,
         2623,
         1818,
         2624,
         2629,
         3048,
         3048,
         3044,
         1819,
         1823,
         1829,
         1819,
         1819,
         1819,
         1832,
         1833,
         1833,
         2630,
         1829,
         2631,
         2632,
         3049,
         3049,
         3050,
         181,
         1824,
         1818,
         1819,
         181,
         181,
         1820,
         1821,
         1821,
         2623,
         1818,
         2624,
         2625,
         3043,
         3043,
         3044,
         181,
         1825,
         1818,
         1819,
         181,
         1834,
         1820,
         1821,
         1821,
         2623,
         1818,
         2624,
         2625,
         3043,
         3043,
         3044,
         1820,
         1826,
         1830,
         1832,
         1820,
         1820,
         1820,
         1835,
         1835,
         2633,
         1830,
         2634,
         2625,
         3051,
         3051,
         3052,
         1821,
         1827,
         1831,
         1833,
         1821,
         1821,
         1835,
         1821,
         1821,
         2635,
         1831,
         2636,
         2637,
         3043,
         3043,
         3053,
         1821,
         1828,
         1831,
         1833,
         1821,
         1821,
         1835,
         1821,
         1821,
         2635,
         1831,
         2636,
         2637,
         3043,
         3043,
         3053,
         2623,
         2626,
         2623,
         2630,
         2623,
         2623,
         2633,
         2635,
         2635,
         2623,
         2623,
         2638,
         2639,
         3054,
         3054,
         3055,
         1818,
         1822,
         1818,
         1829,
         1818,
         1818,
         1830,
         1831,
         1831,
         2623,
         2640,
         2624,
         2629,
         3048,
         3048,
         3044,
         2624,
         2627,
         2624,
         2631,
         2624,
         2624,
         2634,
         2636,
         2636,
         2638,
         2624,
         2624,
         2641,
         3056,
         3056,
         3057,
         2625,
         2628,
         2629,
         2632,
         2625,
         2625,
         2625,
         2637,
         2637,
         2639,
         2629,
         2641,
         2625,
         3058,
         3058,
         3059,
         3043,
         3045,
         3048,
         3049,
         3043,
         3043,
         3051,
         3043,
         3043,
         3054,
         3048,
         3056,
         3058,
         3043,
         3043,
         3060,
         3043,
         3046,
         3048,
         3049,
         3043,
         3043,
         3051,
         3043,
         3043,
         3054,
         3048,
         3056,
         3058,
         3043,
         3043,
         3060,
         3044,
         3047,
         3044,
         3050,
         3044,
         3044,
         3052,
         3053,
         3053,
         3055,
         3044,
         3057,
         3059,
         3060,
         3060,
         3044,
      },
   },
   [nir_search_op_i2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         183,
         2147,
         2148,
         2149,
         2150,
         3131,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         8,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         9,
         2,
         10,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         14,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         7,
         7,
         7,
         14,
         14,
         14,
         14,
         7,
         7,
         14,
         7,
         7,
         14,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         13,
         13,
         6,
         12,
         12,
         0,
         12,
         0,
         12,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         184,
         185,
         1836,
         1837,
         184,
         184,
         184,
         1838,
         2642,
         1836,
         2643,
         184,
         2644,
         2644,
         2645,
         184,
         184,
         185,
         185,
         1839,
         1840,
         1841,
         185,
         1842,
         1843,
         2646,
         1839,
         2647,
         2648,
         2649,
         2650,
         2651,
         3116,
         3117,
         1836,
         1839,
         1836,
         1844,
         1836,
         1836,
         1836,
         1845,
         2642,
         1836,
         2643,
         1836,
         2652,
         2652,
         2653,
         1836,
         1836,
         1837,
         1840,
         1844,
         1837,
         1837,
         1837,
         1837,
         1846,
         2654,
         1844,
         2655,
         1837,
         2656,
         2656,
         2657,
         1837,
         1837,
         184,
         1841,
         1836,
         1837,
         184,
         184,
         184,
         1838,
         2642,
         1836,
         2643,
         184,
         2644,
         2644,
         2645,
         184,
         184,
         184,
         185,
         1836,
         1837,
         184,
         1847,
         184,
         1838,
         2642,
         1836,
         2643,
         184,
         2644,
         2644,
         2645,
         184,
         184,
         184,
         1842,
         1836,
         1837,
         184,
         184,
         184,
         1838,
         2642,
         1836,
         2643,
         184,
         2644,
         2644,
         2645,
         184,
         184,
         1838,
         1843,
         1845,
         1846,
         1838,
         1838,
         1838,
         1838,
         2658,
         1845,
         2659,
         1838,
         2660,
         2660,
         2645,
         1838,
         1838,
         2642,
         2646,
         2642,
         2654,
         2642,
         2642,
         2642,
         2658,
         2642,
         2642,
         2661,
         2642,
         2662,
         2662,
         2663,
         2642,
         2642,
         1836,
         1839,
         1836,
         1844,
         1836,
         1836,
         1836,
         1845,
         2642,
         2664,
         2643,
         1836,
         2652,
         2652,
         2653,
         1836,
         1836,
         2643,
         2647,
         2643,
         2655,
         2643,
         2643,
         2643,
         2659,
         2661,
         2643,
         2643,
         2643,
         2665,
         2665,
         2666,
         2643,
         2643,
         184,
         2648,
         1836,
         1837,
         184,
         184,
         184,
         1838,
         2642,
         1836,
         2643,
         184,
         2644,
         2644,
         2645,
         184,
         184,
         2644,
         2649,
         2652,
         2656,
         2644,
         2644,
         2644,
         2660,
         2662,
         2652,
         2665,
         2644,
         2644,
         2644,
         2667,
         2644,
         2644,
         2644,
         2650,
         2652,
         2656,
         2644,
         2644,
         2644,
         2660,
         2662,
         2652,
         2665,
         2644,
         2644,
         2644,
         2667,
         2644,
         2644,
         2645,
         2651,
         2653,
         2657,
         2645,
         2645,
         2645,
         2645,
         2663,
         2653,
         2666,
         2645,
         2667,
         2667,
         2645,
         2645,
         2645,
         184,
         3116,
         1836,
         1837,
         184,
         184,
         184,
         1838,
         2642,
         1836,
         2643,
         184,
         2644,
         2644,
         2645,
         184,
         184,
         184,
         3117,
         1836,
         1837,
         184,
         184,
         184,
         1838,
         2642,
         1836,
         2643,
         184,
         2644,
         2644,
         2645,
         184,
         184,
      },
   },
   [nir_op_imin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         7,
         2,
         8,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         9,
         4,
         9,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         5,
         10,
         5,
         6,
         11,
         11,
         6,
         10,
         5,
         5,
         10,
         5,
         5,
         10,
         10,
         5,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         9,
         4,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         186,
         187,
         1861,
         1862,
         1863,
         1864,
         1864,
         2696,
         1861,
         2697,
         3097,
         3097,
         187,
         187,
         1865,
         1866,
         1867,
         1868,
         1869,
         2698,
         1865,
         2699,
         3098,
         3099,
         1861,
         1865,
         1861,
         1870,
         1871,
         1872,
         1872,
         2696,
         1861,
         2700,
         3100,
         3100,
         1862,
         1866,
         1870,
         1862,
         1873,
         1874,
         1874,
         2701,
         1870,
         2702,
         3101,
         3101,
         1863,
         1867,
         1871,
         1873,
         1863,
         1875,
         1875,
         2703,
         1871,
         2697,
         3102,
         3102,
         1864,
         1868,
         1872,
         1874,
         1875,
         1864,
         1864,
         2704,
         1872,
         2705,
         3097,
         3097,
         1864,
         1869,
         1872,
         1874,
         1875,
         1864,
         1864,
         2704,
         1872,
         2705,
         3097,
         3097,
         2696,
         2698,
         2696,
         2701,
         2703,
         2704,
         2704,
         2696,
         2696,
         2706,
         3103,
         3103,
         1861,
         1865,
         1861,
         1870,
         1871,
         1872,
         1872,
         2696,
         2707,
         2700,
         3100,
         3100,
         2697,
         2699,
         2700,
         2702,
         2697,
         2705,
         2705,
         2706,
         2700,
         2697,
         3104,
         3104,
         3097,
         3098,
         3100,
         3101,
         3102,
         3097,
         3097,
         3103,
         3100,
         3104,
         3097,
         3097,
         3097,
         3099,
         3100,
         3101,
         3102,
         3097,
         3097,
         3103,
         3100,
         3104,
         3097,
         3097,
      },
   },
   [nir_op_imax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         6,
         2,
         7,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         4,
         4,
         4,
         9,
         9,
         0,
         0,
         8,
         0,
         8,
         8,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         5,
         5,
         10,
         10,
         10,
         5,
         10,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         9,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         188,
         189,
         1876,
         1877,
         188,
         1878,
         2708,
         1876,
         2709,
         2709,
         2710,
         189,
         189,
         1879,
         1880,
         1881,
         1882,
         2711,
         1879,
         2712,
         2713,
         2714,
         1876,
         1879,
         1876,
         1883,
         1876,
         1884,
         2708,
         1876,
         2715,
         2715,
         2716,
         1877,
         1880,
         1883,
         1877,
         1877,
         1885,
         2717,
         1883,
         2718,
         2718,
         2719,
         188,
         1881,
         1876,
         1877,
         188,
         1878,
         2708,
         1876,
         2709,
         2709,
         2710,
         1878,
         1882,
         1884,
         1885,
         1878,
         1878,
         2720,
         1884,
         2721,
         2721,
         2710,
         2708,
         2711,
         2708,
         2717,
         2708,
         2720,
         2708,
         2708,
         2722,
         2722,
         2723,
         1876,
         1879,
         1876,
         1883,
         1876,
         1884,
         2708,
         2724,
         2715,
         2715,
         2716,
         2709,
         2712,
         2715,
         2718,
         2709,
         2721,
         2722,
         2715,
         2709,
         2709,
         2725,
         2709,
         2713,
         2715,
         2718,
         2709,
         2721,
         2722,
         2715,
         2709,
         2709,
         2725,
         2710,
         2714,
         2716,
         2719,
         2710,
         2710,
         2723,
         2716,
         2725,
         2725,
         2710,
      },
   },
   [nir_op_umin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         5,
         2,
         5,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         2,
         6,
         3,
         6,
         3,
         6,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         190,
         191,
         2190,
         2191,
         190,
         2732,
         3105,
         191,
         191,
         2192,
         2193,
         191,
         2733,
         3106,
         2190,
         2192,
         2190,
         2194,
         2190,
         2732,
         3107,
         2191,
         2193,
         2194,
         2191,
         2191,
         2734,
         3105,
         190,
         191,
         2190,
         2191,
         2735,
         2732,
         3105,
         2732,
         2733,
         2732,
         2734,
         2732,
         2732,
         3108,
         3105,
         3106,
         3107,
         3105,
         3105,
         3108,
         3105,
      },
   },
   [nir_op_umax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         2,
         5,
         2,
         5,
         5,
         2,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         192,
         193,
         2195,
         192,
         2736,
         2737,
         193,
         193,
         2196,
         193,
         2738,
         2739,
         2195,
         2196,
         2195,
         2195,
         2740,
         2737,
         192,
         193,
         2195,
         2741,
         2736,
         2737,
         2736,
         2738,
         2740,
         2736,
         2736,
         2742,
         2737,
         2739,
         2737,
         2737,
         2742,
         2737,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         4,
         0,
         4,
         0,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         194,
         195,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         195,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1556,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1557,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1558,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1559,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1560,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1561,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         1562,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         2966,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
         194,
      },
   },
   [nir_search_op_f2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         196,
         1886,
         1887,
         1888,
         1889,
         1890,
         1891,
      },
   },
   [nir_search_op_f2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         197,
         1892,
         1893,
         1894,
         1895,
         1896,
         1897,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         198,
         1898,
         1899,
         1900,
         1901,
         1902,
         1903,
         1904,
         1905,
         1906,
         1907,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         199,
         2041,
         2042,
         2043,
         2044,
         2045,
         2046,
         2047,
         2048,
         2049,
         2050,
         3000,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         8,
         9,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         5,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         14,
         9,
         9,
         9,
         9,
         9,
         15,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         9,
         9,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         1,
         0,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         200,
         2051,
         2052,
         2053,
         2054,
         2055,
         2056,
         2057,
         2058,
         2059,
         2060,
         2061,
         2062,
         2063,
         2998,
         2999,
         3035,
         3036,
         3037,
      },
   },
   [nir_op_f2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         201,
         1908,
         1909,
         1910,
         1911,
         1912,
         1913,
         1914,
      },
   },
   [nir_op_i2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         202,
         2151,
         2152,
         2153,
         2154,
         2155,
         2156,
         2157,
         2158,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         203,
         204,
         203,
         203,
         203,
         204,
         203,
         203,
         203,
         1563,
         203,
         203,
         203,
         1564,
         203,
         203,
      },
   },
   [nir_op_extract_i16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         205,
         206,
         205,
         206,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         207,
         208,
         207,
         207,
         207,
         207,
         208,
         207,
         207,
         207,
         207,
         2197,
         207,
         207,
         207,
         207,
         2198,
         207,
         207,
         207,
         207,
         2199,
         207,
         207,
         207,
      },
   },
   [nir_op_ixor] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         4,
         5,
         6,
         7,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         12,
         13,
         14,
         15,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         2,
         2,
         3,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         5,
         4,
         4,
         5,
         5,
         6,
         6,
         7,
         6,
         7,
         6,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         20,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
      },
      
      .num_filtered_states = 21,
      .table = (const uint16_t []) {
      
         209,
         210,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2967,
         2968,
         2969,
         2970,
         210,
         210,
         210,
         210,
         210,
         210,
         210,
         210,
         210,
         1521,
         210,
         1522,
         210,
         1523,
         210,
         1524,
         1525,
         2971,
         2972,
         2973,
         2974,
         209,
         210,
         209,
         1526,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2967,
         2968,
         2969,
         2970,
         209,
         210,
         1526,
         1526,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2967,
         2968,
         2969,
         2970,
         209,
         210,
         209,
         209,
         209,
         1527,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2967,
         2968,
         2969,
         2970,
         209,
         210,
         209,
         209,
         1527,
         1527,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2967,
         2968,
         2969,
         2970,
         209,
         210,
         209,
         209,
         209,
         209,
         209,
         1528,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2967,
         2968,
         2969,
         2970,
         209,
         210,
         209,
         209,
         209,
         209,
         1528,
         1528,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2967,
         2968,
         2969,
         2970,
         209,
         210,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1529,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2967,
         2968,
         2969,
         2970,
         1517,
         1521,
         1517,
         1517,
         1517,
         1517,
         1517,
         1517,
         1529,
         1529,
         1517,
         1530,
         1517,
         1531,
         1517,
         1532,
         1517,
         2975,
         2976,
         2977,
         2978,
         209,
         210,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1533,
         209,
         1519,
         209,
         1520,
         209,
         2967,
         2968,
         2969,
         2970,
         1518,
         1522,
         1518,
         1518,
         1518,
         1518,
         1518,
         1518,
         1518,
         1530,
         1533,
         1533,
         1518,
         1534,
         1518,
         1535,
         1518,
         2979,
         2980,
         2981,
         2982,
         209,
         210,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1536,
         209,
         1520,
         209,
         2967,
         2968,
         2969,
         2970,
         1519,
         1523,
         1519,
         1519,
         1519,
         1519,
         1519,
         1519,
         1519,
         1531,
         1519,
         1534,
         1536,
         1536,
         1519,
         1537,
         1519,
         2983,
         2984,
         2985,
         2986,
         209,
         210,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1538,
         209,
         2967,
         2968,
         2969,
         2970,
         1520,
         1524,
         1520,
         1520,
         1520,
         1520,
         1520,
         1520,
         1520,
         1532,
         1520,
         1535,
         1520,
         1537,
         1538,
         1538,
         1520,
         2987,
         2988,
         2989,
         2990,
         209,
         1525,
         209,
         209,
         209,
         209,
         209,
         209,
         209,
         1517,
         209,
         1518,
         209,
         1519,
         209,
         1520,
         209,
         2967,
         2968,
         2969,
         2970,
         2967,
         2971,
         2967,
         2967,
         2967,
         2967,
         2967,
         2967,
         2967,
         2975,
         2967,
         2979,
         2967,
         2983,
         2967,
         2987,
         2967,
         2967,
         2991,
         2992,
         2993,
         2968,
         2972,
         2968,
         2968,
         2968,
         2968,
         2968,
         2968,
         2968,
         2976,
         2968,
         2980,
         2968,
         2984,
         2968,
         2988,
         2968,
         2991,
         2968,
         2994,
         2995,
         2969,
         2973,
         2969,
         2969,
         2969,
         2969,
         2969,
         2969,
         2969,
         2977,
         2969,
         2981,
         2969,
         2985,
         2969,
         2989,
         2969,
         2992,
         2994,
         2969,
         2996,
         2970,
         2974,
         2970,
         2970,
         2970,
         2970,
         2970,
         2970,
         2970,
         2978,
         2970,
         2982,
         2970,
         2986,
         2970,
         2990,
         2970,
         2993,
         2995,
         2996,
         2997,
      },
   },
   [nir_op_slt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         211,
         212,
         213,
         214,
      },
   },
   [nir_op_sge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         215,
         216,
         217,
         218,
      },
   },
   [nir_op_seq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         219,
         219,
         219,
         219,
         219,
         219,
         219,
         219,
         2200,
         2201,
         2202,
         2203,
         219,
         2200,
         219,
         219,
         219,
         219,
         219,
         2201,
         219,
         219,
         219,
         219,
         219,
         2202,
         219,
         219,
         219,
         219,
         219,
         2203,
         219,
         219,
         219,
         219,
      },
   },
   [nir_op_sne] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         220,
         220,
         220,
         220,
         220,
         220,
         220,
         220,
         2204,
         2205,
         2206,
         2207,
         220,
         2204,
         220,
         220,
         220,
         220,
         220,
         2205,
         220,
         220,
         220,
         220,
         220,
         2206,
         220,
         220,
         220,
         220,
         220,
         2207,
         220,
         220,
         220,
         220,
      },
   },
   [nir_op_fall_equal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         221,
      },
   },
   [nir_op_fall_equal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         222,
      },
   },
   [nir_op_fall_equal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         223,
      },
   },
   [nir_op_fany_nequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         224,
      },
   },
   [nir_op_fany_nequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         225,
      },
   },
   [nir_op_fany_nequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         226,
      },
   },
   [nir_op_ball_iequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         227,
         227,
         227,
         227,
         227,
         227,
         2130,
         2131,
         227,
         2130,
         227,
         227,
         227,
         2131,
         227,
         227,
      },
   },
   [nir_op_ball_iequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         228,
         228,
         228,
         228,
         228,
         228,
         2132,
         2133,
         228,
         2132,
         228,
         228,
         228,
         2133,
         228,
         228,
      },
   },
   [nir_op_ball_iequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         229,
         229,
         229,
         229,
         229,
         229,
         2134,
         2135,
         229,
         2134,
         229,
         229,
         229,
         2135,
         229,
         229,
      },
   },
   [nir_op_bany_inequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         230,
         230,
         230,
         230,
         230,
         230,
         2180,
         2181,
         230,
         2180,
         230,
         230,
         230,
         2181,
         230,
         230,
      },
   },
   [nir_op_bany_inequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         231,
         231,
         231,
         231,
         231,
         231,
         2182,
         2183,
         231,
         2182,
         231,
         231,
         231,
         2183,
         231,
         231,
      },
   },
   [nir_op_bany_inequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         232,
         232,
         232,
         232,
         232,
         232,
         2184,
         2185,
         232,
         2184,
         232,
         232,
         232,
         2185,
         232,
         232,
      },
   },
   [nir_op_ball_fequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         233,
      },
   },
   [nir_op_ball_fequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         234,
      },
   },
   [nir_op_ball_fequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         235,
      },
   },
   [nir_op_bany_fnequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         236,
      },
   },
   [nir_op_bany_fnequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         237,
      },
   },
   [nir_op_bany_fnequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         238,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         239,
         239,
         240,
         240,
      },
   },
   [nir_op_urol] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         241,
      },
   },
   [nir_op_uror] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         242,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         243,
         2225,
         2694,
         2695,
         3094,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         2,
         2,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         4,
         4,
         5,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         244,
         2214,
         2215,
         2216,
         2217,
         2218,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         245,
         246,
         245,
         245,
         247,
         248,
         247,
         247,
         245,
         2226,
         245,
         245,
         245,
         2690,
         245,
         245,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         249,
         2219,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         3,
         3,
         4,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         250,
         2220,
         2221,
         2222,
         2223,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         251,
         2224,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         252,
         252,
         253,
         253,
      },
   },
   [nir_op_fsin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         254,
      },
   },
   [nir_op_fcos] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         255,
      },
   },
   [nir_op_fcsel] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         256,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2209,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2210,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2211,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
         2213,
      },
   },
   [nir_op_f2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         257,
         2140,
         2141,
      },
   },
   [nir_op_f2ump] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         258,
         2142,
         2143,
      },
   },
   [nir_op_i2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         259,
         2159,
         2160,
      },
   },
   [nir_op_u2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         260,
         2161,
         2162,
      },
   },
   [nir_op_pack_64_2x32_split] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         261,
         261,
         261,
         261,
         261,
         1566,
         261,
         261,
         261,
      },
   },
   [nir_op_unpack_64_2x32_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         262,
         2064,
         2065,
      },
   },
   [nir_op_unpack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         263,
         2227,
         2228,
      },
   },
   [nir_op_pack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         264,
         2229,
         2612,
      },
   },
   [nir_op_unpack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         265,
         2231,
      },
   },
   [nir_op_pack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         266,
         2230,
      },
   },
   [nir_op_unpack_32_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         267,
         2066,
         2067,
      },
   },
   [nir_op_unpack_32_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         268,
         2068,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         269,
         2069,
         0,
         270,
         2069,
         2070,
         2071,
         2072,
         0,
         269,
         2069,
         0,
         270,
         2069,
         2070,
         2071,
         2072,
         0,
         269,
         2069,
         0,
         270,
         2069,
         2070,
         2071,
         2072,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         271,
         2073,
         0,
         272,
         2073,
         2074,
         2075,
         2076,
         0,
         271,
         2073,
         0,
         272,
         2073,
         2074,
         2075,
         2076,
         0,
         271,
         2073,
         0,
         272,
         2073,
         2074,
         2075,
         2076,
      },
   },
   [nir_op_pack_32_2x16_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         273,
      },
   },
   [nir_op_unpack_half_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         0,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         274,
         2077,
         2078,
         2079,
      },
   },
   [nir_op_unpack_half_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         275,
         2080,
      },
   },
   [nir_op_pack_half_2x16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         2170,
         2171,
         2172,
      },
   },
   [nir_op_pack_half_2x16_split] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         276,
         277,
         278,
         279,
      },
   },
   [nir_op_pack_32_4x8_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         280,
      },
   },
   [nir_op_ussub_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         281,
         0,
         281,
      },
   },
   [nir_op_fsub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         282,
      },
   },
   [nir_op_uabs_usub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         283,
      },
   },
   [nir_op_uabs_isub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         284,
      },
   },
   [nir_op_find_lsb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         285,
      },
   },
   [nir_op_ifind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         286,
      },
   },
   [nir_op_ufind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         287,
      },
   },
   [nir_op_fmod] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         288,
      },
   },
   [nir_op_frem] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         289,
      },
   },
   [nir_op_uadd_carry] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         290,
      },
   },
   [nir_op_usub_borrow] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         291,
      },
   },
   [nir_op_bitfield_insert] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         292,
      },
   },
   [nir_op_ihadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         293,
      },
   },
   [nir_op_uhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         294,
      },
   },
   [nir_op_irhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         295,
      },
   },
   [nir_op_urhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         296,
      },
   },
   [nir_op_uadd_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         297,
      },
   },
   [nir_op_usub_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         298,
      },
   },
   [nir_op_iadd_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         299,
      },
   },
   [nir_op_isub_sat] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         300,
      },
   },
   [nir_op_ibitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         301,
      },
   },
   [nir_op_ubitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         302,
      },
   },
   [nir_op_bitfield_select] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         303,
         0,
         0,
         303,
         0,
         2039,
         2040,
         2039,
         0,
         303,
         0,
         0,
         303,
         0,
         2039,
         2040,
         2039,
         0,
         303,
         0,
         0,
         303,
         0,
         2039,
         2040,
         2039,
      },
   },
   [nir_op_bfm] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         2081,
         2082,
         2083,
      },
   },
   [nir_op_pack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         304,
      },
   },
   [nir_op_pack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         305,
      },
   },
   [nir_op_pack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         306,
      },
   },
   [nir_op_pack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         307,
      },
   },
   [nir_op_unpack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         308,
      },
   },
   [nir_op_unpack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         309,
      },
   },
   [nir_op_unpack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         310,
      },
   },
   [nir_op_unpack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         311,
      },
   },
   [nir_op_isign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         312,
         2129,
      },
   },
   [nir_op_amul] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         313,
      },
   },
   [nir_op_umul24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         314,
      },
   },
   [nir_op_umad24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         315,
      },
   },
   [nir_op_imul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         316,
      },
   },
   [nir_op_umad24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         317,
      },
   },
   [nir_op_umul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         318,
      },
   },
   [nir_op_imad24_ir3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         319,
         320,
         321,
         320,
         321,
         322,
         323,
      },
   },
   [nir_op_imul24] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         324,
         324,
         324,
      },
   },
   [nir_op_b2b1] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         325,
      },
   },
   [nir_op_b2b8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         326,
      },
   },
   [nir_op_b2b16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         327,
      },
   },
   [nir_op_b2b32] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         328,
      },
   },
   [nir_op_ldexp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         329,
      },
   },
   [nir_op_ball_iequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2136,
         2137,
         0,
         2136,
         0,
         0,
         0,
         2137,
         0,
         0,
      },
   },
   [nir_op_bany_inequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2186,
         2187,
         0,
         2186,
         0,
         0,
         0,
         2187,
         0,
         0,
      },
   },
   [nir_op_ball_iequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2138,
         2139,
         0,
         2138,
         0,
         0,
         0,
         2139,
         0,
         0,
      },
   },
   [nir_op_bany_inequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         2188,
         2189,
         0,
         2188,
         0,
         0,
         0,
         2189,
         0,
         0,
      },
   },
   [nir_op_fddx] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         330,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         331,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         332,
      },
   },
   [nir_op_fddy] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         333,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         334,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         335,
      },
   },
   [nir_op_umul_low] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         336,
         336,
         336,
      },
   },
   [nir_op_imadsh_mix16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         337,
         337,
         338,
         338,
         339,
         339,
      },
   },
   [nir_op_fisnormal] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         340,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_transform_offsets[] = {
   0,
   0,
   0,
   1,
   0,
   12,
   15,
   17,
   21,
   23,
   25,
   27,
   30,
   34,
   37,
   42,
   0,
   0,
   47,
   0,
   49,
   0,
   51,
   0,
   55,
   0,
   59,
   61,
   0,
   64,
   71,
   75,
   81,
   88,
   98,
   110,
   125,
   138,
   154,
   160,
   167,
   176,
   186,
   196,
   207,
   209,
   217,
   219,
   223,
   226,
   229,
   231,
   233,
   237,
   240,
   245,
   248,
   253,
   257,
   263,
   265,
   267,
   270,
   273,
   277,
   281,
   283,
   285,
   288,
   291,
   295,
   299,
   301,
   304,
   308,
   310,
   313,
   316,
   320,
   324,
   329,
   331,
   333,
   336,
   339,
   343,
   347,
   349,
   351,
   354,
   357,
   361,
   365,
   367,
   370,
   374,
   376,
   379,
   383,
   385,
   387,
   390,
   393,
   396,
   399,
   404,
   409,
   411,
   414,
   417,
   422,
   426,
   431,
   436,
   460,
   466,
   473,
   480,
   506,
   508,
   0,
   511,
   514,
   516,
   519,
   522,
   0,
   525,
   527,
   0,
   0,
   0,
   0,
   529,
   0,
   0,
   0,
   531,
   533,
   0,
   0,
   0,
   0,
   536,
   0,
   538,
   544,
   546,
   0,
   553,
   559,
   561,
   0,
   568,
   573,
   578,
   583,
   588,
   593,
   598,
   603,
   608,
   610,
   613,
   618,
   624,
   629,
   635,
   637,
   640,
   644,
   649,
   654,
   660,
   665,
   671,
   673,
   675,
   677,
   683,
   685,
   691,
   693,
   0,
   696,
   698,
   700,
   702,
   704,
   706,
   708,
   710,
   714,
   716,
   720,
   722,
   0,
   0,
   726,
   730,
   736,
   0,
   0,
   742,
   744,
   748,
   750,
   753,
   755,
   758,
   760,
   763,
   765,
   767,
   769,
   771,
   773,
   775,
   777,
   779,
   781,
   783,
   785,
   787,
   789,
   791,
   793,
   795,
   797,
   799,
   801,
   803,
   805,
   807,
   809,
   811,
   813,
   815,
   817,
   819,
   821,
   823,
   826,
   0,
   0,
   829,
   831,
   836,
   839,
   845,
   0,
   0,
   847,
   849,
   852,
   854,
   856,
   0,
   0,
   0,
   0,
   858,
   860,
   0,
   0,
   0,
   0,
   862,
   865,
   868,
   870,
   879,
   881,
   889,
   892,
   894,
   896,
   898,
   900,
   902,
   0,
   904,
   907,
   909,
   911,
   913,
   915,
   918,
   920,
   922,
   924,
   926,
   928,
   932,
   935,
   938,
   941,
   944,
   947,
   950,
   956,
   962,
   965,
   968,
   970,
   972,
   974,
   976,
   978,
   980,
   982,
   984,
   986,
   988,
   990,
   992,
   994,
   997,
   1000,
   1003,
   1005,
   1008,
   1012,
   1016,
   1021,
   1025,
   1027,
   1029,
   1031,
   1033,
   1037,
   1039,
   1041,
   1043,
   1045,
   1047,
   1049,
   1051,
   1053,
   1055,
   1058,
   1060,
   1062,
   1065,
   1068,
   1070,
   1072,
   1084,
   1097,
   1109,
   1121,
   1133,
   1146,
   1159,
   1171,
   1183,
   1187,
   1191,
   1194,
   1197,
   1199,
   1204,
   1208,
   1212,
   1216,
   1220,
   1223,
   1225,
   1230,
   0,
   1232,
   1234,
   1236,
   1238,
   1240,
   1243,
   1246,
   1249,
   1251,
   1253,
   1255,
   1258,
   1261,
   1265,
   1269,
   1273,
   1277,
   1281,
   1286,
   1289,
   1293,
   1297,
   1300,
   1303,
   1305,
   1308,
   1311,
   1314,
   1317,
   1320,
   1323,
   1327,
   1331,
   1335,
   1338,
   1341,
   1343,
   1345,
   1347,
   1349,
   1352,
   1355,
   1358,
   1360,
   1362,
   1365,
   1368,
   1371,
   1375,
   1379,
   1383,
   1386,
   1389,
   1392,
   1395,
   1399,
   1403,
   1407,
   1410,
   1413,
   1416,
   1420,
   1424,
   1428,
   1431,
   1434,
   1438,
   1442,
   1446,
   1449,
   1452,
   1457,
   1462,
   1466,
   1470,
   1475,
   1479,
   1483,
   1487,
   1491,
   1494,
   1496,
   1502,
   1509,
   1514,
   1522,
   1527,
   1532,
   1540,
   1548,
   1556,
   1564,
   1572,
   1578,
   1588,
   1594,
   1601,
   1613,
   1618,
   1625,
   1633,
   1641,
   1649,
   1657,
   1665,
   1673,
   1679,
   1686,
   1694,
   1700,
   1707,
   1715,
   1720,
   1726,
   1733,
   1738,
   1744,
   1751,
   1759,
   1764,
   1769,
   1777,
   1782,
   1787,
   1792,
   1797,
   1802,
   1810,
   1819,
   1826,
   1836,
   1843,
   1850,
   1860,
   1870,
   1880,
   1890,
   1900,
   1908,
   1920,
   1928,
   1937,
   1951,
   1958,
   1967,
   1977,
   1987,
   1997,
   2007,
   2017,
   2027,
   2035,
   2044,
   2054,
   2062,
   2071,
   2081,
   2088,
   2096,
   2105,
   2112,
   2120,
   2129,
   2139,
   2146,
   2153,
   2163,
   2170,
   2177,
   2184,
   2191,
   2198,
   2203,
   2209,
   2216,
   2222,
   2247,
   2255,
   2261,
   2270,
   2276,
   2282,
   2291,
   2300,
   2309,
   2318,
   2327,
   2334,
   2345,
   2352,
   2360,
   2373,
   2379,
   2387,
   2396,
   2405,
   2414,
   2423,
   2432,
   2441,
   2448,
   2456,
   2465,
   2472,
   2480,
   2489,
   2495,
   2502,
   2510,
   2516,
   2523,
   2531,
   2540,
   2546,
   2552,
   2561,
   2567,
   2573,
   2579,
   2585,
   2591,
   2596,
   2620,
   2627,
   2632,
   2637,
   2643,
   2650,
   2656,
   2681,
   2689,
   2695,
   2704,
   2710,
   2716,
   2725,
   2734,
   2743,
   2752,
   2761,
   2768,
   2779,
   2786,
   2794,
   2807,
   2813,
   2821,
   2830,
   2839,
   2848,
   2857,
   2866,
   2875,
   2882,
   2890,
   2899,
   2906,
   2914,
   2923,
   2929,
   2936,
   2944,
   2950,
   2957,
   2965,
   2974,
   2980,
   2986,
   2995,
   3001,
   3007,
   3013,
   3019,
   3025,
   3031,
   3038,
   3046,
   3053,
   3079,
   3088,
   3095,
   3105,
   3112,
   3119,
   3129,
   3139,
   3149,
   3159,
   3169,
   3177,
   3189,
   3197,
   3206,
   3220,
   3227,
   3236,
   3246,
   3256,
   3266,
   3276,
   3286,
   3296,
   3304,
   3313,
   3323,
   3331,
   3340,
   3350,
   3357,
   3365,
   3374,
   3381,
   3389,
   3398,
   3408,
   3415,
   3422,
   3432,
   3439,
   3446,
   3453,
   3460,
   3467,
   3474,
   3482,
   3491,
   3499,
   3526,
   3536,
   3544,
   3553,
   3564,
   3572,
   3581,
   3590,
   3600,
   3608,
   3619,
   3630,
   3641,
   3652,
   3663,
   3672,
   3685,
   3694,
   3704,
   3719,
   3727,
   3737,
   3748,
   3759,
   3770,
   3781,
   3792,
   3803,
   3812,
   3822,
   3833,
   3842,
   3852,
   3863,
   3871,
   3880,
   3890,
   3898,
   3907,
   3917,
   3928,
   3936,
   3944,
   3955,
   3963,
   3971,
   3979,
   3987,
   3995,
   4002,
   4010,
   4019,
   4027,
   4054,
   4064,
   4072,
   4083,
   4091,
   4099,
   4110,
   4121,
   4132,
   4143,
   4154,
   4163,
   4176,
   4185,
   4195,
   4210,
   4218,
   4228,
   4239,
   4250,
   4261,
   4272,
   4283,
   4294,
   4303,
   4313,
   4324,
   4333,
   4343,
   4354,
   4362,
   4371,
   4381,
   4389,
   4398,
   4408,
   4419,
   4427,
   4435,
   4446,
   4454,
   4462,
   4470,
   4478,
   4486,
   4494,
   4503,
   4513,
   4522,
   4550,
   4561,
   4570,
   4580,
   4592,
   4601,
   4611,
   4621,
   4632,
   4641,
   4653,
   4665,
   4677,
   4689,
   4701,
   4711,
   4725,
   4735,
   4746,
   4762,
   4771,
   4782,
   4794,
   4806,
   4818,
   4830,
   4842,
   4854,
   4864,
   4875,
   4887,
   4897,
   4908,
   4920,
   4929,
   4939,
   4950,
   4959,
   4969,
   4980,
   4992,
   5001,
   5010,
   5022,
   5031,
   5040,
   5049,
   5058,
   5067,
   5073,
   5080,
   5088,
   5095,
   5121,
   5130,
   5137,
   5147,
   5154,
   5161,
   5171,
   5181,
   5191,
   5201,
   5211,
   5219,
   5231,
   5239,
   5248,
   5262,
   5269,
   5278,
   5288,
   5298,
   5308,
   5318,
   5328,
   5338,
   5346,
   5355,
   5365,
   5373,
   5382,
   5392,
   5399,
   5407,
   5416,
   5423,
   5431,
   5440,
   5450,
   5457,
   5464,
   5474,
   5481,
   5488,
   5495,
   5502,
   5509,
   5516,
   5524,
   5533,
   5541,
   5568,
   5578,
   5586,
   5597,
   5605,
   5613,
   5624,
   5635,
   5646,
   5657,
   5668,
   5677,
   5690,
   5699,
   5709,
   5724,
   5732,
   5742,
   5753,
   5764,
   5775,
   5786,
   5797,
   5808,
   5817,
   5827,
   5838,
   5847,
   5857,
   5868,
   5876,
   5885,
   5895,
   5903,
   5912,
   5922,
   5933,
   5941,
   5949,
   5960,
   5968,
   5976,
   5984,
   5992,
   6000,
   6007,
   6015,
   6024,
   6032,
   6059,
   6069,
   6077,
   6088,
   6096,
   6104,
   6115,
   6126,
   6137,
   6148,
   6159,
   6168,
   6181,
   6190,
   6200,
   6215,
   6223,
   6233,
   6244,
   6255,
   6266,
   6277,
   6288,
   6299,
   6308,
   6318,
   6329,
   6338,
   6348,
   6359,
   6367,
   6376,
   6386,
   6394,
   6403,
   6413,
   6424,
   6432,
   6440,
   6451,
   6459,
   6467,
   6475,
   6483,
   6491,
   6499,
   6508,
   6518,
   6527,
   6555,
   6566,
   6575,
   6587,
   6596,
   6605,
   6617,
   6629,
   6641,
   6653,
   6665,
   6675,
   6689,
   6699,
   6710,
   6726,
   6735,
   6746,
   6758,
   6770,
   6782,
   6794,
   6806,
   6818,
   6828,
   6839,
   6851,
   6861,
   6872,
   6884,
   6893,
   6903,
   6914,
   6923,
   6933,
   6944,
   6956,
   6965,
   6974,
   6986,
   6995,
   7004,
   7013,
   7022,
   7031,
   7036,
   7042,
   7049,
   7055,
   7080,
   7088,
   7094,
   7103,
   7109,
   7115,
   7124,
   7133,
   7142,
   7151,
   7160,
   7167,
   7178,
   7185,
   7193,
   7206,
   7212,
   7220,
   7229,
   7238,
   7247,
   7256,
   7265,
   7274,
   7281,
   7289,
   7298,
   7305,
   7313,
   7322,
   7328,
   7335,
   7343,
   7349,
   7356,
   7364,
   7373,
   7379,
   7385,
   7394,
   7400,
   7406,
   7412,
   7418,
   7424,
   7429,
   7435,
   7442,
   7448,
   7473,
   7481,
   7487,
   7496,
   7502,
   7508,
   7517,
   7526,
   7535,
   7544,
   7553,
   7560,
   7571,
   7578,
   7586,
   7599,
   7605,
   7613,
   7622,
   7631,
   7640,
   7649,
   7658,
   7667,
   7674,
   7682,
   7691,
   7698,
   7706,
   7715,
   7721,
   7728,
   7736,
   7742,
   7749,
   7757,
   7766,
   7772,
   7778,
   7787,
   7793,
   7799,
   7805,
   7811,
   7817,
   7823,
   7830,
   7838,
   7845,
   7871,
   7880,
   7887,
   7897,
   7904,
   7911,
   7921,
   7931,
   7941,
   7951,
   7961,
   7969,
   7981,
   7989,
   7998,
   8012,
   8019,
   8028,
   8038,
   8048,
   8058,
   8068,
   8078,
   8088,
   8096,
   8105,
   8115,
   8123,
   8132,
   8142,
   8149,
   8157,
   8166,
   8173,
   8181,
   8190,
   8200,
   8207,
   8214,
   8224,
   8231,
   8238,
   8245,
   8252,
   8259,
   8264,
   8270,
   8277,
   8283,
   8308,
   8316,
   8322,
   8331,
   8337,
   8343,
   8352,
   8361,
   8370,
   8379,
   8388,
   8395,
   8406,
   8413,
   8421,
   8434,
   8440,
   8448,
   8457,
   8466,
   8475,
   8484,
   8493,
   8502,
   8509,
   8517,
   8526,
   8533,
   8541,
   8550,
   8556,
   8563,
   8571,
   8577,
   8584,
   8592,
   8601,
   8607,
   8613,
   8622,
   8628,
   8634,
   8640,
   8646,
   8652,
   8657,
   8663,
   8670,
   8676,
   8701,
   8709,
   8715,
   8724,
   8730,
   8736,
   8745,
   8754,
   8763,
   8772,
   8781,
   8788,
   8799,
   8806,
   8814,
   8827,
   8833,
   8841,
   8850,
   8859,
   8868,
   8877,
   8886,
   8895,
   8902,
   8910,
   8919,
   8926,
   8934,
   8943,
   8949,
   8956,
   8964,
   8970,
   8977,
   8985,
   8994,
   9000,
   9006,
   9015,
   9021,
   9027,
   9033,
   9039,
   9045,
   9051,
   9058,
   9066,
   9073,
   9099,
   9108,
   9115,
   9125,
   9132,
   9139,
   9149,
   9159,
   9169,
   9179,
   9189,
   9197,
   9209,
   9217,
   9226,
   9240,
   9247,
   9256,
   9266,
   9276,
   9286,
   9296,
   9306,
   9316,
   9324,
   9333,
   9343,
   9351,
   9360,
   9370,
   9377,
   9385,
   9394,
   9401,
   9409,
   9418,
   9428,
   9435,
   9442,
   9452,
   9459,
   9466,
   9473,
   9480,
   9487,
   9493,
   9500,
   9506,
   0,
   9511,
   9517,
   9519,
   9523,
   9530,
   9534,
   9541,
   9546,
   9553,
   9562,
   9567,
   9572,
   9579,
   9588,
   9593,
   9596,
   9600,
   9603,
   9606,
   9610,
   9614,
   9617,
   9620,
   9629,
   9642,
   9656,
   9665,
   9675,
   9684,
   9696,
   9706,
   9716,
   9725,
   9734,
   9737,
   9741,
   9746,
   9751,
   9755,
   9759,
   9763,
   9768,
   9773,
   9777,
   9781,
   9785,
   9789,
   9793,
   9796,
   9799,
   9802,
   9805,
   9808,
   9813,
   9819,
   9830,
   9842,
   9848,
   9860,
   9873,
   9877,
   9882,
   9893,
   9905,
   9910,
   9922,
   9935,
   9937,
   9942,
   9947,
   9951,
   9955,
   9958,
   9968,
   9974,
   9979,
   9985,
   9990,
   9995,
   10000,
   10005,
   10010,
   10014,
   10018,
   10022,
   10025,
   10028,
   10031,
   10033,
   10036,
   10040,
   10044,
   10047,
   10050,
   10055,
   10060,
   10066,
   10071,
   10075,
   10080,
   10086,
   10092,
   10097,
   10102,
   10105,
   10107,
   10111,
   10115,
   10119,
   10122,
   10126,
   10131,
   10136,
   10140,
   10144,
   10148,
   10151,
   10155,
   10160,
   10165,
   10169,
   10173,
   10175,
   10177,
   10180,
   10183,
   10186,
   10190,
   10193,
   10197,
   10202,
   10207,
   10211,
   10215,
   10220,
   10223,
   10227,
   10231,
   10234,
   10237,
   10243,
   10254,
   10266,
   10272,
   10284,
   10297,
   10301,
   10306,
   10316,
   10327,
   10332,
   10343,
   10355,
   10357,
   10361,
   10365,
   10369,
   10373,
   10378,
   10386,
   10391,
   10396,
   10400,
   10404,
   10414,
   10419,
   10425,
   10430,
   10435,
   10440,
   10445,
   10450,
   10454,
   10458,
   10462,
   10465,
   10469,
   10473,
   10476,
   10479,
   10484,
   10489,
   10493,
   10497,
   10501,
   10504,
   10507,
   10510,
   10515,
   10521,
   10526,
   10531,
   10536,
   10541,
   10546,
   10550,
   10554,
   10558,
   0,
   10563,
   10569,
   10571,
   10576,
   10587,
   10596,
   10601,
   10611,
   10618,
   10623,
   10629,
   0,
   10636,
   10642,
   10647,
   10657,
   10672,
   10687,
   10702,
   10707,
   10712,
   10717,
   10725,
   10740,
   0,
   10748,
   10751,
   10754,
   10757,
   10760,
   10763,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   10765,
   10768,
   10771,
   10773,
   10776,
   10779,
   10782,
   10785,
   10787,
   10789,
   10794,
   10796,
   10798,
   10803,
   10810,
   10818,
   10823,
   10829,
   10834,
   10840,
   10845,
   10849,
   10851,
   10853,
   10855,
   0,
   10857,
   0,
   0,
   10859,
   0,
   0,
   10862,
   10870,
   10878,
   10887,
   10895,
   10904,
   10911,
   10918,
   10926,
   10936,
   10943,
   10950,
   10952,
   10954,
   10958,
   10960,
   10962,
   0,
   0,
   10964,
   0,
   0,
   10967,
   0,
   0,
   10970,
   10973,
   10976,
   0,
   10978,
   10980,
   10982,
   10987,
   10993,
   11000,
   11007,
   11015,
   11022,
   11031,
   11038,
   11043,
   11051,
   11059,
   11072,
   11085,
   11092,
   11102,
   11110,
   11118,
   11127,
   11141,
   11155,
   11167,
   11182,
   11195,
   11208,
   11221,
   11237,
   11252,
   11266,
   11280,
   11297,
   11313,
   11328,
   11341,
   11357,
   11371,
   11385,
   11393,
   11404,
   11413,
   11422,
   11431,
   11438,
   11448,
   11456,
   11464,
   11471,
   11478,
   11488,
   11498,
   11506,
   11517,
   11528,
   11538,
   11549,
   11561,
   11572,
   11584,
   11597,
   11611,
   11624,
   11631,
   11639,
   11647,
   11655,
   11658,
   11662,
   11666,
   11670,
   11673,
   11676,
   11681,
   11685,
   11689,
   11694,
   11698,
   11702,
   11706,
   11710,
   11715,
   11720,
   11725,
   11730,
   11734,
   11738,
   11744,
   11750,
   11756,
   11762,
   11768,
   11775,
   11781,
   11787,
   11794,
   11800,
   11806,
   11812,
   11818,
   11824,
   11831,
   11837,
   11843,
   11849,
   11856,
   11863,
   11870,
   11877,
   11883,
   11889,
   11895,
   11902,
   11909,
   11916,
   11922,
   11928,
   11934,
   11941,
   11948,
   11955,
   11968,
   11974,
   11980,
   11986,
   11993,
   11999,
   12005,
   12011,
   12017,
   12023,
   12029,
   12035,
   12041,
   12048,
   12054,
   12060,
   12066,
   12073,
   12080,
   12087,
   12094,
   12101,
   12107,
   12113,
   12119,
   12126,
   12133,
   12140,
   12146,
   12152,
   12158,
   12165,
   12172,
   12179,
   12192,
   12195,
   12198,
   12203,
   12207,
   12211,
   12216,
   12220,
   12224,
   12228,
   12232,
   12237,
   12242,
   12247,
   12252,
   12256,
   12260,
   12266,
   12272,
   12275,
   12278,
   12281,
   12283,
   12287,
   12291,
   12295,
   12299,
   12303,
   12306,
   12311,
   12315,
   12319,
   12322,
   12326,
   12329,
   12332,
   12335,
   12338,
   12341,
   12344,
   12347,
   12351,
   12354,
   12358,
   12361,
   12365,
   12369,
   12373,
   12376,
   0,
   12378,
   12380,
   0,
   12385,
   12388,
   12391,
   12394,
   12400,
   12405,
   12415,
   12419,
   12423,
   12426,
   12429,
   12432,
   12434,
   12437,
   12440,
   12443,
   12445,
   12448,
   12452,
   12456,
   12459,
   12463,
   12466,
   12469,
   12472,
   12475,
   12478,
   12481,
   12484,
   12487,
   12490,
   12494,
   12498,
   12502,
   12506,
   12508,
   12510,
   12514,
   12518,
   12520,
   12524,
   12526,
   12528,
   12532,
   12536,
   12538,
   12545,
   12553,
   12558,
   12563,
   12568,
   12575,
   12583,
   12588,
   12593,
   12598,
   12600,
   12602,
   12604,
   12606,
   12608,
   12610,
   12612,
   12614,
   12616,
   0,
   12618,
   12620,
   12622,
   12624,
   12626,
   12628,
   12630,
   12632,
   12634,
   12636,
   12638,
   12643,
   12649,
   12655,
   12663,
   12672,
   12677,
   12684,
   12692,
   12698,
   12705,
   12712,
   12721,
   12731,
   12737,
   12745,
   12754,
   12763,
   12774,
   12786,
   12792,
   12800,
   12809,
   12812,
   12819,
   12833,
   12840,
   12847,
   12861,
   12875,
   12881,
   12893,
   12905,
   12911,
   12917,
   12924,
   12931,
   12937,
   12949,
   12961,
   12964,
   12971,
   12985,
   12992,
   12999,
   13013,
   13027,
   13039,
   13051,
   13058,
   13065,
   13071,
   13083,
   13095,
   13098,
   13101,
   13104,
   13109,
   13114,
   13119,
   13125,
   13130,
   13136,
   13146,
   13149,
   13153,
   13157,
   13161,
   13165,
   13169,
   13172,
   13176,
   13180,
   13184,
   13188,
   13193,
   13196,
   13200,
   13204,
   13208,
   13212,
   13217,
   13226,
   13248,
   13251,
   13254,
   13257,
   13260,
   13263,
   13266,
   13270,
   13273,
   13277,
   13285,
   13288,
   13292,
   13296,
   13300,
   13303,
   13306,
   13310,
   13314,
   13318,
   13322,
   13325,
   13329,
   13333,
   13337,
   13341,
   13349,
   13371,
   13373,
   13376,
   13388,
   13398,
   13405,
   13412,
   13419,
   13458,
   13477,
   13484,
   13491,
   13503,
   13509,
   13519,
   13526,
   13533,
   13540,
   13547,
   13553,
   13569,
   13611,
   13618,
   13625,
   13632,
   13644,
   13647,
   13650,
   13654,
   13659,
   13663,
   13665,
   13667,
   13670,
   13673,
   13675,
   13677,
   13680,
   13683,
   13686,
   13689,
   13693,
   13696,
   13698,
   13700,
   13703,
   13709,
   13715,
   13721,
   13727,
   13734,
   13740,
   13747,
   13758,
   13765,
   13771,
   13779,
   13786,
   13793,
   13802,
   13808,
   13816,
   13823,
   13830,
   13839,
   13851,
   13876,
   13882,
   13888,
   13894,
   13900,
   13907,
   13913,
   13920,
   13931,
   13938,
   13944,
   13952,
   13959,
   13966,
   13975,
   13981,
   13989,
   13996,
   14003,
   14012,
   14024,
   14049,
   14055,
   14061,
   14067,
   14070,
   14073,
   14076,
   14079,
   14082,
   14085,
   14088,
   14090,
   14092,
   14094,
   14096,
   14098,
   14100,
   14102,
   14104,
   14106,
   14110,
   14112,
   14114,
   14118,
   14122,
   14124,
   14127,
   14129,
   14131,
   14133,
   14135,
   14137,
   14139,
   14141,
   14143,
   14145,
   14147,
   14149,
   14153,
   14158,
   14164,
   14167,
   14171,
   14174,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   14178,
   14180,
   14183,
   14186,
   14189,
   14192,
   14195,
   14198,
   14200,
   14202,
   14204,
   14206,
   14209,
   14211,
   14216,
   14220,
   14223,
   14226,
   14231,
   14235,
   14239,
   14243,
   14247,
   14251,
   14255,
   14259,
   14263,
   14267,
   14271,
   14275,
   14278,
   14281,
   14285,
   14288,
   14291,
   14295,
   14297,
   14299,
   14301,
   14303,
   14305,
   14308,
   14310,
   14312,
   14314,
   14316,
   14318,
   14320,
   14326,
   14328,
   14330,
   14332,
   14334,
   14336,
   14338,
   14340,
   14344,
   14348,
   14352,
   14356,
   14360,
   14365,
   14370,
   14375,
   14380,
   14385,
   14389,
   14393,
   14398,
   14403,
   14408,
   14413,
   14417,
   14421,
   14425,
   14429,
   14432,
   14435,
   14440,
   14445,
   14450,
   14455,
   14458,
   14461,
   14466,
   14471,
   14476,
   14481,
   14484,
   14487,
   14492,
   14497,
   14502,
   14507,
   14510,
   14513,
   14518,
   14523,
   14528,
   14533,
   14537,
   14541,
   14547,
   14553,
   14559,
   14565,
   14569,
   14573,
   14579,
   14585,
   14591,
   14597,
   14601,
   14605,
   14611,
   14617,
   14623,
   14629,
   14632,
   14635,
   14640,
   14645,
   14650,
   14655,
   14658,
   14661,
   14666,
   14671,
   14676,
   14681,
   14686,
   14691,
   14696,
   14701,
   14706,
   14711,
   14716,
   14721,
   14728,
   14735,
   14742,
   14749,
   14756,
   14763,
   14765,
   14769,
   14773,
   14777,
   14781,
   14793,
   14806,
   14820,
   14834,
   14848,
   14862,
   14867,
   14872,
   14877,
   14882,
   14888,
   14894,
   14900,
   14906,
   14912,
   14918,
   14924,
   14930,
   14935,
   14940,
   14945,
   14950,
   14955,
   14960,
   14965,
   14970,
   14977,
   14984,
   14991,
   14998,
   15005,
   0,
   15012,
   15014,
   15019,
   15024,
   15028,
   15033,
   15038,
   15041,
   0,
   15045,
   15047,
   15052,
   15058,
   15065,
   15069,
   15073,
   15079,
   15084,
   15088,
   15092,
   15097,
   15101,
   15105,
   15111,
   15116,
   15120,
   15124,
   15129,
   0,
   0,
   15133,
   15135,
   15146,
   15153,
   15160,
   15169,
   15179,
   15184,
   15186,
   15188,
   15191,
   15195,
   0,
   0,
   15197,
   15199,
   0,
   0,
   15203,
   15206,
   15209,
   15212,
   15216,
   0,
   0,
   15220,
   15222,
   0,
   0,
   15226,
   15228,
   15230,
   15235,
   15239,
   15243,
   15248,
   0,
   15250,
   15252,
   15263,
   15271,
   15282,
   15291,
   15300,
   15316,
   15329,
   15345,
   15359,
   15373,
   15384,
   15392,
   15403,
   15412,
   15421,
   15431,
   15443,
   15453,
   15466,
   15477,
   15488,
   15502,
   15513,
   15521,
   15532,
   15541,
   15550,
   15559,
   15571,
   15581,
   15591,
   15596,
   15601,
   15606,
   15611,
   15618,
   15625,
   15632,
   15639,
   15643,
   15649,
   15655,
   15661,
   15667,
   15673,
   15679,
   15685,
   15691,
   15695,
   15701,
   15707,
   15713,
   15719,
   15726,
   15731,
   15736,
   15741,
   15746,
   15752,
   15758,
   15764,
   15770,
   15777,
   15784,
   15791,
   15798,
   15800,
   15807,
   15814,
   15821,
   15828,
   15834,
   15840,
   15846,
   15852,
   15858,
   15864,
   15870,
   15876,
   15882,
   15887,
   15892,
   15895,
   15903,
   15911,
   15919,
   15927,
   15935,
   15943,
   15948,
   15951,
   15953,
   15955,
   15957,
   15959,
   15961,
   15963,
   15966,
   15972,
   15974,
   15979,
   15984,
   15989,
   15994,
   16003,
   16012,
   16022,
   16034,
   16042,
   16053,
   16064,
   16075,
   16087,
   16089,
   16093,
   16100,
   16103,
   16109,
   16115,
   16121,
   16127,
   16131,
   16138,
   16141,
   16147,
   16153,
   16159,
   16165,
   16172,
   16182,
   16185,
   16190,
   16198,
   16202,
   16209,
   16216,
   16223,
   16230,
   16235,
   16243,
   16247,
   16254,
   16261,
   16268,
   16275,
   16279,
   16286,
   16289,
   16295,
   16301,
   16307,
   16313,
   16317,
   16324,
   16327,
   16333,
   16339,
   16345,
   16351,
   16358,
   16361,
   16367,
   16373,
   16379,
   16385,
   16388,
   16394,
   16403,
   16412,
   16421,
   16430,
   16435,
   16440,
   16445,
   16450,
   16461,
   16469,
   16477,
   16485,
   16493,
   16501,
   16509,
   16514,
   16517,
   16519,
   16525,
   16532,
   16539,
   16546,
   16553,
   16561,
   16567,
   16575,
   16582,
   16589,
   16593,
   16597,
   16601,
   16606,
   16611,
   16616,
   16621,
   16626,
   16631,
   16636,
   16641,
   16646,
   16650,
   16654,
   16658,
   16663,
   16669,
   16673,
   16679,
   16683,
   16687,
   16689,
   16693,
   16697,
   16701,
   16704,
   16706,
   16710,
   16714,
   16717,
   16722,
   16727,
   16732,
   16735,
   16740,
   16745,
   16750,
   16753,
   16758,
   16762,
   16768,
   16772,
   16776,
   16782,
   16786,
   16790,
   16794,
   16798,
   16802,
   16805,
   16809,
   16812,
   16815,
   16821,
   16827,
   16833,
   16839,
   16844,
   16850,
   16858,
   16867,
   16872,
   16877,
   16879,
   16881,
   16887,
   16889,
   0,
   0,
   0,
   16895,
   16897,
   16902,
   16906,
   16910,
   16914,
   16918,
   16923,
   16928,
   16933,
   16938,
   16942,
   16946,
   16952,
   16956,
   16960,
   16962,
   16966,
   16970,
   16972,
   16975,
   16979,
   16982,
   16987,
   16992,
   16995,
   17000,
   17005,
   17008,
   17012,
   17018,
   17022,
   17026,
   17033,
   17038,
   17045,
   17053,
   17061,
   17064,
   17068,
   17074,
   17078,
   17081,
   17083,
   17087,
   17091,
   17097,
   17100,
   17103,
   17107,
   17114,
   17122,
   17131,
   17138,
   17146,
   17155,
   17162,
   17170,
   17179,
   17186,
   17194,
   17203,
   17212,
   17222,
   17233,
   17242,
   17252,
   17263,
   17272,
   17282,
   17293,
   17302,
   17312,
   17323,
   17331,
   17340,
   17350,
   17358,
   17367,
   17377,
   17385,
   17394,
   17404,
   17412,
   17421,
   17431,
   17439,
   17448,
   17458,
   17466,
   17475,
   17485,
   17493,
   17502,
   17512,
   17520,
   17529,
   17539,
   17548,
   17558,
   17569,
   17578,
   17588,
   17599,
   17608,
   17618,
   17629,
   17638,
   17648,
   17659,
   17669,
   17680,
   17692,
   17702,
   17713,
   17725,
   17735,
   17746,
   17758,
   17768,
   17779,
   17791,
   17801,
   17812,
   17824,
   17834,
   17845,
   17857,
   17867,
   17878,
   17890,
   17900,
   17911,
   17923,
   17934,
   17946,
   17959,
   17970,
   17982,
   17995,
   18006,
   18018,
   18031,
   18042,
   18054,
   18067,
   18076,
   18086,
   18097,
   18106,
   18116,
   18127,
   18136,
   18146,
   18157,
   18166,
   18176,
   18187,
   18197,
   18208,
   18220,
   18230,
   18241,
   18253,
   18263,
   18274,
   18286,
   18296,
   18307,
   18319,
   18329,
   18340,
   18352,
   18362,
   18373,
   18385,
   18395,
   18406,
   18418,
   18428,
   18439,
   18451,
   18462,
   18474,
   18487,
   18498,
   18510,
   18523,
   18534,
   18546,
   18559,
   18570,
   18582,
   18595,
   18601,
   18609,
   18618,
   18628,
   18636,
   18645,
   18655,
   18663,
   18672,
   18682,
   18690,
   18699,
   18709,
   18717,
   18726,
   18736,
   18744,
   18753,
   18763,
   18771,
   18780,
   18790,
   18798,
   18807,
   18817,
   18824,
   18833,
   18843,
   18854,
   18863,
   18873,
   18884,
   18893,
   18903,
   18914,
   18923,
   18933,
   18944,
   18952,
   18961,
   18971,
   18979,
   18988,
   18998,
   19006,
   19015,
   19025,
   19033,
   19042,
   19052,
   19060,
   19069,
   19079,
   19087,
   19096,
   19106,
   19114,
   19123,
   19133,
   19141,
   19150,
   19160,
   19169,
   19179,
   19190,
   19199,
   19209,
   19220,
   19229,
   19239,
   19250,
   19259,
   19269,
   19280,
   19287,
   19294,
   19301,
   19303,
   19305,
   19310,
   19315,
   19320,
   19325,
   19330,
   19336,
   19342,
   19348,
   19354,
   19361,
   19368,
   19375,
   19382,
   19389,
   19396,
   19403,
   19410,
   19416,
   19422,
   19428,
   19434,
   19440,
   19446,
   19452,
   19458,
   19466,
   19474,
   19482,
   19490,
   19498,
   19506,
   19511,
   19554,
   19597,
   19617,
   19622,
   19626,
   19630,
   19636,
   19639,
   19645,
   19651,
   19664,
   19676,
   19680,
   19687,
   19694,
   19698,
   19708,
   19712,
   19717,
   19722,
   19730,
   19735,
   19743,
   19748,
   19756,
   19764,
   19775,
   19780,
   19788,
   19794,
   19803,
   19809,
   19818,
   19823,
   19831,
   0,
   19836,
   19844,
   19852,
   0,
   0,
   0,
   19860,
   19867,
   19873,
   19876,
   19879,
   19883,
   19889,
   19893,
   19897,
   19901,
   19905,
   19909,
   19913,
   19916,
   19921,
   19925,
   19930,
   19934,
   19939,
   19944,
   0,
   0,
   19948,
   19955,
   19962,
   19964,
   0,
   0,
   0,
   0,
   19966,
   19969,
   0,
   0,
   0,
   0,
   19972,
   19976,
   19980,
   0,
   0,
   0,
   19982,
   19984,
   0,
   19986,
   19997,
   20013,
   20024,
   20036,
   20050,
   20062,
   20067,
   20072,
   20074,
   20081,
   20088,
   20091,
   20094,
   20098,
   20102,
   20106,
   20110,
   20115,
   20120,
   20123,
   20128,
   20132,
   20137,
   20142,
   20146,
   20150,
   20152,
   20160,
   20169,
   20176,
   20179,
   20183,
   20191,
   20199,
   20204,
   20212,
   20223,
   20234,
   20248,
   20262,
   20267,
   20278,
   20281,
   20284,
   0,
   20288,
   20291,
   20297,
   20306,
   20314,
   20327,
   20339,
   20346,
   20352,
   20356,
   20358,
   20361,
   20367,
   20376,
   20389,
   20401,
   20408,
   20414,
   20418,
   20420,
   20423,
   20429,
   20438,
   20451,
   20463,
   20470,
   20476,
   20481,
};

static const nir_algebraic_table nir_opt_algebraic_table = {
   .transforms = nir_opt_algebraic_transforms,
   .transform_offsets = nir_opt_algebraic_transform_offsets,
   .pass_op_table = nir_opt_algebraic_pass_op_table,
   .values = nir_opt_algebraic_values,
   .expression_cond = nir_opt_algebraic_expression_cond,
   .variable_cond = nir_opt_algebraic_variable_cond,
};

bool
nir_opt_algebraic(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[110];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(5499 == ARRAY_SIZE(nir_opt_algebraic_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_fround_even;
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = !options->lower_ffloor;
   condition_flags[24] = options->lower_ffract;
   condition_flags[25] = options->lower_fceil;
   condition_flags[26] = options->lower_ffma16;
   condition_flags[27] = options->lower_ffma32;
   condition_flags[28] = options->lower_ffma64;
   condition_flags[29] = options->fuse_ffma16;
   condition_flags[30] = options->fuse_ffma32;
   condition_flags[31] = options->fuse_ffma64;
   condition_flags[32] = options->lower_fdph;
   condition_flags[33] = !options->lower_fdph;
   condition_flags[34] = options->lower_fdot;
   condition_flags[35] = !options->lower_fsat;
   condition_flags[36] = !options->lower_iabs;
   condition_flags[37] = options->lower_fsat;
   condition_flags[38] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[39] = !options->lower_fsign;
   condition_flags[40] = options->lower_umax;
   condition_flags[41] = options->lower_umin;
   condition_flags[42] = !options->lower_umax;
   condition_flags[43] = !options->lower_umin;
   condition_flags[44] = options->lower_scmp;
   condition_flags[45] = options->lower_vector_cmp;
   condition_flags[46] = !options->lower_rotate;
   condition_flags[47] = options->lower_rotate;
   condition_flags[48] = options->lower_fpow;
   condition_flags[49] = !options->lower_fpow;
   condition_flags[50] = options->lower_fdiv;
   condition_flags[51] = options->lower_fsqrt;
   condition_flags[52] = !options->lower_fsqrt;
   condition_flags[53] = options->lower_sincos;
   condition_flags[54] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[55] = !options->lower_extract_byte;
   condition_flags[56] = !options->lower_extract_word;
   condition_flags[57] = options->has_pack_32_4x8;
   condition_flags[58] = options->lower_pack_64_2x32_split;
   condition_flags[59] = options->lower_pack_32_2x16_split;
   condition_flags[60] = options->lower_unpack_64_2x32_split;
   condition_flags[61] = options->lower_unpack_32_2x16_split;
   condition_flags[62] = options->lower_fmod;
   condition_flags[63] = options->lower_uadd_carry;
   condition_flags[64] = options->lower_usub_borrow;
   condition_flags[65] = options->lower_bitfield_insert;
   condition_flags[66] = options->lower_hadd;
   condition_flags[67] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[69] = options->lower_uadd_sat;
   condition_flags[70] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[71] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[72] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[73] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[74] = options->lower_bitfield_insert_to_shifts;
   condition_flags[75] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[76] = options->lower_bitfield_extract;
   condition_flags[77] = options->lower_bitfield_extract_to_shifts;
   condition_flags[78] = options->lower_ifind_msb;
   condition_flags[79] = options->lower_find_msb_to_reverse;
   condition_flags[80] = options->lower_find_lsb;
   condition_flags[81] = options->lower_extract_byte;
   condition_flags[82] = options->lower_extract_word;
   condition_flags[83] = options->lower_pack_unorm_2x16;
   condition_flags[84] = options->lower_pack_unorm_4x8;
   condition_flags[85] = options->lower_pack_snorm_2x16;
   condition_flags[86] = options->lower_pack_snorm_4x8;
   condition_flags[87] = options->lower_unpack_unorm_2x16;
   condition_flags[88] = options->lower_unpack_unorm_4x8;
   condition_flags[89] = options->lower_unpack_snorm_2x16;
   condition_flags[90] = options->lower_unpack_snorm_4x8;
   condition_flags[91] = options->lower_pack_split;
   condition_flags[92] = options->lower_isign;
   condition_flags[93] = !options->lower_isign;
   condition_flags[94] = options->lower_fsign;
   condition_flags[95] = !options->has_imul24;
   condition_flags[96] = !options->has_umul24;
   condition_flags[97] = !options->has_umad24;
   condition_flags[98] = options->has_imul24;
   condition_flags[99] = options->has_umad24;
   condition_flags[100] = options->has_umul24;
   condition_flags[101] = options->has_fused_comp_and_csel;
   condition_flags[102] = options->lower_iadd_sat;
   condition_flags[103] = options->support_8bit_alu;
   condition_flags[104] = options->support_16bit_alu;
   condition_flags[105] = options->lower_ldexp;
   condition_flags[106] = !options->lower_bitfield_reverse;
   condition_flags[107] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[108] = options->lower_fisnormal;
   condition_flags[109] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 15
 * transforms:
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b'))
 */


static const nir_search_value_union nir_opt_algebraic_before_ffma_values[] = {
   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 1 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 2, 3 },
      0,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 7, 8 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1929_0_0 -> 0 in the cache */
   /* search1929_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1929_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 10, 3 },
      0,
   } },

   /* replace1929_0_0 -> 5 in the cache */
   /* replace1929_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace1929_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 12, 8 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1930_0_0 -> 0 in the cache */
   /* search1930_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1930_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 14, 3 },
      0,
   } },

   /* replace1930_0_0 -> 5 in the cache */
   /* replace1930_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace1930_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 16, 8 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1931_0_0 -> 0 in the cache */
   /* search1931_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1931_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 18, 3 },
      0,
   } },

   /* replace1931_0_0 -> 5 in the cache */
   /* replace1931_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace1931_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 20, 8 },
      -1,
   } },

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search1932_0_0 -> 5 in the cache */
   /* search1932_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search1932_1_0 -> 5 in the cache */
   /* search1932_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 22, 23 },
      -1,
   } },

   /* replace1932_0 -> 5 in the cache */
   /* replace1932_1_0 -> 8 in the cache */
   /* replace1932_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 5, 25 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search1933_0_0 -> 5 in the cache */
   /* search1933_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search1933_1_0 -> 5 in the cache */
   /* search1933_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 27, 28 },
      -1,
   } },

   /* replace1933_0 -> 5 in the cache */
   /* replace1933_1_0 -> 8 in the cache */
   /* replace1933_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 5, 30 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1934_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 33, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search1935_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1935_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 36, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search1936_1_0 -> 39 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 40, 42 },
      -1,
   } },

   /* replace1936 -> 41 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search1937_0 -> 39 in the cache */
   /* search1937_1_0_0 -> 39 in the cache */
   /* search1937_1_0 -> 40 in the cache */
   /* search1937_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 40, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 39, 44 },
      -1,
   } },

   /* replace1937 -> 41 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search1938_0_0 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search1938_1_0 -> 39 in the cache */
   /* search1938_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 46, 47 },
      -1,
   } },

   /* replace1938 -> 41 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search1939_0 -> 39 in the cache */
   /* search1939_1_0_0 -> 39 in the cache */
   /* search1939_1_0 -> 46 in the cache */
   /* search1939_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 46, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 39, 49 },
      -1,
   } },

   /* replace1939 -> 41 in the cache */

   /* ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a') */
   /* search1940_0_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 51 },
      0,
   } },
   /* search1940_1_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 53 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 52, 54, 55 },
      -1,
   } },

   /* replace1940_0_0 -> 51 in the cache */
   /* replace1940_0_1 -> 53 in the cache */
   /* replace1940_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 51, 53, 55 },
      -1,
   } },
   /* replace1940_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 57, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a') */
   /* search1941_0_0 -> 39 in the cache */
   /* search1941_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 53 },
      0,
   } },
   /* search1941_1_0 -> 39 in the cache */
   /* search1941_1_1 -> 51 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 51 },
      0,
   } },
   /* search1941_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 59, 60, 55 },
      -1,
   } },

   /* replace1941_0_0 -> 53 in the cache */
   /* replace1941_0_1 -> 51 in the cache */
   /* replace1941_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 53, 51, 55 },
      -1,
   } },
   /* replace1941_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 62, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 64, 65 },
      0,
   } },
   /* search1942_1_0 -> 64 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 64, 67 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 66, 68, 69 },
      -1,
   } },

   /* replace1942_0_0 -> 69 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 71, 73 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 69, 74 },
      -1,
   } },
   /* replace1942_1_0 -> 64 in the cache */
   /* replace1942_1_1 -> 72 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 64, 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 75, 76 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_before_ffma_expression_cond[] = {
   (is_used_once),
};

static const nir_search_variable_cond nir_opt_algebraic_before_ffma_variable_cond[] = {
   (is_not_const),
};

static const struct transform nir_opt_algebraic_before_ffma_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 24, 26, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 29, 31, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 56, 58, 0 },
   { 61, 63, 0 },
   { 70, 77, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_before_ffma_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         2,
         3,
         19,
         3,
         3,
         20,
         19,
         20,
         19,
      },
   },
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         4,
         5,
         28,
         5,
         5,
         29,
         28,
         29,
         28,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         0,
         5,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         6,
         7,
         6,
         6,
         12,
         13,
         31,
         32,
         7,
         7,
         7,
         7,
         14,
         15,
         33,
         34,
         6,
         7,
         16,
         6,
         12,
         13,
         31,
         32,
         6,
         7,
         6,
         6,
         12,
         17,
         31,
         32,
         12,
         14,
         12,
         12,
         12,
         18,
         32,
         32,
         13,
         15,
         13,
         17,
         18,
         13,
         35,
         36,
         31,
         33,
         31,
         31,
         32,
         35,
         31,
         32,
         32,
         34,
         32,
         32,
         32,
         36,
         32,
         32,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         8,
         9,
         8,
         8,
         21,
         22,
         37,
         38,
         9,
         9,
         9,
         9,
         23,
         24,
         39,
         40,
         8,
         9,
         25,
         8,
         21,
         22,
         37,
         38,
         8,
         9,
         8,
         8,
         21,
         26,
         37,
         38,
         21,
         23,
         21,
         21,
         21,
         27,
         38,
         38,
         22,
         24,
         22,
         26,
         27,
         22,
         41,
         42,
         37,
         39,
         37,
         37,
         38,
         41,
         37,
         38,
         38,
         40,
         38,
         38,
         38,
         42,
         38,
         38,
      },
   },
   [nir_op_fneg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_before_ffma_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   14,
   18,
   20,
   22,
   24,
   26,
   28,
   30,
   32,
   35,
   39,
   41,
   43,
   47,
   49,
   52,
   54,
   57,
   61,
   66,
   68,
   71,
   73,
   76,
   80,
};

static const nir_algebraic_table nir_opt_algebraic_before_ffma_table = {
   .transforms = nir_opt_algebraic_before_ffma_transforms,
   .transform_offsets = nir_opt_algebraic_before_ffma_transform_offsets,
   .pass_op_table = nir_opt_algebraic_before_ffma_pass_op_table,
   .values = nir_opt_algebraic_before_ffma_values,
   .expression_cond = nir_opt_algebraic_before_ffma_expression_cond,
   .variable_cond = nir_opt_algebraic_before_ffma_variable_cond,
};

bool
nir_opt_algebraic_before_ffma(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[110];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(78 == ARRAY_SIZE(nir_opt_algebraic_before_ffma_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_fround_even;
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = !options->lower_ffloor;
   condition_flags[24] = options->lower_ffract;
   condition_flags[25] = options->lower_fceil;
   condition_flags[26] = options->lower_ffma16;
   condition_flags[27] = options->lower_ffma32;
   condition_flags[28] = options->lower_ffma64;
   condition_flags[29] = options->fuse_ffma16;
   condition_flags[30] = options->fuse_ffma32;
   condition_flags[31] = options->fuse_ffma64;
   condition_flags[32] = options->lower_fdph;
   condition_flags[33] = !options->lower_fdph;
   condition_flags[34] = options->lower_fdot;
   condition_flags[35] = !options->lower_fsat;
   condition_flags[36] = !options->lower_iabs;
   condition_flags[37] = options->lower_fsat;
   condition_flags[38] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[39] = !options->lower_fsign;
   condition_flags[40] = options->lower_umax;
   condition_flags[41] = options->lower_umin;
   condition_flags[42] = !options->lower_umax;
   condition_flags[43] = !options->lower_umin;
   condition_flags[44] = options->lower_scmp;
   condition_flags[45] = options->lower_vector_cmp;
   condition_flags[46] = !options->lower_rotate;
   condition_flags[47] = options->lower_rotate;
   condition_flags[48] = options->lower_fpow;
   condition_flags[49] = !options->lower_fpow;
   condition_flags[50] = options->lower_fdiv;
   condition_flags[51] = options->lower_fsqrt;
   condition_flags[52] = !options->lower_fsqrt;
   condition_flags[53] = options->lower_sincos;
   condition_flags[54] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[55] = !options->lower_extract_byte;
   condition_flags[56] = !options->lower_extract_word;
   condition_flags[57] = options->has_pack_32_4x8;
   condition_flags[58] = options->lower_pack_64_2x32_split;
   condition_flags[59] = options->lower_pack_32_2x16_split;
   condition_flags[60] = options->lower_unpack_64_2x32_split;
   condition_flags[61] = options->lower_unpack_32_2x16_split;
   condition_flags[62] = options->lower_fmod;
   condition_flags[63] = options->lower_uadd_carry;
   condition_flags[64] = options->lower_usub_borrow;
   condition_flags[65] = options->lower_bitfield_insert;
   condition_flags[66] = options->lower_hadd;
   condition_flags[67] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[69] = options->lower_uadd_sat;
   condition_flags[70] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[71] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[72] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[73] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[74] = options->lower_bitfield_insert_to_shifts;
   condition_flags[75] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[76] = options->lower_bitfield_extract;
   condition_flags[77] = options->lower_bitfield_extract_to_shifts;
   condition_flags[78] = options->lower_ifind_msb;
   condition_flags[79] = options->lower_find_msb_to_reverse;
   condition_flags[80] = options->lower_find_lsb;
   condition_flags[81] = options->lower_extract_byte;
   condition_flags[82] = options->lower_extract_word;
   condition_flags[83] = options->lower_pack_unorm_2x16;
   condition_flags[84] = options->lower_pack_unorm_4x8;
   condition_flags[85] = options->lower_pack_snorm_2x16;
   condition_flags[86] = options->lower_pack_snorm_4x8;
   condition_flags[87] = options->lower_unpack_unorm_2x16;
   condition_flags[88] = options->lower_unpack_unorm_4x8;
   condition_flags[89] = options->lower_unpack_snorm_2x16;
   condition_flags[90] = options->lower_unpack_snorm_4x8;
   condition_flags[91] = options->lower_pack_split;
   condition_flags[92] = options->lower_isign;
   condition_flags[93] = !options->lower_isign;
   condition_flags[94] = options->lower_fsign;
   condition_flags[95] = !options->has_imul24;
   condition_flags[96] = !options->has_umul24;
   condition_flags[97] = !options->has_umad24;
   condition_flags[98] = options->has_imul24;
   condition_flags[99] = options->has_umad24;
   condition_flags[100] = options->has_umul24;
   condition_flags[101] = options->has_fused_comp_and_csel;
   condition_flags[102] = options->lower_iadd_sat;
   condition_flags[103] = options->support_8bit_alu;
   condition_flags[104] = options->support_16bit_alu;
   condition_flags[105] = options->lower_ldexp;
   condition_flags[106] = !options->lower_bitfield_reverse;
   condition_flags[107] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[108] = options->lower_fisnormal;
   condition_flags[109] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_before_ffma_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 183
 * transforms:
 *    ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b'))
 *    ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b'))
 *    ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))
 *    ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a'))
 *    ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')))
 *    ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a')))
 *    ('fneg', ('fneg', 'a')) => a
 *    ('~fadd@16', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmulz', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('fadd', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fneg', 'a') => ('fmul', 'a', -1.0)
 *    ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b')
 *    ('ineg', 'a') => ('isub', 0, 'a')
 *    ('iabs', 'a') => ('imax', 'a', ('ineg', 'a'))
 *    ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c')
 *    ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c'))
 *    ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0))
 *    ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0))
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd')))
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('ior', 'a', 'a') => a
 *    ('iand', 'a', 'a') => a
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b')
 *    ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a')
 *    ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b'))
 *    ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b'))
 *    ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38)
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g')))
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g')))
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b'))
 *    ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c'))
 *    ('ishl', 'a', 0) => a
 *    ('ishl', 'a', -32) => a
 *    ('ishr', 'a', 0) => a
 *    ('ishr', 'a', -32) => a
 *    ('ushr', 'a', 0) => a
 *    ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1)
 *    ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2)
 *    ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3)
 *    ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1)
 *    ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b')
 *    ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b')
 *    ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b')))
 *    ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a')
 *    ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a')
 *    ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a')
 *    ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a')
 *    ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a')
 *    ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a')
 *    ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a')
 *    ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a')
 *    ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a')
 *    ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a')
 *    ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a')
 *    ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a')
 *    ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a')
 *    ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a')
 *    ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a')
 *    ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a')
 *    ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a')
 *    ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a')
 *    ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a')
 *    ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a')
 *    ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a')
 *    ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b')
 *    ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b')
 *    ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b')
 *    ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b')
 *    ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b')
 *    ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b')
 *    ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b')
 *    ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b')
 *    ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c')
 *    ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c')
 *    ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b')
 *    ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b')
 *    ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b')
 *    ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b')
 *    ('f2fmp', 'a') => ('f2f16', 'a')
 *    ('f2imp', 'a') => ('f2i16', 'a')
 *    ('f2ump', 'a') => ('f2u16', 'a')
 *    ('i2imp', 'a') => ('i2i16', 'a')
 *    ('i2fmp', 'a') => ('i2f16', 'a')
 *    ('i2imp', 'a') => ('u2u16', 'a')
 *    ('u2fmp', 'a') => ('u2f16', 'a')
 *    ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf)
 */


static const nir_search_value_union nir_opt_algebraic_late_values[] = {
   /* ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace1943_0 -> 0 in the cache */
   /* replace1943_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b') */
   /* search1944_0_0_0 -> 0 in the cache */
   /* search1944_0_0_1 -> 1 in the cache */
   /* search1944_0_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 2 },
      0,
   } },
   /* search1944_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace1944_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace1944_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b') */
   /* search1945_0 -> 3 in the cache */
   /* search1945_1_0 -> 0 in the cache */
   /* search1945_1_1 -> 1 in the cache */
   /* search1945_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace1945_0_0 -> 0 in the cache */
   /* replace1945_0 -> 9 in the cache */
   /* replace1945_1 -> 1 in the cache */
   /* replace1945 -> 10 in the cache */

   /* ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b')) */
   /* search1946_0 -> 3 in the cache */
   /* search1946_1_0_0 -> 0 in the cache */
   /* search1946_1_0_1 -> 1 in the cache */
   /* search1946_1_0 -> 2 in the cache */
   /* search1946_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace1946_0 -> 0 in the cache */
   /* replace1946_1_0 -> 1 in the cache */
   /* replace1946_1 -> 5 in the cache */
   /* replace1946 -> 6 in the cache */

   /* ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   /* search1947_0_0 -> 0 in the cache */
   /* search1947_0_1 -> 1 in the cache */
   /* search1947_0 -> 2 in the cache */
   /* search1947_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace1947_0 -> 0 in the cache */
   /* replace1947_1_0 -> 1 in the cache */
   /* replace1947_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search1948_0_0_0 -> 0 in the cache */
   /* search1948_0_0_1 -> 1 in the cache */
   /* search1948_0_0 -> 2 in the cache */
   /* search1948_0 -> 7 in the cache */
   /* search1948_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace1948_0_0 -> 0 in the cache */
   /* replace1948_0 -> 9 in the cache */
   /* replace1948_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search1949_0 -> 3 in the cache */
   /* search1949_1_0 -> 0 in the cache */
   /* search1949_1_1 -> 1 in the cache */
   /* search1949_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace1949_0_0 -> 0 in the cache */
   /* replace1949_0 -> 9 in the cache */
   /* replace1949_1 -> 1 in the cache */
   /* replace1949 -> 16 in the cache */

   /* ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search1950_0 -> 3 in the cache */
   /* search1950_1_0_0 -> 0 in the cache */
   /* search1950_1_0_1 -> 1 in the cache */
   /* search1950_1_0 -> 2 in the cache */
   /* search1950_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace1950_0 -> 0 in the cache */
   /* replace1950_1_0 -> 1 in the cache */
   /* replace1950_1 -> 5 in the cache */
   /* replace1950 -> 14 in the cache */

   /* ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search1951_0_0 -> 0 in the cache */
   /* search1951_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search1951_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace1951_0 -> 0 in the cache */
   /* replace1951_1_0 -> 1 in the cache */
   /* replace1951_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search1952_0_0 -> 0 in the cache */
   /* search1952_0_1 -> 1 in the cache */
   /* search1952_0 -> 19 in the cache */
   /* search1952_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace1952_0 -> 0 in the cache */
   /* replace1952_1_0 -> 1 in the cache */
   /* replace1952_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1953_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 24, 1 },
      0,
   } },
   /* search1953_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 25, 3 },
      -1,
   } },

   /* replace1953_0 -> 0 in the cache */
   /* replace1953_1_0 -> 1 in the cache */
   /* replace1953_1 -> 5 in the cache */
   /* replace1953 -> 14 in the cache */

   /* ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search1954_0_0_0 -> 24 in the cache */
   /* search1954_0_0_1 -> 1 in the cache */
   /* search1954_0_0 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 25 },
      0,
   } },
   /* search1954_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 27, 3 },
      -1,
   } },

   /* replace1954_0_0 -> 0 in the cache */
   /* replace1954_0 -> 9 in the cache */
   /* replace1954_1 -> 1 in the cache */
   /* replace1954 -> 16 in the cache */

   /* ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search1955_0 -> 3 in the cache */
   /* search1955_1_0 -> 24 in the cache */
   /* search1955_1_1 -> 1 in the cache */
   /* search1955_1 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 25 },
      -1,
   } },

   /* replace1955_0_0 -> 0 in the cache */
   /* replace1955_0 -> 9 in the cache */
   /* replace1955_1 -> 1 in the cache */
   /* replace1955 -> 16 in the cache */

   /* ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search1956_0 -> 3 in the cache */
   /* search1956_1_0_0 -> 24 in the cache */
   /* search1956_1_0_1 -> 1 in the cache */
   /* search1956_1_0 -> 25 in the cache */
   /* search1956_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 27 },
      -1,
   } },

   /* replace1956_0 -> 0 in the cache */
   /* replace1956_1_0 -> 1 in the cache */
   /* replace1956_1 -> 5 in the cache */
   /* replace1956 -> 14 in the cache */

   /* ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search1957_0_0 -> 24 in the cache */
   /* search1957_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 24, 1 },
      0,
   } },
   /* search1957_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace1957_0 -> 0 in the cache */
   /* replace1957_1_0 -> 1 in the cache */
   /* replace1957_1 -> 5 in the cache */
   /* replace1957 -> 21 in the cache */

   /* ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search1958_0_0 -> 24 in the cache */
   /* search1958_0_1 -> 1 in the cache */
   /* search1958_0 -> 31 in the cache */
   /* search1958_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace1958_0 -> 0 in the cache */
   /* replace1958_1_0 -> 1 in the cache */
   /* replace1958_1 -> 5 in the cache */
   /* replace1958 -> 23 in the cache */

   /* ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')) */
   /* search1959_0_0 -> 0 in the cache */
   /* search1959_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search1959_1_0_0 -> 0 in the cache */
   /* search1959_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1959_1_1_0 -> 1 in the cache */
   /* search1959_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 34, 37 },
      -1,
   } },

   /* replace1959_0_0 -> 0 in the cache */
   /* replace1959_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* replace1959_1_0 -> 1 in the cache */
   /* replace1959_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 39, 40 },
      -1,
   } },

   /* ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search1960_1_0 -> 42 in the cache */
   /* search1960_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 44, 45 },
      -1,
   } },

   /* replace1960_0 -> 43 in the cache */
   /* replace1960_1_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 43, 47 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))) */
   /* search1961_0_0 -> 0 in the cache */
   /* search1961_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search1961_1_0_0 -> 0 in the cache */
   /* search1961_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1961_1_1_0 -> 1 in the cache */
   /* search1961_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 50, 51 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 49, 52 },
      -1,
   } },

   /* replace1961_0_0_0 -> 0 in the cache */
   /* replace1961_0_0_1 -> 1 in the cache */
   /* replace1961_0_0 -> 39 in the cache */
   /* replace1961_0_1_0 -> 1 in the cache */
   /* replace1961_0_1_1 -> 0 in the cache */
   /* replace1961_0_1 -> 40 in the cache */
   /* replace1961_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 41 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a'))) */
   /* search1962_0_0 -> 42 in the cache */
   /* search1962_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search1962_1_0 -> 42 in the cache */
   /* search1962_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 55, 56 },
      -1,
   } },

   /* replace1962_0_0 -> 43 in the cache */
   /* replace1962_0_1_0 -> 42 in the cache */
   /* replace1962_0_1 -> 47 in the cache */
   /* replace1962_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 48 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   /* search1963_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 59 },
      -1,
   } },

   /* replace1963 -> 42 in the cache */

   /* ('~fadd@16', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 61, 62 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 63, 64 },
      -1,
   } },

   /* replace1964_0 -> 61 in the cache */
   /* replace1964_1 -> 62 in the cache */
   /* replace1964_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 61, 62, 64 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 67, 68 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 69, 70 },
      -1,
   } },

   /* replace1965_0 -> 67 in the cache */
   /* replace1965_1 -> 68 in the cache */
   /* replace1965_2 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 68, 70 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 73, 74 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 75, 76 },
      -1,
   } },

   /* replace1966_0 -> 73 in the cache */
   /* replace1966_1 -> 74 in the cache */
   /* replace1966_2 -> 76 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 73, 74, 76 },
      -1,
   } },

   /* ('~fadd@32', ('fmulz', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search1967_0_0 -> 67 in the cache */
   /* search1967_0_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 67, 68 },
      -1,
   } },
   /* search1967_1 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 79, 70 },
      -1,
   } },

   /* replace1967_0 -> 67 in the cache */
   /* replace1967_1 -> 68 in the cache */
   /* replace1967_2 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 67, 68, 70 },
      -1,
   } },

   /* ('fadd', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search1968_0 -> 0 in the cache */
   /* search1968_1_0 -> 1 in the cache */
   /* search1968_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* replace1968_0 -> 0 in the cache */
   /* replace1968_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('fneg', 'a') => ('fmul', 'a', -1.0) */
   /* search1969_0 -> 42 in the cache */
   /* search1969 -> 59 in the cache */

   /* replace1969_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 42, 84 },
      -1,
   } },

   /* ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b') */
   /* search1970_0 -> 0 in the cache */
   /* search1970_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 86 },
      -1,
   } },

   /* replace1970_0 -> 0 in the cache */
   /* replace1970_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('ineg', 'a') => ('isub', 0, 'a') */
   /* search1971_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 42 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace1971_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 90, 42 },
      -1,
   } },

   /* ('iabs', 'a') => ('imax', 'a', ('ineg', 'a')) */
   /* search1972_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace1972_0 -> 42 in the cache */
   /* replace1972_1_0 -> 42 in the cache */
   /* replace1972_1 -> 89 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 42, 89 },
      -1,
   } },

   /* ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 94, 95 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 96, 97 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 99, 100, 101 },
      -1,
   } },

   /* ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c') */
   /* search1974_0_0 -> 94 in the cache */
   /* search1974_0_1 -> 95 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 94, 95 },
      0,
   } },
   /* search1974_1 -> 97 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 103, 97 },
      -1,
   } },

   /* replace1974_0 -> 99 in the cache */
   /* replace1974_1_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 100 },
      -1,
   } },
   /* replace1974_2 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 99, 105, 101 },
      -1,
   } },

   /* ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c')) */
   /* search1975_0_0 -> 94 in the cache */
   /* search1975_0_1 -> 95 in the cache */
   /* search1975_0 -> 103 in the cache */
   /* search1975_1 -> 97 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 103, 97 },
      -1,
   } },

   /* replace1975_0 -> 99 in the cache */
   /* replace1975_1_0 -> 100 in the cache */
   /* replace1975_1 -> 105 in the cache */
   /* replace1975_2_0 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 99, 105, 108 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0)) */
   /* search1976_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 61 },
      -1,
   } },
   /* search1976_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 110, 62 },
      1,
   } },

   /* replace1976_0_0 -> 61 in the cache */
   /* replace1976_0_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 61, 62 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 113, 114 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 112, 115 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0)) */
   /* search1977_0 -> 61 in the cache */
   /* search1977_1_0 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 62 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 61, 117 },
      1,
   } },

   /* replace1977_0_0 -> 61 in the cache */
   /* replace1977_0_1 -> 62 in the cache */
   /* replace1977_0 -> 112 in the cache */
   /* replace1977_1_0 -> 114 in the cache */
   /* replace1977_1_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 114, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 112, 119 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 122 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 121, 123 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace1978_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 125, 122 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search1979_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 127, 128 },
      -1,
   } },

   /* replace1979_0 -> 0 in the cache */
   /* replace1979_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search1980_0_0 -> 0 in the cache */
   /* search1980_0 -> 127 in the cache */
   /* search1980_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 127, 128 },
      -1,
   } },

   /* replace1980_0 -> 0 in the cache */
   /* replace1980_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search1981_0_0 -> 0 in the cache */
   /* search1981_0 -> 127 in the cache */
   /* search1981_1 -> 128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 127, 128 },
      -1,
   } },

   /* replace1981_0 -> 0 in the cache */
   /* replace1981_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search1982_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 42 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 135, 136 },
      -1,
   } },

   /* replace1982_0 -> 42 in the cache */
   /* replace1982_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 42, 136 },
      -1,
   } },

   /* ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd'))) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 139, 140 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 142, 143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 141, 144 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 3,
      { 145, 146 },
      -1,
   } },

   /* replace1983_0_0 -> 139 in the cache */
   /* replace1983_0_1_0 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 140 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 139, 148 },
      -1,
   } },
   /* replace1983_1_0 -> 142 in the cache */
   /* replace1983_1_1_0 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 142, 150 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 149, 151 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search1984_0_0 -> 0 in the cache */
   /* search1984_0 -> 9 in the cache */
   /* search1984_1_0 -> 1 in the cache */
   /* search1984_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace1984_0 -> 1 in the cache */
   /* replace1984_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search1985_0_0 -> 0 in the cache */
   /* search1985_0 -> 9 in the cache */
   /* search1985_1_0 -> 1 in the cache */
   /* search1985_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace1985_0 -> 1 in the cache */
   /* replace1985_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search1986_0_0 -> 0 in the cache */
   /* search1986_0 -> 9 in the cache */
   /* search1986_1_0 -> 1 in the cache */
   /* search1986_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace1986_0 -> 1 in the cache */
   /* replace1986_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search1987_0_0 -> 0 in the cache */
   /* search1987_0 -> 9 in the cache */
   /* search1987_1_0 -> 1 in the cache */
   /* search1987_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace1987_0 -> 1 in the cache */
   /* replace1987_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search1988_0_0 -> 42 in the cache */
   /* search1988_0 -> 59 in the cache */
   /* search1988_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 59, 84 },
      -1,
   } },

   /* replace1988_0 -> 136 in the cache */
   /* replace1988_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 136, 42 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search1989_0 -> 84 in the cache */
   /* search1989_1_0 -> 42 in the cache */
   /* search1989_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 84, 59 },
      -1,
   } },

   /* replace1989_0 -> 42 in the cache */
   /* replace1989_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 42, 136 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search1990_0_0 -> 42 in the cache */
   /* search1990_0 -> 59 in the cache */
   /* search1990_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 59, 84 },
      -1,
   } },

   /* replace1990_0 -> 136 in the cache */
   /* replace1990_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 136, 42 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search1991_0 -> 84 in the cache */
   /* search1991_1_0 -> 42 in the cache */
   /* search1991_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 84, 59 },
      -1,
   } },

   /* replace1991_0 -> 42 in the cache */
   /* replace1991_1 -> 136 in the cache */
   /* replace1991 -> 138 in the cache */

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search1992_0_0 -> 42 in the cache */
   /* search1992_0 -> 59 in the cache */
   /* search1992_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 59, 84 },
      -1,
   } },

   /* replace1992_0 -> 136 in the cache */
   /* replace1992_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 136, 42 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search1993_0 -> 84 in the cache */
   /* search1993_1_0 -> 42 in the cache */
   /* search1993_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 84, 59 },
      -1,
   } },

   /* replace1993_0 -> 42 in the cache */
   /* replace1993_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 42, 136 },
      -1,
   } },

   /* ('ior', 'a', 'a') => a */
   /* search1994_0 -> 42 in the cache */
   /* search1994_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace1994 -> 42 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search1995_0 -> 42 in the cache */
   /* search1995_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace1995 -> 42 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 174 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 175 },
      0,
   } },
   /* search1996_1 -> 136 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 176, 136 },
      -1,
   } },

   /* replace1996_0_0 -> 136 in the cache */
   /* replace1996_0_1_0 -> 42 in the cache */
   /* replace1996_0_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 136, 59 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 178 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b') */
   /* search1997_0 -> 0 in the cache */
   /* search1997_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1997_0 -> 0 in the cache */
   /* replace1997_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b') */
   /* search1998_0 -> 0 in the cache */
   /* search1998_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1998_0 -> 0 in the cache */
   /* replace1998_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b') */
   /* search1999_0 -> 0 in the cache */
   /* search1999_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace1999_0 -> 0 in the cache */
   /* replace1999_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b') */
   /* search2000_0 -> 0 in the cache */
   /* search2000_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace2000_0 -> 0 in the cache */
   /* replace2000_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search2001_0_0 -> 139 in the cache */
   /* search2001_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 139, 140 },
      0,
   } },
   /* search2001_1_0 -> 139 in the cache */
   /* search2001_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 139, 142 },
      0,
   } },
   /* search2001_2 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 188, 189, 143 },
      -1,
   } },

   /* replace2001_0_0 -> 140 in the cache */
   /* replace2001_0_1 -> 142 in the cache */
   /* replace2001_0_2 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 140, 142, 143 },
      -1,
   } },
   /* replace2001_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 191, 139 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search2002_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 193, 194 },
      -1,
   } },

   /* replace2002_0 -> 194 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace2002_2 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 194, 196, 67 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search2003_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xc000000000000000 /* -2.0 */ },
   } },
   /* search2003_2 -> 194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 198, 194 },
      -1,
   } },

   /* replace2003_0 -> 194 in the cache */
   /* replace2003_1 -> 196 in the cache */
   /* replace2003_2_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 194, 196, 200 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search2004_0 -> 67 in the cache */
   /* search2004_1 -> 198 in the cache */
   /* search2004_2 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 198, 196 },
      -1,
   } },

   /* replace2004_0 -> 196 in the cache */
   /* replace2004_1 -> 194 in the cache */
   /* replace2004_2 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 196, 194, 67 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search2005_0 -> 67 in the cache */
   /* search2005_1 -> 193 in the cache */
   /* search2005_2 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 193, 196 },
      -1,
   } },

   /* replace2005_0 -> 196 in the cache */
   /* replace2005_1 -> 194 in the cache */
   /* replace2005_2_0 -> 67 in the cache */
   /* replace2005_2 -> 200 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 196, 194, 200 },
      -1,
   } },

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search2006_0_0 -> 193 in the cache */
   /* search2006_0_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 193, 67 },
      0,
   } },
   /* search2006_1 -> 194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 206, 194 },
      -1,
   } },

   /* replace2006_0 -> 194 in the cache */
   /* replace2006_1 -> 196 in the cache */
   /* replace2006_2 -> 67 in the cache */
   /* replace2006 -> 197 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search2007_0_0 -> 198 in the cache */
   /* search2007_0_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 198, 67 },
      0,
   } },
   /* search2007_1 -> 194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 208, 194 },
      -1,
   } },

   /* replace2007_0 -> 194 in the cache */
   /* replace2007_1 -> 196 in the cache */
   /* replace2007_2_0 -> 67 in the cache */
   /* replace2007_2 -> 200 in the cache */
   /* replace2007 -> 201 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search2008_0_0 -> 198 in the cache */
   /* search2008_0_1 -> 67 in the cache */
   /* search2008_0 -> 208 in the cache */
   /* search2008_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 208, 196 },
      -1,
   } },

   /* replace2008_0 -> 196 in the cache */
   /* replace2008_1 -> 194 in the cache */
   /* replace2008_2 -> 67 in the cache */
   /* replace2008 -> 203 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search2009_0_0 -> 193 in the cache */
   /* search2009_0_1 -> 67 in the cache */
   /* search2009_0 -> 206 in the cache */
   /* search2009_1 -> 196 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 206, 196 },
      -1,
   } },

   /* replace2009_0 -> 196 in the cache */
   /* replace2009_1 -> 194 in the cache */
   /* replace2009_2_0 -> 67 in the cache */
   /* replace2009_2 -> 200 in the cache */
   /* replace2009 -> 205 in the cache */

   /* ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 213 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 212, 214 },
      -1,
   } },
   /* search2010_1 -> 213 in the cache */
   /* search2010_2 -> 213 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 215, 213, 213 },
      -1,
   } },

   /* replace2010_0 -> 213 in the cache */
   /* replace2010_1 -> 212 in the cache */
   /* replace2010_2 -> 213 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 213, 212, 213 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search2011_0 -> 67 in the cache */
   /* search2011_1 -> 193 in the cache */
   /* search2011_2_0_0 -> 67 in the cache */
   /* search2011_2_0_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 67, 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 218 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 67, 193, 219 },
      -1,
   } },

   /* replace2011_0 -> 67 in the cache */
   /* replace2011_1 -> 196 in the cache */
   /* replace2011_2 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 67, 196, 67 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search2012_0 -> 67 in the cache */
   /* search2012_1 -> 193 in the cache */
   /* search2012_2_0_0 -> 67 in the cache */
   /* search2012_2_0 -> 200 in the cache */
   /* search2012_2_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 200, 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 67, 193, 222 },
      -1,
   } },

   /* replace2012_0 -> 67 in the cache */
   /* replace2012_1 -> 196 in the cache */
   /* replace2012_2 -> 67 in the cache */
   /* replace2012 -> 221 in the cache */

   /* ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search2013_0 -> 67 in the cache */
   /* search2013_1_0 -> 67 in the cache */
   /* search2013_1 -> 200 in the cache */
   /* search2013_2_0 -> 193 in the cache */
   /* search2013_2_1 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 193, 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 67, 200, 224 },
      -1,
   } },

   /* replace2013_0 -> 67 in the cache */
   /* replace2013_1 -> 196 in the cache */
   /* replace2013_2 -> 67 in the cache */
   /* replace2013 -> 221 in the cache */

   /* ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search2014_0 -> 67 in the cache */
   /* search2014_1_0 -> 193 in the cache */
   /* search2014_1_1_0 -> 67 in the cache */
   /* search2014_1_1 -> 200 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 193, 200 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 67, 226 },
      -1,
   } },

   /* replace2014_0 -> 67 in the cache */
   /* replace2014_1 -> 196 in the cache */
   /* replace2014_2 -> 67 in the cache */
   /* replace2014 -> 221 in the cache */

   /* ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 228, 229 },
      0,
   } },
   /* search2015_1_0 -> 228 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 228, 231 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 230, 232 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace2015_1_0 -> 229 in the cache */
   /* replace2015_1_1 -> 231 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 229, 231 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 234, 235 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b')) */
   /* search2016_0_0 -> 228 in the cache */
   /* search2016_0_1 -> 229 in the cache */
   /* search2016_0 -> 230 in the cache */
   /* search2016_1_0 -> 228 in the cache */
   /* search2016_1_1 -> 231 in the cache */
   /* search2016_1 -> 232 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 230, 232 },
      -1,
   } },

   /* replace2016_0 -> 234 in the cache */
   /* replace2016_1_0 -> 229 in the cache */
   /* replace2016_1_1 -> 231 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 229, 231 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 234, 238 },
      -1,
   } },

   /* ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 240 },
      -1,
   } },
   /* search2017_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 241, 43 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x47efffffe0000000 /* 3.4028234663852886e+38 */ },
   } },
   /* search2017_2_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 242, 243, 244 },
      -1,
   } },

   /* replace2017_0_0 -> 42 in the cache */
   /* replace2017_0 -> 244 in the cache */
   /* replace2017_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 244, 243 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g'))) */
   { .variable = {
      { nir_search_value_variable, -7 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 251, 252 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 2,
      { 249, 250, 253 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 3,
      { 247, 248, 254 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 255, 256 },
      -1,
   } },

   /* replace2018_0 -> 247 in the cache */
   /* replace2018_1 -> 248 in the cache */
   /* replace2018_2_0 -> 249 in the cache */
   /* replace2018_2_1 -> 250 in the cache */
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 258, 259, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 249, 250, 261 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 247, 248, 262 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, -5 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 266, 267 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 264, 265, 268 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 269, 270 },
      -1,
   } },

   /* replace2019_0 -> 264 in the cache */
   /* replace2019_1 -> 265 in the cache */
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 272, 273, 274 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 264, 265, 275 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g'))) */
   /* search2020_0_0_0 -> 247 in the cache */
   /* search2020_0_0_1 -> 248 in the cache */
   /* search2020_0_0_2_0 -> 249 in the cache */
   /* search2020_0_0_2_1 -> 250 in the cache */
   /* search2020_0_0_2_2_0 -> 251 in the cache */
   /* search2020_0_0_2_2_1 -> 252 in the cache */
   /* search2020_0_0_2_2 -> 253 in the cache */
   /* search2020_0_0_2 -> 254 in the cache */
   /* search2020_0_0 -> 255 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 255 },
      -1,
   } },
   /* search2020_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 277, 256 },
      -1,
   } },

   /* replace2020_0_0 -> 247 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 247 },
      -1,
   } },
   /* replace2020_1 -> 248 in the cache */
   /* replace2020_2_0_0 -> 249 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 249 },
      -1,
   } },
   /* replace2020_2_1 -> 250 in the cache */
   /* replace2020_2_2_0_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 258 },
      -1,
   } },
   /* replace2020_2_2_1 -> 259 in the cache */
   /* replace2020_2_2_2 -> 260 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 281, 259, 260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 280, 250, 282 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 279, 248, 283 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g'))) */
   /* search2021_0_0 -> 67 in the cache */
   /* search2021_0_1 -> 68 in the cache */
   /* search2021_0_2_0 -> 70 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      3, 1,
      { 286, 287 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 2,
      { 70, 285, 288 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 3,
      { 67, 68, 289 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 290, 291 },
      -1,
   } },

   /* replace2021_0 -> 67 in the cache */
   /* replace2021_1 -> 68 in the cache */
   /* replace2021_2_0 -> 70 in the cache */
   /* replace2021_2_1 -> 285 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 293, 294, 295 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 70, 285, 296 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 67, 68, 297 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e')) */
   /* search2022_0_0 -> 67 in the cache */
   /* search2022_0_1 -> 68 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 299, 300 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 67, 68, 301 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 302, 303 },
      -1,
   } },

   /* replace2022_0 -> 67 in the cache */
   /* replace2022_1 -> 68 in the cache */
   /* replace2022_2_0 -> 70 in the cache */
   /* replace2022_2_1 -> 285 in the cache */
   /* replace2022_2_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 70, 285, 293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 67, 68, 305 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g'))) */
   /* search2023_0_0_0 -> 67 in the cache */
   /* search2023_0_0_1 -> 68 in the cache */
   /* search2023_0_0_2_0 -> 70 in the cache */
   /* search2023_0_0_2_1 -> 285 in the cache */
   /* search2023_0_0_2_2_0 -> 286 in the cache */
   /* search2023_0_0_2_2_1 -> 287 in the cache */
   /* search2023_0_0_2_2 -> 288 in the cache */
   /* search2023_0_0_2 -> 289 in the cache */
   /* search2023_0_0 -> 290 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 290 },
      -1,
   } },
   /* search2023_1 -> 291 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 307, 291 },
      -1,
   } },

   /* replace2023_0_0 -> 67 in the cache */
   /* replace2023_0 -> 200 in the cache */
   /* replace2023_1 -> 68 in the cache */
   /* replace2023_2_0_0 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 70 },
      -1,
   } },
   /* replace2023_2_1 -> 285 in the cache */
   /* replace2023_2_2_0_0 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 293 },
      -1,
   } },
   /* replace2023_2_2_1 -> 294 in the cache */
   /* replace2023_2_2_2 -> 295 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 310, 294, 295 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 309, 285, 311 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 200, 68, 312 },
      -1,
   } },

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search2024_0 -> 67 in the cache */
   /* search2024_1 -> 68 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 67, 68, 314 },
      -1,
   } },

   /* replace2024 -> 314 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search2025_0 -> 67 in the cache */
   /* search2025_1 -> 68 in the cache */
   /* search2025_2 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 67, 68, 314 },
      -1,
   } },

   /* replace2025 -> 314 in the cache */

   /* ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b')) */
   /* search2026_0 -> 67 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 67, 317, 318 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   /* replace2026_0_1_0 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 70 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 320, 321 },
      -1,
   } },
   /* replace2026_1_0 -> 67 in the cache */
   /* replace2026_1_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 67, 68 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 322, 323 },
      -1,
   } },

   /* ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c')) */
   /* search2027_0 -> 67 in the cache */
   /* search2027_1 -> 317 in the cache */
   /* search2027_2 -> 318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 67, 317, 318 },
      -1,
   } },

   /* replace2027_0_0 -> 67 in the cache */
   /* replace2027_0_1_0_0 -> 68 in the cache */
   /* replace2027_0_1_0_1 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 68, 70 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 326 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 67, 327 },
      -1,
   } },
   /* replace2027_1_0 -> 70 in the cache */
   /* replace2027_1 -> 321 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 328, 321 },
      -1,
   } },

   /* ('ishl', 'a', 0) => a */
   /* search2028_0 -> 42 in the cache */
   /* search2028_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 42, 314 },
      -1,
   } },

   /* replace2028 -> 42 in the cache */

   /* ('ishl', 'a', -32) => a */
   /* search2029_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x20 /* -32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 42, 331 },
      -1,
   } },

   /* replace2029 -> 42 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search2030_0 -> 42 in the cache */
   /* search2030_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 42, 314 },
      -1,
   } },

   /* replace2030 -> 42 in the cache */

   /* ('ishr', 'a', -32) => a */
   /* search2031_0 -> 42 in the cache */
   /* search2031_1 -> 331 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 42, 331 },
      -1,
   } },

   /* replace2031 -> 42 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search2032_0 -> 42 in the cache */
   /* search2032_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 42, 314 },
      -1,
   } },

   /* replace2032 -> 42 in the cache */

   /* ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2033_0_0 -> 0 in the cache */
   /* search2033_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 336, 337 },
      -1,
   } },

   /* replace2033_0 -> 0 in the cache */
   /* replace2033_1 -> 1 in the cache */
   /* replace2033 -> 336 in the cache */

   /* ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2034_0_0 -> 0 in the cache */
   /* search2034_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* search2034_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 339, 337 },
      -1,
   } },

   /* replace2034_0 -> 0 in the cache */
   /* replace2034_1 -> 1 in the cache */
   /* replace2034 -> 336 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2035_0_0 -> 0 in the cache */
   /* search2035_0_1 -> 1 in the cache */
   /* search2035_0 -> 336 in the cache */
   /* search2035_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 336, 337 },
      -1,
   } },

   /* replace2035_0 -> 0 in the cache */
   /* replace2035_1 -> 1 in the cache */
   /* replace2035 -> 339 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2036_0_0 -> 0 in the cache */
   /* search2036_0_1 -> 1 in the cache */
   /* search2036_0 -> 339 in the cache */
   /* search2036_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 339, 337 },
      -1,
   } },

   /* replace2036_0 -> 0 in the cache */
   /* replace2036_1 -> 1 in the cache */
   /* replace2036 -> 339 in the cache */

   /* ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2037_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 61 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 343 },
      -1,
   } },

   /* replace2037_0 -> 61 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 61, 345 },
      -1,
   } },

   /* ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2038_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 61 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 347 },
      -1,
   } },

   /* replace2038_0 -> 61 in the cache */
   /* replace2038_1 -> 345 in the cache */
   /* replace2038 -> 346 in the cache */

   /* ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2039_0_0 -> 61 in the cache */
   /* search2039_0 -> 343 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 343 },
      -1,
   } },

   /* replace2039_0 -> 61 in the cache */
   /* replace2039_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 61, 345 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2040_0_0 -> 61 in the cache */
   /* search2040_0 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 347 },
      -1,
   } },

   /* replace2040_0 -> 61 in the cache */
   /* replace2040_1 -> 345 in the cache */
   /* replace2040 -> 350 in the cache */

   /* ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2041_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 352 },
      -1,
   } },

   /* replace2041_0 -> 67 in the cache */
   /* replace2041_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 67, 314 },
      -1,
   } },

   /* ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2042_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 355 },
      -1,
   } },

   /* replace2042_0 -> 67 in the cache */
   /* replace2042_1 -> 314 in the cache */
   /* replace2042 -> 354 in the cache */

   /* ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2043_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 357 },
      -1,
   } },

   /* replace2043_0 -> 67 in the cache */
   /* replace2043_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 67, 314 },
      -1,
   } },

   /* ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2044_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 360 },
      -1,
   } },

   /* replace2044_0 -> 67 in the cache */
   /* replace2044_1 -> 314 in the cache */
   /* replace2044 -> 359 in the cache */

   /* ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2045_0_0 -> 67 in the cache */
   /* search2045_0 -> 352 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 352 },
      -1,
   } },

   /* replace2045_0 -> 67 in the cache */
   /* replace2045_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 67, 314 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2046_0_0 -> 67 in the cache */
   /* search2046_0 -> 355 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 355 },
      -1,
   } },

   /* replace2046_0 -> 67 in the cache */
   /* replace2046_1 -> 314 in the cache */
   /* replace2046 -> 363 in the cache */

   /* ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2047_0_0 -> 67 in the cache */
   /* search2047_0 -> 357 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 357 },
      -1,
   } },

   /* replace2047_0 -> 67 in the cache */
   /* replace2047_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 67, 314 },
      -1,
   } },

   /* ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2048_0_0 -> 67 in the cache */
   /* search2048_0 -> 360 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 360 },
      -1,
   } },

   /* replace2048_0 -> 67 in the cache */
   /* replace2048_1 -> 314 in the cache */
   /* replace2048 -> 366 in the cache */

   /* ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1) */
   /* search2049_0_0 -> 67 in the cache */
   /* search2049_0_1 -> 314 in the cache */
   /* search2049_0 -> 354 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 354, 368 },
      -1,
   } },

   /* replace2049_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 67, 370 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2) */
   /* search2050_0_0 -> 67 in the cache */
   /* search2050_0_1 -> 314 in the cache */
   /* search2050_0 -> 354 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 354, 372 },
      -1,
   } },

   /* replace2050_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 67, 374 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3) */
   /* search2051_0_0 -> 67 in the cache */
   /* search2051_0_1 -> 314 in the cache */
   /* search2051_0 -> 354 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 354, 376 },
      -1,
   } },

   /* replace2051_0 -> 67 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 67, 378 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1) */
   /* search2052_0_0 -> 67 in the cache */
   /* search2052_0_1 -> 368 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 67, 368 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00 /* 65280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 380, 381 },
      -1,
   } },

   /* replace2052_0 -> 67 in the cache */
   /* replace2052_1 -> 370 in the cache */
   /* replace2052 -> 371 in the cache */

   /* ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2) */
   /* search2053_0_0 -> 67 in the cache */
   /* search2053_0_1 -> 372 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 67, 372 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff0000 /* 16711680 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 383, 384 },
      -1,
   } },

   /* replace2053_0 -> 67 in the cache */
   /* replace2053_1 -> 374 in the cache */
   /* replace2053 -> 375 in the cache */

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3) */
   /* search2054_0_0 -> 67 in the cache */
   /* search2054_0_1 -> 376 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 67, 376 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 386, 387 },
      -1,
   } },

   /* replace2054_0 -> 67 in the cache */
   /* replace2054_1 -> 378 in the cache */
   /* replace2054 -> 379 in the cache */

   /* ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3) */
   /* search2055_0 -> 67 in the cache */
   /* search2055_1 -> 376 in the cache */
   /* search2055 -> 386 in the cache */

   /* replace2055_0 -> 67 in the cache */
   /* replace2055_1 -> 378 in the cache */
   /* replace2055 -> 379 in the cache */

   /* ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1) */
   /* search2056_0 -> 67 in the cache */
   /* search2056_1 -> 372 in the cache */
   /* search2056 -> 383 in the cache */

   /* replace2056_0 -> 67 in the cache */
   /* replace2056_1 -> 370 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 67, 370 },
      -1,
   } },

   /* ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b') */
   /* search2057_0_0 -> 0 in the cache */
   /* search2057_0_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 337 },
      -1,
   } },
   /* search2057_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 390, 1 },
      -1,
   } },

   /* replace2057_0 -> 0 in the cache */
   /* replace2057_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b') */
   /* search2058_0_0 -> 0 in the cache */
   /* search2058_0_1 -> 337 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 337 },
      -1,
   } },
   /* search2058_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 393, 1 },
      -1,
   } },

   /* replace2058_0 -> 0 in the cache */
   /* replace2058_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 396, 397 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2059_1_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 399, 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 398, 400 },
      -1,
   } },

   /* replace2059_0_0 -> 396 in the cache */
   /* replace2059_0_1 -> 399 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 396, 399 },
      -1,
   } },
   /* replace2059_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 402, 397 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2060_0_0 -> 396 in the cache */
   /* search2060_0_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 396, 397 },
      0,
   } },
   /* search2060_1_0 -> 399 in the cache */
   /* search2060_1_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 399, 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 404, 405 },
      -1,
   } },

   /* replace2060_0_0 -> 396 in the cache */
   /* replace2060_0_1 -> 399 in the cache */
   /* replace2060_0 -> 402 in the cache */
   /* replace2060_1 -> 397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 402, 397 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2061_0_0 -> 61 in the cache */
   /* search2061_0_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 61, 345 },
      0,
   } },
   /* search2061_1_0 -> 62 in the cache */
   /* search2061_1_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 62, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 408, 409 },
      -1,
   } },

   /* replace2061_0_0 -> 61 in the cache */
   /* replace2061_0_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 61, 62 },
      -1,
   } },
   /* replace2061_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 411, 345 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2062_0_0 -> 61 in the cache */
   /* search2062_0_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 61, 345 },
      0,
   } },
   /* search2062_1_0 -> 62 in the cache */
   /* search2062_1_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 62, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 413, 414 },
      -1,
   } },

   /* replace2062_0_0 -> 61 in the cache */
   /* replace2062_0_1 -> 62 in the cache */
   /* replace2062_0 -> 411 in the cache */
   /* replace2062_1 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 411, 345 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2063_0_0 -> 67 in the cache */
   /* search2063_0_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 67, 314 },
      0,
   } },
   /* search2063_1_0 -> 68 in the cache */
   /* search2063_1_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 68, 314 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 417, 418 },
      -1,
   } },

   /* replace2063_0_0 -> 67 in the cache */
   /* replace2063_0_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 67, 68 },
      -1,
   } },
   /* replace2063_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 420, 314 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2064_0_0 -> 67 in the cache */
   /* search2064_0_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 67, 314 },
      0,
   } },
   /* search2064_1_0 -> 68 in the cache */
   /* search2064_1_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 68, 314 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 422, 423 },
      -1,
   } },

   /* replace2064_0_0 -> 67 in the cache */
   /* replace2064_0_1 -> 68 in the cache */
   /* replace2064_0 -> 420 in the cache */
   /* replace2064_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 420, 314 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2065_0_0 -> 73 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 73, 426 },
      0,
   } },
   /* search2065_1_0 -> 74 in the cache */
   /* search2065_1_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 74, 426 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 427, 428 },
      -1,
   } },

   /* replace2065_0_0 -> 73 in the cache */
   /* replace2065_0_1 -> 74 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 73, 74 },
      -1,
   } },
   /* replace2065_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 430, 426 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2066_0_0 -> 73 in the cache */
   /* search2066_0_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 73, 426 },
      0,
   } },
   /* search2066_1_0 -> 74 in the cache */
   /* search2066_1_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 74, 426 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 432, 433 },
      -1,
   } },

   /* replace2066_0_0 -> 73 in the cache */
   /* replace2066_0_1 -> 74 in the cache */
   /* replace2066_0 -> 430 in the cache */
   /* replace2066_1 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 430, 426 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2067_0 -> 114 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2067_1_1_0 -> 62 in the cache */
   /* search2067_1_1_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 62, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 436, 437 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 114, 438 },
      -1,
   } },

   /* replace2067_0_0 -> 114 in the cache */
   /* replace2067_0_1_0 -> 436 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 114, 440 },
      -1,
   } },
   /* replace2067_1_0 -> 62 in the cache */
   /* replace2067_1_1 -> 436 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 62, 436 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 441, 442 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b'))) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2068_1 -> 345 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 445 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 345, 447 },
      -1,
   } },

   /* replace2068_0_0_0 -> 444 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 444, 449 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 450 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 1,
      { 451 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2069_0 -> 196 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2069_1_1_0 -> 68 in the cache */
   /* search2069_1_1_1 -> 194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 68, 194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 453, 454 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 196, 455 },
      -1,
   } },

   /* replace2069_0_0 -> 196 in the cache */
   /* replace2069_0_1_0 -> 453 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 453 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 196, 457 },
      -1,
   } },
   /* replace2069_1_0 -> 68 in the cache */
   /* replace2069_1_1 -> 453 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 68, 453 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 458, 459 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b'))) */
   /* search2070_0 -> 444 in the cache */
   /* search2070_1 -> 314 in the cache */
   /* search2070_2_0_0 -> 445 in the cache */
   /* search2070_2_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 314, 461 },
      -1,
   } },

   /* replace2070_0_0_0 -> 444 in the cache */
   /* replace2070_0_0_1 -> 449 in the cache */
   /* replace2070_0_0 -> 450 in the cache */
   /* replace2070_0 -> 451 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 1,
      { 451 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2071_1_1_0 -> 74 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 74, 466 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 465, 467 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 464, 468 },
      -1,
   } },

   /* replace2071_0_0 -> 464 in the cache */
   /* replace2071_0_1_0 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 464, 470 },
      -1,
   } },
   /* replace2071_1_0 -> 74 in the cache */
   /* replace2071_1_1 -> 465 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 74, 465 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 471, 472 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b'))) */
   /* search2072_0 -> 444 in the cache */
   /* search2072_1 -> 426 in the cache */
   /* search2072_2_0_0 -> 445 in the cache */
   /* search2072_2_0 -> 446 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 446 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 426, 474 },
      -1,
   } },

   /* replace2072_0_0_0 -> 444 in the cache */
   /* replace2072_0_0_1 -> 449 in the cache */
   /* replace2072_0_0 -> 450 in the cache */
   /* replace2072_0 -> 451 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 1,
      { 451 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2073_0 -> 444 in the cache */
   /* search2073_1_0 -> 140 in the cache */
   /* search2073_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 140, 142 },
      0,
   } },
   /* search2073_2_0 -> 140 in the cache */
   /* search2073_2_1 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 140, 143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 477, 478 },
      -1,
   } },

   /* replace2073_0 -> 140 in the cache */
   /* replace2073_1_0 -> 444 in the cache */
   /* replace2073_1_1 -> 142 in the cache */
   /* replace2073_1_2 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 142, 143 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 140, 480 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2074_0 -> 444 in the cache */
   /* search2074_1_0 -> 140 in the cache */
   /* search2074_1_1 -> 142 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 140, 142 },
      -1,
   } },
   /* search2074_2_0 -> 140 in the cache */
   /* search2074_2_1 -> 143 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 140, 143 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 482, 483 },
      -1,
   } },

   /* replace2074_0 -> 140 in the cache */
   /* replace2074_1_0 -> 444 in the cache */
   /* replace2074_1_1 -> 142 in the cache */
   /* replace2074_1_2 -> 143 in the cache */
   /* replace2074_1 -> 480 in the cache */
   /* replace2074 -> 481 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2075_0 -> 444 in the cache */
   /* search2075_1_0 -> 265 in the cache */
   /* search2075_1_1 -> 272 in the cache */
   /* search2075_1_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 265, 272, 273 },
      0,
   } },
   /* search2075_2_0 -> 265 in the cache */
   /* search2075_2_1 -> 272 in the cache */
   /* search2075_2_2 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 265, 272, 274 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 485, 486 },
      -1,
   } },

   /* replace2075_0 -> 265 in the cache */
   /* replace2075_1 -> 272 in the cache */
   /* replace2075_2_0 -> 444 in the cache */
   /* replace2075_2_1 -> 273 in the cache */
   /* replace2075_2_2 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 273, 274 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 265, 272, 488 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2076_0 -> 444 in the cache */
   /* search2076_1_0 -> 265 in the cache */
   /* search2076_1_1 -> 272 in the cache */
   /* search2076_1_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 265, 272, 273 },
      -1,
   } },
   /* search2076_2_0 -> 265 in the cache */
   /* search2076_2_1 -> 272 in the cache */
   /* search2076_2_2 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 265, 272, 274 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 490, 491 },
      -1,
   } },

   /* replace2076_0 -> 265 in the cache */
   /* replace2076_1 -> 272 in the cache */
   /* replace2076_2_0 -> 444 in the cache */
   /* replace2076_2_1 -> 273 in the cache */
   /* replace2076_2_2 -> 274 in the cache */
   /* replace2076_2 -> 488 in the cache */
   /* replace2076 -> 489 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2077_0 -> 444 in the cache */
   /* search2077_1_0 -> 265 in the cache */
   /* search2077_1_1 -> 272 in the cache */
   /* search2077_1_2 -> 273 in the cache */
   /* search2077_1 -> 485 in the cache */
   /* search2077_2_0 -> 265 in the cache */
   /* search2077_2_1 -> 274 in the cache */
   /* search2077_2_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 265, 274, 273 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 485, 493 },
      -1,
   } },

   /* replace2077_0 -> 265 in the cache */
   /* replace2077_1_0 -> 444 in the cache */
   /* replace2077_1_1 -> 272 in the cache */
   /* replace2077_1_2 -> 274 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 272, 274 },
      -1,
   } },
   /* replace2077_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 265, 495, 273 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2078_0 -> 444 in the cache */
   /* search2078_1_0 -> 265 in the cache */
   /* search2078_1_1 -> 272 in the cache */
   /* search2078_1_2 -> 273 in the cache */
   /* search2078_1 -> 490 in the cache */
   /* search2078_2_0 -> 265 in the cache */
   /* search2078_2_1 -> 274 in the cache */
   /* search2078_2_2 -> 273 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 265, 274, 273 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 490, 497 },
      -1,
   } },

   /* replace2078_0 -> 265 in the cache */
   /* replace2078_1_0 -> 444 in the cache */
   /* replace2078_1_1 -> 272 in the cache */
   /* replace2078_1_2 -> 274 in the cache */
   /* replace2078_1 -> 495 in the cache */
   /* replace2078_2 -> 273 in the cache */
   /* replace2078 -> 496 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2079_0 -> 444 in the cache */
   /* search2079_1_0 -> 68 in the cache */
   /* search2079_1_1 -> 70 in the cache */
   /* search2079_1_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 68, 70, 285 },
      0,
   } },
   /* search2079_2_0 -> 68 in the cache */
   /* search2079_2_1 -> 70 in the cache */
   /* search2079_2_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 68, 70, 293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 499, 500 },
      -1,
   } },

   /* replace2079_0 -> 68 in the cache */
   /* replace2079_1 -> 70 in the cache */
   /* replace2079_2_0 -> 444 in the cache */
   /* replace2079_2_1 -> 285 in the cache */
   /* replace2079_2_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 285, 293 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 68, 70, 502 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2080_0 -> 444 in the cache */
   /* search2080_1_0 -> 68 in the cache */
   /* search2080_1_1 -> 70 in the cache */
   /* search2080_1_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 68, 70, 285 },
      -1,
   } },
   /* search2080_2_0 -> 68 in the cache */
   /* search2080_2_1 -> 70 in the cache */
   /* search2080_2_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 68, 70, 293 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 504, 505 },
      -1,
   } },

   /* replace2080_0 -> 68 in the cache */
   /* replace2080_1 -> 70 in the cache */
   /* replace2080_2_0 -> 444 in the cache */
   /* replace2080_2_1 -> 285 in the cache */
   /* replace2080_2_2 -> 293 in the cache */
   /* replace2080_2 -> 502 in the cache */
   /* replace2080 -> 503 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2081_0 -> 444 in the cache */
   /* search2081_1_0 -> 68 in the cache */
   /* search2081_1_1 -> 70 in the cache */
   /* search2081_1_2 -> 285 in the cache */
   /* search2081_1 -> 499 in the cache */
   /* search2081_2_0 -> 68 in the cache */
   /* search2081_2_1 -> 293 in the cache */
   /* search2081_2_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 68, 293, 285 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 499, 507 },
      -1,
   } },

   /* replace2081_0 -> 68 in the cache */
   /* replace2081_1_0 -> 444 in the cache */
   /* replace2081_1_1 -> 70 in the cache */
   /* replace2081_1_2 -> 293 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 444, 70, 293 },
      -1,
   } },
   /* replace2081_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 68, 509, 285 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2082_0 -> 444 in the cache */
   /* search2082_1_0 -> 68 in the cache */
   /* search2082_1_1 -> 70 in the cache */
   /* search2082_1_2 -> 285 in the cache */
   /* search2082_1 -> 504 in the cache */
   /* search2082_2_0 -> 68 in the cache */
   /* search2082_2_1 -> 293 in the cache */
   /* search2082_2_2 -> 285 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 68, 293, 285 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 444, 504, 511 },
      -1,
   } },

   /* replace2082_0 -> 68 in the cache */
   /* replace2082_1_0 -> 444 in the cache */
   /* replace2082_1_1 -> 70 in the cache */
   /* replace2082_1_2 -> 293 in the cache */
   /* replace2082_1 -> 509 in the cache */
   /* replace2082_2 -> 285 in the cache */
   /* replace2082 -> 510 in the cache */

   /* ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a') */
   /* search2083_0_0_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 67 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 514 },
      -1,
   } },

   /* replace2083_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a') */
   /* search2084_0_0_0 -> 67 in the cache */
   /* search2084_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 517 },
      -1,
   } },

   /* replace2084_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a') */
   /* search2085_0_0_0 -> 67 in the cache */
   /* search2085_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 520 },
      -1,
   } },

   /* replace2085_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a') */
   /* search2086_0_0_0 -> 67 in the cache */
   /* search2086_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 523 },
      -1,
   } },

   /* replace2086_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a') */
   /* search2087_0_0_0 -> 67 in the cache */
   /* search2087_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 526 },
      -1,
   } },

   /* replace2087_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a') */
   /* search2088_0_0_0 -> 67 in the cache */
   /* search2088_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 529 },
      -1,
   } },

   /* replace2088_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a') */
   /* search2089_0_0_0 -> 67 in the cache */
   /* search2089_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 532 },
      -1,
   } },

   /* replace2089_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a') */
   /* search2090_0_0_0 -> 67 in the cache */
   /* search2090_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 535 },
      -1,
   } },

   /* replace2090_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a') */
   /* search2091_0_0_0 -> 67 in the cache */
   /* search2091_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 538 },
      -1,
   } },

   /* replace2091_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a') */
   /* search2092_0_0_0 -> 67 in the cache */
   /* search2092_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 541 },
      -1,
   } },

   /* replace2092_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a') */
   /* search2093_0_0_0 -> 67 in the cache */
   /* search2093_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 544 },
      -1,
   } },

   /* replace2093_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a') */
   /* search2094_0_0_0 -> 67 in the cache */
   /* search2094_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 547 },
      -1,
   } },

   /* replace2094_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a') */
   /* search2095_0_0_0 -> 67 in the cache */
   /* search2095_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 550 },
      -1,
   } },

   /* replace2095_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a') */
   /* search2096_0_0_0 -> 67 in the cache */
   /* search2096_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 553 },
      -1,
   } },

   /* replace2096_0 -> 67 in the cache */
   /* replace2096 -> 200 in the cache */

   /* ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a') */
   /* search2097_0_0_0 -> 67 in the cache */
   /* search2097_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 555 },
      -1,
   } },

   /* replace2097_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a') */
   /* search2098_0_0_0 -> 67 in the cache */
   /* search2098_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 558 },
      -1,
   } },

   /* replace2098_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a') */
   /* search2099_0_0_0 -> 67 in the cache */
   /* search2099_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 561 },
      -1,
   } },

   /* replace2099_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a') */
   /* search2100_0_0_0 -> 67 in the cache */
   /* search2100_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 564 },
      -1,
   } },

   /* replace2100_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a') */
   /* search2101_0_0_0 -> 67 in the cache */
   /* search2101_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 567 },
      -1,
   } },

   /* replace2101_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a') */
   /* search2102_0_0_0 -> 67 in the cache */
   /* search2102_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 570 },
      -1,
   } },

   /* replace2102_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a') */
   /* search2103_0_0_0 -> 67 in the cache */
   /* search2103_0_0 -> 513 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 573 },
      -1,
   } },

   /* replace2103_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b') */
   /* search2104_0_0_0 -> 67 in the cache */
   /* search2104_0_0 -> 513 in the cache */
   /* search2104_0_1_0 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 68 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 577 },
      -1,
   } },

   /* replace2104_0 -> 67 in the cache */
   /* replace2104_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b') */
   /* search2105_0_0_0 -> 67 in the cache */
   /* search2105_0_0 -> 513 in the cache */
   /* search2105_0_1_0 -> 68 in the cache */
   /* search2105_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 580 },
      -1,
   } },

   /* replace2105_0 -> 67 in the cache */
   /* replace2105_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b') */
   /* search2106_0_0_0 -> 67 in the cache */
   /* search2106_0_0 -> 513 in the cache */
   /* search2106_0_1_0 -> 68 in the cache */
   /* search2106_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 583 },
      -1,
   } },

   /* replace2106_0 -> 67 in the cache */
   /* replace2106_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b') */
   /* search2107_0_0_0 -> 67 in the cache */
   /* search2107_0_0 -> 513 in the cache */
   /* search2107_0_1_0 -> 68 in the cache */
   /* search2107_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 586 },
      -1,
   } },

   /* replace2107_0 -> 67 in the cache */
   /* replace2107_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b') */
   /* search2108_0_0_0 -> 67 in the cache */
   /* search2108_0_0 -> 513 in the cache */
   /* search2108_0_1_0 -> 68 in the cache */
   /* search2108_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 589 },
      -1,
   } },

   /* replace2108_0 -> 67 in the cache */
   /* replace2108_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b') */
   /* search2109_0_0_0 -> 67 in the cache */
   /* search2109_0_0 -> 513 in the cache */
   /* search2109_0_1_0 -> 68 in the cache */
   /* search2109_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 592 },
      -1,
   } },

   /* replace2109_0 -> 67 in the cache */
   /* replace2109_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b') */
   /* search2110_0_0_0 -> 67 in the cache */
   /* search2110_0_0 -> 513 in the cache */
   /* search2110_0_1_0 -> 68 in the cache */
   /* search2110_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 595 },
      -1,
   } },

   /* replace2110_0 -> 67 in the cache */
   /* replace2110_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b') */
   /* search2111_0_0_0 -> 67 in the cache */
   /* search2111_0_0 -> 513 in the cache */
   /* search2111_0_1_0 -> 68 in the cache */
   /* search2111_0_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 513, 576 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 598 },
      -1,
   } },

   /* replace2111_0 -> 67 in the cache */
   /* replace2111_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c') */
   /* search2112_0_0_0 -> 67 in the cache */
   /* search2112_0_0 -> 513 in the cache */
   /* search2112_0_1_0 -> 68 in the cache */
   /* search2112_0_1 -> 576 in the cache */
   /* search2112_0_2_0 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 70 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 513, 576, 601 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 602 },
      -1,
   } },

   /* replace2112_0 -> 67 in the cache */
   /* replace2112_1 -> 68 in the cache */
   /* replace2112_2 -> 70 in the cache */
   /* replace2112 -> 72 in the cache */

   /* ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c') */
   /* search2113_0_0_0 -> 67 in the cache */
   /* search2113_0_0 -> 513 in the cache */
   /* search2113_0_1_0 -> 68 in the cache */
   /* search2113_0_1 -> 576 in the cache */
   /* search2113_0_2_0 -> 70 in the cache */
   /* search2113_0_2 -> 601 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 513, 576, 601 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 604 },
      -1,
   } },

   /* replace2113_0 -> 67 in the cache */
   /* replace2113_1 -> 68 in the cache */
   /* replace2113_2 -> 70 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 67, 68, 70 },
      -1,
   } },

   /* ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b') */
   /* search2114_0_0 -> 67 in the cache */
   /* search2114_0 -> 513 in the cache */
   /* search2114_1_0 -> 68 in the cache */
   /* search2114_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 513, 576 },
      -1,
   } },

   /* replace2114_0 -> 67 in the cache */
   /* replace2114_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b') */
   /* search2115_0_0 -> 67 in the cache */
   /* search2115_0 -> 513 in the cache */
   /* search2115_1_0 -> 68 in the cache */
   /* search2115_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 513, 576 },
      -1,
   } },

   /* replace2115_0 -> 67 in the cache */
   /* replace2115_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b') */
   /* search2116_0_0 -> 67 in the cache */
   /* search2116_0 -> 513 in the cache */
   /* search2116_1_0 -> 68 in the cache */
   /* search2116_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 513, 576 },
      -1,
   } },

   /* replace2116_0 -> 67 in the cache */
   /* replace2116_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 67, 68 },
      -1,
   } },

   /* ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b') */
   /* search2117_0_0 -> 67 in the cache */
   /* search2117_0 -> 513 in the cache */
   /* search2117_1_0 -> 68 in the cache */
   /* search2117_1 -> 576 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 513, 576 },
      -1,
   } },

   /* replace2117_0 -> 67 in the cache */
   /* replace2117_1 -> 68 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 67, 68 },
      -1,
   } },

   /* ('f2fmp', 'a') => ('f2f16', 'a') */
   /* search2118_0 -> 67 in the cache */
   /* search2118 -> 513 in the cache */

   /* replace2118_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('f2imp', 'a') => ('f2i16', 'a') */
   /* search2119_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2119_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('f2ump', 'a') => ('f2u16', 'a') */
   /* search2120_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2120_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('i2imp', 'a') => ('i2i16', 'a') */
   /* search2121_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2121_0 -> 67 in the cache */
   /* replace2121 -> 360 in the cache */

   /* ('i2fmp', 'a') => ('i2f16', 'a') */
   /* search2122_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2122_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('i2imp', 'a') => ('u2u16', 'a') */
   /* search2123_0 -> 67 in the cache */
   /* search2123 -> 620 in the cache */

   /* replace2123_0 -> 67 in the cache */
   /* replace2123 -> 357 in the cache */

   /* ('u2fmp', 'a') => ('u2f16', 'a') */
   /* search2124_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 67 },
      -1,
   } },

   /* replace2124_0 -> 67 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 67 },
      -1,
   } },

   /* ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf) */
   /* search2125_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisfinite,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2125_0_0 -> 42 in the cache */
   /* replace2125_0 -> 47 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x7ff0000000000000 /* inf */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 47, 626 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_late_expression_cond[] = {
   (is_used_once),
   (is_only_used_as_float),
};

static const nir_search_variable_cond nir_opt_algebraic_late_variable_cond[] = {
   (is_finite),
   (is_not_const),
   (is_gt_0_and_lt_1),
   (is_not_fmul),
   (is_not_negative),
   (is_not_const_and_not_fsign),
};

static const struct transform nir_opt_algebraic_late_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 172, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 89, 91, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 92, 93, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 180, 181, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 182, 183, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 184, 185, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 187, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 195, 197, 17 },
   { 199, 201, 17 },
   { 202, 203, 17 },
   { 204, 205, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 315, 314, 0 },
   { 319, 324, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 314, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 314, 0 },
   { 325, 329, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 42, 0 },
   { 332, 42, 0 },
   { 386, 379, 120 },
   { 383, 389, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 42, 0 },
   { 334, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 335, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 513, 615, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 616, 617, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 618, 619, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 620, 360, 0 },
   { 620, 357, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 621, 622, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 623, 624, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 625, 627, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 10, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 163, 164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 124, 126, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 161, 162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 154, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 611, 612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 42, 0 },
   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 16, 0 },
   { 29, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 167, 138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { 26, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 165, 166, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 155, 156, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 129, 130, 0 },
   { 137, 138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 609, 610, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 20, 21, 0 },
   { 32, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 170, 171, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 132, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 157, 158, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 607, 608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 22, 23, 0 },
   { 33, 23, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 169, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 133, 134, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 159, 160, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 613, 614, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 236, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 190, 192, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 479, 481, 0 },
   { 484, 481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 487, 489, 0 },
   { 492, 489, 0 },
   { 494, 496, 0 },
   { 498, 496, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 501, 503, 0 },
   { 506, 503, 0 },
   { 508, 510, 0 },
   { 512, 510, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 237, 239, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 207, 197, 17 },
   { 209, 201, 17 },
   { 210, 203, 17 },
   { 211, 205, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 82, 83, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 82, 83, 110 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 80, 81, 30 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 118, 120, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 116, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 111, 116, 116 },
   { 118, 120, 116 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 225, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 42, 0 },
   { 382, 371, 120 },
   { 385, 375, 120 },
   { 388, 379, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 48, 0 },
   { 173, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 173, 42, 0 },
   { 401, 403, 0 },
   { 410, 412, 0 },
   { 419, 421, 0 },
   { 429, 431, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 57, 58, 0 },
   { 172, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 172, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 172, 42, 0 },
   { 406, 407, 0 },
   { 415, 416, 0 },
   { 424, 425, 0 },
   { 434, 435, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 98, 102, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 87, 88, 112 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 104, 106, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 87, 88, 112 },
   { 98, 102, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 98, 102, 115 },
   { 104, 106, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 87, 88, 112 },
   { 104, 106, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 107, 109, 115 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 338, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 340, 336, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 341, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 339, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 42, 0 },
   { 332, 42, 0 },
   { 369, 371, 120 },
   { 373, 375, 120 },
   { 377, 379, 120 },
   { 386, 379, 120 },
   { 383, 389, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 344, 346, 55 },
   { 353, 354, 55 },
   { 358, 359, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 348, 346, 55 },
   { 356, 354, 55 },
   { 361, 359, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 349, 350, 55 },
   { 362, 363, 55 },
   { 365, 366, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 351, 350, 55 },
   { 364, 363, 55 },
   { 367, 366, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 394, 395, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 12, 6, 0 },
   { 163, 164, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 8, 10, 0 },
   { 161, 162, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 18, 14, 0 },
   { 30, 14, 0 },
   { 167, 138, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { 28, 16, 0 },
   { 165, 166, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 152, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 220, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 221, 17 },
   { 225, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 195, 197, 17 },
   { 199, 201, 17 },
   { 202, 203, 17 },
   { 204, 205, 17 },
   { 216, 217, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { 220, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { 223, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 217, 17 },
   { 225, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 271, 276, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 177, 179, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 439, 443, 14 },
   { 456, 460, 16 },
   { 469, 473, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 207, 197, 17 },
   { 209, 201, 17 },
   { 210, 203, 17 },
   { 211, 205, 17 },
   { 439, 443, 14 },
   { 456, 460, 16 },
   { 469, 473, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 271, 276, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 271, 276, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 271, 276, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 271, 276, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 271, 276, 118 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 554, 200, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 587, 588, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 605, 606, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 593, 594, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 584, 585, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 578, 579, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 603, 72, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 565, 566, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 574, 575, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 562, 563, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 515, 516, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 518, 519, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 521, 522, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 524, 525, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 527, 528, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 530, 531, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 533, 534, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 536, 537, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 539, 540, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 542, 543, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 545, 546, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 549, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 551, 552, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 557, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 559, 560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 568, 569, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 571, 572, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 581, 582, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 590, 591, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 596, 597, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 599, 600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 448, 452, 0 },
   { 462, 463, 0 },
   { 475, 476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 245, 246, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 227, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 227, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 227, 221, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 38, 41, 0 },
   { 173, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 53, 54, 0 },
   { 172, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 257, 263, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 257, 263, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 257, 263, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 118 },
   { 271, 276, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 271, 276, 118 },
   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 118 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 292, 298, 118 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 263, 118 },
   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 85, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 278, 284, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 278, 284, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 82, 83, 110 },
   { 278, 284, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 29 },
   { 71, 72, 30 },
   { 77, 78, 31 },
   { 82, 83, 110 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 82, 83, 110 },
   { 278, 284, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 80, 81, 30 },
   { 82, 83, 110 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 271, 276, 118 },
   { 278, 284, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 271, 276, 118 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 278, 284, 118 },
   { 304, 306, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 304, 306, 118 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 257, 263, 118 },
   { 278, 284, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 257, 263, 118 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 278, 284, 118 },
   { 292, 298, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 292, 298, 118 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 82, 83, 110 },
   { 278, 284, 118 },
   { 308, 313, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_late_pass_op_table[nir_num_search_ops] = {
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         51,
         52,
         53,
         0,
         165,
         0,
         54,
         0,
         0,
         0,
         0,
         0,
         0,
         55,
         0,
         56,
         0,
         0,
         56,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         57,
         0,
         0,
         166,
         0,
         56,
         0,
         0,
         56,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         7,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         3,
         9,
         4,
         8,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         10,
         0,
         10,
         12,
         10,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         2,
         3,
         97,
         98,
         98,
         99,
         2,
         97,
         98,
         98,
         181,
         182,
         234,
         235,
         251,
         252,
         3,
         3,
         100,
         101,
         102,
         103,
         3,
         183,
         184,
         185,
         186,
         187,
         236,
         237,
         253,
         254,
         97,
         100,
         97,
         104,
         104,
         105,
         97,
         97,
         104,
         104,
         188,
         189,
         238,
         239,
         251,
         252,
         98,
         101,
         104,
         98,
         98,
         106,
         98,
         104,
         98,
         98,
         190,
         191,
         240,
         241,
         255,
         256,
         98,
         102,
         104,
         98,
         98,
         106,
         98,
         104,
         98,
         98,
         190,
         191,
         240,
         241,
         255,
         256,
         99,
         103,
         105,
         106,
         106,
         99,
         99,
         105,
         106,
         106,
         192,
         193,
         242,
         243,
         257,
         258,
         2,
         3,
         97,
         98,
         98,
         99,
         107,
         97,
         98,
         98,
         181,
         182,
         234,
         235,
         251,
         252,
         97,
         183,
         97,
         104,
         104,
         105,
         97,
         97,
         104,
         104,
         188,
         189,
         238,
         239,
         251,
         252,
         98,
         184,
         104,
         98,
         98,
         106,
         98,
         104,
         98,
         98,
         190,
         191,
         240,
         241,
         255,
         256,
         98,
         185,
         104,
         98,
         98,
         106,
         98,
         104,
         98,
         98,
         190,
         191,
         240,
         241,
         255,
         256,
         181,
         186,
         188,
         190,
         190,
         192,
         181,
         188,
         190,
         190,
         181,
         194,
         244,
         245,
         259,
         260,
         182,
         187,
         189,
         191,
         191,
         193,
         182,
         189,
         191,
         191,
         194,
         182,
         246,
         247,
         261,
         262,
         234,
         236,
         238,
         240,
         240,
         242,
         234,
         238,
         240,
         240,
         244,
         246,
         234,
         248,
         263,
         264,
         235,
         237,
         239,
         241,
         241,
         243,
         235,
         239,
         241,
         241,
         245,
         247,
         248,
         235,
         265,
         266,
         251,
         253,
         251,
         255,
         255,
         257,
         251,
         251,
         255,
         255,
         259,
         261,
         263,
         265,
         251,
         267,
         252,
         254,
         252,
         256,
         256,
         258,
         252,
         252,
         256,
         256,
         260,
         262,
         264,
         266,
         267,
         252,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         7,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         4,
         58,
         59,
         60,
         61,
         62,
         249,
         250,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         63,
         64,
         0,
         0,
         167,
         0,
         0,
         65,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         66,
         0,
         67,
         0,
         0,
         67,
         0,
         0,
         68,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         69,
         0,
         0,
         0,
         168,
         0,
         67,
         0,
         0,
         67,
         0,
         0,
         169,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         5,
         6,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         70,
         71,
         72,
         73,
         6,
         5,
         70,
         5,
         5,
         5,
         5,
         5,
         5,
         71,
         5,
         74,
         5,
         5,
         5,
         5,
         72,
         5,
         5,
         5,
         5,
         5,
         5,
         73,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         5,
         5,
         5,
         5,
         75,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         8,
         76,
         77,
         78,
         8,
         7,
         76,
         7,
         7,
         7,
         7,
         7,
         77,
         7,
         79,
         7,
         7,
         7,
         78,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         80,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         114,
         9,
         9,
         9,
         9,
         115,
         9,
         116,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         231,
         9,
         9,
         116,
         9,
         9,
         9,
         9,
         231,
         9,
         114,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         117,
         9,
         9,
         9,
         9,
         231,
         231,
         9,
         9,
         9,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         1,
         1,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         232,
         10,
         10,
         10,
         118,
         10,
         232,
         10,
         10,
         118,
         119,
         10,
         10,
         10,
         10,
         10,
         10,
         120,
         10,
         10,
         232,
         232,
         10,
         10,
         10,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         11,
         12,
         89,
         90,
         11,
         228,
         12,
         12,
         91,
         92,
         12,
         229,
         89,
         91,
         89,
         93,
         89,
         228,
         90,
         92,
         93,
         90,
         90,
         230,
         11,
         12,
         89,
         90,
         94,
         228,
         228,
         229,
         228,
         230,
         228,
         228,
      },
   },
   [nir_op_fmulz] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         14,
         122,
         123,
         124,
         122,
         122,
         125,
         126,
         123,
         125,
         123,
         127,
         124,
         126,
         127,
         124,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         15,
      },
   },
   [nir_op_iabs] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         16,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         17,
         17,
         128,
         128,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         108,
         109,
         110,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         18,
         141,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         81,
         81,
         0,
         0,
         81,
         82,
         0,
         0,
         0,
         0,
         83,
      },
   },
   [nir_op_fdot2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         19,
      },
   },
   [nir_op_fdot3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         20,
      },
   },
   [nir_op_fdot4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         21,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         22,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         84,
         84,
         84,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         7,
         4,
         8,
         7,
         3,
         0,
         0,
         9,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         10,
         10,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         112,
         23,
         171,
         172,
         176,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         112,
         23,
         171,
         172,
         176,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         173,
         177,
         173,
         174,
         174,
         173,
         178,
         179,
         179,
         173,
         175,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         24,
         23,
         111,
         112,
         23,
         171,
         172,
         176,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         173,
         173,
         173,
         174,
         180,
         173,
         173,
         174,
         180,
         173,
         175,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         113,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         24,
         23,
         111,
         112,
         23,
         171,
         172,
         176,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         173,
         173,
         173,
         174,
         180,
         173,
         173,
         174,
         180,
         173,
         175,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         177,
         173,
         174,
         174,
         173,
         178,
         179,
         179,
         173,
         175,
         173,
         173,
         173,
         174,
         180,
         173,
         173,
         174,
         180,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         180,
         173,
         173,
         174,
         180,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         24,
         23,
         111,
         111,
         23,
         171,
         172,
         172,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         112,
         23,
         23,
         111,
         112,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
         173,
         173,
         173,
         174,
         174,
         173,
         173,
         174,
         174,
         173,
         175,
         23,
         23,
         23,
         111,
         111,
         23,
         23,
         111,
         111,
         23,
         170,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         95,
         0,
         0,
         0,
         96,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         227,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         226,
         0,
         0,
         86,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         87,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         88,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         25,
         142,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         26,
         143,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
         27,
         121,
         233,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         28,
         0,
         29,
         0,
         28,
         0,
         29,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         30,
         0,
         31,
         0,
         30,
         0,
         31,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         32,
         0,
         0,
         32,
         0,
         0,
         133,
         0,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         33,
         0,
         33,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         34,
         0,
         34,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         35,
         129,
         35,
         35,
         35,
         130,
         35,
         35,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         36,
         37,
         36,
         36,
         36,
         37,
         36,
         36,
         36,
         131,
         36,
         36,
         36,
         132,
         36,
         36,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         38,
         135,
         136,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         39,
         137,
         138,
      },
   },
   [nir_op_insert_u8] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         134,
         134,
      },
   },
   [nir_op_insert_u16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         139,
         139,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         40,
         0,
         40,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         41,
         41,
         41,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         42,
         42,
         42,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         140,
      },
   },
   [nir_op_inot] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         43,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         26,
         27,
         28,
         29,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 32,
      .table = (const uint16_t []) {
      
         0,
         195,
         196,
         197,
         198,
         199,
         200,
         201,
         202,
         203,
         204,
         205,
         206,
         207,
         208,
         209,
         210,
         211,
         212,
         213,
         214,
         215,
         216,
         217,
         218,
         219,
         220,
         221,
         222,
         223,
         224,
         225,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         144,
      },
   },
   [nir_op_f2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         44,
      },
   },
   [nir_op_fceil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         145,
      },
   },
   [nir_op_fcos] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         146,
      },
   },
   [nir_op_fddx] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         147,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         148,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         149,
      },
   },
   [nir_op_fddy] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         150,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         151,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         152,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         153,
      },
   },
   [nir_op_ffloor] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         154,
      },
   },
   [nir_op_ffract] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         155,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         156,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         157,
      },
   },
   [nir_op_fround_even] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         158,
      },
   },
   [nir_op_fsign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         159,
      },
   },
   [nir_op_fsin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         160,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         161,
      },
   },
   [nir_op_fmod] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         162,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         163,
      },
   },
   [nir_op_frem] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         164,
      },
   },
   [nir_op_f2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         45,
      },
   },
   [nir_op_f2ump] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         46,
      },
   },
   [nir_op_i2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         47,
      },
   },
   [nir_op_i2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         48,
      },
   },
   [nir_op_u2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         49,
      },
   },
   [nir_op_fisfinite] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         50,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_late_transform_offsets[] = {
   0,
   0,
   0,
   0,
   1,
   0,
   0,
   0,
   0,
   3,
   5,
   0,
   0,
   0,
   0,
   7,
   9,
   0,
   0,
   11,
   13,
   15,
   17,
   0,
   19,
   0,
   0,
   0,
   24,
   26,
   29,
   31,
   34,
   39,
   42,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   44,
   46,
   48,
   50,
   53,
   55,
   57,
   59,
   61,
   63,
   65,
   67,
   69,
   71,
   73,
   75,
   78,
   80,
   82,
   84,
   87,
   89,
   92,
   94,
   96,
   99,
   101,
   104,
   106,
   0,
   108,
   110,
   112,
   115,
   117,
   119,
   121,
   0,
   123,
   0,
   125,
   0,
   127,
   130,
   135,
   0,
   0,
   0,
   0,
   0,
   0,
   140,
   0,
   142,
   144,
   148,
   150,
   152,
   156,
   164,
   166,
   171,
   174,
   0,
   179,
   181,
   183,
   0,
   186,
   0,
   188,
   193,
   195,
   198,
   204,
   207,
   209,
   0,
   215,
   217,
   219,
   221,
   224,
   227,
   230,
   232,
   234,
   236,
   238,
   240,
   248,
   250,
   254,
   258,
   262,
   266,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   268,
   271,
   274,
   278,
   282,
   0,
   284,
   286,
   288,
   290,
   292,
   294,
   297,
   303,
   306,
   309,
   312,
   314,
   316,
   319,
   326,
   337,
   339,
   341,
   344,
   347,
   352,
   357,
   360,
   363,
   366,
   368,
   370,
   372,
   374,
   376,
   378,
   380,
   382,
   384,
   386,
   388,
   390,
   392,
   394,
   396,
   398,
   400,
   402,
   404,
   406,
   408,
   410,
   412,
   414,
   416,
   418,
   420,
   422,
   424,
   426,
   428,
   432,
   434,
   436,
   438,
   440,
   443,
   0,
   446,
   448,
   450,
   452,
   454,
   457,
   460,
   465,
   470,
   473,
   476,
   479,
   482,
   485,
   488,
   491,
   493,
   495,
   498,
   501,
   504,
   507,
   513,
   519,
   523,
   527,
   531,
   535,
   539,
   543,
   547,
   551,
   555,
   559,
};

static const nir_algebraic_table nir_opt_algebraic_late_table = {
   .transforms = nir_opt_algebraic_late_transforms,
   .transform_offsets = nir_opt_algebraic_late_transform_offsets,
   .pass_op_table = nir_opt_algebraic_late_pass_op_table,
   .values = nir_opt_algebraic_late_values,
   .expression_cond = nir_opt_algebraic_late_expression_cond,
   .variable_cond = nir_opt_algebraic_late_variable_cond,
};

bool
nir_opt_algebraic_late(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[122];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(628 == ARRAY_SIZE(nir_opt_algebraic_late_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_fround_even;
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = !options->lower_ffloor;
   condition_flags[24] = options->lower_ffract;
   condition_flags[25] = options->lower_fceil;
   condition_flags[26] = options->lower_ffma16;
   condition_flags[27] = options->lower_ffma32;
   condition_flags[28] = options->lower_ffma64;
   condition_flags[29] = options->fuse_ffma16;
   condition_flags[30] = options->fuse_ffma32;
   condition_flags[31] = options->fuse_ffma64;
   condition_flags[32] = options->lower_fdph;
   condition_flags[33] = !options->lower_fdph;
   condition_flags[34] = options->lower_fdot;
   condition_flags[35] = !options->lower_fsat;
   condition_flags[36] = !options->lower_iabs;
   condition_flags[37] = options->lower_fsat;
   condition_flags[38] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[39] = !options->lower_fsign;
   condition_flags[40] = options->lower_umax;
   condition_flags[41] = options->lower_umin;
   condition_flags[42] = !options->lower_umax;
   condition_flags[43] = !options->lower_umin;
   condition_flags[44] = options->lower_scmp;
   condition_flags[45] = options->lower_vector_cmp;
   condition_flags[46] = !options->lower_rotate;
   condition_flags[47] = options->lower_rotate;
   condition_flags[48] = options->lower_fpow;
   condition_flags[49] = !options->lower_fpow;
   condition_flags[50] = options->lower_fdiv;
   condition_flags[51] = options->lower_fsqrt;
   condition_flags[52] = !options->lower_fsqrt;
   condition_flags[53] = options->lower_sincos;
   condition_flags[54] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[55] = !options->lower_extract_byte;
   condition_flags[56] = !options->lower_extract_word;
   condition_flags[57] = options->has_pack_32_4x8;
   condition_flags[58] = options->lower_pack_64_2x32_split;
   condition_flags[59] = options->lower_pack_32_2x16_split;
   condition_flags[60] = options->lower_unpack_64_2x32_split;
   condition_flags[61] = options->lower_unpack_32_2x16_split;
   condition_flags[62] = options->lower_fmod;
   condition_flags[63] = options->lower_uadd_carry;
   condition_flags[64] = options->lower_usub_borrow;
   condition_flags[65] = options->lower_bitfield_insert;
   condition_flags[66] = options->lower_hadd;
   condition_flags[67] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[69] = options->lower_uadd_sat;
   condition_flags[70] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[71] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[72] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[73] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[74] = options->lower_bitfield_insert_to_shifts;
   condition_flags[75] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[76] = options->lower_bitfield_extract;
   condition_flags[77] = options->lower_bitfield_extract_to_shifts;
   condition_flags[78] = options->lower_ifind_msb;
   condition_flags[79] = options->lower_find_msb_to_reverse;
   condition_flags[80] = options->lower_find_lsb;
   condition_flags[81] = options->lower_extract_byte;
   condition_flags[82] = options->lower_extract_word;
   condition_flags[83] = options->lower_pack_unorm_2x16;
   condition_flags[84] = options->lower_pack_unorm_4x8;
   condition_flags[85] = options->lower_pack_snorm_2x16;
   condition_flags[86] = options->lower_pack_snorm_4x8;
   condition_flags[87] = options->lower_unpack_unorm_2x16;
   condition_flags[88] = options->lower_unpack_unorm_4x8;
   condition_flags[89] = options->lower_unpack_snorm_2x16;
   condition_flags[90] = options->lower_unpack_snorm_4x8;
   condition_flags[91] = options->lower_pack_split;
   condition_flags[92] = options->lower_isign;
   condition_flags[93] = !options->lower_isign;
   condition_flags[94] = options->lower_fsign;
   condition_flags[95] = !options->has_imul24;
   condition_flags[96] = !options->has_umul24;
   condition_flags[97] = !options->has_umad24;
   condition_flags[98] = options->has_imul24;
   condition_flags[99] = options->has_umad24;
   condition_flags[100] = options->has_umul24;
   condition_flags[101] = options->has_fused_comp_and_csel;
   condition_flags[102] = options->lower_iadd_sat;
   condition_flags[103] = options->support_8bit_alu;
   condition_flags[104] = options->support_16bit_alu;
   condition_flags[105] = options->lower_ldexp;
   condition_flags[106] = !options->lower_bitfield_reverse;
   condition_flags[107] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[108] = options->lower_fisnormal;
   condition_flags[109] = !options->vectorize_vec2_16bit;
   condition_flags[110] = options->has_fsub;
   condition_flags[111] = options->lower_fneg;
   condition_flags[112] = options->has_isub || options->lower_ineg;
   condition_flags[113] = options->lower_ineg;
   condition_flags[114] = options->lower_iabs;
   condition_flags[115] = options->has_iadd3;
   condition_flags[116] = options->vectorize_vec2_16bit;
   condition_flags[117] = options->fdot_replicates;
   condition_flags[118] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[119] = options->avoid_ternary_with_two_constants;
   condition_flags[120] = !options->lower_insert_byte;
   condition_flags[121] = !options->lower_insert_word;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_late_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 19
 * transforms:
 *    ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b')
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b')
 *    ('fneg', ('fneg', 'a')) => a
 *    ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b')
 *    ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b'))
 *    ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c'))
 *    ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c')
 *    ('fneg', ('~fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b'))
 *    ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a'))
 *    ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a'))
 */


static const nir_search_value_union nir_opt_algebraic_distribute_src_mods_values[] = {
   /* ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2126_0 -> 0 in the cache */
   /* replace2126_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 8 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 9, 10 },
      -1,
   } },

   /* replace2127_0 -> 6 in the cache */
   /* replace2127_1 -> 8 in the cache */
   /* replace2127_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      -1,
   } },

   /* ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b') */
   /* search2128_0_0 -> 0 in the cache */
   /* search2128_0 -> 1 in the cache */
   /* search2128_1_0 -> 2 in the cache */
   /* search2128_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2128_0 -> 0 in the cache */
   /* replace2128_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b') */
   /* search2129_0_0 -> 0 in the cache */
   /* search2129_0 -> 1 in the cache */
   /* search2129_1_0 -> 2 in the cache */
   /* search2129_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2129_0 -> 0 in the cache */
   /* replace2129_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b') */
   /* search2130_0_0 -> 0 in the cache */
   /* search2130_0 -> 1 in the cache */
   /* search2130_1_0 -> 2 in the cache */
   /* search2130_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2130_0 -> 0 in the cache */
   /* replace2130_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 20 },
      -1,
   } },

   /* replace2131 -> 19 in the cache */

   /* ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b') */
   /* search2132_0_0 -> 0 in the cache */
   /* search2132_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2132_0_0 -> 0 in the cache */
   /* replace2132_0 -> 1 in the cache */
   /* replace2132_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b')) */
   /* search2133_0_0 -> 0 in the cache */
   /* search2133_0_1 -> 2 in the cache */
   /* search2133_0 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2133_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2133_1_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 26, 27 },
      -1,
   } },

   /* ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c')) */
   /* search2134_0_0 -> 6 in the cache */
   /* search2134_0_1 -> 8 in the cache */
   /* search2134_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 29 },
      -1,
   } },

   /* replace2134_0_0 -> 6 in the cache */
   /* replace2134_0 -> 7 in the cache */
   /* replace2134_1 -> 8 in the cache */
   /* replace2134_2_0 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 10 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 8, 31 },
      -1,
   } },

   /* ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c') */
   /* search2135_0_0 -> 6 in the cache */
   /* search2135_0_1 -> 8 in the cache */
   /* search2135_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 33 },
      -1,
   } },

   /* replace2135_0_0 -> 6 in the cache */
   /* replace2135_0 -> 7 in the cache */
   /* replace2135_1_0 -> 8 in the cache */
   /* replace2135_1 -> 9 in the cache */
   /* replace2135_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 7, 9, 10 },
      -1,
   } },

   /* ('fneg', ('~fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2136_0_0 -> 0 in the cache */
   /* search2136_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 36 },
      -1,
   } },

   /* replace2136_0_0 -> 0 in the cache */
   /* replace2136_0 -> 1 in the cache */
   /* replace2136_1_0 -> 2 in the cache */
   /* replace2136_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2137_0_0 -> 0 in the cache */
   /* search2137_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 39 },
      -1,
   } },

   /* replace2137_0_0 -> 0 in the cache */
   /* replace2137_0 -> 1 in the cache */
   /* replace2137_1_0 -> 2 in the cache */
   /* replace2137_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2138_0_0 -> 0 in the cache */
   /* search2138_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 42 },
      -1,
   } },

   /* replace2138_0_0 -> 0 in the cache */
   /* replace2138_0 -> 1 in the cache */
   /* replace2138_1_0 -> 2 in the cache */
   /* replace2138_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b') */
   /* search2139_0_0 -> 0 in the cache */
   /* search2139_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 45 },
      -1,
   } },

   /* replace2139_0_0 -> 0 in the cache */
   /* replace2139_0 -> 1 in the cache */
   /* replace2139_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b') */
   /* search2140_0_0 -> 0 in the cache */
   /* search2140_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 48 },
      -1,
   } },

   /* replace2140_0_0 -> 0 in the cache */
   /* replace2140_0 -> 1 in the cache */
   /* replace2140_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b') */
   /* search2141_0_0 -> 0 in the cache */
   /* search2141_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 51 },
      -1,
   } },

   /* replace2141_0_0 -> 0 in the cache */
   /* replace2141_0 -> 1 in the cache */
   /* replace2141_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b')) */
   /* search2142_0_0 -> 0 in the cache */
   /* search2142_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 54 },
      -1,
   } },

   /* replace2142_0 -> 0 in the cache */
   /* replace2142_1_0 -> 2 in the cache */
   /* replace2142_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a')) */
   /* search2143_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 19 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2143_0_0 -> 19 in the cache */
   /* replace2143_0 -> 20 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 20 },
      -1,
   } },

   /* ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a')) */
   /* search2144_0_0 -> 19 in the cache */
   /* search2144_0 -> 57 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2144_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 61 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_distribute_src_mods_expression_cond[] = {
   (is_used_once),
};


static const struct transform nir_opt_algebraic_distribute_src_mods_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 23, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 21, 19, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 30, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 47, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 49, 50, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 53, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 40, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 43, 44, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 56, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 59, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 25, 28, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 62, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 5, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 12, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 18, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_distribute_src_mods_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         2,
         2,
         2,
         28,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         6,
         7,
         8,
         9,
         10,
         11,
         12,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         1,
         3,
         4,
         5,
         6,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         3,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         4,
         4,
         4,
         4,
         4,
         4,
         29,
         29,
      },
   },
   [nir_op_fdot2_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         5,
         5,
         5,
         30,
      },
   },
   [nir_op_fdot3_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         6,
         6,
         6,
         31,
      },
   },
   [nir_op_fdot4_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         7,
         7,
         7,
         32,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         26,
         27,
      },
   },
   [nir_op_flrp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         8,
      },
   },
   [nir_op_fadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_fmin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_fmax] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_fdph_replicated] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         12,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_distribute_src_mods_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   13,
   15,
   17,
   19,
   21,
   23,
   25,
   27,
   29,
   31,
   33,
   35,
   37,
};

static const nir_algebraic_table nir_opt_algebraic_distribute_src_mods_table = {
   .transforms = nir_opt_algebraic_distribute_src_mods_transforms,
   .transform_offsets = nir_opt_algebraic_distribute_src_mods_transform_offsets,
   .pass_op_table = nir_opt_algebraic_distribute_src_mods_pass_op_table,
   .values = nir_opt_algebraic_distribute_src_mods_values,
   .expression_cond = nir_opt_algebraic_distribute_src_mods_expression_cond,
   .variable_cond = NULL,
};

bool
nir_opt_algebraic_distribute_src_mods(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[122];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   STATIC_ASSERT(63 == ARRAY_SIZE(nir_opt_algebraic_distribute_src_mods_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_fround_even;
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = !options->lower_ffloor;
   condition_flags[24] = options->lower_ffract;
   condition_flags[25] = options->lower_fceil;
   condition_flags[26] = options->lower_ffma16;
   condition_flags[27] = options->lower_ffma32;
   condition_flags[28] = options->lower_ffma64;
   condition_flags[29] = options->fuse_ffma16;
   condition_flags[30] = options->fuse_ffma32;
   condition_flags[31] = options->fuse_ffma64;
   condition_flags[32] = options->lower_fdph;
   condition_flags[33] = !options->lower_fdph;
   condition_flags[34] = options->lower_fdot;
   condition_flags[35] = !options->lower_fsat;
   condition_flags[36] = !options->lower_iabs;
   condition_flags[37] = options->lower_fsat;
   condition_flags[38] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[39] = !options->lower_fsign;
   condition_flags[40] = options->lower_umax;
   condition_flags[41] = options->lower_umin;
   condition_flags[42] = !options->lower_umax;
   condition_flags[43] = !options->lower_umin;
   condition_flags[44] = options->lower_scmp;
   condition_flags[45] = options->lower_vector_cmp;
   condition_flags[46] = !options->lower_rotate;
   condition_flags[47] = options->lower_rotate;
   condition_flags[48] = options->lower_fpow;
   condition_flags[49] = !options->lower_fpow;
   condition_flags[50] = options->lower_fdiv;
   condition_flags[51] = options->lower_fsqrt;
   condition_flags[52] = !options->lower_fsqrt;
   condition_flags[53] = options->lower_sincos;
   condition_flags[54] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[55] = !options->lower_extract_byte;
   condition_flags[56] = !options->lower_extract_word;
   condition_flags[57] = options->has_pack_32_4x8;
   condition_flags[58] = options->lower_pack_64_2x32_split;
   condition_flags[59] = options->lower_pack_32_2x16_split;
   condition_flags[60] = options->lower_unpack_64_2x32_split;
   condition_flags[61] = options->lower_unpack_32_2x16_split;
   condition_flags[62] = options->lower_fmod;
   condition_flags[63] = options->lower_uadd_carry;
   condition_flags[64] = options->lower_usub_borrow;
   condition_flags[65] = options->lower_bitfield_insert;
   condition_flags[66] = options->lower_hadd;
   condition_flags[67] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[68] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[69] = options->lower_uadd_sat;
   condition_flags[70] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[71] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[72] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[73] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[74] = options->lower_bitfield_insert_to_shifts;
   condition_flags[75] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[76] = options->lower_bitfield_extract;
   condition_flags[77] = options->lower_bitfield_extract_to_shifts;
   condition_flags[78] = options->lower_ifind_msb;
   condition_flags[79] = options->lower_find_msb_to_reverse;
   condition_flags[80] = options->lower_find_lsb;
   condition_flags[81] = options->lower_extract_byte;
   condition_flags[82] = options->lower_extract_word;
   condition_flags[83] = options->lower_pack_unorm_2x16;
   condition_flags[84] = options->lower_pack_unorm_4x8;
   condition_flags[85] = options->lower_pack_snorm_2x16;
   condition_flags[86] = options->lower_pack_snorm_4x8;
   condition_flags[87] = options->lower_unpack_unorm_2x16;
   condition_flags[88] = options->lower_unpack_unorm_4x8;
   condition_flags[89] = options->lower_unpack_snorm_2x16;
   condition_flags[90] = options->lower_unpack_snorm_4x8;
   condition_flags[91] = options->lower_pack_split;
   condition_flags[92] = options->lower_isign;
   condition_flags[93] = !options->lower_isign;
   condition_flags[94] = options->lower_fsign;
   condition_flags[95] = !options->has_imul24;
   condition_flags[96] = !options->has_umul24;
   condition_flags[97] = !options->has_umad24;
   condition_flags[98] = options->has_imul24;
   condition_flags[99] = options->has_umad24;
   condition_flags[100] = options->has_umul24;
   condition_flags[101] = options->has_fused_comp_and_csel;
   condition_flags[102] = options->lower_iadd_sat;
   condition_flags[103] = options->support_8bit_alu;
   condition_flags[104] = options->support_16bit_alu;
   condition_flags[105] = options->lower_ldexp;
   condition_flags[106] = !options->lower_bitfield_reverse;
   condition_flags[107] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[108] = options->lower_fisnormal;
   condition_flags[109] = !options->vectorize_vec2_16bit;
   condition_flags[110] = options->has_fsub;
   condition_flags[111] = options->lower_fneg;
   condition_flags[112] = options->has_isub || options->lower_ineg;
   condition_flags[113] = options->lower_ineg;
   condition_flags[114] = options->lower_iabs;
   condition_flags[115] = options->has_iadd3;
   condition_flags[116] = options->vectorize_vec2_16bit;
   condition_flags[117] = options->fdot_replicates;
   condition_flags[118] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[119] = options->avoid_ternary_with_two_constants;
   condition_flags[120] = !options->lower_insert_byte;
   condition_flags[121] = !options->lower_insert_word;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_distribute_src_mods_table);
      }
   }

   return progress;
}

